import * as Interfaces from 'cadlearning.dto/lib/interfaces';
import * as Enums from 'cadlearning.dto/lib/enums';
import { BaseClient } from './base';
import * as i0 from "@angular/core";
export declare class AssessmentsV1Client extends BaseClient {
    /** Adds a details to a assessment. The details must still be uploaded. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected details from a assessment. If the details is no longer associated with anything the details will be completely removed. */
    RemoveResource(ResourceId?: number, AssessmentId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the resources (downloads etc.) associated with the specified assessment */
    ListResourcesByType(AssessmentId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourcesByTypeDto[]>;
    /** Lists the resources on a given assessment */
    ListResources(AssessmentId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceLocatorDto[]>;
    /** Returns the information about t/he current assessment and where it is in the workflow. If it isn't in the workflow then it puts it at stage 2 for triage by default. */
    GetWorkflowStatus(assessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusInfoDto>;
    /** Updates the specified question's workflow step and based on that will execute specific functions. */
    UpdateWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the assessment workflow task */
    UpdateWorkflowTask(body: Interfaces.UpdateWorkflowTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all workflow assignees to the assessment. */
    ListAssignees(assessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentWorkflowAssigneesDto[]>;
    /** Updates the workflow assignments for a given Assessment */
    UpdateAssignees(body: Interfaces.UpdateAssessmentWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the questions for the assessment or lessons */
    ListQuestions(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseStructureForEditingWithChildrenDto>>;
    /** Returns a list of Assessments with their parents for easier identification */
    ListWithParents(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentWithParentsDto[]>;
    /** Assessment Pre-Hire invite new user */
    InvitePreHireUser(body: Interfaces.InvitePreHireUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvitePreHireUserDto>;
    /** Assessment Pre-Hire invite new user */
    InvitePreHireNewUser(body: Interfaces.InvitePreHireUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvitePreHireUserDto>;
    /** Assessment Pre-Hire invite existing user */
    InvitePreHireExistingUser(body: Interfaces.InvitePreHireUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvitePreHireUserDto>;
    /** Lists the available assessments that can be added to the specified course. */
    ListAvailableAssessmentsByCourseId(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentWithParentsDto>>;
    /** Adds an assessment that already exists to a course */
    AddAssessmentToCourse(body: Interfaces.AddAssessmentToCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** removes an assessment from a course */
    RemoveAssessmentFromCourse(body: Interfaces.AddAssessmentToCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get the specified translation */
    GetTranslation(assessmentId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.AssessmentTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the questions for the assessment or lessons */
    GetAssessmentQuestionsWithParents(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentStructureForEditingWithParentItems>>;
    /** Lists all of the courses associated with the given assessment */
    ListCourses(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Lists all of the badges associated with the given assessment */
    ListBadges(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BadgeDto>>;
    /** Lists all of the medallions associated with the given assessment */
    ListMedallions(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.MedallionDto>>;
    /** Updates all of the courses assigned to the Assessment */
    UpdateCourses(body: Interfaces.UpdateAssessmentCoursesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates all of the courses assigned to the Assessment */
    UpdateBadges(body: Interfaces.UpdateAssessmentBadgesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates all of the courses assigned to the Assessment */
    UpdateMedallions(body: Interfaces.UpdateAssessmentMedallionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List custom assessments */
    ListCustomAssessments(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentDto>>;
    /** Remove prehire invitations */
    RemoveAssessmentInvitation(body: Interfaces.AssessmentInvitationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the assessments dynamic items */
    ListAssessmentDynamicItems(assessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentDynamicItemsDto>;
    /** List available assessments */
    ListAvailableAssessments(assessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortContentDto[]>;
    /** Updates the dynamic items attached to an assessment */
    UpdateAssessmentDynamicItems(body: Interfaces.UpdateAssessmentDynamicItemsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Update the assessment's questions. Ensure that you pass all questions associated with the assessment */
    UpdateQuestions(body: Interfaces.UpdateAssessmentQuestionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Generates an assessment */
    GenerateAssessmentGamification(body: Interfaces.GenerateAssessmentGamificationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Generates an assessment */
    GenerateAssessment(body: Interfaces.GenerateAssessmentDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Generate Gap Assessment */
    GenerateGapAssessment(body: Interfaces.GenerateGapAssessmentDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Returns the questions for the assessment or lessons */
    GetQuestions(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseStructureForEditingWithChildrenDto>>;
    /** Returns the questions for the assessment or lessons by course id */
    GetQuestionsByCourseId(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseStructureForEditingWithChildrenDto[]>;
    /** Returns the questions for the assessment or lessons */
    GetQuestionsWithParents(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentStructureForEditingWithParentItems>>;
    /** Returns a user's transcript */
    ListUserTranscript(userId: number, includeIncompletes: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAssessmentTranscriptDto[]>;
    /** Lists the assessments taken in the organization */
    ListTakenAssessments(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Returns the results for the given assessment */
    GetAssessmentResults(userAssessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentResultDto>;
    /** Lists assessments by Topic */
    ListAssessmentInvitations(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentInvitationDto>>;
    /** Answers a question on a user assessment */
    RecordUserAssessmentAnswer(body: Interfaces.UserAssessmentAnswerDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.NextQuestionDto>;
    /** Returns an assessment based on the specific Identity Assessment Id (not the base assessment that is pre-created) */
    GetUserAssessmentById(userAssessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAssessmentDto>;
    /** Returns a new user assessment on the user if the user hasn't started one or returns the current values for the assessment if they have. */
    GetUserAssessment(userId: number, assessmentId: number, parentId?: number, parentType?: Enums.AssessmentParentTypes, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAssessmentDto>;
    /** Deletes an existing user assessment */
    DeleteUserAssessment(userAssessmentId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a new user assessment based on the playlist passed or returns an existing one that has outstanding questions to answer. */
    GetAssessmentByPlayList(userId: number, playListId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAssessmentDto>;
    /** Lists assessments by Course */
    ListByCourseId(courseId?: number, showPrehire?: boolean, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentDto>>;
    /** List custom assessments */
    ListManageableCustomAssessments(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentDto>>;
    /** Insert or update a assessments */
    Upsert(body: Interfaces.AssessmentDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AssessmentDto[]>;
    /** Deletes the passed assessments */
    Delete(body: Interfaces.AssessmentDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the assessments by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Delete the specified translation */
    DeleteTranslation(body: Interfaces.AssessmentTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets question of the day assessment */
    GetQuestionOfTheDayAssessment(userId: number, badgeId?: number, medallionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionOfTheDayAssessmentDto>;
    /** Records question of the day answer and returns the next question if applicable */
    RecordQuestionOfTheDayAnswer(body: Interfaces.RecordQuestionOfTheDayAnswerDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.QuestionOfTheDayAssessmentDto>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AssessmentsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AssessmentsV1Client>;
}
export declare class BadgesV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeDto>;
    /** Insert or update a badge */
    Upsert(body: Interfaces.BadgeDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.BadgeDto[]>;
    /** Recalculates badge earnings */
    RecalculateEarnedBadge(badgeId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists Badges by Medallion */
    ListBadgesByMedallion(medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BadgeDto>>;
    /** Returns a list of lessons based on the question */
    ListLessons(badgeId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeLessonDto[]>;
    /** Allows bulk updating of all lessons associated with the question. */
    UpdateLessons(body: Interfaces.UpdateBadgeLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a display image for a badge */
    AddImageResource(body: Interfaces.ImageUploadDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes a products associated product image */
    RemoveImageResource(BadgeId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Downloads the badge image if any */
    DownloadImage(BadgeId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets an achievement assessment based on badge */
    GetAchievementAssessment(userId: number, badgeId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Gets the badge learning path
            
Not supplying a discipline or medallion id shows all related badges to users selected disciplines. */
    GetLearningPath(userId: number, badgeId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeLearningPathDto>;
    /** Returns a list of the existing translations */
    GetTranslations(badgeId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Get the specified translation */
    GetTranslation(badgeId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.BadgeTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes a translation */
    DeleteTranslation(badgeId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the syndication providers for the given badge */
    ListSyndicationProviders(badgeId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BadgeSyndicationProviderDto>>;
    /** Updates the badge's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateBadgeSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.BadgeSyndicationProviderDto[]>;
    /** Lists the header lessons for the given badge */
    ListHeaderLessons(badgeId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BadgeHeaderLessonDto>>;
    /** Updates the badge's header lessons */
    UpdateHeaderLessons(body: Interfaces.UpdateBadgeHeaderLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.BadgeHeaderLessonDto[]>;
    /** Gets the available lessons for a badge */
    ListAvailableLessons(badgeId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** Delete */
    Delete(body: Interfaces.BadgeDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Delete by Ids */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** List badge groups */
    ListGroups(badgeId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeGroupDto[]>;
    /** Update Badge Groups */
    UpdateGroups(body: Interfaces.UpdateBadgeGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Copies a Badge to a New Organization */
    CopyBadgeToOrganization(badgeId: number, medallionId: number, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.GamificationStructureForEditingDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BadgeDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BadgesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BadgesV1Client>;
}
export declare class BotV1Client extends BaseClient {
    /** Get A Conversation by Id */
    GetConversation(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BotConversationDto>;
    /** Lists the conversations based on the criteria passed. */
    List(body?: Interfaces.ListBotConversationsRequest | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.BotConversationRefDto>>;
    /** Completes a given conversation by Id */
    Complete(willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Adds a message to a conversation or creates a new one if the Id is null */
    Add(body: Interfaces.AddBotCommunicationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.BotResponseDto>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BotV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BotV1Client>;
}
export declare class CampaignDripsV1Client extends BaseClient {
    /** Drip Override for Partners */
    UpdateOverrideDrip(body: Interfaces.CampaignDripDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists campaign Drips */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CampaignDripDto>>;
    /** Get the campaign drip dto */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CampaignDripDto>;
    /** Sends a test email (Without merge field) to a specified email */
    SendTest(dripId: number, email: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Insert or update a campaign drips */
    Upsert(body: Interfaces.CampaignDripDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CampaignDripDto[]>;
    /** Deletes the passed campaign drips */
    Delete(body: Interfaces.CampaignDripDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the campaign drips by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CampaignDripsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CampaignDripsV1Client>;
}
export declare class CampaignsV1Client extends BaseClient {
    /** Lists Subscriptions for the given campaign */
    ListSubscriptions(campaignId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CampaignSubscriptionDto>>;
    /** Updates the Campaign's Subscriptions */
    UpdateSubscriptions(body: Interfaces.UpdateCampaignSubscriptionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CampaignSubscriptionDto[]>;
    /** Gets the specified Campaign */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CampaignDto>;
    /** Lists the campaign drips */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CampaignDto>>;
    /** Insert or update a campaigns */
    Upsert(body: Interfaces.CampaignDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CampaignDto[]>;
    /** Deletes the passed campaigns */
    Delete(body: Interfaces.CampaignDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the campaigns by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CampaignsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CampaignsV1Client>;
}
export declare class CoursesV1Client extends BaseClient {
    /** Adds a resource to a course. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected resource from a course. If the resource is no longer associated with anything the resource will be completely removed. */
    RemoveResource(CourseId?: number, ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the resources (downloads etc.) associated with the specified course */
    ListResourcesByType(CourseId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourcesByTypeDto[]>;
    /** Returns the resources associated with the specified course */
    ListResources(CourseId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceLocatorDto[]>;
    /** Updates the status of an item and if necessary creates a new item and returns the updated item to replace. */
    SetEditingStatus(body: Interfaces.SetCourseItemEditingStatusDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingWithChildrenDto>;
    /** Returns the information about the current course and where it is in the workflow. If it isn't in the workflow then it puts it at stage 2 for triage by default. */
    GetWorkflowStatus(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusInfoDto>;
    /** Updates the specified course's workflow step and based on that will execute specific functions. */
    UpdateWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the course workflow task */
    UpdateWorkflowTask(body: Interfaces.UpdateWorkflowTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all workflow assignees to the Course. */
    ListAssignees(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseWorkflowAssigneesDto[]>;
    /** Updates the workflow assignments for a given course */
    UpdateAssignees(body: Interfaces.UpdateCourseWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List items by course id */
    ListItemsByCourseId(courseId?: number, organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ContentItemDto>>;
    /** Returns the course with user information */
    GetWithUserInfo(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseWithUserInfoDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.CourseTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Delete the specified translation */
    DeleteTranslation(body: Interfaces.CourseTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists lesson with questions */
    ListLessonQuestions(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonWithQuestionsDto>>;
    /** Edit Version Plan */
    EditVersionPlan(courseId: number, versionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Creates a new course from the existing course */
    CreateCourse(body: Interfaces.CreateCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseDto>;
    /** Imports the specified items from the selected course structure into the specified destination. */
    ImportCourse(body: Interfaces.ImportCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deactivates a course and all sub content if not attached to other active items */
    DeactivateCourse(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a list of all lessons on the course */
    ListLessonsByCourse(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Returns a list of all lessons on the course filtered by version */
    ListLessonsByCourseAndVersion(courseId?: number, versionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Edit Introduction */
    EditIntroduction(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Edit Conclusion */
    EditConclusion(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Gets the full course details for editing */
    GetAdmin(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseAdminDto>;
    /** Adds a new lesson to the existing topic. */
    CreateTopic(body: Interfaces.CreateCourseTopicDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingWithChildrenDto>;
    /** Adds a new lesson to the existing topic. */
    CreateLesson(body: Interfaces.CreateCourseLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingWithChildrenDto>;
    /** Returns all of the topics for a given course that are syndicated for your organization */
    ListTopicsWithSyndicatedContent(courseId?: number, organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TopicDto>>;
    /** Lists the syndications for the given course */
    ListSyndications(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseSyndicationDto>>;
    /** Updates the topic's syndications */
    UpdateSyndications(body: Interfaces.UpdateCourseSyndicationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseSyndicationDto[]>;
    /** Lists the syndication providers for the given course */
    ListSyndicationProviders(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseSyndicationProviderDto>>;
    /** Updates the course's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateCourseSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseSyndicationProviderDto[]>;
    /** Returns changes to the given course over time */
    GetCourseFeed(courseId: number, portalUrl: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Updates the course path information */
    UpdateCoursePath(body: Interfaces.UpdateCoursePathDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CoursePathsDto>;
    /** Returns the path information for the specified course */
    GetCoursePaths(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CoursePathsDto>;
    /** Update Organizations on the course */
    UpdateOrganizations(body: Interfaces.UpdateCourseAssignedOrganizationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseAssignedOrganizationsDto[]>;
    /** Update Public Videos on the course */
    UpsertPublicVideos(body: Interfaces.UpdateCoursePublicVideos, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoCourseDto[]>;
    /** Lists all organizations assigned to the current course. */
    ListOrganizations(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseAssignedOrganizationsDto>>;
    /** Updates the products and versions on the course */
    UpdateProductVersions(body: Interfaces.UpdateProductAndVersionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets all of the products and versions associated with the given course */
    ListProductVersions(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductVersionDetailsDto>>;
    /** Creates a custom course for the current organization */
    CreateCustomCourse(body: Interfaces.CreateCustomCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ShortContentDto>;
    /** Lists all courses for the given product with list of versions */
    ListCoursesByProductId(productId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseWithVersionsDto>>;
    /** Lists all Courses grouped by Product */
    ListCoursesByProducts(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CoursesByProductDto[]>;
    /** Gets the course with public details with the specified language code */
    GetWithTranslation(courseId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseDto>;
    /** List the course structure including resources etc. attached directly to the structure with the current user's ratings and percent complete etc. */
    GetStructureWithUserInfo(courseId: number, languageCode?: string, versionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContentItemWithChildrenDto[]>;
    /** Returns a list of the entire structure of the course by the id. */
    GetStructurePublic(courseId: number, versionId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContentItemWithChildrenDto[]>;
    /** Lists all courses that are custom for the current organization of the current user AND do not have products assigned. */
    ListCustomCourses(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseDto>>;
    /** Returns the course structure for editing purposes. */
    GetStructureForEditing(courseId: number, productId?: number, versionId?: number, showOnlyCadlearningVersions?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseStructureForEditingWithChildrenDto[]>;
    /** Updates the specified course's structure with any changes from the user. All items must be included. */
    UpdateCustomCourseStructure(body: Interfaces.UpdateCustomCourseStructureDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get SCORM Package */
    GetSCORMPackage(productId: number, versionId: number, courseId: number, portalUrl: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists all courses that are custom for the current organization of the current user AND do not have products assigned. */
    ListManageableCustomCourses(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseDto>>;
    /** Insert or update a course */
    Upsert(body: Interfaces.CourseDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseDto[]>;
    /** Deletes the passed courses */
    Delete(body: Interfaces.CourseDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the courses by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns courses by owner id with lesson completion percentage */
    ListCoursesByOwner(ownerId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseApprovalCompletionDto>>;
    /** Returns courses by external partner id with lesson completion percentage */
    ListCoursesByExternalPartner(partnerId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseApprovalCompletionDto>>;
    /** Gets course work for hire dashboard */
    CourseForHireDashboard(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseApprovalCompletionDto>>;
    /** Publish Course */
    PublishCourse(body: Interfaces.PublishCourseDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the tasks in Jira related to the course */
    ListProjectManagementTasks(CourseId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectManagementIssueDto>;
    /** Edit Body */
    EditRawAssets(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** List course groups */
    ListGroups(courseId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseGroupDto[]>;
    /** Update Course Groups */
    UpdateGroups(body: Interfaces.UpdateCourseGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.CourseDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoursesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CoursesV1Client>;
}
export declare class DisciplinesV1Client extends BaseClient {
    /** Lists all available roles */
    AdminList(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineDto>>;
    /** Recalculates discipline earnings */
    RecalculateEarnedDiscipline(disciplineId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes the given goals */
    Delete(body: Interfaces.DisciplineDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the given goals by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineDto>;
    /** Gets owned goals */
    GetOwned(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineDto>;
    /** Lists Owned Goals */
    ListOwned(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineWithProductsDto>>;
    /** Insert or update a discipline */
    Upsert(body: Interfaces.DisciplineDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DisciplineDto[]>;
    /** Lists Disciplines with Display Images */
    ListWithDisplayImages(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineDto>>;
    /** Lists Disciplines with Products and Display Images */
    ListWithProducts(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineWithProductsDto>>;
    /** Lists Disciplines with Products and Display Images by Industry Id */
    ListWithProductsByIndustry(industryId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineWithProductsDto[]>;
    /** List associated medallions */
    ListMedallions(disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineMedallionDto[]>;
    /** Allows bulk updating of all medallions associated with the discipline. */
    UpdateMedallions(body: Interfaces.UpdateDisciplineMedallionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List associated industries */
    ListIndustries(disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.IndustryDto[]>;
    /** Updates Industries on a Goal */
    UpdateIndustries(body: Interfaces.UpdateDisciplineIndustriesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of lessons based on the question */
    ListOrganizations(disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineAssignedOrganizationsDto[]>;
    /** Allows bulk updating of all lessons associated with the question. */
    UpdateOrganizations(body: Interfaces.UpdateDisciplineOrganizationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Downloads the Discipline image if any */
    DownloadImage(DisciplineId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Adds a display image for a badge */
    AddImageResource(body: Interfaces.ImageUploadDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes a products associated product image */
    RemoveImageResource(DisciplineId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List Discipline Products */
    ListProducts(disciplineId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineProductDto>>;
    /** Updates the specified Discipline's Products. */
    UpdateProducts(body: Interfaces.UpdateDisciplineProductDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DisciplineProductDto[]>;
    /** Gets an achievement assessment based on discipline */
    GetAchievementAssessment(userId: number, disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Gets the discipline learning path in the form of a Discipline first tree */
    GetLearningPath(userId: number, disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineLearningPathDto>;
    /** Gets the discipline certificate information */
    GetCertificateInfo(userId: number, disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDisciplineLearningPathDto>;
    /** Update Public Videos on the Discipline */
    UpsertPublicVideos(body: Interfaces.UpdateDisciplinePublicVideosDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoDisciplineDto[]>;
    /** Returns a list of the existing translations */
    GetTranslations(disciplineId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Get the specified translation */
    GetTranslation(disciplineId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.DisciplineTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes a translation */
    DeleteTranslation(disciplineId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the syndication providers for the given discipline */
    ListSyndicationProviders(disciplineId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineSyndicationProviderDto>>;
    /** Updates the discipline's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateDisciplineSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DisciplineSyndicationProviderDto[]>;
    /** Lists the header lessons for the given discipline */
    ListHeaderLessons(disciplineId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineHeaderLessonDto>>;
    /** Updates the discipline's header lessons */
    UpdateHeaderLessons(body: Interfaces.UpdateDisciplineHeaderLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DisciplineHeaderLessonDto[]>;
    /** Gets the available lessons for a discipline */
    ListAvailableLessons(disciplineId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** Lists disciplines by product version */
    ListDisciplinesByProductVersion(productId?: number, versionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineDto>>;
    /** Gets the goal structure for editing */
    GetDisciplineStructureForEditing(disciplineId: number, sourceProductId?: number, sourceVersionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.GamificationStructureForEditingWithChildrenDto>;
    /** Saves a set of discipline, medallions, badges with their children */
    SaveDisciplineStructure(body: Interfaces.GamificationStructureForEditingWithChildrenDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List discipline groups */
    ListGroups(disciplineId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineGroupDto[]>;
    /** Update Discipline Groups */
    UpdateGroups(body: Interfaces.UpdateDisciplineGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DisciplinesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DisciplinesV1Client>;
}
export declare class DocumentsV1Client extends BaseClient {
    /** Lists documents by category */
    ListByCategory(categoryId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DocumentDto>>;
    /** Lists the document categories in the system */
    ListDocumentCategories(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DocumentCategoryDto>>;
    /** Inserts or updates a single document category */
    InsertOrUpdateDocumentCategory(body: Interfaces.DocumentCategoryDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DocumentCategoryDto>;
    /** Updates the systems document categories */
    UpdateDocumentCategories(body: Interfaces.DocumentCategoryDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a document category */
    GetDocumentCategory(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DocumentCategoryDto>;
    /** Deletes a document category */
    DeleteDocumentCategory(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** List Document Links */
    ListDocumentLinks(documentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DocumentLinkDto[]>;
    /** Update Document Links */
    UpdateDocumentLinks(body: Interfaces.UpdateDocumentLinksDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Uploads a new document */
    UploadDocument(body: object, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DocumentDto>;
    /** Gets a document access token so that the document may be downloaded. */
    DownloadDocument(DocumentId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a list of documents, grouped by category, by the organization id */
    ListDocumentsByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DocumentCategoriesWithDocumentsDto[]>;
    /** Insert or update a documents */
    Upsert(body: Interfaces.DocumentDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DocumentDto[]>;
    /** Deletes the passed documents */
    Delete(body: Interfaces.DocumentDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the documents by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DocumentDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DocumentDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DocumentsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DocumentsV1Client>;
}
export declare class DomainsV1Client extends BaseClient {
    /** Updates the auth methods for the given domain. Should include all valid auth methods */
    UpdateAuthMethods(body: Interfaces.UpdateAuthMethodsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AuthMethodAdminDto[]>;
    /** Delete by Ids */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Uploads the specified stylesheet to azure */
    UploadStyleSheet(body: Interfaces.UploadDomainStyleSheetDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** GetDomainStyleSheet */
    GetStyleSheet(DomainId?: number, FallbackUrl?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Get Domain By Email Address */
    GetDomainByEmailAddress(emailAddress: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DomainAndAuthMethodsDto[]>;
    /** Returns the information for the domain by the site's Url */
    GetDomainWithAuthMethodsByUrl(siteUrl: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DomainAndAuthMethodsDto>;
    /** List auth methods by Domain Id */
    ListAuthMethodsByDomainId(domainId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AuthMethodDto[]>;
    /** List auth methods by Domain Id */
    ListAuthMethodsByDomainIdAdmin(domainId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AuthMethodAdminDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DomainDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DomainDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.DomainDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.DomainDto[]>;
    /** Deletes the dtos */
    Delete(body: Interfaces.DomainDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DomainsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DomainsV1Client>;
}
export declare class EntitlementsV1Client extends BaseClient {
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.EntitlementDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.EntitlementDto[]>;
    /** Returns the payment history for the given entitlement */
    ListPaymentHistory(entitlementId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EntitlementPaymentHistoryDto[]>;
    /** Lists entitlements for organization tools */
    ListOrgToolSubscriptionsByOrganizationId(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EntitlementDto>>;
    /** Renews a subscription */
    RenewSubscription(entitlementId: number, billingAddressId: number, paymentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Renews a subscription */
    RenewPartnerSubscription(body: Interfaces.RenewPartnerUserEntitlementDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Purchase a new subscription for a user or organization */
    PurchaseSubscription(body: Interfaces.PurchaseSubscriptionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all entitlements for the given user. */
    ListByUserId(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EntitlementDto[]>;
    /** Lists all entitlements for the given organization. */
    ListByOrganizationId(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EntitlementDto[]>;
    /** Cancels the specified entitlement */
    CancelEntitlement(entitlementId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the entitlement's payment details. */
    UpdateEntitlementPaymentDetails(body: Interfaces.UpdateEntitlementPaymentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates all of the user assignments on Organization entitlements */
    UpdateOrganizationEntitlementUsers(body: Interfaces.UpdateOrganizationEntitlementUsersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates all of the user assignments on Organization entitlements */
    BulkCreateEntitlements(body: Interfaces.BulkCreateEntitlementsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EntitlementDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EntitlementDto>>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.EntitlementDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EntitlementsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EntitlementsV1Client>;
}
export declare class IndustriesV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.IndustryDto>;
    /** Insert or update a badge */
    Upsert(body: Interfaces.IndustryDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.IndustryDto[]>;
    /** Delete */
    Delete(body: Interfaces.IndustryDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Delete by Ids */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.IndustryDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IndustriesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<IndustriesV1Client>;
}
export declare class InventoryV1Client extends BaseClient {
    /** Updates Inventory Items on inventory */
    UpdateItems(body: Interfaces.UpdateInventoryItemsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InventoryItemDto[]>;
    /** Gets an Inventory item by Sku. */
    GetBySku(sku: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InventoryDto>;
    /** Lists inventory items based on the inventory id */
    ListItems(inventoryId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InventoryItemDto[]>;
    /** Returns the inventory item with price by sku with optional partner Id to get the right pricing */
    GetWithPriceBySku(sku: string, partnerId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InventoryWithPriceDto>;
    /** Returns a list of Web products */
    ListWebProducts(subscriptionsOnly?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InventoryWithPriceDto[]>;
    /** Returns a list of web SKUs by the course id */
    ListWebSkusByCourse(courseId?: number, partnerId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InventoryWithPriceDto>>;
    /** Insert or update a inventory */
    Upsert(body: Interfaces.InventoryDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InventoryDto[]>;
    /** Deletes the passed inventory */
    Delete(body: Interfaces.InventoryDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the inventory by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InventoryDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InventoryDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<InventoryV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InventoryV1Client>;
}
export declare class InvoicesV1Client extends BaseClient {
    /** Calculate Sales Tax on the given request */
    RequestSalesTaxes(body: Interfaces.SalesTaxRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SalesTaxResultDto[]>;
    /** Calculate Sales Tax on the given invoice */
    CalculateTaxes(body: Interfaces.InvoiceWithInventoryDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SalesTaxResultDto[]>;
    /** Accept a quote */
    CopyQuote(body: Interfaces.CopyQuoteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvoiceDto>;
    /** Voids a payment within the system and automatically updates balances on invoices etc.
This does not reverse entitlements etc. at this time. */
    VoidPayment(paymentId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Marks the invoice as shipped */
    ShipInvoice(body: Interfaces.ShipInvoiceDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Unlocks an invoice that has not yet received payment but was locked to allow for payment. */
    UnlockInvoice(invoiceId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lock the invoice and prepare it to accept a payment */
    LockInvoiceForPayment(invoiceId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Completes the specified invoice posting it and creating entitlements etc. from it. */
    CompleteInvoice(invoiceId: number, sendToCustomer?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Posts the payment to the specified invoices */
    PostPaymentToInvoice(body: Interfaces.MakePaymentDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the stored credentials for the given contact */
    ListStoredPaymentCredentials(contactId?: number, type?: Enums.ContactTypes, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.StoredPaymentCredentialDto>>;
    /** Lists quotes by requesting organization */
    ListQuotesByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InvoiceDisplayDto[]>;
    /** Lists the bills from organization */
    ListBillsByOrganizationId(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InvoiceDisplayDto[]>;
    /** Lists invoices by the Identity */
    ListByUserId(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceDisplayDto>>;
    /** Lists quotes by requesting organization */
    ListRfqsByDeal(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InvoiceDisplayDto[]>;
    /** Lists invoices by organization */
    ListByOrganizationId(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceDisplayDto>>;
    /** Accept a quote */
    AcceptQuote(body: Interfaces.AcceptQuoteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Accept a quote */
    RejectQuote(body: Interfaces.RejectQuoteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a displayable list of invoices */
    ListForDisplay(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceDisplayDto>>;
    /** Returns a displayable version of the specified invoice */
    GetForDisplay(invoiceId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InvoiceDisplayDto>;
    /** Submits a quote to sales */
    SubmitQuote(body: Interfaces.SubmitQuoteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the inventory for the given invoice */
    UpdateInventory(body: Interfaces.UpdateInvoiceInventoryDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvoiceInventoryDto[]>;
    /** Lists a set of quotes by the parent request for a quote */
    ListQuotesByRFQ(rfqId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceDisplayDto>>;
    /** Returns the price for the given inventory number between the two parties */
    GetInventoryItemPrice(fromContactId: number, toContactId: number, toContactType: Enums.ContactTypes, inventoryId: number, units: number, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Allows the customer to dispute the invoice */
    DisputeInvoice(body: Interfaces.DisputeInvoiceDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists all of the inventory items on the invoice specified. */
    ListInventory(invoiceId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceInventoryDto>>;
    /** List all payments for the given invoice */
    ListPayments(invoiceId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoicePaymentDto>>;
    /** Insert or update a invoices */
    Upsert(body: Interfaces.InvoiceDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.InvoiceDto[]>;
    /** Deletes the passed invoices */
    Delete(body: Interfaces.InvoiceDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the invoices by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.InvoiceDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.InvoiceDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<InvoicesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InvoicesV1Client>;
}
export declare class JobsV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobDto>;
    /** Lists the available products for the given job based on the products assigned to the disciplines on the role. */
    ListAvailableProductsAndVersions(jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDto[]>;
    /** Insert or update a job */
    Upsert(body: Interfaces.JobDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.JobDto[]>;
    /** Gets the job learning path in the form of a job first tree */
    GetLearningPath(userId: number, jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobLearningPathDto>;
    /** Returns a list of jobs with the ids of the included discipline */
    ListJobsWithDisciplineIds(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobWithDisciplineIdsDto[]>;
    /** List Products by JobId(s) */
    ListJobsWithProducts(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobWithProductsDto>>;
    /** List Products by JobId(s) */
    ListProducts(jobIds?: number[], body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobProductDto>>;
    /** Updates the specified Discipline's Products. */
    UpdateProducts(body: Interfaces.UpdateJobProductDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.JobProductDto[]>;
    /** List associated industries */
    ListIndustries(jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.IndustryDto[]>;
    /** Updates the specified Discipline's Products. */
    UpdateIndustries(body: Interfaces.UpdateJobIndustriesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.JobIndustryDto[]>;
    /** Returns a list of lessons based on the question */
    ListOrganizations(jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobAssignedOrganizationsDto[]>;
    /** Allows bulk updating of all organizations associated with the job. */
    UpdateOrganizations(body: Interfaces.UpdateJobOrganizationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes the given roles */
    Delete(body: Interfaces.JobDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the given role by id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists all available roles */
    AdminList(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobDto>>;
    /** List associated Disciplines */
    ListDisciplines(jobId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.DisciplineDto>>;
    /** Allows bulk updating of all disciplines associated with the job. */
    UpdateDisciplines(body: Interfaces.UpdateJobDisciplinesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Update Public Videos on the Job */
    UpsertPublicVideos(body: Interfaces.UpdateJobPublicVideosDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoJobDto[]>;
    /** Recalculates job earnings */
    RecalculateEarnedJob(jobId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a display image for a badge */
    AddImageResource(body: Interfaces.ImageUploadDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes a job's associated product image */
    RemoveImageResource(JobId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Downloads the job image if any */
    DownloadImage(JobId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets an achievement assessment based on job */
    GetAchievementAssessment(userId: number, jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Returns a list of the existing translations */
    GetTranslations(jobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Get the specified translation */
    GetTranslation(jobId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.JobTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes a translation */
    DeleteTranslation(jobId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the syndication providers for the given job */
    ListSyndicationProviders(jobId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobSyndicationProviderDto>>;
    /** Updates the job's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateJobSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.JobSyndicationProviderDto[]>;
    /** Lists the header lessons for the given job */
    ListHeaderLessons(jobId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobHeaderLessonDto>>;
    /** Updates the job's header lessons */
    UpdateHeaderLessons(body: Interfaces.UpdateJobHeaderLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.JobHeaderLessonDto[]>;
    /** Gets the available lessons for a job */
    ListAvailableLessons(jobId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** List job groups */
    ListGroups(jobId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobGroupDto[]>;
    /** Update Job Groups */
    UpdateGroups(body: Interfaces.UpdateJobGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.JobDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<JobsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<JobsV1Client>;
}
export declare class LessonsV1Client extends BaseClient {
    /** Lists the tasks in Jira related to the lesson */
    ListProjectManagementTasks(LessonId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectManagementIssueDto>;
    /** Completes the lesson dependency task in Project Management for a lesson */
    CompleteLessonProjectManagementDependencies(body: Interfaces.ProjectManagementCompleteTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Completes the lesson commands task in Jira for a lesson */
    JiraCompleteLessonCommands(body: Interfaces.ProjectManagementCompleteTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Completes the lesson questions task in Jira for a lesson */
    JiraCompleteLessonQuestions(body: Interfaces.ProjectManagementCompleteTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Completes the lesson resources task in Jira for a lesson */
    JiraCompleteLessonResources(body: Interfaces.ProjectManagementCompleteTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Searches Project Management Issues */
    SearchProjectManagementIssues(SearchKeywords?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectManagementIssueDto[]>;
    /** Adds a resource to a lesson. This should post a MultiPartForm that includes all of the resource properties AND the file as a stream. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected resource from a lesson. If the resource is no longer associated with anything the resource will be completely removed. */
    RemoveResource(LessonId?: number, ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the resources (downloads etc.) associated with the specified lesson */
    ListResourcesByType(LessonId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourcesByTypeDto[]>;
    /** Returns the resources (downloads etc.) associated with the specified lesson */
    ListResources(LessonId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceLocatorDto[]>;
    /** Updates the specified lesson's workflow step and based on that will execute specific functions. */
    UpdateWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Approves work for hire step */
    ApproveWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Approves work for hire step */
    RejectWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the information about the current lesson and where it is in the workflow. If it isn't in the workflow then it puts it at stage 2 for triage by default. */
    GetWorkflowStatus(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusInfoDto>;
    /** Updates the lesson workflow task */
    UpdateWorkflowTask(body: Interfaces.UpdateWorkflowTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all workflow assignees to the Lesson. */
    ListAssignees(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonWorkflowAssigneesDto[]>;
    /** Updates the workflow assignments for a given course */
    UpdateAssignees(body: Interfaces.UpdateLessonWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Sets the current user's rating of the selected lesson. */
    SetCurrentUserRating(body: Interfaces.SetLessonUserRatingRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SetLessonUserRatingResponseDto>;
    /** Get */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonDto>;
    /** Get the script/narration for the lesson */
    GetLessonScript(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Returns the next and previous lessons based on the current lesson and course */
    GetNextAndPreviousLessons(lessonId: number, courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseNextAndPreviousLessonsDto>;
    /** Returns the next and previous lessons based on the current lesson and goal */
    GetNextAndPreviousLessonsByGoal(lessonId: number, goalId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseNextAndPreviousLessonsDto>;
    /** Returns the next and previous lessons based on the current lesson and playlist */
    GetNextAndPreviousLessonsByPlaylist(lessonId: number, playListId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseNextAndPreviousLessonsDto>;
    /** Returns a list of courses that are associated with the lesson */
    GetLessonCoursesList(lessonId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Forces a reload from documentProvider of the contents of the lesson */
    ForceReloadBody(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Edit Body */
    EditBody(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Edit Body */
    EditRawAssets(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Edit Body */
    GetRawAssetFiles(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto[]>;
    /** Gets possible lesson versions based on its attached courses */
    GetPossibleLessonVersions(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PossibleLessonVersionsDto[]>;
    /** List Labels */
    ListLabels(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonLabelDto[]>;
    /** Lists all available lesson labels */
    ListAllLabels(willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Updates lesson Labels */
    UpdateLabels(body: Interfaces.UpdateLessonLabelsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonLabelDto[]>;
    /** List Labels */
    ListDependencies(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonDependencyDto[]>;
    /** Updates lesson Labels */
    UpdateDependencies(body: Interfaces.UpdateLessonDependenciesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonDependencyDto[]>;
    /** Removes a lesson from production and allows editing. Means that it will not show up anywhere until it is completed. */
    RemoveFromProduction(body: Interfaces.EditProductionLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get Admin version of the Lesson */
    GetAdmin(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonAdminDto>;
    /** Returns a list of the existing translations */
    GetTranslations(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Get the specified translation */
    GetTranslation(lessonId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.LessonTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes a translation */
    DeleteTranslation(lessonId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Copies a lesson that is in a course and adds it immediately after that lesson, setting the status to the first step of the workflow and flagged as orange. */
    CopyLesson(body: Interfaces.CopyLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonDto>;
    /** Lists all lessons with course information and can be filtered using oData. */
    ListLessonsWithCourses(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonWithCourseInfoDto>>;
    /** Lists the syndications for the given lesson */
    ListSyndications(lessonId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonSyndicationDto>>;
    /** Updates the topic's syndications */
    UpdateSyndications(body: Interfaces.UpdateLessonSyndicationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonSyndicationDto[]>;
    /** Lists the syndication providers for the given lesson */
    ListSyndicationProviders(lessonId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonSyndicationProviderDto>>;
    /** Updates the topic's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateLessonSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonSyndicationProviderDto[]>;
    /** Update Public Videos on the lesson */
    UpsertPublicVideos(body: Interfaces.UpdateLessonPublicVideosDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoLessonDto[]>;
    /** Lists all lessons with course information by a requested assessment id */
    ListLessonsWithCoursesForAssessment(assessmentId: number, nameFilter?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonWithCourseInfoDto[]>;
    /** Gets all of the products and versions associated with the given lesson */
    ListProductVersions(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDetailsDto[]>;
    /** Creates a custom lesson under the specified parent. */
    CreateCustomLesson(body: Interfaces.CreateCustomLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ShortContentDto>;
    /** Updates the products and versions on the lesson */
    UpdateProductVersions(body: Interfaces.UpdateProductAndVersionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the commands on a lesson */
    ListCommands(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonCommandDto[]>;
    /** Lists possible commands that can be attached to a lesson */
    ListPossibleLessonCommands(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionCommandDto[]>;
    /** Updates the commands on a lesson */
    UpdateCommands(body: Interfaces.UpdateLessonCommandsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonCommandDto[]>;
    /** Logs the view of a lesson by the current user */
    LogLessonView(body: Interfaces.LessonVideoDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get the promo video for the given lesson and language */
    GetPromoVideoUri(lessonId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Returns a list of videos for the specified lesson. */
    GetLessonVideos(lessonId: number, courseId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.VideoWithCaptionsDto[]>;
    /** Gets a single organization lesson note */
    GetOrganizationNote(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationLessonNoteDto>;
    /** Updates organization lesson notes for an org */
    UpdateOrganizationNotes(body: Interfaces.UpdateOrganizationLessonNotesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the full lesson with user statistics */
    GetLessonDetailsWithUserInfo(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonDetailsWithUserInfoDto>;
    /** Returns the public content for the lesson details. */
    GetLessonPublicDetails(lessonId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicLessonDetailsDto>;
    /** Gets the associated workflows with the lesson */
    GetLessonWorkflows(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortContentDto[]>;
    /** Saves a lesson override thumbnail with the specified resource */
    SaveLessonOverrideThumbnail(body: Interfaces.UpdateLessonOverrideThumbnailDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Publish Lesson */
    PublishLesson(body: Interfaces.PublishLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a lessons publication status
<param name="command" /><param name="cancellationToken" /> */
    GetPublicationStatus(LessonId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonPublicationStatusDto>;
    /** Lists badges of the lesson */
    ListBadges(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonBadgeDto[]>;
    /** Lists medallions of the lesson */
    ListMedallions(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonMedallionDto[]>;
    /** Lists disciplines of the lesson */
    ListDisciplines(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonDisciplineDto[]>;
    /** Lists jobs of the lesson */
    ListJobs(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonJobDto[]>;
    /** Completes the lesson resources task in Jira for a lesson */
    ViewedInProduction(lessonId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Insert or update one or more lessons */
    Upsert(body: Interfaces.LessonDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LessonDto[]>;
    /** Deletes the passed lessons */
    Delete(body: Interfaces.LessonDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the lessons by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<LessonsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LessonsV1Client>;
}
export declare class MedallionsV1Client extends BaseClient {
    /** Deletes the given medallions */
    Delete(body: Interfaces.MedallionDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the given medallions by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.MedallionDto>;
    /** Insert or update a medallion */
    Upsert(body: Interfaces.MedallionDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.MedallionDto[]>;
    /** Lists Badges by Medallion */
    ListBadges(medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.MedallionBadgeDto>>;
    /** Allows bulk updating of all badges associated with the medallion. */
    UpdateBadges(body: Interfaces.UpdateMedallionBadgesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Recalculates discipline earnings */
    RecalculateEarnedMedallion(medallionId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a display image for a medallion. */
    AddImageResource(body: Interfaces.ImageUploadDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes a products associated product image */
    RemoveImageResource(MedallionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Downloads the medallion image if any */
    DownloadImage(MedallionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets an achievement assessment based on medallion */
    GetAchievementAssessment(userId: number, medallionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Gets the medallion learning path in the form of a Medallion first tree */
    GetLearningPath(userId: number, medallionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.MedallionLearningPathDto>;
    /** Returns a list of the existing translations */
    GetTranslations(medallionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Get the specified translation */
    GetTranslation(medallionId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.MedallionTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.MedallionTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes a translation */
    DeleteTranslation(medallionId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the syndication providers for the given medallion */
    ListSyndicationProviders(medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.MedallionSyndicationProviderDto>>;
    /** Updates the medallion's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateMedallionSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.MedallionSyndicationProviderDto[]>;
    /** Lists the header lessons for the given medallion */
    ListHeaderLessons(medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.MedallionHeaderLessonDto>>;
    /** Updates the medallion's header lessons */
    UpdateHeaderLessons(body: Interfaces.UpdateMedallionHeaderLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.MedallionHeaderLessonDto[]>;
    /** Gets the available lessons for a medallion */
    ListAvailableLessons(medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** List medallion groups */
    ListGroups(medallionId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.MedallionGroupDto[]>;
    /** Update Medallion Groups */
    UpdateGroups(body: Interfaces.UpdateMedallionGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Copies a Medallion to a New Organization */
    CopyMedallionToOrganization(medallionId: number, disciplineId: number, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.GamificationStructureForEditingDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.MedallionDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MedallionsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MedallionsV1Client>;
}
export declare class OrganizationsV1Client extends BaseClient {
    /**  */
    AddIndividualSubscriptionToPartner(body: Interfaces.AddIndividualSubscriptionToPartnerDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AddIndividualSubscriptionToPartnerResultDto>;
    /** Adds a Subscription to the org */
    AddSubscriptionToPartnerOrganization(body: Interfaces.AddPartnerOrganizationSubscriptionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationAddSubscriptionResponseDto>;
    /** Enterprise Request Information */
    EnterpriseRequestInformation(body: Interfaces.EnterpriseRequestInformationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a Subscription to the org */
    AddSubscriptionToOrganization(body: Interfaces.OrganizationAddSubscriptionRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationAddSubscriptionResponseDto>;
    /** Completes the invitation process */
    CompleteInvite(body: Interfaces.CompleteInviteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Completes the Auth side of the complete partner subscription process */
    CompletePartnerSubscription(body: Interfaces.CompletePartnerInviteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a Subscription to the org */
    CompletePartnerSmbSubscription(body: Interfaces.CompletePartnerSubscriptionOrganizationRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationAddSubscriptionResponseDto>;
    /** Returns the specified Identity for the given organization */
    GetOrganizationUser(OrganizationId?: number, UserId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationUserDto>;
    /** Can an organization sell resale items */
    CanOrganizationSellResale(OrganizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Lists all of the jobs under the Organization's Identity. */
    ListOrganizationUserJobs(organizationId?: number, userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserJobDto>>;
    /** Updates the user's jobs */
    UpdateOrganizationUserJobs(body: Interfaces.UpdateUserJobsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserJobDto[]>;
    /** Updates an organization users and their roles. */
    UpdateOrganizationUser(body: Interfaces.OrganizationUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Deletes the specified Organization Identity */
    DeleteOrganizationUser(body: Interfaces.OrganizationUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the xAPI configuration information */
    GetXApiCredentials(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationxApiCredentialsDto>;
    /** Update the xApi credentials for the specified organization */
    UpdateXApiCredentials(body: Interfaces.OrganizationxApiCredentialsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of email domains for the given user */
    ListEmailDomains(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationEmailDomainDto>>;
    /** Updates the specified organization's email domains */
    UpdateEmailDomains(body: Interfaces.UpdateOrganizationEmailDomainsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationEmailDomainDto[]>;
    /** Inserts or updates an organization with administrative information. */
    AdminUpsert(body: Interfaces.AdminOrganizationDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AdminOrganizationDto[]>;
    /** Lists all organizations with administrative information */
    AdminList(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AdminOrganizationDto>>;
    /** Assigns the specified roles to the user. All existing roles if not included will be removed. */
    AssignRolesToUser(body: Interfaces.AssignRolesToUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of roles for the given user */
    ListUserRoles(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationUserRoleDto[]>;
    /** Broadcasts an organizational message */
    Broadcast(body: Interfaces.NotificationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all messages under the organization */
    GetOrganizationMessages(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationMessageDto[]>;
    /** Returns all messages under the organization */
    GetMessages(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationMessageDto[]>;
    /** Allows inserting, updating, deleting messages under the specified organization. Should include all messages as any others will be deleted. */
    UpdateMessages(body: Interfaces.UpdateOrganizationMessagesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationMessageDto[]>;
    /** Lists the courses associated with a group and organization */
    ListUserGroupCourses(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationGroupCoursesDto[]>;
    /** Updates the organization group courses for an organization */
    UpdateOrganizationGroupCourses(body: Interfaces.UpdateOrganizationGroupCoursesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Allows invitation of a user to an organization */
    InviteUser(body: Interfaces.InviteUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationUserDto>;
    /** Gets the specified organization's content creation capabilities */
    GetOrganizationContentCreationCapabilities(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationContentCapabilitiesDto>;
    /** Lists the customers of the specified organization */
    ListCustomers(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationDto[]>;
    /** Gets all of the users for the given organization with roles. */
    ListOrganizationUsers(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationUserDto>>;
    /** Partner has a resale SKU */
    PartnerHasResaleSku(sku: string, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Gets if the current Org is an SMB */
    IsSmb(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Determines whether or not an org is a educational institution */
    IsEduOrganization(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Determines whether or not an org is a partner */
    IsPartnerOrganization(OrganizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Lists a partners user expiring entitlements */
    ListExpiringEntitlements(organizationId: number, days: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ExpiringEntitlementDto[]>;
    /** Gets an email template from the system */
    GetEmailTemplate(key: string, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationEmailTemplateDto>;
    /** Updates the e-mail templates for an organization */
    UpdateEmailTemplates(body: Interfaces.UpdateEmailTemplateDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates a specific partner prospect */
    UpdatePartnerProspect(body: Interfaces.PartnerProspectDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Updates a partners prospects */
    UpdatePartnerProspects(body: Interfaces.UpdatePartnerProspectsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists all partner prospects */
    ListPartnerProspects(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PartnerProspectDto>>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    ListProspectContacts(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContactDto[]>;
    /** Gets a list of organizations owned by the partner */
    ListPartnerOrganizations(partnerId: number, isLead?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationDto>>;
    /** Lists all groups currently existing within an organization */
    ListUserFields(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationUserFieldsDto>;
    /** Returns a list of stored payment credentials */
    ListPaymentCredentials(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.StoredPaymentCredentialDto>>;
    /** Gets a specific organization with administrative information */
    AdminGet(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AdminOrganizationDto>;
    /** Lists Permission Requests */
    ListPermissionRequests(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationPermissionsDto>>;
    /** Creates a Permission Request */
    ListPermissions(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationPermissionsDto[]>;
    /** Searches for available permission requests */
    PermissionRequestSearch(email: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrgUserWithOrganizationDto[]>;
    /** Accepts a permission request */
    AcceptPermissionRequest(body: Interfaces.OrganizationPermissionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Accepts a permission request */
    UpdatePermission(body: Interfaces.OrganizationPermissionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Denies a permission request */
    DenyPermissionRequest(body: Interfaces.OrganizationPermissionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Denies a permission request */
    RevokePermission(body: Interfaces.OrganizationPermissionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Creates a permission request */
    CreatePermissionRequest(body: Interfaces.OrganizationPermissionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Determines if an organization has a particular sku assigned to them */
    HasEntitlementSku(organizationId: number, sku: string, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Returns if the given organization has unused entitlements */
    HasUnusedEntitlements(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Gets the set of features an organization has access to */
    GetOrganizationFeatures(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationFeaturesDto>;
    /** Lists addresses by user id */
    ListAddresses(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationAddressDto>>;
    /** Update Identity Addresses */
    UpdateAddresses(body: Interfaces.UpdateOrganizationAddressesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationAddressDto[]>;
    /** Lists organization groups */
    ListGroups(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationGroupDto>>;
    /** Update Identity Addresses */
    UpdateGroups(body: Interfaces.UpdateOrganizationGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationGroupDto[]>;
    /** Returns the specific organization requested. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationDto>;
    /** Lists the available organizations */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.OrganizationDto>>;
    /** Inserts or updates the organizations */
    Upsert(body: Interfaces.OrganizationDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationDto[]>;
    /** Deletes the given entities */
    Delete(body: Interfaces.OrganizationDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the given entities by ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Runs SMb Rollup for single org */
    RunSmbRollup(body: Interfaces.SmbRollupSubscriptionRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SmbRollupSubscriptionResultDto>;
    /** List Identity Groups by Identity */
    ListUserGroupsByUser(organizationId: number, userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationUserGroupDto[]>;
    /** Updates the Organization's Identity Groups. */
    UpdateUserGroupsByUser(body: Interfaces.UpdateOrganizationUserGroupsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationUserGroupDto[]>;
    /** Gets a list of groups by partners organizations. */
    GetPartnerOrganizationGroups(partnerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PartnerOrganizationGroupDto[]>;
    /** Uploads users in csv format */
    UploadPartnerUsers(organizationId?: number, sendEmailInvites?: boolean, SKU?: string, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrganizationUserDto[]>;
    /** Returns all courses that have available syndicated content */
    ListCoursesWithSyndicatedContent(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseDto[]>;
    /** Gets Organizations Question Options */
    GetOrganizationContentOptions(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationContentOptionsDto>;
    /** Gets Public Organization Info */
    GetPublicOrganizationInfo(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationShortDto>;
    /** Gets the current inventory for the specified organization */
    GetCurrentPriceList(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationPriceListInventoryDto[]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<OrganizationsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<OrganizationsV1Client>;
}
export declare class PaymentMethodsV1Client extends BaseClient {
    /** List Payment Methods */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PaymentMethodDto>>;
    /**  */
    Upsert(body: Interfaces.PaymentMethodDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PaymentMethodDto[]>;
    /** Lists the stored credentials for the given contact */
    ListStoredPaymentCredentials(contactId?: number, type?: Enums.ContactTypes, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.StoredPaymentCredentialDto>>;
    /** Gets the specified stored payment credential */
    GetStoredPaymentCredential(storedPaymentCredentialId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.StoredPaymentCredentialDto>;
    /** Updates the given payment credential with new expiry etc. */
    UpdateCreditCardPaymentCredentials(body: Interfaces.UpdateCreditCardPaymentCredentialDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Add Payment Credentials */
    InsertOrUpdatePaymentCredential(body: Interfaces.AddStoredPaymentCredentialDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.StoredPaymentCredentialDto>;
    /** Deletes the specified payment credential */
    DeletePaymentCredential(credentialId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PaymentMethodDto>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PaymentMethodDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PaymentMethodsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PaymentMethodsV1Client>;
}
export declare class PaymentProvidersV1Client extends BaseClient {
    /** Returns a list of implementations for the specified provider */
    ListImplementations(providerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PaymentProviderImplementationDto[]>;
    /** Updates the specified provider's implementations. Should include all implementations for the given provider */
    UpdateImplementations(body: Interfaces.UpdatePaymentProviderImplementationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PaymentProviderImplementationDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PaymentProviderDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PaymentProviderDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.PaymentProviderDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PaymentProviderDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PaymentProviderDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PaymentProvidersV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PaymentProvidersV1Client>;
}
export declare class PlatformV1Client extends BaseClient {
    /** List all platform reports */
    ListReports(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PlatformReportDto>>;
    /** Get a specified report */
    GetReport(id: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PlatformReportDto>;
    /** Inserts or Updates a given platform report */
    UpsertReport(body: Interfaces.PlatformReportDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlatformReportDto>;
    /** Delete a specified report */
    DeleteReport(id?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlatformV1Client>;
}
export declare class PlaylistsV1Client extends BaseClient {
    /** Get the given playlist. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PlayListWithContentDto>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.PlayListWithContentDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlayListWithContentDto[]>;
    /** Inserts or Updates the playlist content passed. */
    UpsertWithContent(body: Interfaces.PlayListWithContentDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlayListWithContentDto>;
    /** Returns the playlists that the user can view */
    ListPlaylistByUser(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PlayListWithContentDto[]>;
    /** Lists the users associated with a playlist */
    ListPlayListUsers(playListId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PlayListUserDto[]>;
    /** Deletes a specified user from the playlist */
    DeletePlayListUser(body: Interfaces.PlayListUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the playlists for the specified user. If the user is not specified gets the play lists for the currently logged in user. */
    ListPlayListsByOwningOrganization(owningOrganization?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PlayListWithContentDto>>;
    /** Generates Lessons based on the gap and adds them to the playlist */
    GenerateGapLessons(playlistId: number, productId: number, versionId: number, version2Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PlayListWithContentDto>;
    /** Allows the owner of a play list to invite users into that play list. */
    InviteEmailAddressesToPlayList(body: Interfaces.InvitePlayListEmailAddressesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<string[]>;
    /** Invites users to a playlist by their group */
    InviteUsersByGroups(body: Interfaces.InvitePlayListUsersByGroupDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlayListUserDto[]>;
    /** Allows an administrator of an organization to invite users to a play list */
    InviteUsersToPlayList(body: Interfaces.InvitePlayListUsersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<string[]>;
    /** Lists the syndication providers for the given playList */
    ListSyndicationProviders(playListId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PlayListSyndicationProviderDto>>;
    /** Updates the topic's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdatePlayListSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlayListSyndicationProviderDto[]>;
    /** Lists the header lessons for the given playList */
    ListHeaderLessons(playListId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PlayListHeaderLessonDto>>;
    /** Updates the playList's header lessons */
    UpdateHeaderLessons(body: Interfaces.UpdatePlayListHeaderLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PlayListHeaderLessonDto[]>;
    /** Gets the available lessons for a playlist */
    ListAvailableLessons(playlistId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PlayListWithContentDto>>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PlayListWithContentDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlaylistsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlaylistsV1Client>;
}
export declare class PreferencesV1Client extends BaseClient {
    /** Gets a grid layouts by ID and the current user */
    GetDefaultGridLayout(gridKey: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserGridLayoutDto>;
    /** Gets a grid layouts by ID and the current user */
    ListGridLayouts(gridKey: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserGridLayoutDto[]>;
    /** Inserts or Updates a grid layout. */
    UpsertGridLayout(body: Interfaces.UserGridLayoutDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserGridLayoutDto>;
    /** Deletes the specified grid layout */
    DeleteGridLayout(id?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PreferencesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PreferencesV1Client>;
}
export declare class PriceListRevisionsV1Client extends BaseClient {
    /** Creates a new copy of a revision with today as the start date and all existing inventory still attached with existing pricing */
    CopyRevision(revisionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PriceListRevisionDto>;
    /** Returns the inventory of a given revision */
    ListInventory(revisionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PriceListRevisionInventoryDto>>;
    /** Returns the inventory of a given revision */
    ListPartnerResaleBillingInventory(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PriceListRevisionInventoryDto>>;
    /** Updates the inventory for a given revision. All inventory associated with the revision must be passed. */
    UpdateInventory(body: Interfaces.UpdatePriceListRevisionInventoryDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PriceListRevisionInventoryDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PriceListRevisionDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PriceListRevisionDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.PriceListRevisionDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PriceListRevisionDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PriceListRevisionDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PriceListRevisionsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PriceListRevisionsV1Client>;
}
export declare class PriceListsV1Client extends BaseClient {
    /** Get all revisions under a price list */
    ListRevisions(priceListId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PriceListRevisionDto>>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PriceListDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PriceListDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.PriceListDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PriceListDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PriceListDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PriceListsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PriceListsV1Client>;
}
export declare class ProductCategoriesV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductCategoryDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductCategoryDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.ProductCategoryDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductCategoryDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.ProductCategoryDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProductCategoriesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ProductCategoriesV1Client>;
}
export declare class ProductsV1Client extends BaseClient {
    /** Request the changes feed in atom. */
    ChangesFeed(portalUrl: string, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Get version from web url */
    GetVersionFromWebUrl(url: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDto>;
    /** Returns the Product and Version Ids based on the vendor info returned by the product. */
    GetVersionFromVendorInfo(productVendor: string, versionVendor: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDto>;
    /** Lists the vendor ids associated with a product */
    ListVendorIds(productId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string[]>;
    /** Updates vendor ids for the associated product */
    UpdateVendorIds(body: Interfaces.UpdateProductVendorIdsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get the specified translation */
    GetTranslation(productId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.ProductTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the translation categories associated with a product */
    ListTranslationCategories(productId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductTranslationCategoryDto[]>;
    /** Updates translation categories for the associated product */
    UpdateTranslationCategories(body: Interfaces.UpdateProductTranslationCategoryDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductTranslationCategoryDto[]>;
    /** Lists the categories associated with the Product */
    ListCategories(productId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductCategoryDto[]>;
    /** Updates Product Categories */
    UpdateCategories(body: Interfaces.UpdateProductCategoriesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets the mapping between CADLearning product/version Ids and the product's own internal values. */
    GetProductVersionIdsFromAppInfo(productName: string, productVersion: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductAndVersionIdDto>;
    /** Returns a set of commands for each version in a product */
    ListVersionCommands(productId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductCommandLessonsDto[]>;
    /** Lists the lessons associated with a particular version command */
    ListVersionCommandLessons(versionId: number, command: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonDto[]>;
    /** Gets a product version command with its translations */
    GetProductVersionCommandWithTranslations(command: string, versionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionCommandWithTranslationsDto>;
    /** Insert or Update Product Version Command */
    UpsertProductVersionCommandWithTranslations(body: Interfaces.UpdateProductVersionCommandDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Removes a product version command */
    RemoveProductVersionCommand(body: Interfaces.RemoveProductVersionCommandDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all of the lessons for a given product and version */
    ListLessonsByProductVersion(versionId?: number, languageCode?: string, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Returns all of the lessons for a given product and version */
    ListLessonsByProductVersionForAddVersion(versionId?: number, languageCode?: string, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AddVersionLessonDto>>;
    /** Adds a version and modifies lessons based on update status */
    AddVersion(body: Interfaces.UpdateProductVersionAddDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists all courses by product version */
    ListCoursesByProductVersion(versionId?: number, languageCode?: string, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Updates Product Versions */
    UpdateVersions(body: Interfaces.UpdateProductVersionsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductVersionDto[]>;
    /** Lists all products that are custom for the current organization of the current user. */
    ListCustomProducts(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductDto>>;
    /** Adds a display image for a product */
    AddProductImageResource(body: Interfaces.ImageUploadDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes a products associated product image */
    RemoveProductImage(ProductId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Creates a custom product for the current organization */
    CreateCustomProduct(body: Interfaces.CreateCustomProductDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductDto>;
    /** Returns a list of products concepts */
    ListProductWebAddresses(id?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductWebAddressDto>>;
    /** Updates Product Concepts */
    UpdateProductWebAddresses(body: Interfaces.UpdateProductWebAddressesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductWebAddressDto[]>;
    /** Returns a list of active products with courses in them that are active */
    ListActiveProducts(onlyShowOwnedOrganizations?: boolean, owningOrganizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductDto>>;
    /** Lists all courses by product version */
    ListCoursesByVersion(versionId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortContentDto[]>;
    /** Lists all courses by product version */
    ListCoursesByVersionAdmin(versionId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortContentDto[]>;
    /** List all work flows for the given product version. */
    ListWorkflowsByVersion(versionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortCourseDto[]>;
    /** Returns the Course for a given product based on latest version and default course or user's preference */
    GetProductCourse(productId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionAndCourseDto>;
    /** Returns the Course for a given product based on latest version and default course or user's preference */
    GetProductVersionCourse(productId: number, versionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionAndCourseDto>;
    /** Returns a list of versions for the given product */
    GetVersionsAdmin(productId: number, onlyWithCourse?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDto[]>;
    /** Returns a list of versions for the given product */
    GetVersions(productId: number, onlyWithCourse?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionDto[]>;
    /** Returns a list of versions for the given product ids */
    GetVersionByProductIds(body: number[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductVersionDto[]>;
    /** Get Product Information translated to the specified language code */
    GetWithLanguage(id: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductDto>;
    /** Insert or update a assessments */
    Upsert(body: Interfaces.ProductDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductDto[]>;
    /** Deletes the passed assessments */
    Delete(body: Interfaces.ProductDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the assessments by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists sites attached to the product */
    ListSites(productId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductSiteDto>>;
    /** Updates Sites */
    UpdateSites(body: Interfaces.UpdateProductSitesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProductSiteDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProductDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProductsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ProductsV1Client>;
}
export declare class ProjectsV1Client extends BaseClient {
    /** Generates a prehire assessment based on project position concepts */
    CreatePrehireAssessment(body: Interfaces.GenerateProjectPreHireAssessmentDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** List Project Products */
    ListProducts(projectId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProjectProductDto[]>;
    /** Lists the users on the given project */
    ListJobs(projectId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectJobDto[]>;
    /** Deletes the specified job. */
    DeleteJob(projectJobId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the users on the given project */
    GetJob(projectJobId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectJobDto>;
    /** Updates a specific job. */
    UpsertJob(body: Interfaces.ProjectJobDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProjectJobDto>;
    /** Updates the specified Project's Products. */
    UpdateProducts(body: Interfaces.UpdateProjectProductDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProjectProductDto[]>;
    /** Generates a prehire assessment based on project position concepts */
    MatchProjectJobToUsers(body: Interfaces.RequestProjectMatchDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProjectUserRankDto[]>;
    /** Insert or update a project */
    Upsert(body: Interfaces.ProjectDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProjectDto[]>;
    /** Deletes the passed projects */
    Delete(body: Interfaces.ProjectDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the projects by the ids passed */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProjectDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ProjectsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ProjectsV1Client>;
}
export declare class PublicVideosV1Client extends BaseClient {
    /** Gets a public video */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDto>;
    /** Upsert a Public Video */
    Upsert(body: Interfaces.PublicVideoDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoDto[]>;
    /** Adds a resource to a public video. The resource must still be uploaded. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected resource from a public video. If the resource is no longer associated with anything the resource will be completely removed. */
    RemoveResource(PublicVideoId?: number, ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** List all of the courses on the public video */
    ListCourses(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoCourseDto[]>;
    /** Update Courses attached to a public video */
    UpsertCourses(body: Interfaces.UpdatePublicVideoCoursesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoCourseDto[]>;
    /** List all of the lessons on the public video */
    ListLessons(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoLessonDto[]>;
    /** Lists Public Videos By Course */
    ListByCourse(courseId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PublicVideoCourseDto>>;
    /** Lists Public Videos By Lesson */
    ListByLesson(lessonId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PublicVideoLessonDto>>;
    /** Lists Public Videos By Discipline */
    ListByDiscipline(disciplineId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PublicVideoDisciplineDto>>;
    /** Lists Public Videos By Job */
    ListByJob(jobId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PublicVideoJobDto>>;
    /** Update Lessons attached to a public video */
    UpsertLessons(body: Interfaces.UpdatePublicVideoLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoLessonDto[]>;
    /** List all of the disciplines on the public video */
    ListDisciplines(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDisciplineDto[]>;
    /** Update Disciplines attached to a public video */
    UpsertDisciplines(body: Interfaces.UpdatePublicVideoDisciplinesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoDisciplineDto[]>;
    /** List all of the jobs on the public video */
    ListJobs(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoJobDto[]>;
    /** Update jobs attached to a public video */
    UpsertJobs(body: Interfaces.UpdatePublicVideoJobsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.PublicVideoJobDto[]>;
    /** Get Public Video Captions */
    GetVideoCaptions(PublicVideoId?: number, PreferedLanguage?: string, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CaptionWithUrlDto[]>;
    /** Delete Video Object attached to a Public Video */
    DeleteVideo(PublicVideoId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get Public Video Captions */
    DeleteCaption(publicVideoId?: number, captionId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get the specified translation */
    GetTranslation(publicVideoId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoTranslationDto>;
    /** Gets related videos by a public videos linked courses */
    GetRelatedVideosByCourses(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDto[]>;
    /** Gets related videos by a public videos linked lessons */
    GetRelatedVideosByLessons(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDto[]>;
    /** Gets related videos by a public videos linked disciplines */
    GetRelatedVideosByDisciplines(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDto[]>;
    /** Gets related videos by a public videos linked jobs */
    GetRelatedVideosByJobs(publicVideoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PublicVideoDto[]>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.PublicVideoDto>>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.PublicVideoDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PublicVideosV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PublicVideosV1Client>;
}
export declare class QuestionsV1Client extends BaseClient {
    /** Adds a resource to a question. The resource must still be uploaded. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected resource from a question. If the resource is no longer associated with anything the resource will be completely removed. */
    RemoveResource(ResourceId?: number, QuestionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the resources (downloads etc.) associated with the specified lesson */
    ListResourcesByType(QuestionId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourcesByTypeDto[]>;
    /** Returns the resources (downloads etc.) associated with the specified lesson */
    ListResources(QuestionId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceLocatorDto[]>;
    /** Returns all workflow assignees to the question. */
    ListAssignees(questionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionWorkflowAssigneesDto[]>;
    /** Updates the workflow assignments for a given question */
    UpdateAssignees(body: Interfaces.UpdateQuestionWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the information about t/he current question and where it is in the workflow. If it isn't in the workflow then it puts it at stage 2 for triage by default. */
    GetWorkflowStatus(questionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusInfoDto>;
    /** Updates the specified question's workflow step and based on that will execute specific functions. */
    UpdateWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the question workflow task */
    UpdateWorkflowTask(body: Interfaces.UpdateWorkflowTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto>;
    /** Get the specified translation */
    GetTranslation(questionId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.QuestionTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Delete the specified translation */
    DeleteTranslation(body: Interfaces.QuestionTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the possible lessons to be added to an answer */
    ListAnswerPossibleLessons(answerId?: number, versionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Returns a list of lessons based on the question */
    ListLessonsWithTime(questionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionLessonDto[]>;
    /** Allows bulk updating of all lessons associated with the question. */
    UpdateLessonsWithTime(body: Interfaces.UpdateQuestionLessonTimeDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of branching questions based on the Answer */
    ListAnswerBranchingQuestions(answerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AnswerQuestionDto[]>;
    /** Questions from assessments or lessons that can be added to a question branch */
    ListAvailableForQuestionBranch(questionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Allows bulk updating of all questions associated with the answer. */
    UpdateBranchingQuestions(body: Interfaces.UpdateQuestionBranchDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of lessons based on the question */
    ListLessons(questionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortContentDto[]>;
    /** Allows bulk updating of all lessons associated with the question. */
    UpdateLessons(body: Interfaces.UpdateQuestionLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the answers associated with a question */
    UpdateAnswers(body: Interfaces.UpdateAnswersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AnswerDto[]>;
    /** Gets a list of questions by the assessment */
    ListByAssessmentId(assessmentId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Adds a link between the specified lesson and question */
    AddLesson(body: Interfaces.AddRemoveQuestionFromLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a link between the specified lesson and help question */
    HelpQuestionAddLesson(body: Interfaces.AddRemoveQuestionFromLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Removes a specified lesson from the question. */
    RemoveLesson(body: Interfaces.AddRemoveQuestionFromLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Removes a specified lesson from the help question. */
    HelpQuestionRemoveLesson(body: Interfaces.AddRemoveQuestionFromLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a list of questions that can be added to the given lesson based on the product information */
    ListAvailableForLessonAdd(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Returns a list of suggested lessons based on the Answer */
    ListAnswerSuggestedLessons(answerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AnswerLessonDto[]>;
    /** Imports a question into a new organization */
    ImportQuestionToOrganization(body: Interfaces.ImportQuestionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingWithChildrenDto>;
    /** Questions that can be added to the specified assessment */
    ListAvailableForAssessmentAdd(assessmentId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.QuestionWithProductAndLessonDto>>;
    /** Updates suggested lessons on the specified answer */
    UpdateAnswerSuggestedLessons(body: Interfaces.UpdateAnswerSuggestedLessonsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a list of questions by the lesson */
    PublicListByLessonId(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Gets a list of questions by the lesson */
    ListByLessonId(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Gets a list of questions by the lesson */
    ListByLessonIdWithAnswers(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Gets a list of questions by the lesson with the workflow step */
    ListByLessonIdWithWorkflow(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionWithWorkflowDto[]>;
    /** Gets a list of questions by the lesson with the workflow step */
    ListHelpQuestionsByLessonId(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.HelpQuestionDto[]>;
    /** List Help Questions */
    ListHelpQuestions(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.HelpQuestionDto>>;
    /** Insert or update a assessments */
    Upsert(body: Interfaces.QuestionDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.QuestionDto[]>;
    /** Insert or update a help question */
    UpsertHelpQuestions(body: Interfaces.HelpQuestionDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.HelpQuestionDto[]>;
    /** Lists orphaned questions for an organization */
    ListOrphanedQuestions(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.QuestionDto>>;
    /** Deletes the passed assessments */
    Delete(body: Interfaces.QuestionDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the assessments by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.QuestionDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<QuestionsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<QuestionsV1Client>;
}
export declare class ReportsV1Client extends BaseClient {
    /** Provides a detailed list of all activity given the load criteria. */
    UserActivity(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmployeeActivityDto>>;
    /** Lists all reports for the given user */
    ListReports(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportDto[]>;
    /** Active Users By Month Summary */
    ActiveUsersByMonth(organizationId?: number, numberOfMonths?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.Int32NameValueDto[]>;
    /** Most Recent Badges acquired by a given user. */
    MostRecentBadges(userId?: number, asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeDto[]>;
    /** Returns Organizational Learning Statistics */
    OrganizationStats(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationStatsDto>;
    /** Returns the current Gross MRR */
    GrossMRR(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Returns the current Gross ARR */
    GrossARR(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Gross MRR Trends */
    GrossMRRTrends(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DecimalNameValueDto[]>;
    /** Gross ARR Trends */
    GrossARRTrends(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DecimalNameValueDto[]>;
    /** Gross MRR Trends */
    MonthlyChurnTrends(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ChurnRateByDateDto[]>;
    /** Gross MRR Trends */
    YearlyChurnTrends(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ChurnRateByDateDto[]>;
    /** Monthly Churn Rate */
    MonthlyChurnRate(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ChurnRateDto[]>;
    /** Yearly Churn Rate */
    YearlyChurnRate(asOf?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ChurnRateDto[]>;
    /** Engagement Trends over the organization for the past 12 months by month */
    OrganizationEngagementTrends(OrganizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EngagementTrendsDto[]>;
    /** Medallions assigned to Employees and their trends of completion */
    OrganizationSkillsGaps(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SkillsGapDto[]>;
    /** Medallions assigned to Employees and their trends of completion */
    OrganizationSkillsGapsAtDate(organizationId: number, date: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SkillsGapDto[]>;
    /** Most Improved Employees */
    OrganizationMostImprovedEmployees(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeScoreChangeDto[]>;
    /** Struggling Employees */
    OrganizationStrugglingEmployees(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeScoreChangeDto[]>;
    /** Most engaged employees over the past 3 months */
    OrganizationMostEngaged(OrganizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeWithEngagementDto[]>;
    /** Least engaged employees over the past 3 months */
    OrganizationLeastEngaged(OrganizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeWithEngagementDto[]>;
    /** Least engaged employees over the past 3 months */
    OrganizationRockStars(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeWithOverallGoalCompletionDto[]>;
    /** Get a List of Roles with assigned Employees and status */
    EmployeesAssignedToRoles(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmployeeAssignedToItemDto>>;
    /** Get a List of Goals with assigned Employees and status */
    EmployeesAssignedToGoals(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmployeeAssignedToItemDto>>;
    /** Get a List of Employees and their Roles with status */
    EmployeeRoleSummary(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeItemCompletionDto[]>;
    /** Get a List of Employees and their Goals with status */
    EmployeeGoalSummary(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmployeeItemCompletionDto[]>;
    /** Get a List of Employees and their Roles with status */
    EmployeeRoleSummaryFlattened(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmployeeItemCompletionFlattenedDto>>;
    /** Get a List of Employees and their Goals with status */
    EmployeeGoalSummaryFlattened(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmployeeItemCompletionFlattenedDto>>;
    /** Download Goal Data */
    DownloadGoalData(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DownloadGoalDataDto[]>;
    /** Download Role Data */
    DownloadRoleData(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DownloadRoleDataDto[]>;
    /** Schedule a Report */
    ScheduleReport(body: Interfaces.ScheduleReportDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get a schedule for a specific report */
    GetReportSchedule(organizationId: number, report: Enums.OrganizationReportTypes, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ScheduleReportDetailsDto>;
    /** List Report schedules by Organization */
    ListReportSchedules(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ScheduleReportDetailsDto[]>;
    /** Total Inactive users by Organization */
    TotalInActiveUsersByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Total Assessments over Organization's Current Entitlement Period */
    TotalAssessmentsOverEntitlementPeriod(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Total Active Users by Organization */
    TotalActiveUsersByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Most Taken assessments by Organization */
    MostTakenAssessmentsByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportMostTakenAssessmentDto[]>;
    /** Most Active Products by Organization */
    MostActiveProductsByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportMostActiveProduct[]>;
    /** Total Users by Organization */
    TotalUsersByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** List all trials on all organizations */
    ListTrials(dtStart?: Date, dtEnd?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportTrialsDto>>;
    /** Gets a partners sales rep sales info */
    GetPartnerSalesRepInfo(partnerId?: number, dtStart?: Date, dtEnd?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportSalesBySalesRepDto>>;
    /** Lists the tokens associated with a particular partner that have been redeemed */
    ListPartnerRedeemedTokens(partnerId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportPartnerTokenDto>>;
    /** Lists Billable Inventory */
    ListBillableInventory(dtStart: Date, dtEnd: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportBillableInventoryDto[]>;
    /** List Identity Detail Activity */
    GetUserActivity(organizationId: number, userId: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportUserDetailViewsDto[]>;
    /** Returns items that have stalled in the pipeline */
    WorkflowStalledItems(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportWorkFlowTaskDetailsDto[]>;
    /** Lists all Workflow items that had errors */
    WorkflowErrors(dtFrom?: Date, dtTo?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportWorkflowTaskChangesDto>>;
    /** Returns items that have aged out. */
    WorkflowAgingItems(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportWorkFlowTaskDetailsDto[]>;
    /** Lists the work flow task changes by date range. */
    WorkflowTaskChanges(dtFrom?: Date, dtTo?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportWorkflowTaskChangesDto>>;
    /** Total current active Monthly personal subscriptions */
    TotalActiveMonthlies(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Total current active Year personal subscriptions */
    TotalActiveYearlies(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Current Users Online */
    UsersOnline(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTotalDto>;
    /** Totals of active users by platform */
    PlatformTotals(dtFrom: Date, organizationId?: number, userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportPlatformTotalDto[]>;
    /** Gets a course summary across editing steps in its topics */
    CourseGlanceReport(courseId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseAtAGlanceReportDto>;
    /** Top Partners by Leads */
    TopPartnersByLeads(dtFrom: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTopOrganizationsByDollarValueDto[]>;
    /** Top partners by Dollars Sold */
    TopPartnersByDollarsSold(dtFrom: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTopOrganizationsByDollarValueDto[]>;
    /** Top Sales People in the company by dollar value. */
    TopSales(dtFrom: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTopUsersByDollarValueDto[]>;
    /** Top organizations by Dollars Sold */
    TopOrganizationsByDollarsSold(dtFrom: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportTopOrganizationsByDollarValueDto[]>;
    /** Upcoming Renewals */
    UpcomingEnterpriseRenewals(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportUpcomingOrganizationRenewalsDto>>;
    /** Most Active Products */
    MostActiveProducts(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportMostActiveProduct[]>;
    /** Lists all partner activity */
    ListPartnerActivity(days: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportPartnerActivityDto[]>;
    /** Provides the user history of a given assessment */
    AssessmentUserHistory(assessmentId?: number, organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentUserHistoryDto>>;
    /** Returns Assessment Scoring Statistical Data */
    AssessmentDistributionReport(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AssessmentDistributionDto>>;
    /** A report that lists all of your employees that have taken the given assessment and their detailed scores with question information. */
    AssessmentReportCard(assessmentId: number, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssessmentReportCardDto>;
    /** Returns a list of Lessons with their total activity by project */
    ListProjectLessonViews(organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportProjectLessonViewsDto[]>;
    /** Returns a list of courses that can be used for LMS import */
    CourseList(portalUrl: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportCoursesDto[]>;
    /** Returns all lesson activity for your given organization */
    DownloadAssessmentData(userName?: string, password?: string, organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DownloadAssessmentDataDto[]>;
    /** Returns all lesson activity for your given organization */
    ListLessonActivityDetails(organizationId?: number, userId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportLessonActivityDetailsDto[]>;
    /** Returns a list of summary data about user views */
    ListUserLessonViews(StartOn?: Date, EndOn?: Date, OrganizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportUserLessonViewsDto>>;
    /** Returns Report data based on detailed version information and lesson details */
    ListProjectUserViews(projectId: number, organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportProjectUserViewsDto[]>;
    /** Returns a list of Lessons with their total activity by project */
    ListProjectLessonActivity(projectId: number, organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportLessonViewsDto[]>;
    /** Returns Report data based on detailed version information and lesson details */
    ListProductVersionViews(productId: number, organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportProductVersionViewsDto[]>;
    /** Returns a list of products and their views */
    ListProductLessonViews(organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportProductViewsDto[]>;
    /** List Product Command Views */
    ListProductCommandViews(productId: number, organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportProductCommandViewsDto[]>;
    /** Returns a list of Lessons with their total activity */
    ListLessonViews(OrganizationId?: number, StartOn?: Date, EndOn?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportLessonViewsDto[]>;
    /** Returns a list of Lessons with their total activity */
    ListActivity(organizationId?: number, userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportActivityItemDto>>;
    /** Returns a list of Resources with their total activity */
    ListResourceViews(OrganizationId?: number, StartOn?: Date, EndOn?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportResourceViewsDto[]>;
    /** List Group Views */
    ListGroupViews(organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportGroupViewsDto[]>;
    /** List Group Product Views */
    ListGroupProductViews(organizationId: number, groupName: string, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportGroupProductViewsDto[]>;
    /** Returns a list of Users for an organization with their organization information */
    OrganizationUserEntitlements(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportOrganizationUserEntitlementsDto>>;
    /** Returns a list of Users for an organization with their organization information */
    OrganizationUsers(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportOrganizationUsersDto>>;
    /** Lists the tokens associated with a particular partner */
    ListPartnerTokens(partnerId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportPartnerTokenDto>>;
    /** Returns a list or courses viewed by the user and their completion percentage for that course */
    CourseCompletionByUser(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportCourseCompletionDto>>;
    /** Returns a list or courses viewed by the user and their total number of lessons completed out of the total number of lessons on the course */
    CourseCompletionLessonsByUser(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportCourseCompletionLessonsDto[]>;
    /** Returns the most viewed lessons for the given user */
    MostPopularLessons(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportLessonViewsDto[]>;
    /** Returns total sign ups per month */
    SignupsByMonth(organizationId?: number, dtStart?: Date, dtEnd?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportSignupsByMonthDto>>;
    /** Returns all detail sign ups by month */
    SignupsByMonthDetail(organizationId?: number, dtStart?: Date, dtEnd?: Date, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ReportSignupsByMonthDetailDto>>;
    /**  */
    TimeSavedAcrossOrganization(organizationId?: number, dtStart?: Date, dtEnd?: Date, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TimeSavedAcrossOrganizationResultDto>;
    /** Returns the subscriptions per invoice metric */
    SubscriptionsPerInvoice(willHandleError?: boolean, withCredentials?: boolean): Promise<number>;
    /** Gets the badges with the users under an organization with who earned the badge */
    GetBadgeWithUsersAchieved(organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeWithUsersDto[]>;
    /** Gets the achievements a user has tested out of */
    GetTestedOutAchievements(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ReportAchievementsTestedOutDto>;
    /**  */
    CompetenciesAchievedByOrganization(organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CompetenciesAchievedDto[]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ReportsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ReportsV1Client>;
}
export declare class ResourcesV1Client extends BaseClient {
    /** Gets the JWT Token required for playback of azure media assets */
    GetVideoPermissions(VideoId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Takes existing raw resources and creates a new video generating all of the media resources on Azure etc. in a queued process. */
    QueueCreateVideoFromResources(body: Interfaces.CreateVideoFromResourcesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Proxy endpoint for public videos */
    VideoPublic(videoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Proxy endpoint for public videos */
    PlaybackPublicVideo(videoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets lesson m3u8 */
    VideoFromLesson(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets lesson m3u8 */
    PlaybackVideoFromLesson(lessonId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Proxy endpoint for private videos */
    Video(videoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Proxy endpoint for private videos */
    PlaybackVideo(videoId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the captions for the specified video if any including the urls for any captions for playback */
    GetVideoCaptions(VideoId?: number, PreferredLanguage?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CaptionWithUrlDto[]>;
    /** Allows adding one or more new captions to an existing video */
    AddCaptionsToVideo(body: Interfaces.AddCaptionsToVideoDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CaptionDto[]>;
    /** Secondary Playlist generation */
    SecondaryVideoPlaybackPlayList(hlsUrl: string, playbackUrl: string, armored_token?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Video proxy for captions */
    SecondaryVideoCaptionsPlayList(captionId: number, length: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the video passed. */
    DeleteVideo(VideoId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Imports the resource into the selected lesson */
    ImportResource(body: Interfaces.ImportResourceDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Gets a list of resources by parent and resource type */
    GetResourcesByParentAndType(parentId: number, parentType: Enums.ContentItemTypes, resourceType: Enums.ResourceTypes, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceDto[]>;
    /** Deletes a Caption set */
    DeleteCaption(captionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a list of resources with their parents. */
    ListWithParents(itemType?: Enums.ContentItemTypes, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceWithParentDto[]>;
    /** Create captions from lesson Script */
    CreateCaptionsFromScript(body: Interfaces.CreateCaptionsFromScriptDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Allows adding a link to an existing course or topic */
    AddLink(body: Interfaces.AddLinkDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceDto>;
    /** Download a given resource by Id */
    DownloadResource(ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a resource Url */
    GetResourceUrl(ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Gets a resource Url for Syndication partners */
    GetSyndicatedResourceUrl(ResourceId?: number, Secret?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Gets video token with applied secret */
    GetSyndicatedVideoTokenUrl(LessonId: number, Secret: string, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Logs the view of a resource by the current user */
    LogResourceView(body: Interfaces.ResourceViewDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets the specified resource */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceDto>;
    /** Updates the given resources */
    Upsert(body: Interfaces.ResourceDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceDto[]>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ResourceDto>>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.ResourceDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ResourcesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ResourcesV1Client>;
}
export declare class SalesTaxesV1Client extends BaseClient {
    /** Lists sales taxes */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SalesTaxDto>>;
    /** Returns a list of sales tax providers to apply to a sales tax. */
    ListProviders(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SalesTaxProviderDto[]>;
    /** Updates/Inserts the specified sales taxes
<param name="dtos"></param><param name="cancellationToken"></param> */
    Upsert(body: Interfaces.SalesTaxDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SalesTaxDto[]>;
    /** Deletes the specified sales taxes
<param name="dtos"></param><param name="cancellationToken"></param> */
    Delete(body: Interfaces.SalesTaxDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the specified sales taxes by id
<param name="id"></param><param name="cancellationToken"></param> */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists sales tax exemptions by contact
<param name="contactId"></param><param name="contactType"></param> */
    ListSalesTaxExemptionsByContact(contactId: number, contactType: Enums.ContactTypes, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SalesTaxExemptionDto[]>;
    /** Lists sales tax exemptions */
    ListSalesTaxExemptions(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SalesTaxExemptionDto>>;
    /** Gets a security token to view the certificate for the request */
    RequestCertificateAccessToken(SalesTaxExemptionNumber?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Get sales tax exemption
<param name="requestId"></param><param name="cancellationToken"></param> */
    GetSalesTaxExemption(requestId: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SalesTaxExemptionDto>;
    /** Updates sales tax exemptions by contact
<param name="update"></param><param name="cancellationToken"></param> */
    UpdateSalesTaxExemption(body: Interfaces.SalesTaxExemptionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SalesTaxExemptionDto>;
    /** Allows a new user or existing user to request sales tax exemption. Creates or updates the contact, and adds the exemption without verifying and sends to the appropriate team for validation
<param name="request"></param><param name="cancellationToken" /> */
    RequestSalesTaxExemption(body: Interfaces.RequestSalesTaxExemptionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SalesTaxExemptRequestResultDto>;
    /** Rejects an outstanding request and notifies the admin on the account
<param name="requestId"></param><param name="cancellationToken"></param> */
    AcceptSalesTaxExemptionRequest(requestId: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Rejects an outstanding request and notifies the admin on the account
<param name="requestId"></param><param name="reason"></param> */
    RejectSalesTaxExemptionRequest(requestId?: string, reason?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Removes a previous request
<param name="requestId"></param><param name="cancellationToken"></param> */
    RemoveSalesTaxExemptionRequest(requestId?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SalesTaxDto>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SalesTaxesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SalesTaxesV1Client>;
}
export declare class SearchV1Client extends BaseClient {
    /** Does a quick search for the top 5 items of each type that is returned. */
    QuickSearch(searchPhrase: string, languageCode?: string, count?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuickSearchResultDto[]>;
    /** Searches all lessons and returns meta data to do an incremental property search. */
    SearchLessons(searchPhrase: string, languageCode?: string, count?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContentSearchResponseDto>;
    /** Searches for lessons based on product information */
    SearchLessonsByProductCodes(searchPhrase: string, count: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContentSearchResultsWithUserInfoDto[]>;
    /** Gets the list results Q would see. */
    SearchQuestionsTest(question: string, count: number, productId?: number, versionId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionSearchResultDto[]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SearchV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SearchV1Client>;
}
export declare class ShippingMethodsV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShippingMethodDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShippingMethodDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.ShippingMethodDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ShippingMethodDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.ShippingMethodDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ShippingMethodsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ShippingMethodsV1Client>;
}
export declare class SitesV1Client extends BaseClient {
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SiteDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SiteDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.SiteDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SiteDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.SiteDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SitesV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SitesV1Client>;
}
export declare class SupportV1Client extends BaseClient {
    /** Lists Questions with oData Filtering */
    ListQuestions(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SupportQuestionDto>>;
    /** Lists Questions by Answer */
    ListQuestionsByAnswer(answerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SupportQuestionDto[]>;
    /** Updates Questions to support answers */
    UpdateAnswerQuestions(body: Interfaces.UpdateSupportAnswerQuestions, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SupportQuestionDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SupportAnswerDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SupportAnswerDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.SupportAnswerDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SupportAnswerDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.SupportAnswerDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SupportV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SupportV1Client>;
}
export declare class SyndicationProvidersV1Client extends BaseClient {
    /** Returns a list of implementations for the specified provider */
    ListImplementations(providerId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SyndicationProviderImplementationDto[]>;
    /** Updates the specified provider's implementations. Should include all implementations for the given provider */
    UpdateImplementations(body: Interfaces.UpdateSyndicationProviderImplementationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SyndicationProviderImplementationDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SyndicationProviderDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.SyndicationProviderDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.SyndicationProviderDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.SyndicationProviderDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.SyndicationProviderDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SyndicationProvidersV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SyndicationProvidersV1Client>;
}
export declare class SystemV1Client extends BaseClient {
    /** Returns a list of system settings */
    ListSystemSettings(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SystemSettingDto[]>;
    /** Gets the current list of email domains that cannot be configured in the system */
    ListEmailDomainBlackLists(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.EmailDomainBlackListItemDto[]>;
    /** Adds a domain to the blacklist */
    AddEmailDomainBlack(body: Interfaces.EmailDomainBlackListItemDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Removes a domain from the blacklist */
    DeleteEmailDomainBlack(domain?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns a list of Edu Domains */
    ListEduDomains(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EduDomainDto>>;
    /** Updates the set of configured edu domains */
    UpdateEduDomains(body: Interfaces.UpdateEduDomainsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Creates a new audience for the given client */
    CreateAudience(clientId: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AudienceDto>;
    /** Creates a new hash for the audience */
    RegenerateAudienceKey(id: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AudienceDto>;
    /** Deletes the specified audience */
    DeleteAudience(identifier?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists the audiences for the specified client */
    ListAudiences(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AudienceDto[]>;
    /** Clients all current clients */
    ListClients(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ClientDto[]>;
    /** Removes a client */
    DeleteClient(clientId?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Inserts or updates the given clients */
    UpsertClient(body: Interfaces.ClientDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ClientDto[]>;
    /** Updates the client secret in the database. */
    ChangeClientSecret(body: Interfaces.UpdateClientSecretDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Get latest client version */
    GetLatestClientVersion(clientId: string, version: Enums.ClientVersions, willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Gets a list of merge fields for a particular email template */
    ListMergeFields(emailKey: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.MergeFieldDto[]>;
    /** Gets a list of configured email templates */
    ListEmailTemplates(showInternal?: boolean, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.EmailTemplateDto>>;
    /** Get default email template */
    GetDefaultEmailTemplate(key: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationEmailTemplateDto>;
    /** Update email templates */
    UpdateEmailTemplates(body: Interfaces.UpdateEmailTemplateDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Ping/Pong */
    Ping(willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Ping/Pong */
    PostPing(body: Interfaces.PingDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<string>;
    /** Gets terms of service last updated date */
    GetTermsOfServiceDate(willHandleError?: boolean, withCredentials?: boolean): Promise<Date>;
    /** Updates the set of configured system settings */
    UpdateSystemSettings(body: Interfaces.UpdateSystemSettingsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Broadcasts a system message to everyone. */
    BroadcastSystemMessage(body: Interfaces.SystemMessageDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Reports an error from a secure client */
    ReportError(body: Interfaces.ErrorLogDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets a static page translation */
    GetPageTranslation(pageName?: string, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.StaticPageTranslationDto>;
    /** Updates a static page translation */
    UpdatePageTranslation(body: Interfaces.StaticPageTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets pages with their associated languages */
    GetPageTranslationLanguages(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.StaticPageTranslationWithLanguagesDto[]>;
    /** Copies a set of keys to a new language for a page */
    CopyFromPage(body: Interfaces.CopyStaticPageTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Copies a set of keys to a new language for a page */
    DeletePageLanguage(body: Interfaces.StaticPageTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Because code gen generates dtos from API, I needs this in order for LanguageImportDto to be generated */
    ImportExcelLanguagesDummy(willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.LanguageImportDto>;
    /** Severs _sharepoint links */
    SeverSharepointLinks(willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SystemV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SystemV1Client>;
}
export declare class TokensV1Client extends BaseClient {
    /** Cancels the given token */
    Cancel(tokenId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Redeem the given token */
    Redeem(body: Interfaces.RedeemTokenDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the tokens assigned to the given organization */
    ListByOrganizationId(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TokenDto>>;
    /** Returns a list of tokens by who redeemed them */
    ListByRedeemedById(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TokenDto[]>;
    /** Insert or update a tokens */
    Upsert(body: Interfaces.TokenDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.TokenDto[]>;
    /** Deletes the passed tokens */
    Delete(body: Interfaces.TokenDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the tokens by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TokenDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TokenDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TokensV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TokensV1Client>;
}
export declare class TopicsV1Client extends BaseClient {
    /** Adds a resource to a topic. The content and the file must be uploaded using multipart forms. */
    AddResource(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceLocatorDto>;
    /** Removes the selected resource from a topic. If the resource is no longer associated with anything the resource will be completely removed. */
    RemoveResource(TopicId?: number, ResourceId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Returns the resources (downloads etc.) associated with the specified lesson */
    ListResourcesByTypeAdmin(TopicId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourcesByTypeDto[]>;
    /** Returns the resources associated with the specified topic */
    ListResources(TopicId?: number, ShowAll?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ResourceLocatorDto[]>;
    /** Returns the information about t/he current topic and where it is in the workflow. If it isn't in the workflow then it puts it at stage 2 for triage by default. */
    GetWorkflowStatus(topicId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusInfoDto>;
    /** Updates the status of an item and if necessary creates a new item and returns the updated item to replace. */
    SetEditingStatus(body: Interfaces.SetTopicItemEditingStatusDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingDto>;
    /** Updates the specified topic's workflow step and based on that will execute specific functions. */
    UpdateWorkflowStep(body: Interfaces.UpdateWorkflowStepDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the topic workflow task */
    UpdateWorkflowTask(body: Interfaces.UpdateWorkflowTaskDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns all workflow assignees to the Topic. */
    ListAssignees(topicId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TopicWorkflowAssigneesDto[]>;
    /** Updates the workflow assignments for a given Topic */
    UpdateAssignees(body: Interfaces.UpdateTopicWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List items by topic id */
    ListItemsByTopicId(topicId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ContentItemDto[]>;
    /** Get the specified translation */
    GetTranslation(topicId: number, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TopicTranslationDto>;
    /** Updates the specified translation */
    UpdateTranslation(body: Interfaces.TopicTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Delete the specified translation */
    DeleteTranslation(body: Interfaces.TopicTranslationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the items for the Topic for editing. */
    GetStructureForEditing(topicId: number, showOnlyCadlearningVersions?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.CourseStructureForEditingDto[]>;
    /** Updates the specified topic's structure with any changes from the user. All items must be included. */
    UpdateTopicStructure(body: Interfaces.UpdateTopicStructureDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists lesson with questions */
    ListLessonQuestions(topicId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.LessonWithQuestionsDto[]>;
    /** Edit Introduction */
    EditIntroduction(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Edit Conclusion */
    EditConclusion(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.SharepointFileDetailsDto>;
    /** Get Admin version of the topic */
    GetAdmin(Id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TopicAdminDto>;
    /** Adds a new lesson to the existing topic. */
    CreateLesson(body: Interfaces.CreateTopicLessonDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CourseStructureForEditingDto>;
    /** Returns a list of syndicated lessons for the given topic */
    ListSyndicatedLessons(topicId?: number, organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** Lists the syndications for the given topic */
    ListSyndications(topicId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TopicSyndicationDto>>;
    /** Updates the topic's syndications */
    UpdateSyndications(body: Interfaces.UpdateTopicSyndicationsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.TopicSyndicationDto[]>;
    /** Lists the syndication providers for the given topic */
    ListSyndicationProviders(topicId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TopicSyndicationProviderDto>>;
    /** Updates the topic's syndication providers */
    UpdateSyndicationProviders(body: Interfaces.UpdateTopicSyndicationProvidersDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.TopicSyndicationProviderDto[]>;
    /** Creates a Custom Topic */
    CreateCustomTopic(body: Interfaces.CreateCustomTopicDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ShortContentDto>;
    /** Insert or update a topics */
    Upsert(body: Interfaces.TopicDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.TopicDto[]>;
    /** Deletes the passed topics */
    Delete(body: Interfaces.TopicDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the topics by the passed ids. */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Publish Topic */
    PublishTopic(body: Interfaces.PublishTopicDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the tasks in project management related to the topic */
    ListProjectManagementTasks(TopicId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProjectManagementIssueDto>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TopicDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TopicDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TopicsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TopicsV1Client>;
}
export declare class UsersV1Client extends BaseClient {
    /** Creates a data retrieval or removal request */
    CreateDataRequest(body: Interfaces.UserDataRequestWithResourcesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserDataRequestDto>;
    /** Approves a data retrieval or removal request */
    ApproveDataRequest(RequestId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Rejects a data retrieval or removal request */
    RejectDataRequest(body: Interfaces.UserDataRequestRejectDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Creates a data retrieval or removal request */
    DeleteDataRequest(RequestId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets current user data retrieval or removal requests */
    GetUserDataRequestsWithDocuments(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDataRequestWithResourcesDto[]>;
    /** Gets a data request */
    GetUserDataRequestWithDocuments(requestId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDataRequestWithResourcesDto>;
    /** Lists data requests */
    ListUserDataRequests(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserDataRequestWithResourcesDto>>;
    /** Attaches zip to user data request and also downloads. */
    AttachActivityToUserRequest(userRequestId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Removes the selected resource from a user request document. */
    RemoveUserRequestDocument(RequestId?: number, DocumentId?: number, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a resource to a course. The resource must still be uploaded. */
    AddResourceToUserDataRequest(body: Interfaces.FileUploadWithParentDetailsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ResourceDto>;
    /** Download the document specified. */
    DownloadUserRequestDocument(RequestId?: number, DocumentId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Set's the current user's default discipline id */
    SetDisciplines(body: Interfaces.SetDisciplinesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Adds a discipline to a user */
    UpsertDiscipline(body: Interfaces.UserDisciplineDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Removes a user discipline */
    RemoveDiscipline(userId?: number, disciplineId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Removes a user Job */
    RemoveJob(userId?: number, userJobId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Lists users selected disciplines, by discipline */
    ListSelectedUserDisciplines(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineWithProductsDto[]>;
    /** Gets a users earned achievements for a particular organization */
    GetEarnedGamificationAwards(userId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.GamificationUserEarnedDto>;
    /** Gets if Achievements are ready for display by the user. */
    AchievementsReady(userId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets the user's jobs and status including disciplines and medallions. */
    JobStatus(userId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WhatsNextJobDto[]>;
    /** Progress Stats */
    ProgressStats(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserProgressStatsDto>;
    /** Progress */
    Progress(userId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WhatsNextDisciplineDto[]>;
    /** Gets the discipline learning path in the form of a Discipline first tree */
    GetLearningPath(userId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineLearningPathDto[]>;
    /** Gets the user's learning path */
    YourPath(userId: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.BadgeLearningPathDto[]>;
    /** Gets the Average Scores between the user, their organization, and the greater industry for the users goals */
    GetDisciplineAverageScores(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.DisciplineAverageScoresDto>;
    /** Gets the Average Scores between the user, their organization, and the greater industry for the users jobs */
    GetJobAverageScores(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.JobAverageScoresDto>;
    /** Return the Identity's To-do */
    WhatsNext(userId?: number, languageCode?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WhatsNextDto[]>;
    /** Sets the current user's active organization */
    SetOrganization(body: Interfaces.SetOrganizationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Creates a Permission Request */
    ListPermissions(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationPermissionsDto[]>;
    /** Gets a list of all of the organizations that a user is assigned to */
    ListOrganizations(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationDto[]>;
    /** Gets the current organizational message for the current user their selected organization */
    GetOrganizationalMessage(willHandleError?: boolean, withCredentials?: boolean): Promise<string>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    InsertOrUpdateUserAndOrganizationDetails(body: Interfaces.OrgUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrgUserDto>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    UpsertUserAndOrganizationDetails(body: Interfaces.OrgUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrgUserDto>;
    /** Has the user logging in accepted the terms of agreement */
    ClearSSOLogins(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    InsertOrUpdateUserAndOrganizationDetailsWithOrganization(body: Interfaces.OrgUserWithOrganizationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrgUserDto>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    UpsertUserAndOrganizationDetailsWithOrganization(body: Interfaces.OrgUserWithOrganizationDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.OrgUserDto>;
    /** Gets the organizational user information */
    GetUserAndOrganizationDetailsWithOrganization(userId: number, organizationId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrgUserDto>;
    /** Returns a list of users for the given organization */
    ListByOrganizationId(organizationId?: number, active?: boolean, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserWithRolesDto>>;
    /** Gets the organizational user information */
    GetProspectOrgUserDetails(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProspectOrgUserDto>;
    /** Lists Permission Requests */
    ListPermissionRequests(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationPermissionsDto[]>;
    /** Resumes a Pre-Hire assessment */
    ResumePreHireAssessment(code?: string, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Completes the assessment pre-hire process */
    CompleteAssessmentInvite(body: Interfaces.CompleteAssessmentInviteDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Returns the Users that are part of the specified organization and roles */
    GetUsersByRolesAndOrganization(organizationId: number, roleId: number[], willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDto[]>;
    /** Submits the conversation's question and answer for review */
    SubmitConversationQuestionAnswer(body: Interfaces.QConversationQuestionAnswerDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns a bot conversation */
    GetConversation(id: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QConversationStateDto>;
    /** List the user's custom reports */
    ListReports(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserReportDto>>;
    /** List the user's custom reports */
    ListCustomReports(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserReportDto>>;
    /** Returns a Identity report for editing */
    GetReport(id: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserReportDto>;
    /** Returns a Identity report for editing */
    GetSavedReport(reportName: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserReportDto>;
    /** Returns a Identity report for editing */
    GetCustomReport(reportName: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserReportDto>;
    /** Updates or Inserts the given Identity Report */
    UpsertReport(body: Interfaces.UserReportDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserReportDto>;
    /** Deletes the given Identity Report by the Id of the report */
    DeleteReportById(id?: string, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Requests access to the portal associated with the specified email address */
    RequestAccess(body: Interfaces.RequestAccessDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Allows password reset if a user cannot log in. */
    RequestResetPassword(body: Interfaces.RequestResetPasswordDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Complete the password reset process */
    ResetPassword(body: Interfaces.ResetPasswordDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Completes the request access verification process */
    VerifyRequestAccess(body: Interfaces.VerifyRequestAccessDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Circumvents the url process and simply grants a code */
    RequestVerifyEduWithCode(body: Interfaces.RequestVerifyEduDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /**  */
    AddEduSubscriptionToUser(body: Interfaces.EduAddSubscriptionRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.EduAddSubscriptionResponseDto>;
    /** Adds a trial to a given user */
    AddTrialToUser(body: Interfaces.UserAddTrialRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserAddTrialResponseDto>;
    /** Adds a Subscription to the user */
    AddSubscriptionToUser(body: Interfaces.UserAddSubscriptionRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserAddSubscriptionResponseDto>;
    /**  */
    AddEduSubscriptionPaymentToUser(body: Interfaces.EduSubscriptionPaymentRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.EduAddSubscriptionResponseDto>;
    /** Adds a Subscription to the user */
    AddSubscriptionTokenToUser(body: Interfaces.UserAddTokenSubscriptionRequestDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserAddSubscriptionResponseDto>;
    /** Lists all users with administrative information */
    AdminList(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.AdminUserDto>>;
    /** Gets the specified user with administrative information */
    AdminGet(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AdminUserDto>;
    /** Inserts or updates an organization with administrative information. */
    AdminUpsert(body: Interfaces.AdminUserDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.AdminUserDto[]>;
    /** Request the rights information for the specified lessons. */
    RequestLessonRights(body: Interfaces.RequestLessonRightsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<string>;
    /** Sends an email to one or more users */
    AdminSendEmail(body: Interfaces.SendEmailDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists all of the jobs under the Identity. */
    ListJobs(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserJobDto>>;
    /** Updates the user's jobs */
    UpdateJobs(body: Interfaces.UpdateUserJobsDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserJobDto[]>;
    /** Updates the user's jobs */
    UpsertJob(body: Interfaces.UserJobDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserJobDto>;
    /** Returns a list of roles for the given user */
    ListUserRoles(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrganizationUserRoleDto[]>;
    /** Assigns the specified roles to the user. All existing roles if not included will be removed. */
    AssignRolesToUser(body: Interfaces.AssignRolesToUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Returns the current tasks of the user specified. */
    GetUnclaimedQuestions(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.QuestionDto[]>;
    /** Returns the current tasks of the user specified. */
    GetCurrentAssignments(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssignmentDto[]>;
    /** Returns the current tasks of the user specified. */
    GetSMEContractorAssignments(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.AssignmentDto[]>;
    /** Lists all courses that the user is assigned to for production */
    ListCoursesInProcess(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Lists the recent CMS Activity by the user */
    ListCMSRecentActivity(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ShortContentDto>>;
    /** Report a translation error */
    ReportTranslationError(body: Interfaces.ReportTranslationErrorDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists reported translation errors */
    ListTranslationErrors(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.TranslationErrorDto>>;
    /** Lists reported translation errors */
    RemoveTranslationError(body: Interfaces.TranslationErrorDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Allows a user to change their password */
    ChangePassword(body: Interfaces.ChangePasswordDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists the users saved product preferences */
    ListUserProductPreferences(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ProductVersionCoursePreferenceDto[]>;
    /** Updates all currently logged in user's product version and course preferences */
    UpdateProductVersionCoursePreferences(body: Interfaces.UpdateProductVersionCoursePreferencesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Lists all stored payment credentials for the user */
    ListPaymentCredentials(userId: number, showAdmin?: boolean, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.StoredPaymentCredentialDto[]>;
    /** Lists a users email preferences */
    ListEmailPreferences(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserSubscriptionDto[]>;
    /** Updates a users email preferences */
    UpdateEmailPreferences(body: Interfaces.UpdateUserSubscriptionDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Gets the organizational user information */
    GetUserAndOrganizationDetails(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.OrgUserDto>;
    /** Allows administrators (only) to force a password change for a user. */
    AdminChangePassword(body: Interfaces.AdminChangePasswordDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Resets a user's password and allows them to go to the site to reset their password. */
    AdminResetPassword(body: Interfaces.AdminResetPassword, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    ListProspectContacts(organizationId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ContactDto>>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    InsertOrUpdateUserAndProspectUserDetails(body: Interfaces.ProspectOrgUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProspectOrgUserDto>;
    /** Inserts or updates a new or existing users into the current user's managing organization */
    UpsertUserAndProspectUserDetails(body: Interfaces.ProspectOrgUserDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.ProspectOrgUserDto>;
    /** Returns if the user has already had a trial on their account. */
    HasUserHadTrial(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Set user's Language */
    SetLanguage(body: Interfaces.SetLanguageDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Set's the current user's default project id */
    SetProject(body: Interfaces.SetProjectDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Updates the specified user's availability for expert escalation */
    UpdateAvailability(body: Interfaces.UserUpdateAvailabilityDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** Return if the current user owns the specified product and version */
    GetProductVersionOwnership(versionId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<boolean>;
    /** Updates the currently logged in user's Product/Version/Course preferences */
    UpdateProductVersionCoursePreference(body: Interfaces.UpdateProductVersionCoursePreferenceDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /**  */
    GetExpiredUserEntitlements(userId: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ExpiredUserEntitlementDto[]>;
    /** Returns all products suggested publicly if the user isn't logged in. */
    GetPublicSuggestedProducts(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserSuggestedProductsDto[]>;
    /** Returns the suggested content for the home page Question Library */
    GetSuggestedContent(userId?: number, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserSuggestedContentDto[]>;
    /** Returns suggested products in the order they should be displayed. */
    GetSuggestedProducts(userId?: number, showAll?: boolean, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserSuggestedProductsDto[]>;
    /** Returns suggested products in the order they should be displayed. */
    GetSuggestedProductsAdmin(userId?: number, showAll?: boolean, organizationId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserSuggestedProductsDto[]>;
    /** List Projects */
    ListProjects(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.PageableResponse<Interfaces.ProjectDto>>;
    /** Returns the most recent courses viewed by the current user */
    GetRecentActivity(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortLessonWithCoursesDto[]>;
    /**  */
    CheckForNotifications(willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Has the user logging in accepted the terms of agreement at the current time */
    AcceptTerms(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAcceptedTermsDto>;
    /** Has the user logging in accepted the terms of agreement */
    HasAcceptedTerms(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserAcceptedTermsDto>;
    /** Reports a command usage in the software. */
    GetCommandContentCount(body: Interfaces.PluginNotifyPageDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<number>;
    /** Report a page view from a user */
    ReportPage(body: Interfaces.PluginNotifyPageDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CommandNotificationDto>;
    /** Report a page view from a user */
    ReportPageCommand(body: Interfaces.PluginNotifyPageCommandDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CommandNotificationDto>;
    /** Reports a command usage in the software. */
    ReportCommand(body: Interfaces.PluginNotifyCommandDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.CommandNotificationDto>;
    /** Gets the user by username */
    GetUserByName(username: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDto>;
    /** Lists addresses by user id */
    ListAddresses(userId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserAddressDto>>;
    /** Update Identity Addresses */
    UpdateAddresses(body: Interfaces.UpdateUserAddressesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserAddressDto[]>;
    /** Removes a user by encryption */
    RemoveByEncryption(UserId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Gets Users recommended lessons based on selected disciplines */
    GetRecommendedLessons(userId?: number, badgeId?: number, medallionId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.LessonDto>>;
    /** Lists new Question since Last Seen. Will return a maximum of 200 results ordered descending by updated date. */
    NewContentSinceLastSeen(userId?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.ShortLessonWithCoursesDto[]>;
    /** Gets a specific Atom based on it's Id. */
    Get(id: number, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.UserDto>;
    /** Returns a list of items */
    List(body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.UserDto>>;
    /** Inserts or Updates the dtos passed. */
    Upsert(body: Interfaces.UserDto[], willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<Interfaces.UserDto[]>;
    /** Deletes the dto by Id */
    DeleteByIds(id?: number, willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    /** Deletes the dtos */
    Delete(body: Interfaces.UserDto[], willHandleError?: boolean, withCredentials?: boolean): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UsersV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UsersV1Client>;
}
export declare class WorkflowsV1Client extends BaseClient {
    /** Updates the workflow assignments for a given translation */
    UpdateTranslationAssignees(body: Interfaces.UpdateTranslationWorkflowAssigneesDto, willHandleError?: boolean, withCredentials?: boolean, progress?: (progress: number) => void): Promise<void>;
    /** List the assignees to the given translation */
    ListAssignees(parentId: number, parentType: Enums.ContentItemTypes, languageCode: string, willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.TranslationWorkflowAssigneeDto[]>;
    /** List All history for the item controlled by workflow */
    ListHistoryByItem(workflowId?: number, itemId?: number, languageCode?: string, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.WorkflowHistoryDto>>;
    /** Get a task in the workflow status */
    GetTaskStatus(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowStatusDetailsDto[]>;
    /** Get the workload report by users */
    GetWorkloadByUser(willHandleError?: boolean, withCredentials?: boolean): Promise<Interfaces.WorkflowWorkLoadByUserDto[]>;
    /** List workflow steps */
    ListWorkflowSteps(workflowId?: number, body?: Interfaces.LoadCriteria | null, willHandleError?: boolean): Promise<Interfaces.PageableResponse<Interfaces.WorkFlowStepDto>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<WorkflowsV1Client, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WorkflowsV1Client>;
}
//# sourceMappingURL=client.d.ts.map