import { FormArray, FormGroup, FormControl, FormBuilder } from '@angular/forms';
import * as Interfaces from 'cadlearning.dto/lib/interfaces';
import * as Enums from 'cadlearning.dto/lib/enums';
/** Interface for a form from a AcceptQuoteDto*/
export interface IAcceptQuoteDtoForm {
    /** Quote being accepted */
    QuoteId: FormControl<number | null>;
}
/**
/* Generates a form from a AcceptQuoteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AcceptQuoteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAcceptQuoteDtoForm(fb: FormBuilder, dto?: Interfaces.AcceptQuoteDto | null): FormGroup<IAcceptQuoteDtoForm>;
/** Interface for a form from a ActivityFilterDataDto*/
export interface IActivityFilterDataDtoForm {
    /** Products and Versions available to filter by */
    ProductAndVersions: FormArray<FormGroup<IProductVersionDtoForm>>;
    /** Projects available to filter by */
    Projects: FormArray<FormGroup<IInt32NameValueDtoForm>>;
    /** Play lists available to filter by */
    PlayLists: FormArray<FormGroup<IInt32NameValueDtoForm>>;
    /** Courses available to filter by */
    Courses: FormArray<FormGroup<IInt32NameValueDtoForm>>;
    /** Organizations available to filter by */
    Organizations: FormArray<FormGroup<IInt32NameValueDtoForm>>;
}
/**
/* Generates a form from a ActivityFilterDataDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ActivityFilterDataDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetActivityFilterDataDtoForm(fb: FormBuilder, dto?: Interfaces.ActivityFilterDataDto | null): FormGroup<IActivityFilterDataDtoForm>;
/** Interface for a form from a AddAssessmentToCourseDto*/
export interface IAddAssessmentToCourseDtoForm {
    /** The course to add the assessment to */
    CourseId: FormControl<number | null>;
    /** The assessment to add */
    AssessmentId: FormControl<number | null>;
}
/**
/* Generates a form from a AddAssessmentToCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddAssessmentToCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddAssessmentToCourseDtoForm(fb: FormBuilder, dto?: Interfaces.AddAssessmentToCourseDto | null): FormGroup<IAddAssessmentToCourseDtoForm>;
/** Interface for a form from a AddBotCommunicationDto*/
export interface IAddBotCommunicationDtoForm {
    /** The Id of the existing conversation to contribute to or null if a new conversation */
    Id: FormControl<string | null>;
    /** The communication to add */
    Content: FormControl<string | null>;
    /** Provide context to the question like "I'm working in Revit 2023" */
    Context: FormControl<string | null>;
}
/**
/* Generates a form from a AddBotCommunicationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddBotCommunicationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddBotCommunicationDtoForm(fb: FormBuilder, dto?: Interfaces.AddBotCommunicationDto | null): FormGroup<IAddBotCommunicationDtoForm>;
/** Interface for a form from a AddCaptionsToVideoDto*/
export interface IAddCaptionsToVideoDtoForm {
    /** Video Id */
    VideoId: FormControl<number | null>;
    /** Caption Resource Ids */
    CaptionResourceIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a AddCaptionsToVideoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddCaptionsToVideoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddCaptionsToVideoDtoForm(fb: FormBuilder, dto?: Interfaces.AddCaptionsToVideoDto | null): FormGroup<IAddCaptionsToVideoDtoForm>;
/** Interface for a form from a AddIndividualSubscriptionToPartnerDto*/
export interface IAddIndividualSubscriptionToPartnerDtoForm {
    /** The partner id */
    PartnerId: FormControl<number | null>;
    /** The sku adding to the entitlement */
    SKU: FormControl<string | null>;
    /** The user id to add the subscription to. If null, it will create the user based on other fields. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** For manually setting an ends on date. (Admin only). */
    EndsOn: FormControl<Date | null>;
}
/**
/* Generates a form from a AddIndividualSubscriptionToPartnerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddIndividualSubscriptionToPartnerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddIndividualSubscriptionToPartnerDtoForm(fb: FormBuilder, dto?: Interfaces.AddIndividualSubscriptionToPartnerDto | null): FormGroup<IAddIndividualSubscriptionToPartnerDtoForm>;
/** Interface for a form from a AddIndividualSubscriptionToPartnerResultDto*/
export interface IAddIndividualSubscriptionToPartnerResultDtoForm {
    /** Indicates success */
    Success: FormControl<boolean | null>;
    /** User Subscription Creation Result Codes */
    Result: FormControl<Enums.UserSubscriptionCreationResultCodes | null>;
    /** Error field, if operation was unsuccessful will be shown here. */
    Error: FormControl<string | null>;
    /** The rolling invoice id */
    InvoiceId: FormControl<number | null>;
}
/**
/* Generates a form from a AddIndividualSubscriptionToPartnerResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddIndividualSubscriptionToPartnerResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddIndividualSubscriptionToPartnerResultDtoForm(fb: FormBuilder, dto?: Interfaces.AddIndividualSubscriptionToPartnerResultDto | null): FormGroup<IAddIndividualSubscriptionToPartnerResultDtoForm>;
/** Interface for a form from a AddLinkDto*/
export interface IAddLinkDtoForm {
    /** Parent Id */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** Lesson */
    Text: FormControl<string | null>;
    /** Link */
    Link: FormControl<string | null>;
}
/**
/* Generates a form from a AddLinkDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddLinkDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddLinkDtoForm(fb: FormBuilder, dto?: Interfaces.AddLinkDto | null): FormGroup<IAddLinkDtoForm>;
/** Interface for a form from a AddPartnerOrganizationSubscriptionDto*/
export interface IAddPartnerOrganizationSubscriptionDtoForm {
    /** The organization which to add the subscription. If this is null then the other fields for the user must be filled in. */
    OrganizationId: FormControl<number | null>;
    /** The User which to add the subscription. If this is null then the other fields for the user must be filled in. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Email Address */
    ConfirmEmail: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** The SKU to use for the trial */
    SKU: FormControl<string | null>;
    /** Reseller Id. Used for setting associated organization */
    PartnerId: FormControl<number | null>;
    /** Organization Lesson */
    OrganizationName: FormControl<string | null>;
    /** Organization Size */
    OrganizationSize: FormControl<number | null>;
    /** Organization Domain */
    OrganizationDomain: FormControl<string | null>;
    /** Entitlement Quantity */
    EntitlementQuantity: FormControl<number | null>;
    /** The added users */
    Users: FormArray<FormGroup<IUserDtoForm>>;
    /** Stored billing address for payments */
    BillingAddressId: FormControl<number | null>;
    /** Stored payment id */
    StoredPaymentId: FormControl<number | null>;
}
/**
/* Generates a form from a AddPartnerOrganizationSubscriptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddPartnerOrganizationSubscriptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddPartnerOrganizationSubscriptionDtoForm(fb: FormBuilder, dto?: Interfaces.AddPartnerOrganizationSubscriptionDto | null): FormGroup<IAddPartnerOrganizationSubscriptionDtoForm>;
/** Interface for a form from a AddRemoveQuestionFromLessonDto*/
export interface IAddRemoveQuestionFromLessonDtoForm {
    /** The lesson to remove */
    LessonId: FormControl<number | null>;
    /** The Question to remove */
    QuestionId: FormControl<number | null>;
}
/**
/* Generates a form from a AddRemoveQuestionFromLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddRemoveQuestionFromLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddRemoveQuestionFromLessonDtoForm(fb: FormBuilder, dto?: Interfaces.AddRemoveQuestionFromLessonDto | null): FormGroup<IAddRemoveQuestionFromLessonDtoForm>;
/** Interface for a form from a AddStoredPaymentCredentialDto*/
export interface IAddStoredPaymentCredentialDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Payment Method Id */
    PaymentMethodId: FormControl<number | null>;
    /** Payment Method */
    PaymentMethod: FormControl<string | null>;
    /** Organization Id (null if attached to a user) */
    OrganizationId: FormControl<number | null>;
    /** Organization (null if attached to a user) */
    Organization: FormControl<string | null>;
    /** User Id (null if attached to an organization) */
    UserId: FormControl<number | null>;
    /** User (null if attached to an organization) */
    User: FormControl<string | null>;
    /** The reference number with the processor used to make a payment etc. with the credentials */
    ProcessorReferenceNumber: FormControl<string | null>;
    /** Merchant Payment Profile Id */
    SubProcessorReferenceNumber: FormControl<string | null>;
    /** Card or Account Holder Lesson */
    CardHolderName: FormControl<string | null>;
    /** The masked identifier (either card # or Account # masked) */
    MaskedIdentifier: FormControl<string | null>;
    /** The expiry year if any */
    ExpiryYear: FormControl<number | null>;
    /** The expiry month if any */
    ExpiryMonth: FormControl<number | null>;
    /** Billing Address Id */
    BillingAddressId: FormControl<number | null>;
    /** Is stored credential deleted */
    Deleted: FormControl<boolean | null>;
    /** Contact Types */
    ContactType: FormControl<Enums.ContactTypes | null>;
    /** The Contact Id associated with the stored credentials */
    ContactId: FormControl<number | null>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
}
/**
/* Generates a form from a AddStoredPaymentCredentialDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddStoredPaymentCredentialDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddStoredPaymentCredentialDtoForm(fb: FormBuilder, dto?: Interfaces.AddStoredPaymentCredentialDto | null): FormGroup<IAddStoredPaymentCredentialDtoForm>;
/** Interface for a form from a AddVersionLessonDto*/
export interface IAddVersionLessonDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Version Lesson Status */
    Status: FormControl<Enums.VersionLessonStatus | null>;
}
/**
/* Generates a form from a AddVersionLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddVersionLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddVersionLessonDtoForm(fb: FormBuilder, dto?: Interfaces.AddVersionLessonDto | null): FormGroup<IAddVersionLessonDtoForm>;
/** Interface for a form from a AddressBaseDto*/
export interface IAddressBaseDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Is the address the default for the user */
    Default: FormControl<boolean | null>;
    /** Is the address the billing address for the user */
    Billing: FormControl<boolean | null>;
    /** Is the address the shipping address for the user */
    Shipping: FormControl<boolean | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal/Zip Code */
    PostalCode: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
}
/**
/* Generates a form from a AddressBaseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AddressBaseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAddressBaseDtoForm(fb: FormBuilder, dto?: Interfaces.AddressBaseDto | null): FormGroup<IAddressBaseDtoForm>;
/** Interface for a form from a AdminChangePasswordDto*/
export interface IAdminChangePasswordDtoForm {
    /** The user to change */
    UserId: FormControl<number | null>;
    /** The new password */
    Password: FormControl<string | null>;
    /** Confirmation of the new password */
    ConfirmPassword: FormControl<string | null>;
}
/**
/* Generates a form from a AdminChangePasswordDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AdminChangePasswordDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAdminChangePasswordDtoForm(fb: FormBuilder, dto?: Interfaces.AdminChangePasswordDto | null): FormGroup<IAdminChangePasswordDtoForm>;
/** Interface for a form from a AdminOrganizationDto*/
export interface IAdminOrganizationDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Is the organization an active customer */
    Active: FormControl<boolean | null>;
    /** When was the organization created */
    CreatedOn: FormControl<Date | null>;
    /** When was the organization updated */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags associated with the organization */
    Tags: FormControl<string | null>;
    /** Option to show only organization assessments */
    ShowOnlyOrgAssessments: FormControl<boolean | null>;
    /** Indicates whether or not the organization is a lead prospect for a partner */
    Lead: FormControl<boolean | null>;
    /** Sales Rep Id */
    SalesRepId: FormControl<number | null>;
    /** Partner */
    PartnerOrganizationId: FormControl<number | null>;
    /** Partner Organization */
    PartnerOrganization: FormControl<string | null>;
    /** Organization Answer Sharing Options */
    AnswerSharingOption: FormControl<Enums.OrganizationAnswerSharingOptions | null>;
    /** Organization Bot Escalation Rules */
    BotEscalationRule: FormControl<Enums.OrganizationBotEscalationRules | null>;
    /** Organization Types */
    Type: FormControl<Enums.OrganizationTypes | null>;
    /** Price List Id */
    PriceListId: FormControl<number | null>;
    /** Price List */
    PriceList: FormControl<string | null>;
    /** Billing Price List Id */
    BillingPriceListId: FormControl<number | null>;
    /** Billing Price List */
    BillingPriceList: FormControl<string | null>;
    /** Azure Subscription Id */
    AzureSubscriptionId: FormControl<string | null>;
    /** Azure Blob Storage Connection String */
    AzureBlobStorageConnectionString: FormControl<string | null>;
    /** Azure Media Services Client Id */
    AzureMediaServicesClientId: FormControl<string | null>;
    /** Azure Media Services Key */
    AzureMediaServicesKey: FormControl<string | null>;
    /** Azure Media Services Issuer */
    AzureMediaServicesIssuer: FormControl<string | null>;
    /** Azure Media Services Audience */
    AzureMediaServicesAudience: FormControl<string | null>;
    /** Media Services Endpoint */
    MediaServicesRestApiEndpoint: FormControl<string | null>;
    /** Azure Tenant Id */
    AzureTenantId: FormControl<string | null>;
    /** Azure Resource Group Lesson */
    AzureResourceGroupName: FormControl<string | null>;
    /** Desired Number of Users */
    DesiredNumberOfUsers: FormControl<number | null>;
    /** Use Bill As while processing credit cards */
    UseBillAs: FormControl<boolean | null>;
    /** RedVector's Organization Id */
    RedVectorOrganizationId: FormControl<string | null>;
    /** Whether or not an organization can sell resale items in Portal */
    CanSellResale: FormControl<boolean | null>;
    /** Automatically Assign Custom Question from Partners */
    AutomaticallyAssignCustomContent: FormControl<boolean | null>;
    /** Automatically Assign Accomplishments from Partners */
    AutomaticallyAssignAccomplishments: FormControl<boolean | null>;
    /** Tax Exemption Reasons */
    TaxExemptionReason: FormControl<Enums.TaxExemptionReasons | null>;
    /** Federal Id */
    FederalId: FormControl<string | null>;
    /** State Id */
    StateId: FormControl<string | null>;
    /** Local Id */
    LocalId: FormControl<string | null>;
    /** Partner Invoice Types */
    PartnerInvoiceType: FormControl<Enums.PartnerInvoiceType | null>;
    /** YouTube Client Id */
    YouTubeClientId: FormControl<string | null>;
    /** YouTube Client Secret */
    YouTubeClientSecret: FormControl<string | null>;
    /** YouTube Access Token */
    YouTubeAccessToken: FormControl<string | null>;
    /** YouTube One Time Auth Code for Offline Access */
    YouTubeAuthCode: FormControl<string | null>;
    /** YouTube User Id for Auth Code flow exchange */
    YouTubeUserId: FormControl<string | null>;
    /** Organization Partner Billing Type */
    BillingType: FormControl<Enums.PartnerBillingType | null>;
    /** Can sell CADLearning Question */
    CADLearningContent: FormControl<boolean | null>;
    /** Can Sell Bluebeam Question */
    BluebeamContent: FormControl<boolean | null>;
    /** Third Party Rest API Endpoint */
    ThirdPartyRestEndpoint: FormControl<string | null>;
    /** Client Secret for communicating with rest endpoint */
    ClientSecret: FormControl<string | null>;
    /** Union Type */
    UnionType: FormControl<string | null>;
    /** Url Prefix for Created Domains */
    UrlPrefix: FormControl<string | null>;
    /** Sub Org Price List Id */
    SubOrgPriceListId: FormControl<number | null>;
    /** Sub Org Price List */
    SubOrgPriceList: FormControl<string | null>;
    /** Organization Types */
    SubOrgType: FormControl<Enums.OrganizationTypes | null>;
    /** Chart Types */
    ScoreSettings: FormControl<Enums.OrganizationScoreSettings | null>;
}
/**
/* Generates a form from a AdminOrganizationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AdminOrganizationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAdminOrganizationDtoForm(fb: FormBuilder, dto?: Interfaces.AdminOrganizationDto | null): FormGroup<IAdminOrganizationDtoForm>;
/** Interface for a form from a AdminResetPassword*/
export interface IAdminResetPasswordForm {
    /** The User Id to reset */
    UserId: FormControl<number | null>;
    /** The Url the user should be redirected to */
    ResetEntryUrl: FormControl<string | null>;
}
/**
/* Generates a form from a AdminResetPassword
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AdminResetPassword from which to create the form.
/* @returns FormGroup
 */
export declare function GetAdminResetPasswordForm(fb: FormBuilder, dto?: Interfaces.AdminResetPassword | null): FormGroup<IAdminResetPasswordForm>;
/** Interface for a form from a AdminUserDto*/
export interface IAdminUserDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** This is the Email Address - Required for Identity Framework */
    UserName: FormControl<string | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The user's full name */
    Name: FormControl<string | null>;
    /** The user's email */
    Email: FormControl<string | null>;
    /** Is the email address confirmed? */
    EmailConfirmed: FormControl<boolean | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Is the phone number confirmed? */
    PhoneNumberConfirmed: FormControl<boolean | null>;
    /** Is the user active? */
    Active: FormControl<boolean | null>;
    /** Creation Date */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** EduConfirmed */
    EduConfirmed: FormControl<boolean | null>;
    /** User Expert Bot Escalation Availabilities */
    ExpertBotEscalationAvailability: FormControl<Enums.UserExpertBotEscalationAvailabilities | null>;
    /** Available for Escalation */
    AvailableForEscalation: FormControl<boolean | null>;
    /** Users selected language */
    LanguageCode: FormControl<string | null>;
    /** Tax Exemption Reasons */
    TaxExemptionReason: FormControl<Enums.TaxExemptionReasons | null>;
}
/**
/* Generates a form from a AdminUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AdminUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAdminUserDtoForm(fb: FormBuilder, dto?: Interfaces.AdminUserDto | null): FormGroup<IAdminUserDtoForm>;
/** Interface for a form from a AggregateCriteria*/
export interface IAggregateCriteriaForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Aggregation: FormControl<Enums.Aggregations | null>;
}
/**
/* Generates a form from a AggregateCriteria
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AggregateCriteria from which to create the form.
/* @returns FormGroup
 */
export declare function GetAggregateCriteriaForm(fb: FormBuilder, dto?: Interfaces.AggregateCriteria | null): FormGroup<IAggregateCriteriaForm>;
/** Interface for a form from a AggregateResult*/
export interface IAggregateResultForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Aggregation: FormControl<Enums.Aggregations | null>;
    /**  */
    Result: FormControl<string | null>;
}
/**
/* Generates a form from a AggregateResult
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AggregateResult from which to create the form.
/* @returns FormGroup
 */
export declare function GetAggregateResultForm(fb: FormBuilder, dto?: Interfaces.AggregateResult | null): FormGroup<IAggregateResultForm>;
/** Interface for a form from a AnswerDisplayDto*/
export interface IAnswerDisplayDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The Answer */
    Text: FormControl<string | null>;
}
/**
/* Generates a form from a AnswerDisplayDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AnswerDisplayDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAnswerDisplayDtoForm(fb: FormBuilder, dto?: Interfaces.AnswerDisplayDto | null): FormGroup<IAnswerDisplayDtoForm>;
/** Interface for a form from a AnswerDto*/
export interface IAnswerDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Question linked to the Answer */
    QuestionId: FormControl<number | null>;
    /** Order of the answer on the question */
    Order: FormControl<number | null>;
    /** The Answer */
    Text: FormControl<string | null>;
    /** How much of a credit do they get based on the answer? */
    PercentCredit: FormControl<number | null>;
    /** Is the answer published? */
    Active: FormControl<boolean | null>;
    /** Answer is a premium answer that requires payment */
    Premium: FormControl<boolean | null>;
}
/**
/* Generates a form from a AnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.AnswerDto | null): FormGroup<IAnswerDtoForm>;
/** Interface for a form from a AnswerLessonDto*/
export interface IAnswerLessonDtoForm {
    /** Lesson ID */
    LessonId: FormControl<number | null>;
    /** Answer ID */
    AnswerId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a AnswerLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AnswerLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAnswerLessonDtoForm(fb: FormBuilder, dto?: Interfaces.AnswerLessonDto | null): FormGroup<IAnswerLessonDtoForm>;
/** Interface for a form from a AnswerQuestionDto*/
export interface IAnswerQuestionDtoForm {
    /** Question ID */
    QuestionId: FormControl<number | null>;
    /** Answer ID */
    AnswerId: FormControl<number | null>;
    /** Question Question */
    Question: FormControl<string | null>;
}
/**
/* Generates a form from a AnswerQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AnswerQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAnswerQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.AnswerQuestionDto | null): FormGroup<IAnswerQuestionDtoForm>;
/** Interface for a form from a AnswerTranslationDto*/
export interface IAnswerTranslationDtoForm {
    /** Answer Id */
    AnswerId: FormControl<number | null>;
    /** Answer in English */
    Answer: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Answer Text */
    AnswerText: FormControl<string | null>;
}
/**
/* Generates a form from a AnswerTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AnswerTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAnswerTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.AnswerTranslationDto | null): FormGroup<IAnswerTranslationDtoForm>;
/** Interface for a form from a AssessmentDistributionDto*/
export interface IAssessmentDistributionDtoForm {
    /** AssessmentId */
    AssessmenetId: FormControl<number | null>;
    /** Assessment Lesson */
    Assessment: FormControl<string | null>;
    /** Lower Value (lowest score) */
    Lower: FormControl<number | null>;
    /** Upper Value (highest score) */
    Upper: FormControl<number | null>;
    /** Middle Value */
    Median: FormControl<number | null>;
    /** Average */
    Mean: FormControl<number | null>;
    /** 1st Quartile */
    Q1: FormControl<number | null>;
    /** 2nd Quartile */
    Q2: FormControl<number | null>;
    /** 3rd Quartile */
    Q3: FormControl<number | null>;
    /** Bell Curve Data */
    Curve: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a AssessmentDistributionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentDistributionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentDistributionDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentDistributionDto | null): FormGroup<IAssessmentDistributionDtoForm>;
/** Interface for a form from a AssessmentDto*/
export interface IAssessmentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** An Enumeration of different types of assessments */
    Type: FormControl<Enums.AssessmentTypes | null>;
    /** The owner when creating a new custom assessment. If it's created from KAMS this will stay null. */
    OwningOrganizationId: FormControl<number | null>;
    /** Set to true to make the assessment a branching assessment */
    FollowBranch: FormControl<boolean | null>;
    /** Set to true to allow the user to go back a question */
    AllowBack: FormControl<boolean | null>;
    /** Is a dynamic assessment */
    Dynamic: FormControl<boolean | null>;
    /** Number of questions for a dynamic assessment */
    NumberOfQuestions: FormControl<number | null>;
    /** Determines if assessment can be changed after publishing */
    Static: FormControl<boolean | null>;
    /** The role attached to the assessment, if applicable */
    JobId: FormControl<number | null>;
}
/**
/* Generates a form from a AssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentDto | null): FormGroup<IAssessmentDtoForm>;
/** Interface for a form from a AssessmentDynamicItemsDto*/
export interface IAssessmentDynamicItemsDtoForm {
    /**  */
    CourseId: FormControl<number | null>;
    /**  */
    AssessmentId: FormControl<number | null>;
    /**  */
    ConceptIds: FormArray<FormControl<number | null>>;
    /**  */
    TopicIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a AssessmentDynamicItemsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentDynamicItemsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentDynamicItemsDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentDynamicItemsDto | null): FormGroup<IAssessmentDynamicItemsDtoForm>;
/** Interface for a form from a AssessmentInvitationDto*/
export interface IAssessmentInvitationDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Assessment ID */
    AssessmentId: FormControl<number | null>;
    /** User Assessment ID - The attached user assessment id that the user took */
    UserAssessmentId: FormControl<number | null>;
    /** Invitation User's Lesson */
    User: FormControl<string | null>;
    /** User */
    UserId: FormControl<number | null>;
    /** Invitation URL */
    InvitationURL: FormControl<string | null>;
    /** Invite Code */
    InviteCode: FormControl<string | null>;
    /** Status */
    Status: FormControl<string | null>;
    /** First Name */
    FirstName: FormControl<string | null>;
    /** Last Name */
    LastName: FormControl<string | null>;
    /** Email */
    Email: FormControl<string | null>;
}
/**
/* Generates a form from a AssessmentInvitationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentInvitationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentInvitationDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentInvitationDto | null): FormGroup<IAssessmentInvitationDtoForm>;
/** Interface for a form from a AssessmentReportCardDto*/
export interface IAssessmentReportCardDtoForm {
    /** Assessment Id */
    AssessmentId: FormControl<number | null>;
    /** Assessment Lesson */
    AssessmentName: FormControl<string | null>;
    /** All questions on the assessment */
    Questions: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Users who have taken it */
    Users: FormArray<FormGroup<IAssessmentReportCardUserDtoForm>>;
}
/**
/* Generates a form from a AssessmentReportCardDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentReportCardDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentReportCardDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentReportCardDto | null): FormGroup<IAssessmentReportCardDtoForm>;
/** Interface for a form from a AssessmentReportCardQuestionResultDto*/
export interface IAssessmentReportCardQuestionResultDtoForm {
    /** Question Id */
    QuestionId: FormControl<number | null>;
    /** Question */
    Question: FormControl<string | null>;
    /** Score */
    Score: FormControl<number | null>;
    /** Out Of */
    OutOf: FormControl<number | null>;
}
/**
/* Generates a form from a AssessmentReportCardQuestionResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentReportCardQuestionResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentReportCardQuestionResultDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentReportCardQuestionResultDto | null): FormGroup<IAssessmentReportCardQuestionResultDtoForm>;
/** Interface for a form from a AssessmentReportCardUserDto*/
export interface IAssessmentReportCardUserDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Question Results */
    QuestionResults: FormArray<FormGroup<IAssessmentReportCardQuestionResultDtoForm>>;
    /** Score */
    Score: FormControl<number | null>;
    /** Out Of */
    OutOf: FormControl<number | null>;
}
/**
/* Generates a form from a AssessmentReportCardUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentReportCardUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentReportCardUserDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentReportCardUserDto | null): FormGroup<IAssessmentReportCardUserDtoForm>;
/** Interface for a form from a AssessmentResultDto*/
export interface IAssessmentResultDtoForm {
    /** The User Assessment Id */
    Id: FormControl<number | null>;
    /** The name of the assessment */
    Name: FormControl<string | null>;
    /** Total possible score */
    OutOf: FormControl<number | null>;
    /** User's score */
    Score: FormControl<number | null>;
    /** User's total time taken to complete the assessment */
    TotalDuration: FormControl<string | null>;
    /** Results are from a pre-hire assessment */
    IsPreHire: FormControl<boolean | null>;
    /** Incorrect Answers */
    IncorrectAnswers: FormArray<FormGroup<IWrongAnswerDtoForm>>;
}
/**
/* Generates a form from a AssessmentResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentResultDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentResultDto | null): FormGroup<IAssessmentResultDtoForm>;
/** Interface for a form from a AssessmentStructureForEditingWithParentItems*/
export interface IAssessmentStructureForEditingWithParentItemsForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Itme that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Item Change status for KAMS */
    EditingStatus: FormControl<Enums.ItemChangeStatuses | null>;
    /** Is this a new feature? */
    NewFeature: FormControl<boolean | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Assignees for the step */
    Assignees: FormControl<string | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Labels */
    Labels: FormControl<string | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Number of Questions */
    Questions: FormControl<number | null>;
    /** Versions */
    Versions: FormControl<string | null>;
    /** Is Waiting For Customer Approval */
    IsWaitingForCustomerApproval: FormControl<boolean | null>;
    /** Is Waiting For Question Team */
    IsWaitingForContentTeam: FormControl<boolean | null>;
    /** Topics */
    Topics: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Lessons */
    Lessons: FormArray<FormGroup<ILessonWithCourseInfoDtoForm>>;
}
/**
/* Generates a form from a AssessmentStructureForEditingWithParentItems
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentStructureForEditingWithParentItems from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentStructureForEditingWithParentItemsForm(fb: FormBuilder, dto?: Interfaces.AssessmentStructureForEditingWithParentItems | null): FormGroup<IAssessmentStructureForEditingWithParentItemsForm>;
/** Interface for a form from a AssessmentTranslationDto*/
export interface IAssessmentTranslationDtoForm {
    /** Lesson Id */
    AssessmentId: FormControl<number | null>;
    /** Lesson Lesson */
    Assessment: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a AssessmentTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentTranslationDto | null): FormGroup<IAssessmentTranslationDtoForm>;
/** Interface for a form from a AssessmentUserHistoryDto*/
export interface IAssessmentUserHistoryDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User's Name */
    Name: FormControl<string | null>;
    /** Most Recent Score */
    MostRecentScore: FormControl<number | null>;
    /** Scores over time */
    Scores: FormArray<FormGroup<IAssessmentUserHistoryScoreDtoForm>>;
}
/**
/* Generates a form from a AssessmentUserHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentUserHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentUserHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentUserHistoryDto | null): FormGroup<IAssessmentUserHistoryDtoForm>;
/** Interface for a form from a AssessmentUserHistoryScoreDto*/
export interface IAssessmentUserHistoryScoreDtoForm {
    /** Completed On */
    CompletedOn: FormControl<Date | null>;
    /** Score */
    Score: FormControl<number | null>;
}
/**
/* Generates a form from a AssessmentUserHistoryScoreDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentUserHistoryScoreDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentUserHistoryScoreDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentUserHistoryScoreDto | null): FormGroup<IAssessmentUserHistoryScoreDtoForm>;
/** Interface for a form from a AssessmentWithParentsDto*/
export interface IAssessmentWithParentsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** An Enumeration of different types of assessments */
    Type: FormControl<Enums.AssessmentTypes | null>;
    /** The owner when creating a new custom assessment. If it's created from KAMS this will stay null. */
    OwningOrganizationId: FormControl<number | null>;
    /** Set to true to make the assessment a branching assessment */
    FollowBranch: FormControl<boolean | null>;
    /** Set to true to allow the user to go back a question */
    AllowBack: FormControl<boolean | null>;
    /** Is a dynamic assessment */
    Dynamic: FormControl<boolean | null>;
    /** Number of questions for a dynamic assessment */
    NumberOfQuestions: FormControl<number | null>;
    /** Determines if assessment can be changed after publishing */
    Static: FormControl<boolean | null>;
    /** The role attached to the assessment, if applicable */
    JobId: FormControl<number | null>;
    /** The parents of the assessment in a list */
    Parents: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a AssessmentWithParentsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentWithParentsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentWithParentsDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentWithParentsDto | null): FormGroup<IAssessmentWithParentsDtoForm>;
/** Interface for a form from a AssessmentWorkflowAssigneesDto*/
export interface IAssessmentWorkflowAssigneesDtoForm {
    /** Assessment Id */
    AssessmentId: FormControl<number | null>;
    /** Assessment Lesson */
    Assessment: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role Lesson */
    Role: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a AssessmentWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssessmentWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssessmentWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.AssessmentWorkflowAssigneesDto | null): FormGroup<IAssessmentWorkflowAssigneesDtoForm>;
/** Interface for a form from a AssignRolesToUserDto*/
export interface IAssignRolesToUserDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Roles to Assign */
    Roles: FormArray<FormGroup<IOrganizationUserRoleDtoForm>>;
}
/**
/* Generates a form from a AssignRolesToUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssignRolesToUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssignRolesToUserDtoForm(fb: FormBuilder, dto?: Interfaces.AssignRolesToUserDto | null): FormGroup<IAssignRolesToUserDtoForm>;
/** Interface for a form from a AssignmentDto*/
export interface IAssignmentDtoForm {
    /** Item Assigned To */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Parent */
    Parent: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Workflow Step */
    WorkflowStep: FormControl<string | null>;
    /** Has the workflow sent this item back for correction? */
    Returned: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
}
/**
/* Generates a form from a AssignmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AssignmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAssignmentDtoForm(fb: FormBuilder, dto?: Interfaces.AssignmentDto | null): FormGroup<IAssignmentDtoForm>;
/** Interface for a form from a AudienceDto*/
export interface IAudienceDtoForm {
    /** Identifier */
    Audience: FormControl<string | null>;
    /** Base 64 Secret for signing */
    Base64Secret: FormControl<string | null>;
    /** The name of the audience */
    ClientId: FormControl<string | null>;
}
/**
/* Generates a form from a AudienceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AudienceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAudienceDtoForm(fb: FormBuilder, dto?: Interfaces.AudienceDto | null): FormGroup<IAudienceDtoForm>;
/** Interface for a form from a AuthMethodAdminDto*/
export interface IAuthMethodAdminDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The domain that the AuthMethod exists on */
    OrganizationDomainId: FormControl<number | null>;
    /** The name of the Auth Method for display if not standard service */
    Name: FormControl<string | null>;
    /** Authorization Types supported by the domain */
    Type: FormControl<Enums.AuthTypes | null>;
    /** The Url to the endpoint if not a standardized service such as google or facebook */
    IdPUrl: FormControl<string | null>;
    /** Is the AuthMethod active? */
    Active: FormControl<boolean | null>;
    /** For oAuth 2 providers the Audience will be provided if applicable. For Azure Active Directory this is the Tennant */
    Audience: FormControl<string | null>;
    /** For oAuth 2 providers this will be provided. */
    ClientId: FormControl<string | null>;
    /** Azure Tenant Id */
    TenantId: FormControl<string | null>;
    /** Looks up Group Names for Azure SSO */
    LookUpGroupNames: FormControl<boolean | null>;
    /** The oAuth client secret if any */
    ClientSecret: FormControl<string | null>;
    /** Certificate Information */
    Certificate: FormControl<string | null>;
    /** Certificate Expiry Information */
    CertificateExpiresOn: FormControl<Date | null>;
    /** Controls if the auth method allows signing up automatically on login. */
    AutoSignUpOnLogin: FormControl<boolean | null>;
    /** Context used to make the request unique */
    Context: FormControl<string | null>;
}
/**
/* Generates a form from a AuthMethodAdminDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AuthMethodAdminDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAuthMethodAdminDtoForm(fb: FormBuilder, dto?: Interfaces.AuthMethodAdminDto | null): FormGroup<IAuthMethodAdminDtoForm>;
/** Interface for a form from a AuthMethodDto*/
export interface IAuthMethodDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The domain that the AuthMethod exists on */
    OrganizationDomainId: FormControl<number | null>;
    /** The name of the Auth Method for display if not standard service */
    Name: FormControl<string | null>;
    /** Authorization Types supported by the domain */
    Type: FormControl<Enums.AuthTypes | null>;
    /** The Url to the endpoint if not a standardized service such as google or facebook */
    IdPUrl: FormControl<string | null>;
    /** Is the AuthMethod active? */
    Active: FormControl<boolean | null>;
    /** For oAuth 2 providers the Audience will be provided if applicable. For Azure Active Directory this is the Tennant */
    Audience: FormControl<string | null>;
    /** For oAuth 2 providers this will be provided. */
    ClientId: FormControl<string | null>;
    /** Azure Tenant Id */
    TenantId: FormControl<string | null>;
    /** Looks up Group Names for Azure SSO */
    LookUpGroupNames: FormControl<boolean | null>;
}
/**
/* Generates a form from a AuthMethodDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original AuthMethodDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetAuthMethodDtoForm(fb: FormBuilder, dto?: Interfaces.AuthMethodDto | null): FormGroup<IAuthMethodDtoForm>;
/** Interface for a form from a BadgeDto*/
export interface IBadgeDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a BadgeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeDto | null): FormGroup<IBadgeDtoForm>;
/** Interface for a form from a BadgeGroupDto*/
export interface IBadgeGroupDtoForm {
    /** Badge id */
    BadgeId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Group */
    GroupId: FormControl<number | null>;
}
/**
/* Generates a form from a BadgeGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeGroupDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeGroupDto | null): FormGroup<IBadgeGroupDtoForm>;
/** Interface for a form from a BadgeHeaderLessonDto*/
export interface IBadgeHeaderLessonDtoForm {
    /** Badge id */
    BadgeId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Header Lesson Id */
    LessonId: FormControl<number | null>;
    /** Header Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a BadgeHeaderLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeHeaderLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeHeaderLessonDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeHeaderLessonDto | null): FormGroup<IBadgeHeaderLessonDtoForm>;
/** Interface for a form from a BadgeLearningPathDto*/
export interface IBadgeLearningPathDtoForm {
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Badge Lesson */
    Name: FormControl<string | null>;
    /** Badge Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Lessons */
    TotalLessons: FormControl<number | null>;
    /** Completed Lessons */
    TotalCompletedLessons: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Badge Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Remaining Lessons with Questions to complete */
    Lessons: FormArray<FormGroup<ILessonPathDtoForm>>;
    /** Medallions of which the badge is a part */
    ContributesToMedallions: FormArray<FormGroup<IMedallionPathDtoForm>>;
    /** Disciplines of which the badge is a part */
    ContributesToDisciplines: FormArray<FormGroup<IDisciplinePathDtoForm>>;
    /** Badge Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
}
/**
/* Generates a form from a BadgeLearningPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeLearningPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeLearningPathDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeLearningPathDto | null): FormGroup<IBadgeLearningPathDtoForm>;
/** Interface for a form from a BadgeLessonDto*/
export interface IBadgeLessonDtoForm {
    /** Lesson Id */
    Id: FormControl<number | null>;
    /** Lesson Lesson */
    Name: FormControl<string | null>;
    /** Lesson Length */
    Length: FormControl<number | null>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a BadgeLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeLessonDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeLessonDto | null): FormGroup<IBadgeLessonDtoForm>;
/** Interface for a form from a BadgeSyndicationProviderDto*/
export interface IBadgeSyndicationProviderDtoForm {
    /** Badge id */
    BadgeId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a BadgeSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeSyndicationProviderDto | null): FormGroup<IBadgeSyndicationProviderDtoForm>;
/** Interface for a form from a BadgeTranslationDto*/
export interface IBadgeTranslationDtoForm {
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a BadgeTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeTranslationDto | null): FormGroup<IBadgeTranslationDtoForm>;
/** Interface for a form from a BadgeUserEarnedDto*/
export interface IBadgeUserEarnedDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Earned On */
    EarnedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
}
/**
/* Generates a form from a BadgeUserEarnedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeUserEarnedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeUserEarnedDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeUserEarnedDto | null): FormGroup<IBadgeUserEarnedDtoForm>;
/** Interface for a form from a BadgeUserReportDto*/
export interface IBadgeUserReportDtoForm {
    /** User Lesson */
    Name: FormControl<string | null>;
    /** Date Achieved */
    DateAchieved: FormControl<Date | null>;
}
/**
/* Generates a form from a BadgeUserReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeUserReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeUserReportDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeUserReportDto | null): FormGroup<IBadgeUserReportDtoForm>;
/** Interface for a form from a BadgeWithUsersDto*/
export interface IBadgeWithUsersDtoForm {
    /** Badge Lesson */
    Name: FormControl<string | null>;
    /** Number of users achieved the badge */
    NumberOfUsersAchieved: FormControl<number | null>;
    /** Users that achieved the badge */
    Users: FormArray<FormGroup<IBadgeUserReportDtoForm>>;
}
/**
/* Generates a form from a BadgeWithUsersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BadgeWithUsersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBadgeWithUsersDtoForm(fb: FormBuilder, dto?: Interfaces.BadgeWithUsersDto | null): FormGroup<IBadgeWithUsersDtoForm>;
/** Interface for a form from a BotConversationDto*/
export interface IBotConversationDtoForm {
    /** Id of the conversation */
    Id: FormControl<string | null>;
    /** User */
    UserId: FormControl<number | null>;
    /** The organization that the user was logged in as when they were talking to the bot */
    OrganizationId: FormControl<number | null>;
    /** The Context of the conversation i.e. "I'm working in Revit 2023" */
    Context: FormControl<string | null>;
    /** The Product that is being used */
    ProductId: FormControl<number | null>;
    /** The version of the product being used */
    VersionId: FormControl<number | null>;
    /** When did the conversation start? */
    StartedOn: FormControl<Date | null>;
    /** When did it end if it is not still in progress? */
    EndedOn: FormControl<Date | null>;
    /** The elements of the conversation */
    Conversation: FormArray<FormGroup<IBotConversationElementDtoForm>>;
}
/**
/* Generates a form from a BotConversationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BotConversationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBotConversationDtoForm(fb: FormBuilder, dto?: Interfaces.BotConversationDto | null): FormGroup<IBotConversationDtoForm>;
/** Interface for a form from a BotConversationElementDto*/
export interface IBotConversationElementDtoForm {
    /** Who communicated */
    Source: FormControl<Enums.BotConversationSources | null>;
    /** What was the communication? */
    Content: FormControl<string | null>;
    /** When? */
    DateTime: FormControl<Date | null>;
}
/**
/* Generates a form from a BotConversationElementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BotConversationElementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBotConversationElementDtoForm(fb: FormBuilder, dto?: Interfaces.BotConversationElementDto | null): FormGroup<IBotConversationElementDtoForm>;
/** Interface for a form from a BotConversationRefDto*/
export interface IBotConversationRefDtoForm {
    /** Id of the conversation */
    Id: FormControl<string | null>;
    /** User */
    UserId: FormControl<number | null>;
    /** The organization that the user was logged in as when they were talking to the bot */
    OrganizationId: FormControl<number | null>;
    /** When did the conversation start? */
    StartedOn: FormControl<Date | null>;
    /** When did it end if it is not still in progress? */
    EndedOn: FormControl<Date | null>;
    /** The elements of the conversation */
    InitialQuestion: FormControl<string | null>;
}
/**
/* Generates a form from a BotConversationRefDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BotConversationRefDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBotConversationRefDtoForm(fb: FormBuilder, dto?: Interfaces.BotConversationRefDto | null): FormGroup<IBotConversationRefDtoForm>;
/** Interface for a form from a BotResponseDto*/
export interface IBotResponseDtoForm {
    /** Who communicated */
    Source: FormControl<Enums.BotConversationSources | null>;
    /** What was the communication? */
    Content: FormControl<string | null>;
    /** When? */
    DateTime: FormControl<Date | null>;
    /** The conversation Id that the response is for. */
    ConversationId: FormControl<string | null>;
}
/**
/* Generates a form from a BotResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BotResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBotResponseDtoForm(fb: FormBuilder, dto?: Interfaces.BotResponseDto | null): FormGroup<IBotResponseDtoForm>;
/** Interface for a form from a BulkCreateEntitlementsDto*/
export interface IBulkCreateEntitlementsDtoForm {
    /** Inventory Id */
    InventoryId: FormControl<number | null>;
    /** Inventory Item Id */
    InventoryItemId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Units */
    Units: FormControl<number | null>;
}
/**
/* Generates a form from a BulkCreateEntitlementsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original BulkCreateEntitlementsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetBulkCreateEntitlementsDtoForm(fb: FormBuilder, dto?: Interfaces.BulkCreateEntitlementsDto | null): FormGroup<IBulkCreateEntitlementsDtoForm>;
/** Interface for a form from a CampaignDripDto*/
export interface ICampaignDripDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Campaign Id */
    CampaignId: FormControl<number | null>;
    /** Campaign */
    Campaign: FormControl<string | null>;
    /** Subject */
    Subject: FormControl<string | null>;
    /** Units from Start */
    UnitsFromStart: FormControl<number | null>;
    /** Campaign Drip Units */
    UnitType: FormControl<Enums.CampaignDripUnits | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Release On */
    ReleaseOn: FormControl<Date | null>;
    /** Message */
    Message: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** PlayList Id */
    PlayListId: FormControl<number | null>;
    /** PlayList Lesson */
    PlayList: FormControl<string | null>;
}
/**
/* Generates a form from a CampaignDripDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CampaignDripDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCampaignDripDtoForm(fb: FormBuilder, dto?: Interfaces.CampaignDripDto | null): FormGroup<ICampaignDripDtoForm>;
/** Interface for a form from a CampaignDto*/
export interface ICampaignDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Campaign Types */
    CampaignType: FormControl<Enums.CampaignTypes | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** Owning Organization */
    OwningOrganization: FormControl<string | null>;
}
/**
/* Generates a form from a CampaignDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CampaignDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCampaignDtoForm(fb: FormBuilder, dto?: Interfaces.CampaignDto | null): FormGroup<ICampaignDtoForm>;
/** Interface for a form from a CampaignSubscriptionDto*/
export interface ICampaignSubscriptionDtoForm {
    /** Campaign Id */
    CampaignId: FormControl<number | null>;
    /** Campaign */
    Campaign: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** signed Up On */
    SignedUpOn: FormControl<Date | null>;
    /** Subscription Types */
    SubscriptionType: FormControl<Enums.SubscriptionTypes | null>;
}
/**
/* Generates a form from a CampaignSubscriptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CampaignSubscriptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCampaignSubscriptionDtoForm(fb: FormBuilder, dto?: Interfaces.CampaignSubscriptionDto | null): FormGroup<ICampaignSubscriptionDtoForm>;
/** Interface for a form from a CaptionDto*/
export interface ICaptionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** the video that the caption is associated with */
    VideoId: FormControl<number | null>;
    /** The language Code of the caption */
    LanguageCode: FormControl<string | null>;
    /** The full script in html format */
    Script: FormControl<string | null>;
    /** Any external link */
    ExternalId: FormControl<string | null>;
}
/**
/* Generates a form from a CaptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CaptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCaptionDtoForm(fb: FormBuilder, dto?: Interfaces.CaptionDto | null): FormGroup<ICaptionDtoForm>;
/** Interface for a form from a CaptionWithUrlDto*/
export interface ICaptionWithUrlDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** the video that the caption is associated with */
    VideoId: FormControl<number | null>;
    /** The language Code of the caption */
    LanguageCode: FormControl<string | null>;
    /** The full script in html format */
    Script: FormControl<string | null>;
    /** Any external link */
    ExternalId: FormControl<string | null>;
    /** Url to caption file */
    Url: FormControl<string | null>;
}
/**
/* Generates a form from a CaptionWithUrlDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CaptionWithUrlDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCaptionWithUrlDtoForm(fb: FormBuilder, dto?: Interfaces.CaptionWithUrlDto | null): FormGroup<ICaptionWithUrlDtoForm>;
/** Interface for a form from a ChangePasswordDto*/
export interface IChangePasswordDtoForm {
    /** The ID of the user to change. This should match the current user authentication and is used as a checksum. */
    UserId: FormControl<number | null>;
    /** The current password. This will be validated before the password can be changed. */
    CurrentPassword: FormControl<string | null>;
    /** The new password */
    Password: FormControl<string | null>;
    /** The password repeated for confirmation */
    ConfirmPassword: FormControl<string | null>;
}
/**
/* Generates a form from a ChangePasswordDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ChangePasswordDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetChangePasswordDtoForm(fb: FormBuilder, dto?: Interfaces.ChangePasswordDto | null): FormGroup<IChangePasswordDtoForm>;
/** Interface for a form from a ChartDetail*/
export interface IChartDetailForm {
    /** Chart Types */
    ChartType: FormControl<Enums.ChartTypes | null>;
    /**  */
    Axis: FormGroup<IGroupCriteriaForm>;
}
/**
/* Generates a form from a ChartDetail
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ChartDetail from which to create the form.
/* @returns FormGroup
 */
export declare function GetChartDetailForm(fb: FormBuilder, dto?: Interfaces.ChartDetail | null): FormGroup<IChartDetailForm>;
/** Interface for a form from a ChildResourceDto*/
export interface IChildResourceDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the resource */
    Name: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
}
/**
/* Generates a form from a ChildResourceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ChildResourceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetChildResourceDtoForm(fb: FormBuilder, dto?: Interfaces.ChildResourceDto | null): FormGroup<IChildResourceDtoForm>;
/** Interface for a form from a ChurnRateByDateDto*/
export interface IChurnRateByDateDtoForm {
    /** Date */
    Date: FormControl<Date | null>;
    /** Details */
    Details: FormArray<FormGroup<IChurnRateDtoForm>>;
}
/**
/* Generates a form from a ChurnRateByDateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ChurnRateByDateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetChurnRateByDateDtoForm(fb: FormBuilder, dto?: Interfaces.ChurnRateByDateDto | null): FormGroup<IChurnRateByDateDtoForm>;
/** Interface for a form from a ChurnRateDto*/
export interface IChurnRateDtoForm {
    /** Billing Recurring Periods */
    RecurringPeriod: FormControl<Enums.RecurringPeriods | null>;
    /** Inventory Item Types */
    InventoryType: FormControl<Enums.InventoryItemTypes | null>;
    /** Sku */
    SKU: FormControl<string | null>;
    /** Inventory */
    Inventory: FormControl<string | null>;
    /** Current Amount */
    CurrentValue: FormControl<number | null>;
    /** Current Count */
    CurrentCount: FormControl<number | null>;
    /** Previous Amount */
    PreviousValue: FormControl<number | null>;
    /** Previous Count */
    PreviousCount: FormControl<number | null>;
    /** Change in Amount */
    ValueDelta: FormControl<number | null>;
    /** Count Delta */
    CountDelta: FormControl<number | null>;
    /** Ended Count */
    EndedCount: FormControl<number | null>;
    /** Ended Amount */
    EndedValue: FormControl<number | null>;
    /** Started Count */
    StartedCount: FormControl<number | null>;
    /** Started Amount */
    StartedValue: FormControl<number | null>;
}
/**
/* Generates a form from a ChurnRateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ChurnRateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetChurnRateDtoForm(fb: FormBuilder, dto?: Interfaces.ChurnRateDto | null): FormGroup<IChurnRateDtoForm>;
/** Interface for a form from a ClientDto*/
export interface IClientDtoForm {
    /** Id */
    Id: FormControl<string | null>;
    /** Secret */
    Secret: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Application Types */
    ApplicationType: FormControl<Enums.ApplicationTypes | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Refresh token lifetime in seconds */
    RefreshTokenLifeTime: FormControl<number | null>;
    /** Allow Origin (Default is *) */
    AllowedOrigin: FormControl<string | null>;
    /** Release Version */
    ReleaseVersion: FormControl<string | null>;
    /** Beta Version */
    BetaVersion: FormControl<string | null>;
    /** Internal Version */
    InternalVersion: FormControl<string | null>;
}
/**
/* Generates a form from a ClientDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ClientDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetClientDtoForm(fb: FormBuilder, dto?: Interfaces.ClientDto | null): FormGroup<IClientDtoForm>;
/** Interface for a form from a ColumnDetail*/
export interface IColumnDetailForm {
    /** Field Lesson */
    FieldName: FormControl<string | null>;
    /** Order of column */
    Order: FormControl<number | null>;
    /** Is the column frozen while being placed in a grid */
    Frozen: FormControl<boolean | null>;
    /** Is the column visible? */
    Visible: FormControl<boolean | null>;
    /** Width */
    Width: FormControl<number | null>;
}
/**
/* Generates a form from a ColumnDetail
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ColumnDetail from which to create the form.
/* @returns FormGroup
 */
export declare function GetColumnDetailForm(fb: FormBuilder, dto?: Interfaces.ColumnDetail | null): FormGroup<IColumnDetailForm>;
/** Interface for a form from a CommandNotificationDto*/
export interface ICommandNotificationDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version Lesson */
    Version: FormControl<string | null>;
    /** Command */
    Command: FormControl<string | null>;
    /** Plugin Command Notification Types */
    NotificationType: FormControl<Enums.CommandNotificationTypes | null>;
    /** Lessons */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Suggested workflows */
    Workflows: FormArray<FormGroup<IShortCourseDtoForm>>;
}
/**
/* Generates a form from a CommandNotificationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CommandNotificationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCommandNotificationDtoForm(fb: FormBuilder, dto?: Interfaces.CommandNotificationDto | null): FormGroup<ICommandNotificationDtoForm>;
/** Interface for a form from a CompetenciesAchievedDto*/
export interface ICompetenciesAchievedDtoForm {
    /** Medallion Lesson */
    MedallionName: FormControl<string | null>;
    /** Number of Users With Medallion */
    NumberOfUsersWithMedallion: FormControl<number | null>;
    /** Comptencies Achieved History */
    History: FormGroup<ICompetenciesAchievedHistoryDtoForm>;
    /** Users with medallion and if achieved */
    Users: FormArray<FormGroup<ICompetenciesAchievedUserDtoForm>>;
}
/**
/* Generates a form from a CompetenciesAchievedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompetenciesAchievedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompetenciesAchievedDtoForm(fb: FormBuilder, dto?: Interfaces.CompetenciesAchievedDto | null): FormGroup<ICompetenciesAchievedDtoForm>;
/** Interface for a form from a CompetenciesAchievedHistoryDto*/
export interface ICompetenciesAchievedHistoryDtoForm {
    /** Date */
    Date: FormControl<Date | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
}
/**
/* Generates a form from a CompetenciesAchievedHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompetenciesAchievedHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompetenciesAchievedHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.CompetenciesAchievedHistoryDto | null): FormGroup<ICompetenciesAchievedHistoryDtoForm>;
/** Interface for a form from a CompetenciesAchievedUserDto*/
export interface ICompetenciesAchievedUserDtoForm {
    /** User Lesson */
    Name: FormControl<string | null>;
    /** Users achieved badges within medallion */
    Score: FormControl<number | null>;
    /** Total badges in medallion */
    OutOf: FormControl<number | null>;
    /** Date Achieved */
    DateAchieved: FormControl<Date | null>;
}
/**
/* Generates a form from a CompetenciesAchievedUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompetenciesAchievedUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompetenciesAchievedUserDtoForm(fb: FormBuilder, dto?: Interfaces.CompetenciesAchievedUserDto | null): FormGroup<ICompetenciesAchievedUserDtoForm>;
/** Interface for a form from a CompleteAssessmentInviteDto*/
export interface ICompleteAssessmentInviteDtoForm {
    /** The assignment id */
    AssessmentId: FormControl<number | null>;
    /** The email/user name */
    Email: FormControl<string | null>;
    /** The first name */
    FirstName: FormControl<string | null>;
    /** Last name */
    LastName: FormControl<string | null>;
    /** Security Code */
    Code: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
}
/**
/* Generates a form from a CompleteAssessmentInviteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompleteAssessmentInviteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompleteAssessmentInviteDtoForm(fb: FormBuilder, dto?: Interfaces.CompleteAssessmentInviteDto | null): FormGroup<ICompleteAssessmentInviteDtoForm>;
/** Interface for a form from a CompleteBotConversationDto*/
export interface ICompleteBotConversationDtoForm {
    /** The Id of the conversation to complete */
    Id: FormControl<string | null>;
}
/**
/* Generates a form from a CompleteBotConversationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompleteBotConversationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompleteBotConversationDtoForm(fb: FormBuilder, dto?: Interfaces.CompleteBotConversationDto | null): FormGroup<ICompleteBotConversationDtoForm>;
/** Interface for a form from a CompleteInviteDto*/
export interface ICompleteInviteDtoForm {
    /** The email/user name */
    Email: FormControl<string | null>;
    /** The first name */
    FirstName: FormControl<string | null>;
    /** Last name */
    LastName: FormControl<string | null>;
    /** Security Code */
    Code: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
}
/**
/* Generates a form from a CompleteInviteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompleteInviteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompleteInviteDtoForm(fb: FormBuilder, dto?: Interfaces.CompleteInviteDto | null): FormGroup<ICompleteInviteDtoForm>;
/** Interface for a form from a CompletePartnerInviteDto*/
export interface ICompletePartnerInviteDtoForm {
    /** The email/user name */
    Email: FormControl<string | null>;
    /** Security Code */
    Code: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Password */
    PartnerId: FormControl<number | null>;
}
/**
/* Generates a form from a CompletePartnerInviteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompletePartnerInviteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompletePartnerInviteDtoForm(fb: FormBuilder, dto?: Interfaces.CompletePartnerInviteDto | null): FormGroup<ICompletePartnerInviteDtoForm>;
/** Interface for a form from a CompletePartnerSubscriptionOrganizationRequestDto*/
export interface ICompletePartnerSubscriptionOrganizationRequestDtoForm {
    /** Organization Id to complete the deal */
    OrganizationId: FormControl<number | null>;
    /** Partner of record on the deal */
    PartnerId: FormControl<number | null>;
    /** Email of the user */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirm Password */
    ConfirmPassword: FormControl<string | null>;
    /** SKU */
    SKU: FormControl<string | null>;
    /** Billing Street Address */
    BillingStreetAddress: FormControl<string | null>;
    /** Billing Street Address 2 */
    BillingStreetAddress2: FormControl<string | null>;
    /** Billing TownCity */
    BillingTownCity: FormControl<string | null>;
    /** Billing Postal Code */
    BillingPostalCode: FormControl<string | null>;
    /** Billing State */
    BillingState: FormControl<string | null>;
    /** Billing Country */
    BillingCountry: FormControl<string | null>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
    /** Payment Method */
    PaymentMethodId: FormControl<number | null>;
    /** Additional Users to add to the organization */
    Users: FormArray<FormGroup<IUserDtoForm>>;
}
/**
/* Generates a form from a CompletePartnerSubscriptionOrganizationRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompletePartnerSubscriptionOrganizationRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompletePartnerSubscriptionOrganizationRequestDtoForm(fb: FormBuilder, dto?: Interfaces.CompletePartnerSubscriptionOrganizationRequestDto | null): FormGroup<ICompletePartnerSubscriptionOrganizationRequestDtoForm>;
/** Interface for a form from a CompletionHistoryDto*/
export interface ICompletionHistoryDtoForm {
    /** Date of History Reading */
    Date: FormControl<Date | null>;
    /** Completion percentage at date */
    PercentComplete: FormControl<number | null>;
    /** Parent Item */
    ItemId: FormControl<number | null>;
    /** The Type of the parent that kicked off the assessment */
    ItemType: FormControl<Enums.AssessmentParentTypes | null>;
}
/**
/* Generates a form from a CompletionHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CompletionHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCompletionHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.CompletionHistoryDto | null): FormGroup<ICompletionHistoryDtoForm>;
/** Interface for a form from a ContactDto*/
export interface IContactDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** This is the Email Address */
    Email: FormControl<string | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The user's full name */
    Name: FormControl<string | null>;
    /** Contact Created On */
    CreatedOn: FormControl<Date | null>;
    /** Contact Updated On */
    UpdatedOn: FormControl<Date | null>;
}
/**
/* Generates a form from a ContactDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContactDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContactDtoForm(fb: FormBuilder, dto?: Interfaces.ContactDto | null): FormGroup<IContactDtoForm>;
/** Interface for a form from a ContentItemDto*/
export interface IContentItemDtoForm {
    /** Parent Id */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** Item Id */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** New Feature */
    NewFeature: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** User Rating */
    UserRating: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Earliest lesson on data item if it's a lesson */
    EarliestLesson: FormControl<number | null>;
    /** The Url if Type = Uri */
    Url: FormControl<string | null>;
}
/**
/* Generates a form from a ContentItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContentItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContentItemDtoForm(fb: FormBuilder, dto?: Interfaces.ContentItemDto | null): FormGroup<IContentItemDtoForm>;
/** Interface for a form from a ContentItemWithChildrenDto*/
export interface IContentItemWithChildrenDtoForm {
    /** Parent Id */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** Item Id */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** New Feature */
    NewFeature: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** User Rating */
    UserRating: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Earliest lesson on data item if it's a lesson */
    EarliestLesson: FormControl<number | null>;
    /** The Url if Type = Uri */
    Url: FormControl<string | null>;
    /** Expanded */
    Expanded: FormControl<boolean | null>;
    /** Children */
    Children: FormArray<FormGroup<IContentItemWithChildrenDtoForm>>;
}
/**
/* Generates a form from a ContentItemWithChildrenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContentItemWithChildrenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContentItemWithChildrenDtoForm(fb: FormBuilder, dto?: Interfaces.ContentItemWithChildrenDto | null): FormGroup<IContentItemWithChildrenDtoForm>;
/** Interface for a form from a ContentSearchResponseDto*/
export interface IContentSearchResponseDtoForm {
    /** Total Results including those not in the current page */
    TotalResults: FormControl<number | null>;
    /** All Results */
    Results: FormArray<FormGroup<IContentSearchResultDtoForm>>;
    /** Owned */
    Owned: FormArray<FormGroup<ISearchFilterDtoForm>>;
    /** Products represented in the results */
    Products: FormArray<FormGroup<ISearchFilterDtoForm>>;
    /** Languages represented in the results */
    Languages: FormArray<FormGroup<ISearchFilterDtoForm>>;
}
/**
/* Generates a form from a ContentSearchResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContentSearchResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContentSearchResponseDtoForm(fb: FormBuilder, dto?: Interfaces.ContentSearchResponseDto | null): FormGroup<IContentSearchResponseDtoForm>;
/** Interface for a form from a ContentSearchResultDto*/
export interface IContentSearchResultDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Any tags on the item */
    Tags: FormControl<string | null>;
    /** When the item was created */
    CreatedOn: FormControl<Date | null>;
    /** When the item was updated */
    UpdatedOn: FormControl<Date | null>;
    /** The language key of the item */
    LanguageId: FormControl<string | null>;
    /** A json encoded object with a list of courses on the lesson */
    CourseInfo: FormArray<FormGroup<IShortContentDtoForm>>;
    /** The product Ids that are associated with the item */
    Products: FormArray<FormGroup<IProductVersionDtoForm>>;
    /** Search probability of match */
    Rank: FormControl<number | null>;
    /** How long the item is */
    Length: FormControl<number | null>;
    /** Do you own this product? */
    Owned: FormControl<boolean | null>;
}
/**
/* Generates a form from a ContentSearchResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContentSearchResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContentSearchResultDtoForm(fb: FormBuilder, dto?: Interfaces.ContentSearchResultDto | null): FormGroup<IContentSearchResultDtoForm>;
/** Interface for a form from a ContentSearchResultsWithUserInfoDto*/
export interface IContentSearchResultsWithUserInfoDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Any tags on the item */
    Tags: FormControl<string | null>;
    /** When the item was created */
    CreatedOn: FormControl<Date | null>;
    /** When the item was updated */
    UpdatedOn: FormControl<Date | null>;
    /** The language key of the item */
    LanguageId: FormControl<string | null>;
    /** A json encoded object with a list of courses on the lesson */
    CourseInfo: FormArray<FormGroup<IShortContentDtoForm>>;
    /** The product Ids that are associated with the item */
    Products: FormArray<FormGroup<IProductVersionDtoForm>>;
    /** Search probability of match */
    Rank: FormControl<number | null>;
    /** How long the item is */
    Length: FormControl<number | null>;
    /** Do you own this product? */
    Owned: FormControl<boolean | null>;
    /** How far the user has gotten in the lesson */
    PercentComplete: FormControl<number | null>;
}
/**
/* Generates a form from a ContentSearchResultsWithUserInfoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ContentSearchResultsWithUserInfoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetContentSearchResultsWithUserInfoDtoForm(fb: FormBuilder, dto?: Interfaces.ContentSearchResultsWithUserInfoDto | null): FormGroup<IContentSearchResultsWithUserInfoDtoForm>;
/** Interface for a form from a CopyLessonDto*/
export interface ICopyLessonDtoForm {
    /** The Lesson to copy */
    LessonId: FormControl<number | null>;
    /** The Id of the Parent. If none specified then all parents will be affected. */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** The workflow step to put the copied lesson as. */
    WorkflowStepId: FormControl<number | null>;
    /** Reason */
    Reason: FormControl<string | null>;
    /** Versions */
    Versions: FormArray<FormGroup<IProductVersionDetailsDtoForm>>;
}
/**
/* Generates a form from a CopyLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CopyLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCopyLessonDtoForm(fb: FormBuilder, dto?: Interfaces.CopyLessonDto | null): FormGroup<ICopyLessonDtoForm>;
/** Interface for a form from a CopyQuoteDto*/
export interface ICopyQuoteDtoForm {
    /** Quote being rejected */
    QuoteId: FormControl<number | null>;
}
/**
/* Generates a form from a CopyQuoteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CopyQuoteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCopyQuoteDtoForm(fb: FormBuilder, dto?: Interfaces.CopyQuoteDto | null): FormGroup<ICopyQuoteDtoForm>;
/** Interface for a form from a CopyStaticPageTranslationDto*/
export interface ICopyStaticPageTranslationDtoForm {
    /** Page Lesson */
    PageName: FormControl<string | null>;
    /** From Language */
    FromLanguage: FormControl<string | null>;
    /** To Language */
    ToLanguage: FormControl<string | null>;
}
/**
/* Generates a form from a CopyStaticPageTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CopyStaticPageTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCopyStaticPageTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.CopyStaticPageTranslationDto | null): FormGroup<ICopyStaticPageTranslationDtoForm>;
/** Interface for a form from a CourseActivityDetailDto*/
export interface ICourseActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Length of Course */
    Length: FormControl<number | null>;
    /** Tags */
    Tags: FormControl<string | null>;
}
/**
/* Generates a form from a CourseActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.CourseActivityDetailDto | null): FormGroup<ICourseActivityDetailDtoForm>;
/** Interface for a form from a CourseAdminDto*/
export interface ICourseAdminDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** Contet Preface */
    Introduction: FormControl<string | null>;
    /** The conclusion of the item */
    Conclusion: FormControl<string | null>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** External Partner Id - When Working on courses that aren't owned by the partner but are monitored by them. */
    ExternalPartnerId: FormControl<number | null>;
    /** The featured lesson used for the home page */
    FeaturedLessonId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is the course a workflow */
    Workflow: FormControl<boolean | null>;
    /** Restrict Course from All Access Entitlements */
    RestrictFromAllAccess: FormControl<boolean | null>;
    /** Question Fore Hire */
    ForHire: FormControl<boolean | null>;
    /** Course requires script approval */
    RequireScriptApproval: FormControl<boolean | null>;
    /** Course requires narration approval */
    RequireNarrationApproval: FormControl<boolean | null>;
    /** Course requires question approval */
    RequireQuestionApproval: FormControl<boolean | null>;
    /** Course requires final approval */
    RequireFinalApproval: FormControl<boolean | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
}
/**
/* Generates a form from a CourseAdminDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseAdminDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseAdminDtoForm(fb: FormBuilder, dto?: Interfaces.CourseAdminDto | null): FormGroup<ICourseAdminDtoForm>;
/** Interface for a form from a CourseApprovalCompletionDto*/
export interface ICourseApprovalCompletionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Percentage course is complete */
    PercentageComplete: FormControl<number | null>;
    /** Is the org an owner of the course */
    Owner: FormControl<boolean | null>;
    /** Does course have rejections */
    HasRejections: FormControl<boolean | null>;
    /** Number of Lessons in Question Approval Workflow */
    NumberOfLessonsInQuestionApproval: FormControl<number | null>;
    /** Number of Lessons in Script Approval Workflow */
    NumberOfLessonsInScriptApproval: FormControl<number | null>;
    /** Number of Lessons in Narration Approval Workflow */
    NumberOfLessonsInNarrationApproval: FormControl<number | null>;
    /** Number of Lessons in Final Approval Workflow */
    NumberOfLessonsInFinalApproval: FormControl<number | null>;
    /** Total Number of Lessons */
    TotalLessons: FormControl<number | null>;
}
/**
/* Generates a form from a CourseApprovalCompletionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseApprovalCompletionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseApprovalCompletionDtoForm(fb: FormBuilder, dto?: Interfaces.CourseApprovalCompletionDto | null): FormGroup<ICourseApprovalCompletionDtoForm>;
/** Interface for a form from a CourseAssignedOrganizationsDto*/
export interface ICourseAssignedOrganizationsDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a CourseAssignedOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseAssignedOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseAssignedOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.CourseAssignedOrganizationsDto | null): FormGroup<ICourseAssignedOrganizationsDtoForm>;
/** Interface for a form from a CourseAtAGlanceReportDto*/
export interface ICourseAtAGlanceReportDtoForm {
    /** Course Lesson */
    Course: FormControl<string | null>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Course WOrkflow Step */
    CourseWorkflowStep: FormControl<string | null>;
    /** Course Workflow Step Id */
    CourseWorkflowStepId: FormControl<number | null>;
    /** Start Date */
    StartDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Topics */
    Topics: FormArray<FormGroup<ITopicAtAGlanceReportDtoForm>>;
}
/**
/* Generates a form from a CourseAtAGlanceReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseAtAGlanceReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseAtAGlanceReportDtoForm(fb: FormBuilder, dto?: Interfaces.CourseAtAGlanceReportDto | null): FormGroup<ICourseAtAGlanceReportDtoForm>;
/** Interface for a form from a CourseDto*/
export interface ICourseDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** Contet Preface */
    Introduction: FormControl<string | null>;
    /** The conclusion of the item */
    Conclusion: FormControl<string | null>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** External Partner Id - When Working on courses that aren't owned by the partner but are monitored by them. */
    ExternalPartnerId: FormControl<number | null>;
    /** The featured lesson used for the home page */
    FeaturedLessonId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is the course a workflow */
    Workflow: FormControl<boolean | null>;
    /** Restrict Course from All Access Entitlements */
    RestrictFromAllAccess: FormControl<boolean | null>;
    /** Question Fore Hire */
    ForHire: FormControl<boolean | null>;
    /** Course requires script approval */
    RequireScriptApproval: FormControl<boolean | null>;
    /** Course requires narration approval */
    RequireNarrationApproval: FormControl<boolean | null>;
    /** Course requires question approval */
    RequireQuestionApproval: FormControl<boolean | null>;
    /** Course requires final approval */
    RequireFinalApproval: FormControl<boolean | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
}
/**
/* Generates a form from a CourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseDtoForm(fb: FormBuilder, dto?: Interfaces.CourseDto | null): FormGroup<ICourseDtoForm>;
/** Interface for a form from a CourseGroupDto*/
export interface ICourseGroupDtoForm {
    /** Course id */
    CourseId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Group */
    GroupId: FormControl<number | null>;
}
/**
/* Generates a form from a CourseGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseGroupDtoForm(fb: FormBuilder, dto?: Interfaces.CourseGroupDto | null): FormGroup<ICourseGroupDtoForm>;
/** Interface for a form from a CourseNextAndPreviousLessonsDto*/
export interface ICourseNextAndPreviousLessonsDtoForm {
    /** Next Lesson Id */
    NextLessonId: FormControl<number | null>;
    /** Next Lesson Lesson */
    NextLesson: FormControl<string | null>;
    /** Previous Lesson Id */
    PreviousLessonId: FormControl<number | null>;
    /** Previous Lesson Lesson */
    PreviousLesson: FormControl<string | null>;
}
/**
/* Generates a form from a CourseNextAndPreviousLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseNextAndPreviousLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseNextAndPreviousLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.CourseNextAndPreviousLessonsDto | null): FormGroup<ICourseNextAndPreviousLessonsDtoForm>;
/** Interface for a form from a CoursePathItemDto*/
export interface ICoursePathItemDtoForm {
    /** Id of the item */
    Id: FormControl<string | null>;
    /** Parent Course Path Item */
    ParentCoursePathItemId: FormControl<string | null>;
    /** Lesson of the Decision Point */
    Name: FormControl<string | null>;
    /** Command */
    Command: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Lessons */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Associated Resources */
    Resources: FormArray<FormGroup<IResourceDtoForm>>;
    /** Course Path Items */
    Items: FormArray<FormGroup<ICoursePathItemDtoForm>>;
}
/**
/* Generates a form from a CoursePathItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CoursePathItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCoursePathItemDtoForm(fb: FormBuilder, dto?: Interfaces.CoursePathItemDto | null): FormGroup<ICoursePathItemDtoForm>;
/** Interface for a form from a CoursePathsDto*/
export interface ICoursePathsDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** The workflow layout */
    WorkflowLayout: FormControl<string | null>;
    /** The Items in the workflow */
    Items: FormArray<FormGroup<ICoursePathItemDtoForm>>;
}
/**
/* Generates a form from a CoursePathsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CoursePathsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCoursePathsDtoForm(fb: FormBuilder, dto?: Interfaces.CoursePathsDto | null): FormGroup<ICoursePathsDtoForm>;
/** Interface for a form from a CourseStructureForEditingDto*/
export interface ICourseStructureForEditingDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Itme that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Item Change status for KAMS */
    EditingStatus: FormControl<Enums.ItemChangeStatuses | null>;
    /** Is this a new feature? */
    NewFeature: FormControl<boolean | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Assignees for the step */
    Assignees: FormControl<string | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Labels */
    Labels: FormControl<string | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Number of Questions */
    Questions: FormControl<number | null>;
    /** Versions */
    Versions: FormControl<string | null>;
    /** Is Waiting For Customer Approval */
    IsWaitingForCustomerApproval: FormControl<boolean | null>;
    /** Is Waiting For Question Team */
    IsWaitingForContentTeam: FormControl<boolean | null>;
}
/**
/* Generates a form from a CourseStructureForEditingDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseStructureForEditingDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseStructureForEditingDtoForm(fb: FormBuilder, dto?: Interfaces.CourseStructureForEditingDto | null): FormGroup<ICourseStructureForEditingDtoForm>;
/** Interface for a form from a CourseStructureForEditingWithChildrenDto*/
export interface ICourseStructureForEditingWithChildrenDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Itme that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Item Change status for KAMS */
    EditingStatus: FormControl<Enums.ItemChangeStatuses | null>;
    /** Is this a new feature? */
    NewFeature: FormControl<boolean | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Assignees for the step */
    Assignees: FormControl<string | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Labels */
    Labels: FormControl<string | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Number of Questions */
    Questions: FormControl<number | null>;
    /** Versions */
    Versions: FormControl<string | null>;
    /** Is Waiting For Customer Approval */
    IsWaitingForCustomerApproval: FormControl<boolean | null>;
    /** Is Waiting For Question Team */
    IsWaitingForContentTeam: FormControl<boolean | null>;
    /** Child Items */
    ChildItems: FormArray<FormGroup<ICourseStructureForEditingDtoForm>>;
}
/**
/* Generates a form from a CourseStructureForEditingWithChildrenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseStructureForEditingWithChildrenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseStructureForEditingWithChildrenDtoForm(fb: FormBuilder, dto?: Interfaces.CourseStructureForEditingWithChildrenDto | null): FormGroup<ICourseStructureForEditingWithChildrenDtoForm>;
/** Interface for a form from a CourseSyndicationDto*/
export interface ICourseSyndicationDtoForm {
    /** Course id */
    CourseId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Types */
    Type: FormControl<Enums.SyndicationTypes | null>;
}
/**
/* Generates a form from a CourseSyndicationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseSyndicationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseSyndicationDtoForm(fb: FormBuilder, dto?: Interfaces.CourseSyndicationDto | null): FormGroup<ICourseSyndicationDtoForm>;
/** Interface for a form from a CourseSyndicationProviderDto*/
export interface ICourseSyndicationProviderDtoForm {
    /** Course id */
    CourseId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a CourseSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.CourseSyndicationProviderDto | null): FormGroup<ICourseSyndicationProviderDtoForm>;
/** Interface for a form from a CourseTranslationDto*/
export interface ICourseTranslationDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Lesson Lesson */
    Course: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Preface */
    Introduction: FormControl<string | null>;
    /** Postface */
    Conclusion: FormControl<string | null>;
    /** Marketing */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
}
/**
/* Generates a form from a CourseTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.CourseTranslationDto | null): FormGroup<ICourseTranslationDtoForm>;
/** Interface for a form from a CourseWithUserInfoDto*/
export interface ICourseWithUserInfoDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** Contet Preface */
    Introduction: FormControl<string | null>;
    /** The conclusion of the item */
    Conclusion: FormControl<string | null>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** External Partner Id - When Working on courses that aren't owned by the partner but are monitored by them. */
    ExternalPartnerId: FormControl<number | null>;
    /** The featured lesson used for the home page */
    FeaturedLessonId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is the course a workflow */
    Workflow: FormControl<boolean | null>;
    /** Restrict Course from All Access Entitlements */
    RestrictFromAllAccess: FormControl<boolean | null>;
    /** Question Fore Hire */
    ForHire: FormControl<boolean | null>;
    /** Course requires script approval */
    RequireScriptApproval: FormControl<boolean | null>;
    /** Course requires narration approval */
    RequireNarrationApproval: FormControl<boolean | null>;
    /** Course requires question approval */
    RequireQuestionApproval: FormControl<boolean | null>;
    /** Course requires final approval */
    RequireFinalApproval: FormControl<boolean | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Total Lessons */
    TotalLessons: FormControl<number | null>;
    /** Total Viewed */
    TotalViewed: FormControl<number | null>;
    /** Total Length Viewed */
    TotalLengthViewed: FormControl<number | null>;
}
/**
/* Generates a form from a CourseWithUserInfoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseWithUserInfoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseWithUserInfoDtoForm(fb: FormBuilder, dto?: Interfaces.CourseWithUserInfoDto | null): FormGroup<ICourseWithUserInfoDtoForm>;
/** Interface for a form from a CourseWithVersionsDto*/
export interface ICourseWithVersionsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Featured Lesson */
    FeaturedLessonId: FormControl<number | null>;
    /** Is The course a workflow? */
    Workflow: FormControl<boolean | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** Lesson of the owning organization */
    OwningOrganization: FormControl<string | null>;
    /** Versions applicable to the course */
    Versions: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a CourseWithVersionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseWithVersionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseWithVersionsDtoForm(fb: FormBuilder, dto?: Interfaces.CourseWithVersionsDto | null): FormGroup<ICourseWithVersionsDtoForm>;
/** Interface for a form from a CourseWorkflowAssigneesDto*/
export interface ICourseWorkflowAssigneesDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Course Lesson */
    Course: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role Lesson */
    Role: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CourseWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CourseWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCourseWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.CourseWorkflowAssigneesDto | null): FormGroup<ICourseWorkflowAssigneesDtoForm>;
/** Interface for a form from a CoursesByProductDto*/
export interface ICoursesByProductDtoForm {
    /** Product Id */
    Id: FormControl<number | null>;
    /** Product Lesson */
    Name: FormControl<string | null>;
    /** Courses */
    Courses: FormArray<FormGroup<ICourseDtoForm>>;
}
/**
/* Generates a form from a CoursesByProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CoursesByProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCoursesByProductDtoForm(fb: FormBuilder, dto?: Interfaces.CoursesByProductDto | null): FormGroup<ICoursesByProductDtoForm>;
/** Interface for a form from a CreateCaptionsFromScriptDto*/
export interface ICreateCaptionsFromScriptDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Video Id */
    VideoId: FormControl<number | null>;
}
/**
/* Generates a form from a CreateCaptionsFromScriptDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCaptionsFromScriptDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCaptionsFromScriptDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCaptionsFromScriptDto | null): FormGroup<ICreateCaptionsFromScriptDtoForm>;
/** Interface for a form from a CreateCourseDto*/
export interface ICreateCourseDtoForm {
    /** The name of the new course */
    Name: FormControl<string | null>;
    /** The Course for which this course will be based on with all structure and resources copied into the new course */
    BaseOnCourseId: FormControl<number | null>;
    /** The product and version associated with the new course */
    ProductVersionId: FormControl<number | null>;
}
/**
/* Generates a form from a CreateCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCourseDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCourseDto | null): FormGroup<ICreateCourseDtoForm>;
/** Interface for a form from a CreateCourseLessonDto*/
export interface ICreateCourseLessonDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Topic Lesson */
    Name: FormControl<string | null>;
    /** Topic Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCourseLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCourseLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCourseLessonDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCourseLessonDto | null): FormGroup<ICreateCourseLessonDtoForm>;
/** Interface for a form from a CreateCourseTopicDto*/
export interface ICreateCourseTopicDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Topic Lesson */
    Name: FormControl<string | null>;
    /** Topic Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCourseTopicDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCourseTopicDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCourseTopicDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCourseTopicDto | null): FormGroup<ICreateCourseTopicDtoForm>;
/** Interface for a form from a CreateCustomCourseDto*/
export interface ICreateCustomCourseDtoForm {
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCustomCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCustomCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCustomCourseDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCustomCourseDto | null): FormGroup<ICreateCustomCourseDtoForm>;
/** Interface for a form from a CreateCustomLessonDto*/
export interface ICreateCustomLessonDtoForm {
    /** Course Id */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCustomLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCustomLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCustomLessonDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCustomLessonDto | null): FormGroup<ICreateCustomLessonDtoForm>;
/** Interface for a form from a CreateCustomProductDto*/
export interface ICreateCustomProductDtoForm {
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCustomProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCustomProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCustomProductDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCustomProductDto | null): FormGroup<ICreateCustomProductDtoForm>;
/** Interface for a form from a CreateCustomTopicDto*/
export interface ICreateCustomTopicDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateCustomTopicDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateCustomTopicDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateCustomTopicDtoForm(fb: FormBuilder, dto?: Interfaces.CreateCustomTopicDto | null): FormGroup<ICreateCustomTopicDtoForm>;
/** Interface for a form from a CreateTopicLessonDto*/
export interface ICreateTopicLessonDtoForm {
    /** The associated Topic */
    TopicId: FormControl<number | null>;
    /** The Lesson Lesson */
    Name: FormControl<string | null>;
    /** The Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a CreateTopicLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateTopicLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateTopicLessonDtoForm(fb: FormBuilder, dto?: Interfaces.CreateTopicLessonDto | null): FormGroup<ICreateTopicLessonDtoForm>;
/** Interface for a form from a CreateVideoFromResourcesDto*/
export interface ICreateVideoFromResourcesDtoForm {
    /** Parent Item that the video will be attached to */
    ParentItemId: FormControl<number | null>;
    /** Question Item Types */
    ParentItemType: FormControl<Enums.ContentItemTypes | null>;
    /** The video resource to use */
    VideoResourceId: FormControl<number | null>;
    /** The language associated with the media */
    LanguageCode: FormControl<string | null>;
    /** The audio resources to use if any (for multi-language) */
    AudioResourceIds: FormArray<FormControl<number | null>>;
    /** The captions to associate with the video resource */
    CaptionResourceIds: FormArray<FormControl<number | null>>;
    /** Is Video Public */
    Public: FormControl<boolean | null>;
}
/**
/* Generates a form from a CreateVideoFromResourcesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original CreateVideoFromResourcesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetCreateVideoFromResourcesDtoForm(fb: FormBuilder, dto?: Interfaces.CreateVideoFromResourcesDto | null): FormGroup<ICreateVideoFromResourcesDtoForm>;
/** Interface for a form from a DecimalNameValueDto*/
export interface IDecimalNameValueDtoForm {
    /** Lesson of the item */
    Name: FormControl<string | null>;
    /** Value of the Item */
    Value: FormControl<number | null>;
}
/**
/* Generates a form from a DecimalNameValueDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DecimalNameValueDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDecimalNameValueDtoForm(fb: FormBuilder, dto?: Interfaces.DecimalNameValueDto | null): FormGroup<IDecimalNameValueDtoForm>;
/** Interface for a form from a DisciplineAssignedOrganizationsDto*/
export interface IDisciplineAssignedOrganizationsDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineAssignedOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineAssignedOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineAssignedOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineAssignedOrganizationsDto | null): FormGroup<IDisciplineAssignedOrganizationsDtoForm>;
/** Interface for a form from a DisciplineAverageScoreDisciplineDto*/
export interface IDisciplineAverageScoreDisciplineDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
    /** Organization Average Score */
    OrganizationScore: FormControl<number | null>;
    /** Industry Average Score */
    IndustryScore: FormControl<number | null>;
    /** Users own Score */
    OwnScore: FormControl<number | null>;
}
/**
/* Generates a form from a DisciplineAverageScoreDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineAverageScoreDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineAverageScoreDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineAverageScoreDisciplineDto | null): FormGroup<IDisciplineAverageScoreDisciplineDtoForm>;
/** Interface for a form from a DisciplineAverageScoresDto*/
export interface IDisciplineAverageScoresDtoForm {
    /** Include Organizational Score */
    IncludeOrganizationScore: FormControl<boolean | null>;
    /** Include Industry Score */
    IncludeIndustryScore: FormControl<boolean | null>;
    /** Disciplines */
    Disciplines: FormArray<FormGroup<IDisciplineAverageScoreDisciplineDtoForm>>;
}
/**
/* Generates a form from a DisciplineAverageScoresDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineAverageScoresDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineAverageScoresDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineAverageScoresDto | null): FormGroup<IDisciplineAverageScoresDtoForm>;
/** Interface for a form from a DisciplineDto*/
export interface IDisciplineDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Was the discipline added by a job */
    AddedByJob: FormControl<boolean | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display	Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineDto | null): FormGroup<IDisciplineDtoForm>;
/** Interface for a form from a DisciplineGroupDto*/
export interface IDisciplineGroupDtoForm {
    /** Discipline id */
    DisciplineId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Group */
    GroupId: FormControl<number | null>;
}
/**
/* Generates a form from a DisciplineGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineGroupDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineGroupDto | null): FormGroup<IDisciplineGroupDtoForm>;
/** Interface for a form from a DisciplineHeaderLessonDto*/
export interface IDisciplineHeaderLessonDtoForm {
    /** Discipline id */
    DisciplineId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Header Lesson Id */
    LessonId: FormControl<number | null>;
    /** Header Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineHeaderLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineHeaderLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineHeaderLessonDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineHeaderLessonDto | null): FormGroup<IDisciplineHeaderLessonDtoForm>;
/** Interface for a form from a DisciplineIndustryDto*/
export interface IDisciplineIndustryDtoForm {
    /** Industry Id */
    Id: FormControl<number | null>;
    /** Industry Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineIndustryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineIndustryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineIndustryDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineIndustryDto | null): FormGroup<IDisciplineIndustryDtoForm>;
/** Interface for a form from a DisciplineLearningPathDto*/
export interface IDisciplineLearningPathDtoForm {
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Discipline Lesson */
    Name: FormControl<string | null>;
    /** Discipline Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Medallions */
    TotalMedallions: FormControl<number | null>;
    /** Number of Completed Medallions */
    TotalCompletedMedallions: FormControl<number | null>;
    /** Total # of Badges */
    TotalBadges: FormControl<number | null>;
    /** When the Discipline was started. */
    StartedOn: FormControl<Date | null>;
    /** When will the trend hit 0? */
    TrendZeroOn: FormControl<Date | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Discipline Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** History of completion */
    History: FormArray<FormGroup<ILearningPathHistoryDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
    /** Was the discipline added by a job? */
    AddedByJob: FormControl<boolean | null>;
    /** Medallions */
    Medallions: FormArray<FormGroup<IMedallionLearningPathDtoForm>>;
    /** Discipline Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
}
/**
/* Generates a form from a DisciplineLearningPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineLearningPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineLearningPathDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineLearningPathDto | null): FormGroup<IDisciplineLearningPathDtoForm>;
/** Interface for a form from a DisciplineMedallionDto*/
export interface IDisciplineMedallionDtoForm {
    /** Medallion Id */
    Id: FormControl<number | null>;
    /** Medallion Lesson */
    Name: FormControl<string | null>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a DisciplineMedallionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineMedallionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineMedallionDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineMedallionDto | null): FormGroup<IDisciplineMedallionDtoForm>;
/** Interface for a form from a DisciplinePathDto*/
export interface IDisciplinePathDtoForm {
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Discipline Lesson */
    Name: FormControl<string | null>;
    /** Discipline Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Medallions */
    TotalMedallions: FormControl<number | null>;
    /** Number of Completed Medallions */
    TotalCompletedMedallions: FormControl<number | null>;
    /** Total # of Badges */
    TotalBadges: FormControl<number | null>;
    /** When the Discipline was started. */
    StartedOn: FormControl<Date | null>;
    /** When will the trend hit 0? */
    TrendZeroOn: FormControl<Date | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Discipline Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** History of completion */
    History: FormArray<FormGroup<ILearningPathHistoryDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a DisciplinePathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplinePathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplinePathDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplinePathDto | null): FormGroup<IDisciplinePathDtoForm>;
/** Interface for a form from a DisciplineProductDto*/
export interface IDisciplineProductDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineProductDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineProductDto | null): FormGroup<IDisciplineProductDtoForm>;
/** Interface for a form from a DisciplineProductVersionDto*/
export interface IDisciplineProductVersionDtoForm {
    /** Product */
    Product: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
}
/**
/* Generates a form from a DisciplineProductVersionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineProductVersionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineProductVersionDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineProductVersionDto | null): FormGroup<IDisciplineProductVersionDtoForm>;
/** Interface for a form from a DisciplineSyndicationProviderDto*/
export interface IDisciplineSyndicationProviderDtoForm {
    /** Discipline id */
    DisciplineId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineSyndicationProviderDto | null): FormGroup<IDisciplineSyndicationProviderDtoForm>;
/** Interface for a form from a DisciplineTranslationDto*/
export interface IDisciplineTranslationDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a DisciplineTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineTranslationDto | null): FormGroup<IDisciplineTranslationDtoForm>;
/** Interface for a form from a DisciplineUserEarnedDto*/
export interface IDisciplineUserEarnedDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Earned On */
    EarnedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
}
/**
/* Generates a form from a DisciplineUserEarnedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineUserEarnedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineUserEarnedDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineUserEarnedDto | null): FormGroup<IDisciplineUserEarnedDtoForm>;
/** Interface for a form from a DisciplineWithProductsDto*/
export interface IDisciplineWithProductsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Was the discipline added by a job */
    AddedByJob: FormControl<boolean | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display	Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
    /** Products and Versions */
    Products: FormArray<FormGroup<IDisciplineProductVersionDtoForm>>;
    /** When the user started */
    StartedOn: FormControl<Date | null>;
    /** Is Preferred By the User */
    IsPreferred: FormControl<boolean | null>;
}
/**
/* Generates a form from a DisciplineWithProductsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisciplineWithProductsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisciplineWithProductsDtoForm(fb: FormBuilder, dto?: Interfaces.DisciplineWithProductsDto | null): FormGroup<IDisciplineWithProductsDtoForm>;
/** Interface for a form from a DisputeInvoiceDto*/
export interface IDisputeInvoiceDtoForm {
    /** Invoice Id to dispute */
    InvoiceId: FormControl<number | null>;
    /** Line items on the invoice */
    LineItems: FormArray<FormGroup<IInvoiceInventoryDtoForm>>;
}
/**
/* Generates a form from a DisputeInvoiceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DisputeInvoiceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDisputeInvoiceDtoForm(fb: FormBuilder, dto?: Interfaces.DisputeInvoiceDto | null): FormGroup<IDisputeInvoiceDtoForm>;
/** Interface for a form from a DocumentCategoriesWithDocumentsDto*/
export interface IDocumentCategoriesWithDocumentsDtoForm {
    /** The category name */
    Name: FormControl<string | null>;
    /** The documents in the category */
    Documents: FormArray<FormGroup<IDocumentDtoForm>>;
}
/**
/* Generates a form from a DocumentCategoriesWithDocumentsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DocumentCategoriesWithDocumentsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDocumentCategoriesWithDocumentsDtoForm(fb: FormBuilder, dto?: Interfaces.DocumentCategoriesWithDocumentsDto | null): FormGroup<IDocumentCategoriesWithDocumentsDtoForm>;
/** Interface for a form from a DocumentCategoryDto*/
export interface IDocumentCategoryDtoForm {
    /** Category Id */
    Id: FormControl<number | null>;
    /** Category Lesson */
    Name: FormControl<string | null>;
    /** Category Description */
    Description: FormControl<string | null>;
    /** Category is Featured */
    Featured: FormControl<boolean | null>;
    /** Category Featured sort order */
    FeaturedSortOrder: FormControl<number | null>;
    /** Category Branding color */
    BrandingColor: FormControl<string | null>;
}
/**
/* Generates a form from a DocumentCategoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DocumentCategoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDocumentCategoryDtoForm(fb: FormBuilder, dto?: Interfaces.DocumentCategoryDto | null): FormGroup<IDocumentCategoryDtoForm>;
/** Interface for a form from a DocumentDto*/
export interface IDocumentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** The language of the item */
    LanguageCode: FormControl<string | null>;
    /** Url */
    Uri: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
    /** The file name if any of the resource */
    FileName: FormControl<string | null>;
    /** The size of the resource */
    Size: FormControl<string | null>;
    /** the last time it was uploaded */
    DateTimeFileUpdated: FormControl<Date | null>;
    /** Resource Locations */
    Location: FormControl<Enums.ResourceLocations | null>;
    /** Any child resources of this parent */
    ChildResources: FormArray<FormGroup<IChildResourceDtoForm>>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** Document Category Id */
    DocumentCategoryId: FormControl<number | null>;
    /** Document Category Lesson */
    DocumentCategory: FormControl<string | null>;
}
/**
/* Generates a form from a DocumentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DocumentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDocumentDtoForm(fb: FormBuilder, dto?: Interfaces.DocumentDto | null): FormGroup<IDocumentDtoForm>;
/** Interface for a form from a DocumentLinkDto*/
export interface IDocumentLinkDtoForm {
    /** Document Category Id */
    DocumentId: FormControl<number | null>;
    /** Item Resource Id */
    ItemId: FormControl<number | null>;
    /** Item Lesson */
    ItemName: FormControl<string | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Permissions for Document */
    Permissions: FormControl<Enums.DocumentPermissions | null>;
}
/**
/* Generates a form from a DocumentLinkDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DocumentLinkDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDocumentLinkDtoForm(fb: FormBuilder, dto?: Interfaces.DocumentLinkDto | null): FormGroup<IDocumentLinkDtoForm>;
/** Interface for a form from a DomainAndAuthMethodsDto*/
export interface IDomainAndAuthMethodsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the domain */
    Name: FormControl<string | null>;
    /** Is the domain active? */
    Active: FormControl<boolean | null>;
    /** When was it created? */
    CreatedOn: FormControl<Date | null>;
    /** When was it updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** The Organization that the domain is associated with */
    OrganizationId: FormControl<number | null>;
    /** The Url for the portal site that goes with the domain */
    PortalUrl: FormControl<string | null>;
    /** Defines if Request Access will be displayed on the login page of the site. */
    ShowRequestAccess: FormControl<boolean | null>;
    /** Limit Logins to the domain's Organization Users */
    LimitLoginsToOrganizationUsers: FormControl<boolean | null>;
    /** Allow sign up from login */
    AllowSignUp: FormControl<boolean | null>;
    /** Only allow signup from domains with linked email address. */
    SignUpOnlyLinkedEmailDomains: FormControl<boolean | null>;
    /** Automatically Assign Entitlements As Neccessary */
    AutomaticallyAssignEntitlementsAsNecessary: FormControl<boolean | null>;
    /** Site */
    SiteId: FormControl<number | null>;
    /** Site */
    Site: FormControl<string | null>;
    /** Auth Methods */
    AuthMethods: FormArray<FormGroup<IAuthMethodDtoForm>>;
}
/**
/* Generates a form from a DomainAndAuthMethodsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DomainAndAuthMethodsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDomainAndAuthMethodsDtoForm(fb: FormBuilder, dto?: Interfaces.DomainAndAuthMethodsDto | null): FormGroup<IDomainAndAuthMethodsDtoForm>;
/** Interface for a form from a DomainDto*/
export interface IDomainDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the domain */
    Name: FormControl<string | null>;
    /** Is the domain active? */
    Active: FormControl<boolean | null>;
    /** When was it created? */
    CreatedOn: FormControl<Date | null>;
    /** When was it updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** The Organization that the domain is associated with */
    OrganizationId: FormControl<number | null>;
    /** The Url for the portal site that goes with the domain */
    PortalUrl: FormControl<string | null>;
    /** Defines if Request Access will be displayed on the login page of the site. */
    ShowRequestAccess: FormControl<boolean | null>;
    /** Limit Logins to the domain's Organization Users */
    LimitLoginsToOrganizationUsers: FormControl<boolean | null>;
    /** Allow sign up from login */
    AllowSignUp: FormControl<boolean | null>;
    /** Only allow signup from domains with linked email address. */
    SignUpOnlyLinkedEmailDomains: FormControl<boolean | null>;
    /** Automatically Assign Entitlements As Neccessary */
    AutomaticallyAssignEntitlementsAsNecessary: FormControl<boolean | null>;
    /** Site */
    SiteId: FormControl<number | null>;
    /** Site */
    Site: FormControl<string | null>;
}
/**
/* Generates a form from a DomainDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DomainDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDomainDtoForm(fb: FormBuilder, dto?: Interfaces.DomainDto | null): FormGroup<IDomainDtoForm>;
/** Interface for a form from a DownloadAssessmentDataDto*/
export interface IDownloadAssessmentDataDtoForm {
    /** User id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    UserName: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Department */
    Division: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Level */
    Level: FormControl<string | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Completed On */
    CompletedOn: FormControl<Date | null>;
    /** Assessment Id */
    AssessmentId: FormControl<number | null>;
    /** Assessment Lesson */
    Assessment: FormControl<string | null>;
    /** Play List Id */
    PlayListId: FormControl<number | null>;
    /** Play List Lesson */
    PlayList: FormControl<string | null>;
    /** Question Id */
    QuestionId: FormControl<number | null>;
    /** Question */
    Question: FormControl<string | null>;
    /** Answer Id */
    AnswerId: FormControl<number | null>;
    /** Answer */
    Answer: FormControl<string | null>;
    /** Correct Answer */
    CorrectAnswerId: FormControl<number | null>;
    /** Correct Answer */
    CorrectAnswer: FormControl<string | null>;
    /** Score */
    Score: FormControl<number | null>;
}
/**
/* Generates a form from a DownloadAssessmentDataDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DownloadAssessmentDataDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDownloadAssessmentDataDtoForm(fb: FormBuilder, dto?: Interfaces.DownloadAssessmentDataDto | null): FormGroup<IDownloadAssessmentDataDtoForm>;
/** Interface for a form from a DownloadGoalDataDto*/
export interface IDownloadGoalDataDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Username */
    Username: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Goal Percent */
    GoalPercent: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** Medallion Percent */
    MedallionPercent: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** Badge Percent */
    BadgePercent: FormControl<number | null>;
}
/**
/* Generates a form from a DownloadGoalDataDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DownloadGoalDataDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDownloadGoalDataDtoForm(fb: FormBuilder, dto?: Interfaces.DownloadGoalDataDto | null): FormGroup<IDownloadGoalDataDtoForm>;
/** Interface for a form from a DownloadRoleDataDto*/
export interface IDownloadRoleDataDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Username */
    Username: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Role */
    Role: FormControl<string | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Goal Percent */
    GoalPercent: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** Medallion Percent */
    MedallionPercent: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** Badge Percent */
    BadgePercent: FormControl<number | null>;
}
/**
/* Generates a form from a DownloadRoleDataDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original DownloadRoleDataDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetDownloadRoleDataDtoForm(fb: FormBuilder, dto?: Interfaces.DownloadRoleDataDto | null): FormGroup<IDownloadRoleDataDtoForm>;
/** Interface for a form from a EditProductionLessonDto*/
export interface IEditProductionLessonDtoForm {
    /** Lesson */
    LessonId: FormControl<number | null>;
    /** Workflow Step to Assign */
    WorkflowStepId: FormControl<number | null>;
    /** Reason for removing it from production. */
    Reason: FormControl<string | null>;
}
/**
/* Generates a form from a EditProductionLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EditProductionLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEditProductionLessonDtoForm(fb: FormBuilder, dto?: Interfaces.EditProductionLessonDto | null): FormGroup<IEditProductionLessonDtoForm>;
/** Interface for a form from a EduAddSubscriptionRequestDto*/
export interface IEduAddSubscriptionRequestDtoForm {
    /** The User to add the trial to. If this is null then the other fields for the user must be filled in. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirmation Password */
    ConfirmPassword: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Provider */
    Provider: FormControl<string | null>;
    /** Unique Provider Key that links the provider to the user. */
    ProviderKey: FormControl<string | null>;
    /** External Access Token */
    ExternalAccessToken: FormControl<string | null>;
    /** Organization Lesson */
    EducationalInstitution: FormControl<string | null>;
    /** Entitlement Quantity */
    EntitlementQuantity: FormControl<number | null>;
    /** Edu Verification Code */
    Code: FormControl<string | null>;
}
/**
/* Generates a form from a EduAddSubscriptionRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EduAddSubscriptionRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEduAddSubscriptionRequestDtoForm(fb: FormBuilder, dto?: Interfaces.EduAddSubscriptionRequestDto | null): FormGroup<IEduAddSubscriptionRequestDtoForm>;
/** Interface for a form from a EduAddSubscriptionResponseDto*/
export interface IEduAddSubscriptionResponseDtoForm {
    /** Error Message */
    ErrorMessage: FormControl<string | null>;
    /** Edu Subscription Status Codes */
    Result: FormControl<Enums.EduSubscriptionStatusCodes | null>;
    /** The main Dto that describes a user */
    User: FormGroup<IUserDtoForm>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Invoice Id */
    InvoiceId: FormControl<string | null>;
}
/**
/* Generates a form from a EduAddSubscriptionResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EduAddSubscriptionResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEduAddSubscriptionResponseDtoForm(fb: FormBuilder, dto?: Interfaces.EduAddSubscriptionResponseDto | null): FormGroup<IEduAddSubscriptionResponseDtoForm>;
/** Interface for a form from a EduDomainDto*/
export interface IEduDomainDtoForm {
    /** The domain */
    Domain: FormControl<string | null>;
}
/**
/* Generates a form from a EduDomainDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EduDomainDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEduDomainDtoForm(fb: FormBuilder, dto?: Interfaces.EduDomainDto | null): FormGroup<IEduDomainDtoForm>;
/** Interface for a form from a EduSubscriptionPaymentRequestDto*/
export interface IEduSubscriptionPaymentRequestDtoForm {
    /** The User to add the edu subscription to. */
    UserId: FormControl<number | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City or Town */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal Code */
    PostalCode: FormControl<string | null>;
    /** Country Code */
    CountryCode: FormControl<string | null>;
    /**  */
    PaymentMethodId: FormControl<number | null>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
}
/**
/* Generates a form from a EduSubscriptionPaymentRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EduSubscriptionPaymentRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEduSubscriptionPaymentRequestDtoForm(fb: FormBuilder, dto?: Interfaces.EduSubscriptionPaymentRequestDto | null): FormGroup<IEduSubscriptionPaymentRequestDtoForm>;
/** Interface for a form from a EmailDomainBlackListItemDto*/
export interface IEmailDomainBlackListItemDtoForm {
    /** The domain */
    Domain: FormControl<string | null>;
    /** Block Email Domain Registration */
    BlockEmailDomainRegistration: FormControl<boolean | null>;
    /** Block Purchase from this domain */
    BlockPurchase: FormControl<boolean | null>;
}
/**
/* Generates a form from a EmailDomainBlackListItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmailDomainBlackListItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmailDomainBlackListItemDtoForm(fb: FormBuilder, dto?: Interfaces.EmailDomainBlackListItemDto | null): FormGroup<IEmailDomainBlackListItemDtoForm>;
/** Interface for a form from a EmailTemplateDto*/
export interface IEmailTemplateDtoForm {
    /** The key of the email template */
    Key: FormControl<string | null>;
    /** The friendly name of the email template */
    FriendlyName: FormControl<string | null>;
    /** The subject of the e-mail */
    Subject: FormControl<string | null>;
    /** The default html of the template */
    DefaultTemplate: FormControl<string | null>;
    /** Bit value indicating whether or not the email template is internal to CADLearning */
    Internal: FormControl<boolean | null>;
}
/**
/* Generates a form from a EmailTemplateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmailTemplateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmailTemplateDtoForm(fb: FormBuilder, dto?: Interfaces.EmailTemplateDto | null): FormGroup<IEmailTemplateDtoForm>;
/** Interface for a form from a EmployeeActivityDto*/
export interface IEmployeeActivityDtoForm {
    /** Date and Time of the activity */
    DateTime: FormControl<Date | null>;
    /** IP Address of the activity */
    Origin: FormControl<string | null>;
    /** Client that was used to view the activity */
    ClientId: FormControl<string | null>;
    /** User Details */
    Employee: FormGroup<IUserActivityDetailDtoForm>;
    /** Organization Details */
    Organization: FormGroup<IOrganizationActivityDetailDtoForm>;
    /** Course Activity Details */
    Course: FormGroup<ICourseActivityDetailDtoForm>;
    /** Topic Details */
    Topic: FormGroup<ITopicActivityDetailDtoForm>;
    /** Lesson Detail */
    Lesson: FormGroup<ILessonActivityDetailDtoForm>;
    /** Product Details */
    Product: FormGroup<IProductActivityDetailDtoForm>;
    /** Project Details */
    Project: FormGroup<IProjectActivityDetailDtoForm>;
    /** Play List Details */
    PlayList: FormGroup<IPlaylistActivityDetailDtoForm>;
}
/**
/* Generates a form from a EmployeeActivityDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeActivityDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeActivityDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeActivityDto | null): FormGroup<IEmployeeActivityDtoForm>;
/** Interface for a form from a EmployeeAssignedToItemDto*/
export interface IEmployeeAssignedToItemDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Employee Id */
    EmployeeId: FormControl<number | null>;
    /** Employee Name */
    EmployeeName: FormControl<string | null>;
    /** Email Address */
    EmployeeEmailAddress: FormControl<string | null>;
    /** Score */
    EmployeeScore: FormControl<number | null>;
    /** OutOf */
    EmployeeOutOf: FormControl<number | null>;
    /** Percent */
    EmployeePercent: FormControl<number | null>;
}
/**
/* Generates a form from a EmployeeAssignedToItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeAssignedToItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeAssignedToItemDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeAssignedToItemDto | null): FormGroup<IEmployeeAssignedToItemDtoForm>;
/** Interface for a form from a EmployeeItemCompletionDto*/
export interface IEmployeeItemCompletionDtoForm {
    /** Lesson */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Items */
    Items: FormArray<FormGroup<IItemCompletionDtoForm>>;
}
/**
/* Generates a form from a EmployeeItemCompletionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeItemCompletionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeItemCompletionDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeItemCompletionDto | null): FormGroup<IEmployeeItemCompletionDtoForm>;
/** Interface for a form from a EmployeeItemCompletionFlattenedDto*/
export interface IEmployeeItemCompletionFlattenedDtoForm {
    /** Lesson */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Lesson */
    GoalId: FormControl<number | null>;
    /** Lesson */
    Goal: FormControl<string | null>;
    /** Score */
    Score: FormControl<number | null>;
    /** OutOf */
    OutOf: FormControl<number | null>;
    /** Percent */
    Percent: FormControl<number | null>;
}
/**
/* Generates a form from a EmployeeItemCompletionFlattenedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeItemCompletionFlattenedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeItemCompletionFlattenedDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeItemCompletionFlattenedDto | null): FormGroup<IEmployeeItemCompletionFlattenedDtoForm>;
/** Interface for a form from a EmployeeScoreChangeDto*/
export interface IEmployeeScoreChangeDtoForm {
    /** Id of the employee */
    Id: FormControl<number | null>;
    /** Lesson of the employee */
    Name: FormControl<string | null>;
    /** History of results */
    Change: FormControl<number | null>;
}
/**
/* Generates a form from a EmployeeScoreChangeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeScoreChangeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeScoreChangeDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeScoreChangeDto | null): FormGroup<IEmployeeScoreChangeDtoForm>;
/** Interface for a form from a EmployeeWithEngagementDto*/
export interface IEmployeeWithEngagementDtoForm {
    /** User Id */
    Id: FormControl<number | null>;
    /** User Lesson */
    Name: FormControl<string | null>;
    /** Engagement Ratio calculation result */
    EngagementRatio: FormControl<number | null>;
}
/**
/* Generates a form from a EmployeeWithEngagementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeWithEngagementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeWithEngagementDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeWithEngagementDto | null): FormGroup<IEmployeeWithEngagementDtoForm>;
/** Interface for a form from a EmployeeWithOverallGoalCompletionDto*/
export interface IEmployeeWithOverallGoalCompletionDtoForm {
    /** User Id */
    Id: FormControl<number | null>;
    /** User Lesson */
    Name: FormControl<string | null>;
    /** Completion Percentage */
    CompletionPercentage: FormControl<number | null>;
}
/**
/* Generates a form from a EmployeeWithOverallGoalCompletionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EmployeeWithOverallGoalCompletionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEmployeeWithOverallGoalCompletionDtoForm(fb: FormBuilder, dto?: Interfaces.EmployeeWithOverallGoalCompletionDto | null): FormGroup<IEmployeeWithOverallGoalCompletionDtoForm>;
/** Interface for a form from a EngagementTrendsDto*/
export interface IEngagementTrendsDtoForm {
    /** Date of the Measurement */
    Date: FormControl<Date | null>;
    /** Percentage of Emploeyes who engaged with the system in the past month */
    Percentage: FormControl<number | null>;
}
/**
/* Generates a form from a EngagementTrendsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EngagementTrendsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEngagementTrendsDtoForm(fb: FormBuilder, dto?: Interfaces.EngagementTrendsDto | null): FormGroup<IEngagementTrendsDtoForm>;
/** Interface for a form from a EnterpriseRequestInformationDto*/
export interface IEnterpriseRequestInformationDtoForm {
    /** Partner Id */
    PartnerId: FormControl<number | null>;
    /** Organization Types */
    OrganizationSize: FormControl<Enums.OrganizationSizes | null>;
    /** Organization Lesson */
    OrganizationName: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Message */
    Message: FormControl<string | null>;
}
/**
/* Generates a form from a EnterpriseRequestInformationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EnterpriseRequestInformationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEnterpriseRequestInformationDtoForm(fb: FormBuilder, dto?: Interfaces.EnterpriseRequestInformationDto | null): FormGroup<IEnterpriseRequestInformationDtoForm>;
/** Interface for a form from a EntitlementDto*/
export interface IEntitlementDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Assigned to User Id */
    UserId: FormControl<number | null>;
    /** Assigned to user name */
    User: FormControl<string | null>;
    /** Assigned to an organization id */
    OrganizationId: FormControl<number | null>;
    /** Assigned to an Organization name */
    Organization: FormControl<string | null>;
    /** The token id that created the entitlement if any */
    TokenId: FormControl<number | null>;
    /** Starts on */
    StartsOn: FormControl<Date | null>;
    /** Ends on */
    EndsOn: FormControl<Date | null>;
    /** What is the item in question? */
    InventoryItemId: FormControl<number | null>;
    /** The name of the inventory item associated with the entitlement */
    InventoryItem: FormControl<string | null>;
    /** Inventory Item Types */
    InventoryItemType: FormControl<Enums.InventoryItemTypes | null>;
    /** The inventory associated with the entitlement */
    InventoryId: FormControl<number | null>;
    /** The name of the inventory associated with the entitlement */
    Inventory: FormControl<string | null>;
    /** When was it cancelled */
    CancelledOn: FormControl<Date | null>;
    /** Billing Recurring Periods */
    RecurringPeriod: FormControl<Enums.RecurringPeriods | null>;
    /** The last time a payment was made */
    LastPaymentOn: FormControl<Date | null>;
    /** Next Payment On */
    NextPaymentOn: FormControl<Date | null>;
    /** Payment Credentials for recurring billing */
    PaymentCredentialsId: FormControl<number | null>;
    /** The name of the Payment credentials for recurring billing */
    PaymentCredentials: FormControl<string | null>;
    /** Determines whether an entitlement is active or not */
    Active: FormControl<boolean | null>;
    /** Serial Number */
    SerialNumber: FormControl<string | null>;
}
/**
/* Generates a form from a EntitlementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EntitlementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEntitlementDtoForm(fb: FormBuilder, dto?: Interfaces.EntitlementDto | null): FormGroup<IEntitlementDtoForm>;
/** Interface for a form from a EntitlementPaymentHistoryDto*/
export interface IEntitlementPaymentHistoryDtoForm {
    /** Entitlement Id */
    EntitlementId: FormControl<number | null>;
    /** Invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Invoice Date */
    InvoiceDate: FormControl<Date | null>;
    /** Invoice Total */
    InvoiceTotal: FormControl<number | null>;
    /** Payment Id */
    PaymentId: FormControl<number | null>;
    /** Payment Date */
    PaymentDate: FormControl<Date | null>;
    /** Payment Total */
    PaymentTotal: FormControl<number | null>;
}
/**
/* Generates a form from a EntitlementPaymentHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original EntitlementPaymentHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetEntitlementPaymentHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.EntitlementPaymentHistoryDto | null): FormGroup<IEntitlementPaymentHistoryDtoForm>;
/** Interface for a form from a ErrorLogDto*/
export interface IErrorLogDtoForm {
    /** Source File Path */
    SourceFilePath: FormControl<string | null>;
    /** Source Line Number */
    SourceLineNumber: FormControl<number | null>;
    /** Source Member Lesson */
    SourceMemberName: FormControl<string | null>;
    /** Error Message */
    ErrorMessage: FormControl<string | null>;
    /** Additional Details */
    AdditionalDetails: FormControl<string | null>;
    /** Stack Trace */
    StackTrace: FormControl<string | null>;
    /** Client Id */
    ClientId: FormControl<string | null>;
    /** Client Secret */
    ClientSecret: FormControl<string | null>;
}
/**
/* Generates a form from a ErrorLogDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ErrorLogDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetErrorLogDtoForm(fb: FormBuilder, dto?: Interfaces.ErrorLogDto | null): FormGroup<IErrorLogDtoForm>;
/** Interface for a form from a ExpiredUserEntitlementDto*/
export interface IExpiredUserEntitlementDtoForm {
    /** Is a trial entitlement */
    IsTrial: FormControl<boolean | null>;
    /** Is owned by an organization */
    IsOrganizationOwned: FormControl<boolean | null>;
    /** The ending date of the last entitlement */
    EndsOn: FormControl<Date | null>;
}
/**
/* Generates a form from a ExpiredUserEntitlementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ExpiredUserEntitlementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetExpiredUserEntitlementDtoForm(fb: FormBuilder, dto?: Interfaces.ExpiredUserEntitlementDto | null): FormGroup<IExpiredUserEntitlementDtoForm>;
/** Interface for a form from a ExpiringEntitlementDto*/
export interface IExpiringEntitlementDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Assigned to User Id */
    UserId: FormControl<number | null>;
    /** Assigned to user name */
    User: FormControl<string | null>;
    /** Assigned to an organization id */
    OrganizationId: FormControl<number | null>;
    /** Assigned to an Organization name */
    Organization: FormControl<string | null>;
    /** The token id that created the entitlement if any */
    TokenId: FormControl<number | null>;
    /** Starts on */
    StartsOn: FormControl<Date | null>;
    /** Ends on */
    EndsOn: FormControl<Date | null>;
    /** What is the item in question? */
    InventoryItemId: FormControl<number | null>;
    /** The name of the inventory item associated with the entitlement */
    InventoryItem: FormControl<string | null>;
    /** Inventory Item Types */
    InventoryItemType: FormControl<Enums.InventoryItemTypes | null>;
    /** The inventory associated with the entitlement */
    InventoryId: FormControl<number | null>;
    /** The name of the inventory associated with the entitlement */
    Inventory: FormControl<string | null>;
    /** When was it cancelled */
    CancelledOn: FormControl<Date | null>;
    /** Billing Recurring Periods */
    RecurringPeriod: FormControl<Enums.RecurringPeriods | null>;
    /** The last time a payment was made */
    LastPaymentOn: FormControl<Date | null>;
    /** Next Payment On */
    NextPaymentOn: FormControl<Date | null>;
    /** Payment Credentials for recurring billing */
    PaymentCredentialsId: FormControl<number | null>;
    /** The name of the Payment credentials for recurring billing */
    PaymentCredentials: FormControl<string | null>;
    /** Determines whether an entitlement is active or not */
    Active: FormControl<boolean | null>;
    /** Serial Number */
    SerialNumber: FormControl<string | null>;
    /** Email Address */
    Email: FormControl<string | null>;
}
/**
/* Generates a form from a ExpiringEntitlementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ExpiringEntitlementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetExpiringEntitlementDtoForm(fb: FormBuilder, dto?: Interfaces.ExpiringEntitlementDto | null): FormGroup<IExpiringEntitlementDtoForm>;
/** Interface for a form from a FileUploadWithParentDetailsDto*/
export interface IFileUploadWithParentDetailsDtoForm {
    /** The URI if the Type is Link. The Filename otherwise */
    Uri: FormControl<string | null>;
    /** The Lesson of the resource. */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
    /** The language associated with the resource. */
    LanguageCode: FormControl<string | null>;
    /** If Type != Url then the file that will be posted. */
    File: FormControl<File | null>;
    /** The Parent to the file that is being uploaded */
    ParentId: FormControl<number | null>;
}
/**
/* Generates a form from a FileUploadWithParentDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original FileUploadWithParentDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetFileUploadWithParentDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.FileUploadWithParentDetailsDto | null): FormGroup<IFileUploadWithParentDetailsDtoForm>;
/** Interface for a form from a FilterCriteria*/
export interface IFilterCriteriaForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Op: FormControl<Enums.LogicalOperators | null>;
    /**  */
    Relation: FormControl<Enums.RelationalOperators | null>;
    /**  */
    Values: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a FilterCriteria
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original FilterCriteria from which to create the form.
/* @returns FormGroup
 */
export declare function GetFilterCriteriaForm(fb: FormBuilder, dto?: Interfaces.FilterCriteria | null): FormGroup<IFilterCriteriaForm>;
/** Interface for a form from a GamificationStructureForEditingDto*/
export interface IGamificationStructureForEditingDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Item that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
}
/**
/* Generates a form from a GamificationStructureForEditingDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GamificationStructureForEditingDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGamificationStructureForEditingDtoForm(fb: FormBuilder, dto?: Interfaces.GamificationStructureForEditingDto | null): FormGroup<IGamificationStructureForEditingDtoForm>;
/** Interface for a form from a GamificationStructureForEditingWithChildrenDto*/
export interface IGamificationStructureForEditingWithChildrenDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Item that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Child Items */
    ChildItems: FormArray<FormGroup<IGamificationStructureForEditingWithChildrenDtoForm>>;
}
/**
/* Generates a form from a GamificationStructureForEditingWithChildrenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GamificationStructureForEditingWithChildrenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGamificationStructureForEditingWithChildrenDtoForm(fb: FormBuilder, dto?: Interfaces.GamificationStructureForEditingWithChildrenDto | null): FormGroup<IGamificationStructureForEditingWithChildrenDtoForm>;
/** Interface for a form from a GamificationUserEarnedDto*/
export interface IGamificationUserEarnedDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** Badges */
    Badges: FormArray<FormGroup<IBadgeUserEarnedDtoForm>>;
    /** Medallions */
    Medallions: FormArray<FormGroup<IMedallionUserEarnedDtoForm>>;
    /** Disciplines */
    Disciplines: FormArray<FormGroup<IDisciplineUserEarnedDtoForm>>;
}
/**
/* Generates a form from a GamificationUserEarnedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GamificationUserEarnedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGamificationUserEarnedDtoForm(fb: FormBuilder, dto?: Interfaces.GamificationUserEarnedDto | null): FormGroup<IGamificationUserEarnedDtoForm>;
/** Interface for a form from a GenerateAssessmentDto*/
export interface IGenerateAssessmentDtoForm {
    /** The assessment id */
    AssessmentId: FormControl<number | null>;
    /** The assessment name */
    Name: FormControl<string | null>;
    /** The number of questions to generate in the assessment */
    Questions: FormControl<number | null>;
    /** The concept ids to generate the assessment from */
    ConceptIds: FormArray<FormControl<number | null>>;
    /** The topic ids to generate the assessment from */
    TopicIds: FormArray<FormControl<number | null>>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
}
/**
/* Generates a form from a GenerateAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GenerateAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGenerateAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.GenerateAssessmentDto | null): FormGroup<IGenerateAssessmentDtoForm>;
/** Interface for a form from a GenerateAssessmentGamificationDto*/
export interface IGenerateAssessmentGamificationDtoForm {
    /** The assessment id */
    AssessmentId: FormControl<number | null>;
    /** The assessment name */
    Name: FormControl<string | null>;
    /** The number of questions to generate in the assessment */
    Questions: FormControl<number | null>;
    /** The badge ids to generate the assessment from */
    BadgeIds: FormArray<FormControl<number | null>>;
    /** The medallion ids to generate the assessment from */
    MedallionIds: FormArray<FormControl<number | null>>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
}
/**
/* Generates a form from a GenerateAssessmentGamificationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GenerateAssessmentGamificationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGenerateAssessmentGamificationDtoForm(fb: FormBuilder, dto?: Interfaces.GenerateAssessmentGamificationDto | null): FormGroup<IGenerateAssessmentGamificationDtoForm>;
/** Interface for a form from a GenerateGapAssessmentDto*/
export interface IGenerateGapAssessmentDtoForm {
    /** The assessment id */
    AssessmentId: FormControl<number | null>;
    /** The assessment name */
    Name: FormControl<string | null>;
    /** The number of questions to generate in the assessment */
    Questions: FormControl<number | null>;
    /** The concept ids to generate the assessment from */
    ConceptIds: FormArray<FormControl<number | null>>;
    /** The topic ids to generate the assessment from */
    TopicIds: FormArray<FormControl<number | null>>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version 2 Id */
    Version2Id: FormControl<number | null>;
}
/**
/* Generates a form from a GenerateGapAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GenerateGapAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGenerateGapAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.GenerateGapAssessmentDto | null): FormGroup<IGenerateGapAssessmentDtoForm>;
/** Interface for a form from a GenerateProjectPreHireAssessmentDto*/
export interface IGenerateProjectPreHireAssessmentDtoForm {
    /** Project Job id */
    ProjectJobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Assessment Lesson */
    AssessmentName: FormControl<string | null>;
    /** Number Of Questions */
    NumberOfQuestions: FormControl<number | null>;
}
/**
/* Generates a form from a GenerateProjectPreHireAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GenerateProjectPreHireAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGenerateProjectPreHireAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.GenerateProjectPreHireAssessmentDto | null): FormGroup<IGenerateProjectPreHireAssessmentDtoForm>;
/** Interface for a form from a GetBotConversationDto*/
export interface IGetBotConversationDtoForm {
    /** The Id of the conversation to retrieve */
    Id: FormControl<string | null>;
}
/**
/* Generates a form from a GetBotConversationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GetBotConversationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetGetBotConversationDtoForm(fb: FormBuilder, dto?: Interfaces.GetBotConversationDto | null): FormGroup<IGetBotConversationDtoForm>;
/** Interface for a form from a GroupCriteria*/
export interface IGroupCriteriaForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Direction: FormControl<Enums.OrderDirections | null>;
    /**  */
    Aggregates: FormArray<FormGroup<IAggregateCriteriaForm>>;
    /**  */
    SubGroup: FormGroup<IGroupCriteriaForm>;
}
/**
/* Generates a form from a GroupCriteria
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GroupCriteria from which to create the form.
/* @returns FormGroup
 */
export declare function GetGroupCriteriaForm(fb: FormBuilder, dto?: Interfaces.GroupCriteria | null): FormGroup<IGroupCriteriaForm>;
/** Interface for a form from a GroupResult*/
export interface IGroupResultForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Value: FormControl<string | null>;
    /**  */
    Aggregates: FormArray<FormGroup<IAggregateResultForm>>;
    /**  */
    SubGroupResults: FormArray<FormGroup<IGroupResultForm>>;
}
/**
/* Generates a form from a GroupResult
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original GroupResult from which to create the form.
/* @returns FormGroup
 */
export declare function GetGroupResultForm(fb: FormBuilder, dto?: Interfaces.GroupResult | null): FormGroup<IGroupResultForm>;
/** Interface for a form from a HelpQuestionDto*/
export interface IHelpQuestionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The text of the question */
    Text: FormControl<string | null>;
}
/**
/* Generates a form from a HelpQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original HelpQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetHelpQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.HelpQuestionDto | null): FormGroup<IHelpQuestionDtoForm>;
/** Interface for a form from a ImageUploadDetailsDto*/
export interface IImageUploadDetailsDtoForm {
    /** The Parent to the file that is being uploaded */
    ParentId: FormControl<number | null>;
    /** The Image that will be uploaded */
    File: FormControl<File | null>;
}
/**
/* Generates a form from a ImageUploadDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ImageUploadDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetImageUploadDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.ImageUploadDetailsDto | null): FormGroup<IImageUploadDetailsDtoForm>;
/** Interface for a form from a ImportCourseDto*/
export interface IImportCourseDtoForm {
    /** The Id of the course that the items will be imported from */
    SourceCourseId: FormControl<number | null>;
    /** The Id of the course that the items will be imported into. */
    DestinationCourseId: FormControl<number | null>;
    /** The items to be imported */
    Items: FormArray<FormGroup<ICourseStructureForEditingWithChildrenDtoForm>>;
}
/**
/* Generates a form from a ImportCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ImportCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetImportCourseDtoForm(fb: FormBuilder, dto?: Interfaces.ImportCourseDto | null): FormGroup<IImportCourseDtoForm>;
/** Interface for a form from a ImportQuestionDto*/
export interface IImportQuestionDtoForm {
    /** The question id */
    QuestionId: FormControl<number | null>;
    /** The assessment id */
    AssessmentId: FormControl<number | null>;
    /** The organization id */
    OrganizationId: FormControl<number | null>;
    /** The order of the question */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a ImportQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ImportQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetImportQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.ImportQuestionDto | null): FormGroup<IImportQuestionDtoForm>;
/** Interface for a form from a ImportResourceDto*/
export interface IImportResourceDtoForm {
    /** The parent item that will have a link to the given resource */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** The Resource to be imported */
    ResourceId: FormControl<number | null>;
    /** Directions for use if any */
    Directions: FormControl<string | null>;
}
/**
/* Generates a form from a ImportResourceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ImportResourceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetImportResourceDtoForm(fb: FormBuilder, dto?: Interfaces.ImportResourceDto | null): FormGroup<IImportResourceDtoForm>;
/** Interface for a form from a IndustryDto*/
export interface IIndustryDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a IndustryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original IndustryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetIndustryDtoForm(fb: FormBuilder, dto?: Interfaces.IndustryDto | null): FormGroup<IIndustryDtoForm>;
/** Interface for a form from a Int32NameValueDto*/
export interface IInt32NameValueDtoForm {
    /** Lesson of the item */
    Name: FormControl<string | null>;
    /** Value of the Item */
    Value: FormControl<number | null>;
}
/**
/* Generates a form from a Int32NameValueDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original Int32NameValueDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInt32NameValueDtoForm(fb: FormBuilder, dto?: Interfaces.Int32NameValueDto | null): FormGroup<IInt32NameValueDtoForm>;
/** Interface for a form from a InventoryDto*/
export interface IInventoryDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Keywords */
    Keywords: FormControl<string | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Ends On */
    EndsOn: FormControl<Date | null>;
    /** SKU */
    SKU: FormControl<string | null>;
    /** Show on web */
    ShowOnWeb: FormControl<boolean | null>;
    /** Is the inventory item active */
    Active: FormControl<boolean | null>;
}
/**
/* Generates a form from a InventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.InventoryDto | null): FormGroup<IInventoryDtoForm>;
/** Interface for a form from a InventoryItemDto*/
export interface IInventoryItemDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Inventory Identifier */
    InventoryId: FormControl<number | null>;
    /** Inventory Lesson */
    Inventory: FormControl<string | null>;
    /** The Id of the item */
    ItemId: FormControl<number | null>;
    /** The name of the item */
    Item: FormControl<string | null>;
    /** Inventory Item Types */
    Type: FormControl<Enums.InventoryItemTypes | null>;
    /** Billing Recurring Periods */
    RecurringPeriod: FormControl<Enums.RecurringPeriods | null>;
    /** Requires Shipping */
    RequiresShipping: FormControl<boolean | null>;
}
/**
/* Generates a form from a InventoryItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InventoryItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInventoryItemDtoForm(fb: FormBuilder, dto?: Interfaces.InventoryItemDto | null): FormGroup<IInventoryItemDtoForm>;
/** Interface for a form from a InventoryWithPriceDto*/
export interface IInventoryWithPriceDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Keywords */
    Keywords: FormControl<string | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Ends On */
    EndsOn: FormControl<Date | null>;
    /** SKU */
    SKU: FormControl<string | null>;
    /** Show on web */
    ShowOnWeb: FormControl<boolean | null>;
    /** Price */
    Price: FormControl<number | null>;
}
/**
/* Generates a form from a InventoryWithPriceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InventoryWithPriceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInventoryWithPriceDtoForm(fb: FormBuilder, dto?: Interfaces.InventoryWithPriceDto | null): FormGroup<IInventoryWithPriceDtoForm>;
/** Interface for a form from a InvitePlayListEmailAddressesDto*/
export interface IInvitePlayListEmailAddressesDtoForm {
    /** The url of the site that users will be directed to, to view the play list and or accept/reject it. */
    SiteUrl: FormControl<string | null>;
    /** The play list to invite into */
    PlayListId: FormControl<number | null>;
    /** A list of email addresses to invite */
    EmailAddresses: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a InvitePlayListEmailAddressesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvitePlayListEmailAddressesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvitePlayListEmailAddressesDtoForm(fb: FormBuilder, dto?: Interfaces.InvitePlayListEmailAddressesDto | null): FormGroup<IInvitePlayListEmailAddressesDtoForm>;
/** Interface for a form from a InvitePlayListUsersByGroupDto*/
export interface IInvitePlayListUsersByGroupDtoForm {
    /** The url of the site that users will be directed to, to view the play list and or accept/reject it. */
    SiteUrl: FormControl<string | null>;
    /** The play list to invite into */
    PlayListId: FormControl<number | null>;
    /** Organization Id for groups */
    OrganizationId: FormControl<number | null>;
    /** A list of UserIds to invite */
    Groups: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a InvitePlayListUsersByGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvitePlayListUsersByGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvitePlayListUsersByGroupDtoForm(fb: FormBuilder, dto?: Interfaces.InvitePlayListUsersByGroupDto | null): FormGroup<IInvitePlayListUsersByGroupDtoForm>;
/** Interface for a form from a InvitePlayListUsersDto*/
export interface IInvitePlayListUsersDtoForm {
    /** The url of the site that users will be directed to, to view the play list and or accept/reject it. */
    SiteUrl: FormControl<string | null>;
    /** The play list to invite into */
    PlayListId: FormControl<number | null>;
    /** A list of UserIds to invite */
    UserIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a InvitePlayListUsersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvitePlayListUsersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvitePlayListUsersDtoForm(fb: FormBuilder, dto?: Interfaces.InvitePlayListUsersDto | null): FormGroup<IInvitePlayListUsersDtoForm>;
/** Interface for a form from a InvitePreHireUserDto*/
export interface IInvitePreHireUserDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** The assessment to invite them to */
    AssessmentId: FormControl<number | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Phone Number */
    SendEmail: FormControl<boolean | null>;
    /** Invitation URL */
    InvitationURL: FormControl<string | null>;
    /** The main Dto that describes a user */
    User: FormGroup<IUserDtoForm>;
}
/**
/* Generates a form from a InvitePreHireUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvitePreHireUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvitePreHireUserDtoForm(fb: FormBuilder, dto?: Interfaces.InvitePreHireUserDto | null): FormGroup<IInvitePreHireUserDtoForm>;
/** Interface for a form from a InviteUserDto*/
export interface IInviteUserDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** The portal to invite them to */
    PortalId: FormControl<number | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Phone Extension */
    PhoneExt: FormControl<string | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Group */
    GroupId: FormControl<number | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Send invite email */
    SendEmail: FormControl<boolean | null>;
    /** Personal Login to invite existing user */
    PersonalLogin: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Sku to give to the invited user */
    SKU: FormControl<string | null>;
}
/**
/* Generates a form from a InviteUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InviteUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInviteUserDtoForm(fb: FormBuilder, dto?: Interfaces.InviteUserDto | null): FormGroup<IInviteUserDtoForm>;
/** Interface for a form from a InvoiceDisplayDto*/
export interface IInvoiceDisplayDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The originating Organization Id */
    FromOrganizationId: FormControl<number | null>;
    /** The user to email when a quote is submitted */
    FromOrganizationUserId: FormControl<number | null>;
    /** The name of the originating organization */
    FromOrganization: FormControl<string | null>;
    /** Who is being invoiced/billed/POed */
    ToContactId: FormControl<number | null>;
    /** Contact Types */
    ToContactType: FormControl<Enums.ContactTypes | null>;
    /** Invoice Types */
    Type: FormControl<Enums.InvoiceTypes | null>;
    /** A link to a purchase order if this invoice was created from one. */
    PurchaseOrderId: FormControl<number | null>;
    /** the date of the invoice */
    Date: FormControl<Date | null>;
    /** the subtotal of all line items */
    SubTotal: FormControl<number | null>;
    /** The sales tax that is applied */
    SalesTax1Id: FormControl<number | null>;
    /** The name of the sales tax applied */
    SalesTax1: FormControl<string | null>;
    /** The amount of the first sales tax */
    SalesTax1Amount: FormControl<number | null>;
    /** The second sales tax applied */
    SalesTax2Id: FormControl<number | null>;
    /** The name of the second sales tax */
    SalesTax2: FormControl<string | null>;
    /** The amount of the second sales tax */
    SalesTax2Amount: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethodId: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethod: FormControl<string | null>;
    /** The amount of the shipping */
    Shipping: FormControl<number | null>;
    /** The grand total of the invoice all inclusive */
    GrandTotal: FormControl<number | null>;
    /** The current balance of the invoice */
    Balance: FormControl<number | null>;
    /** The id of the Billing Address for the invoice */
    BillingAddressId: FormControl<number | null>;
    /** The shipping Address for the invoice if applicable */
    ShippingAddressId: FormControl<number | null>;
    /** Invoice # */
    InvoiceNumber: FormControl<number | null>;
    /** The Number of the bill */
    BillNumber: FormControl<string | null>;
    /** Purchase Order # */
    PurchaseOrderNumber: FormControl<string | null>;
    /** Invoice Statuses */
    Status: FormControl<Enums.InvoiceStatuses | null>;
    /** Notes field */
    Notes: FormControl<string | null>;
    /** Lesson of the contact */
    ToContact: FormControl<string | null>;
}
/**
/* Generates a form from a InvoiceDisplayDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoiceDisplayDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoiceDisplayDtoForm(fb: FormBuilder, dto?: Interfaces.InvoiceDisplayDto | null): FormGroup<IInvoiceDisplayDtoForm>;
/** Interface for a form from a InvoiceDto*/
export interface IInvoiceDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The originating Organization Id */
    FromOrganizationId: FormControl<number | null>;
    /** The user to email when a quote is submitted */
    FromOrganizationUserId: FormControl<number | null>;
    /** The name of the originating organization */
    FromOrganization: FormControl<string | null>;
    /** Who is being invoiced/billed/POed */
    ToContactId: FormControl<number | null>;
    /** Contact Types */
    ToContactType: FormControl<Enums.ContactTypes | null>;
    /** Invoice Types */
    Type: FormControl<Enums.InvoiceTypes | null>;
    /** A link to a purchase order if this invoice was created from one. */
    PurchaseOrderId: FormControl<number | null>;
    /** the date of the invoice */
    Date: FormControl<Date | null>;
    /** the subtotal of all line items */
    SubTotal: FormControl<number | null>;
    /** The sales tax that is applied */
    SalesTax1Id: FormControl<number | null>;
    /** The name of the sales tax applied */
    SalesTax1: FormControl<string | null>;
    /** The amount of the first sales tax */
    SalesTax1Amount: FormControl<number | null>;
    /** The second sales tax applied */
    SalesTax2Id: FormControl<number | null>;
    /** The name of the second sales tax */
    SalesTax2: FormControl<string | null>;
    /** The amount of the second sales tax */
    SalesTax2Amount: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethodId: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethod: FormControl<string | null>;
    /** The amount of the shipping */
    Shipping: FormControl<number | null>;
    /** The grand total of the invoice all inclusive */
    GrandTotal: FormControl<number | null>;
    /** The current balance of the invoice */
    Balance: FormControl<number | null>;
    /** The id of the Billing Address for the invoice */
    BillingAddressId: FormControl<number | null>;
    /** The shipping Address for the invoice if applicable */
    ShippingAddressId: FormControl<number | null>;
    /** Invoice # */
    InvoiceNumber: FormControl<number | null>;
    /** The Number of the bill */
    BillNumber: FormControl<string | null>;
    /** Purchase Order # */
    PurchaseOrderNumber: FormControl<string | null>;
    /** Invoice Statuses */
    Status: FormControl<Enums.InvoiceStatuses | null>;
    /** Notes field */
    Notes: FormControl<string | null>;
}
/**
/* Generates a form from a InvoiceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoiceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoiceDtoForm(fb: FormBuilder, dto?: Interfaces.InvoiceDto | null): FormGroup<IInvoiceDtoForm>;
/** Interface for a form from a InvoiceInventoryDto*/
export interface IInvoiceInventoryDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Inventory Id */
    InventoryId: FormControl<number | null>;
    /** Inventory Lesson */
    InventoryName: FormControl<string | null>;
    /** Units */
    Units: FormControl<number | null>;
    /** Price */
    Price: FormControl<number | null>;
    /** Create Token */
    CreateToken: FormControl<boolean | null>;
    /** If Create Token, also allow configuration of token expiration date */
    TokenExpirationDate: FormControl<Date | null>;
    /** Disputed? */
    Disputed: FormControl<boolean | null>;
    /** Dispute Reason */
    DisputeReason: FormControl<string | null>;
    /** Entitlements */
    Entitlements: FormArray<FormGroup<IInvoiceInventoryEntitlementDtoForm>>;
}
/**
/* Generates a form from a InvoiceInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoiceInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoiceInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.InvoiceInventoryDto | null): FormGroup<IInvoiceInventoryDtoForm>;
/** Interface for a form from a InvoiceInventoryEntitlementDto*/
export interface IInvoiceInventoryEntitlementDtoForm {
    /** Invoice Inventory Id */
    InvoiceInventoryId: FormControl<number | null>;
    /** Entitlement Id */
    EntitlementId: FormControl<number | null>;
    /** Description of the entitlement */
    Entitlement: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User name */
    User: FormControl<string | null>;
    /** Org User */
    InvoiceNumber: FormControl<string | null>;
}
/**
/* Generates a form from a InvoiceInventoryEntitlementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoiceInventoryEntitlementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoiceInventoryEntitlementDtoForm(fb: FormBuilder, dto?: Interfaces.InvoiceInventoryEntitlementDto | null): FormGroup<IInvoiceInventoryEntitlementDtoForm>;
/** Interface for a form from a InvoicePaymentDto*/
export interface IInvoicePaymentDtoForm {
    /** the invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Payment Id */
    PaymentId: FormControl<number | null>;
    /** Date of payment */
    Date: FormControl<Date | null>;
    /** Payment Total */
    PaymentTotal: FormControl<number | null>;
    /** How much of the payment total was applied to the specified invoice */
    InvoiceAmountPaid: FormControl<number | null>;
    /** Payment Method Id */
    PaymentMethodId: FormControl<number | null>;
    /** Payment Method */
    PaymentMethod: FormControl<string | null>;
    /** Payemnt Statuses */
    Status: FormControl<Enums.PaymentStatuses | null>;
}
/**
/* Generates a form from a InvoicePaymentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoicePaymentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoicePaymentDtoForm(fb: FormBuilder, dto?: Interfaces.InvoicePaymentDto | null): FormGroup<IInvoicePaymentDtoForm>;
/** Interface for a form from a InvoiceWithInventoryDto*/
export interface IInvoiceWithInventoryDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The originating Organization Id */
    FromOrganizationId: FormControl<number | null>;
    /** The user to email when a quote is submitted */
    FromOrganizationUserId: FormControl<number | null>;
    /** The name of the originating organization */
    FromOrganization: FormControl<string | null>;
    /** Who is being invoiced/billed/POed */
    ToContactId: FormControl<number | null>;
    /** Contact Types */
    ToContactType: FormControl<Enums.ContactTypes | null>;
    /** Invoice Types */
    Type: FormControl<Enums.InvoiceTypes | null>;
    /** A link to a purchase order if this invoice was created from one. */
    PurchaseOrderId: FormControl<number | null>;
    /** the date of the invoice */
    Date: FormControl<Date | null>;
    /** the subtotal of all line items */
    SubTotal: FormControl<number | null>;
    /** The sales tax that is applied */
    SalesTax1Id: FormControl<number | null>;
    /** The name of the sales tax applied */
    SalesTax1: FormControl<string | null>;
    /** The amount of the first sales tax */
    SalesTax1Amount: FormControl<number | null>;
    /** The second sales tax applied */
    SalesTax2Id: FormControl<number | null>;
    /** The name of the second sales tax */
    SalesTax2: FormControl<string | null>;
    /** The amount of the second sales tax */
    SalesTax2Amount: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethodId: FormControl<number | null>;
    /** The name of the shipping method */
    ShippingMethod: FormControl<string | null>;
    /** The amount of the shipping */
    Shipping: FormControl<number | null>;
    /** The grand total of the invoice all inclusive */
    GrandTotal: FormControl<number | null>;
    /** The current balance of the invoice */
    Balance: FormControl<number | null>;
    /** The id of the Billing Address for the invoice */
    BillingAddressId: FormControl<number | null>;
    /** The shipping Address for the invoice if applicable */
    ShippingAddressId: FormControl<number | null>;
    /** Invoice # */
    InvoiceNumber: FormControl<number | null>;
    /** The Number of the bill */
    BillNumber: FormControl<string | null>;
    /** Purchase Order # */
    PurchaseOrderNumber: FormControl<string | null>;
    /** Invoice Statuses */
    Status: FormControl<Enums.InvoiceStatuses | null>;
    /** Notes field */
    Notes: FormControl<string | null>;
    /** Inventory Items */
    Items: FormArray<FormGroup<IInvoiceInventoryDtoForm>>;
}
/**
/* Generates a form from a InvoiceWithInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original InvoiceWithInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetInvoiceWithInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.InvoiceWithInventoryDto | null): FormGroup<IInvoiceWithInventoryDtoForm>;
/** Interface for a form from a ItemCompletionDto*/
export interface IItemCompletionDtoForm {
    /** Lesson */
    Id: FormControl<number | null>;
    /** Item Name */
    Name: FormControl<string | null>;
    /** Score */
    Score: FormControl<number | null>;
    /** OutOf */
    OutOf: FormControl<number | null>;
    /** Percent */
    Percent: FormControl<number | null>;
}
/**
/* Generates a form from a ItemCompletionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ItemCompletionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetItemCompletionDtoForm(fb: FormBuilder, dto?: Interfaces.ItemCompletionDto | null): FormGroup<IItemCompletionDtoForm>;
/** Interface for a form from a JobAssignedOrganizationsDto*/
export interface IJobAssignedOrganizationsDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a JobAssignedOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobAssignedOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobAssignedOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.JobAssignedOrganizationsDto | null): FormGroup<IJobAssignedOrganizationsDtoForm>;
/** Interface for a form from a JobAverageScoreJobDto*/
export interface IJobAverageScoreJobDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Organization Average Score */
    OrganizationScore: FormControl<number | null>;
    /** Industry Average Score */
    IndustryScore: FormControl<number | null>;
    /** Users own Score */
    OwnScore: FormControl<number | null>;
}
/**
/* Generates a form from a JobAverageScoreJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobAverageScoreJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobAverageScoreJobDtoForm(fb: FormBuilder, dto?: Interfaces.JobAverageScoreJobDto | null): FormGroup<IJobAverageScoreJobDtoForm>;
/** Interface for a form from a JobAverageScoresDto*/
export interface IJobAverageScoresDtoForm {
    /** Include Organizational Score */
    IncludeOrganizationScore: FormControl<boolean | null>;
    /** Include Industry Score */
    IncludeIndustryScore: FormControl<boolean | null>;
    /** Jobs */
    Jobs: FormArray<FormGroup<IJobAverageScoreJobDtoForm>>;
}
/**
/* Generates a form from a JobAverageScoresDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobAverageScoresDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobAverageScoresDtoForm(fb: FormBuilder, dto?: Interfaces.JobAverageScoresDto | null): FormGroup<IJobAverageScoresDtoForm>;
/** Interface for a form from a JobDisciplineDto*/
export interface IJobDisciplineDtoForm {
    /** Discipline Id */
    Id: FormControl<number | null>;
    /** Discipline Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a JobDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.JobDisciplineDto | null): FormGroup<IJobDisciplineDtoForm>;
/** Interface for a form from a JobDto*/
export interface IJobDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a JobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobDtoForm(fb: FormBuilder, dto?: Interfaces.JobDto | null): FormGroup<IJobDtoForm>;
/** Interface for a form from a JobGroupDto*/
export interface IJobGroupDtoForm {
    /** Job id */
    JobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Group */
    GroupId: FormControl<number | null>;
    /** Group Lesson */
    GroupName: FormControl<string | null>;
}
/**
/* Generates a form from a JobGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobGroupDtoForm(fb: FormBuilder, dto?: Interfaces.JobGroupDto | null): FormGroup<IJobGroupDtoForm>;
/** Interface for a form from a JobHeaderLessonDto*/
export interface IJobHeaderLessonDtoForm {
    /** Job id */
    JobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Header Lesson Id */
    LessonId: FormControl<number | null>;
    /** Header Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a JobHeaderLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobHeaderLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobHeaderLessonDtoForm(fb: FormBuilder, dto?: Interfaces.JobHeaderLessonDto | null): FormGroup<IJobHeaderLessonDtoForm>;
/** Interface for a form from a JobIndustryDto*/
export interface IJobIndustryDtoForm {
    /** Industry Id */
    Id: FormControl<number | null>;
    /** Industry Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a JobIndustryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobIndustryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobIndustryDtoForm(fb: FormBuilder, dto?: Interfaces.JobIndustryDto | null): FormGroup<IJobIndustryDtoForm>;
/** Interface for a form from a JobLearningPathDto*/
export interface IJobLearningPathDtoForm {
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Discipline Lesson */
    Name: FormControl<string | null>;
    /** Discipline Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Disciplines */
    TotalDisciplines: FormControl<number | null>;
    /** Number of Completed Medallions */
    TotalCompletedDisciplines: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Total # of Badges */
    TotalBadges: FormControl<number | null>;
    /** When the Job was started. */
    StartedOn: FormControl<Date | null>;
    /** When will the trend line hit 0? */
    TrendZeroOn: FormControl<Date | null>;
    /** Discipline Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** History of completion */
    History: FormArray<FormGroup<ILearningPathHistoryDtoForm>>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Disciplines */
    Disciplines: FormArray<FormGroup<IDisciplineLearningPathDtoForm>>;
}
/**
/* Generates a form from a JobLearningPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobLearningPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobLearningPathDtoForm(fb: FormBuilder, dto?: Interfaces.JobLearningPathDto | null): FormGroup<IJobLearningPathDtoForm>;
/** Interface for a form from a JobProductDto*/
export interface IJobProductDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a JobProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobProductDtoForm(fb: FormBuilder, dto?: Interfaces.JobProductDto | null): FormGroup<IJobProductDtoForm>;
/** Interface for a form from a JobSyndicationProviderDto*/
export interface IJobSyndicationProviderDtoForm {
    /** Job id */
    JobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a JobSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.JobSyndicationProviderDto | null): FormGroup<IJobSyndicationProviderDtoForm>;
/** Interface for a form from a JobTranslationDto*/
export interface IJobTranslationDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a JobTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.JobTranslationDto | null): FormGroup<IJobTranslationDtoForm>;
/** Interface for a form from a JobWithDisciplineIdsDto*/
export interface IJobWithDisciplineIdsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Discipline Ids in the Job */
    DisciplineIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a JobWithDisciplineIdsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobWithDisciplineIdsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobWithDisciplineIdsDtoForm(fb: FormBuilder, dto?: Interfaces.JobWithDisciplineIdsDto | null): FormGroup<IJobWithDisciplineIdsDtoForm>;
/** Interface for a form from a JobWithProductsDto*/
export interface IJobWithProductsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
    /** Products */
    Products: FormArray<FormGroup<IJobProductDtoForm>>;
}
/**
/* Generates a form from a JobWithProductsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original JobWithProductsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetJobWithProductsDtoForm(fb: FormBuilder, dto?: Interfaces.JobWithProductsDto | null): FormGroup<IJobWithProductsDtoForm>;
/** Interface for a form from a LanguageImportDto*/
export interface ILanguageImportDtoForm {
    /** Is a test run */
    Test: FormControl<boolean | null>;
    /** Imported/Updated items */
    Items: FormArray<FormGroup<ILanguageImportItemDtoForm>>;
}
/**
/* Generates a form from a LanguageImportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LanguageImportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLanguageImportDtoForm(fb: FormBuilder, dto?: Interfaces.LanguageImportDto | null): FormGroup<ILanguageImportDtoForm>;
/** Interface for a form from a LanguageImportItemDto*/
export interface ILanguageImportItemDtoForm {
    /** Page Lesson */
    Page: FormControl<string | null>;
    /** Lookup Key */
    Key: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Before Import */
    BeforeValue: FormControl<string | null>;
    /** After Import */
    AfterValue: FormControl<string | null>;
}
/**
/* Generates a form from a LanguageImportItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LanguageImportItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLanguageImportItemDtoForm(fb: FormBuilder, dto?: Interfaces.LanguageImportItemDto | null): FormGroup<ILanguageImportItemDtoForm>;
/** Interface for a form from a LearningPathHistoryDto*/
export interface ILearningPathHistoryDtoForm {
    /** Date with remaining */
    Date: FormControl<Date | null>;
    /** Remaining Badges */
    Remaining: FormControl<number | null>;
}
/**
/* Generates a form from a LearningPathHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LearningPathHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLearningPathHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.LearningPathHistoryDto | null): FormGroup<ILearningPathHistoryDtoForm>;
/** Interface for a form from a LessonActivityDetailDto*/
export interface ILessonActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Tags */
    Tags: FormControl<string | null>;
}
/**
/* Generates a form from a LessonActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.LessonActivityDetailDto | null): FormGroup<ILessonActivityDetailDtoForm>;
/** Interface for a form from a LessonAdminDto*/
export interface ILessonAdminDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** The body of the item */
    Content: FormControl<string | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** The Organization that owns the lesson */
    OwningOrganizationId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is Lesson Obsolete */
    Obsolete: FormControl<boolean | null>;
    /** Cover Art Thumbnail */
    CoverArtUri: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Has Viewed Lesson In Production */
    ViewedInProduction: FormControl<boolean | null>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
}
/**
/* Generates a form from a LessonAdminDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonAdminDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonAdminDtoForm(fb: FormBuilder, dto?: Interfaces.LessonAdminDto | null): FormGroup<ILessonAdminDtoForm>;
/** Interface for a form from a LessonBadgeDto*/
export interface ILessonBadgeDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** User Assigned To Id */
    AssignedToId: FormControl<number | null>;
    /** user Lesson Assigned To */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a LessonBadgeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonBadgeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonBadgeDtoForm(fb: FormBuilder, dto?: Interfaces.LessonBadgeDto | null): FormGroup<ILessonBadgeDtoForm>;
/** Interface for a form from a LessonCommandDto*/
export interface ILessonCommandDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Command */
    Command: FormControl<string | null>;
}
/**
/* Generates a form from a LessonCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonCommandDtoForm(fb: FormBuilder, dto?: Interfaces.LessonCommandDto | null): FormGroup<ILessonCommandDtoForm>;
/** Interface for a form from a LessonDependencyDto*/
export interface ILessonDependencyDtoForm {
    /** Lesson */
    LessonId: FormControl<number | null>;
    /** Depends On Lesson Id */
    DependsOnLessonId: FormControl<number | null>;
    /** Depends On Lesson Lesson */
    DependsOnLesson: FormControl<string | null>;
}
/**
/* Generates a form from a LessonDependencyDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonDependencyDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonDependencyDtoForm(fb: FormBuilder, dto?: Interfaces.LessonDependencyDto | null): FormGroup<ILessonDependencyDtoForm>;
/** Interface for a form from a LessonDetailsWithUserInfoDto*/
export interface ILessonDetailsWithUserInfoDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** The body of the item */
    Content: FormControl<string | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** The Organization that owns the lesson */
    OwningOrganizationId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is Lesson Obsolete */
    Obsolete: FormControl<boolean | null>;
    /** Cover Art Thumbnail */
    CoverArtUri: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Has Viewed Lesson In Production */
    ViewedInProduction: FormControl<boolean | null>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** User's rating */
    UserRating: FormControl<number | null>;
}
/**
/* Generates a form from a LessonDetailsWithUserInfoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonDetailsWithUserInfoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonDetailsWithUserInfoDtoForm(fb: FormBuilder, dto?: Interfaces.LessonDetailsWithUserInfoDto | null): FormGroup<ILessonDetailsWithUserInfoDtoForm>;
/** Interface for a form from a LessonDisciplineDto*/
export interface ILessonDisciplineDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
    /** User Assigned To Id */
    AssignedToId: FormControl<number | null>;
    /** user Lesson Assigned To */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a LessonDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.LessonDisciplineDto | null): FormGroup<ILessonDisciplineDtoForm>;
/** Interface for a form from a LessonDto*/
export interface ILessonDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** The body of the item */
    Content: FormControl<string | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** The Organization that owns the lesson */
    OwningOrganizationId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is Lesson Obsolete */
    Obsolete: FormControl<boolean | null>;
    /** Cover Art Thumbnail */
    CoverArtUri: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Has Viewed Lesson In Production */
    ViewedInProduction: FormControl<boolean | null>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a LessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonDtoForm(fb: FormBuilder, dto?: Interfaces.LessonDto | null): FormGroup<ILessonDtoForm>;
/** Interface for a form from a LessonJobDto*/
export interface ILessonJobDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** User Assigned To Id */
    AssignedToId: FormControl<number | null>;
    /** user Lesson Assigned To */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a LessonJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonJobDtoForm(fb: FormBuilder, dto?: Interfaces.LessonJobDto | null): FormGroup<ILessonJobDtoForm>;
/** Interface for a form from a LessonLabelDto*/
export interface ILessonLabelDtoForm {
    /** Lesson */
    LessonId: FormControl<number | null>;
    /** Label */
    Label: FormControl<string | null>;
}
/**
/* Generates a form from a LessonLabelDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonLabelDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonLabelDtoForm(fb: FormBuilder, dto?: Interfaces.LessonLabelDto | null): FormGroup<ILessonLabelDtoForm>;
/** Interface for a form from a LessonMedallionDto*/
export interface ILessonMedallionDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** User Assigned To Id */
    AssignedToId: FormControl<number | null>;
    /** user Lesson Assigned To */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a LessonMedallionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonMedallionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonMedallionDtoForm(fb: FormBuilder, dto?: Interfaces.LessonMedallionDto | null): FormGroup<ILessonMedallionDtoForm>;
/** Interface for a form from a LessonPathDto*/
export interface ILessonPathDtoForm {
    /** Lesson Id */
    Id: FormControl<number | null>;
    /** Lesson Lesson */
    Name: FormControl<string | null>;
    /** Lesson Length */
    Length: FormControl<number | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Has the lesson been earned? */
    Earned: FormControl<boolean | null>;
}
/**
/* Generates a form from a LessonPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonPathDtoForm(fb: FormBuilder, dto?: Interfaces.LessonPathDto | null): FormGroup<ILessonPathDtoForm>;
/** Interface for a form from a LessonPublicationStatusDto*/
export interface ILessonPublicationStatusDtoForm {
    /** Has Commands */
    HasCommands: FormControl<boolean | null>;
    /** Has Dependencies */
    HasDependencies: FormControl<boolean | null>;
    /** Has Lesson */
    HasName: FormControl<boolean | null>;
    /** Has Description */
    HasDescription: FormControl<boolean | null>;
    /** Has Questions */
    HasQuestions: FormControl<boolean | null>;
    /** Has Video */
    HasVideo: FormControl<boolean | null>;
    /** Has Resources */
    HasResources: FormControl<boolean | null>;
    /** Has Badges */
    HasBadges: FormControl<boolean | null>;
    /** Has Open Jira Subtasks */
    HasOpenJiraSubtasks: FormControl<boolean | null>;
    /** Has Viewed Lesson In Production */
    HasViwedInProduction: FormControl<boolean | null>;
}
/**
/* Generates a form from a LessonPublicationStatusDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonPublicationStatusDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonPublicationStatusDtoForm(fb: FormBuilder, dto?: Interfaces.LessonPublicationStatusDto | null): FormGroup<ILessonPublicationStatusDtoForm>;
/** Interface for a form from a LessonSyndicationDto*/
export interface ILessonSyndicationDtoForm {
    /** Lesson id */
    LessonId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Syndication Types */
    Type: FormControl<Enums.SyndicationTypes | null>;
    /** Organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a LessonSyndicationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonSyndicationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonSyndicationDtoForm(fb: FormBuilder, dto?: Interfaces.LessonSyndicationDto | null): FormGroup<ILessonSyndicationDtoForm>;
/** Interface for a form from a LessonSyndicationProviderDto*/
export interface ILessonSyndicationProviderDtoForm {
    /** Lesson id */
    LessonId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a LessonSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.LessonSyndicationProviderDto | null): FormGroup<ILessonSyndicationProviderDtoForm>;
/** Interface for a form from a LessonTranslationDto*/
export interface ILessonTranslationDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Question */
    Content: FormControl<string | null>;
    /** Marketing */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
}
/**
/* Generates a form from a LessonTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.LessonTranslationDto | null): FormGroup<ILessonTranslationDtoForm>;
/** Interface for a form from a LessonVideoDto*/
export interface ILessonVideoDtoForm {
    /** The Lesson Viewed */
    LessonId: FormControl<number | null>;
    /** The originating Course */
    CourseId: FormControl<number | null>;
    /** The Topic */
    TopicId: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Project Id */
    ProjectId: FormControl<number | null>;
    /** Playlist Id */
    PlaylistId: FormControl<number | null>;
    /** The client viewing the lesson */
    ClientId: FormControl<string | null>;
    /** Resource Id */
    ResourceId: FormControl<number | null>;
}
/**
/* Generates a form from a LessonVideoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonVideoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonVideoDtoForm(fb: FormBuilder, dto?: Interfaces.LessonVideoDto | null): FormGroup<ILessonVideoDtoForm>;
/** Interface for a form from a LessonWithCourseInfoDto*/
export interface ILessonWithCourseInfoDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** The body of the item */
    Content: FormControl<string | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** The Organization that owns the lesson */
    OwningOrganizationId: FormControl<number | null>;
    /** Marketing Description */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
    /** Is Lesson Obsolete */
    Obsolete: FormControl<boolean | null>;
    /** Cover Art Thumbnail */
    CoverArtUri: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Has Viewed Lesson In Production */
    ViewedInProduction: FormControl<boolean | null>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
    /** The courses associated with the current lesson */
    Courses: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a LessonWithCourseInfoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonWithCourseInfoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonWithCourseInfoDtoForm(fb: FormBuilder, dto?: Interfaces.LessonWithCourseInfoDto | null): FormGroup<ILessonWithCourseInfoDtoForm>;
/** Interface for a form from a LessonWithQuestionsDto*/
export interface ILessonWithQuestionsDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Questions */
    Questions: FormArray<FormGroup<IQuestionDtoForm>>;
}
/**
/* Generates a form from a LessonWithQuestionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonWithQuestionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonWithQuestionsDtoForm(fb: FormBuilder, dto?: Interfaces.LessonWithQuestionsDto | null): FormGroup<ILessonWithQuestionsDtoForm>;
/** Interface for a form from a LessonWorkflowAssigneesDto*/
export interface ILessonWorkflowAssigneesDtoForm {
    /** The Lesson Id */
    LessonId: FormControl<number | null>;
    /** The Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role Lesson */
    Role: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a LessonWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LessonWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetLessonWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.LessonWorkflowAssigneesDto | null): FormGroup<ILessonWorkflowAssigneesDtoForm>;
/** Interface for a form from a ListBotConversationsRequest*/
export interface IListBotConversationsRequestForm {
    /**  */
    Criteria: FormGroup<ILoadCriteriaForm>;
}
/**
/* Generates a form from a ListBotConversationsRequest
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ListBotConversationsRequest from which to create the form.
/* @returns FormGroup
 */
export declare function GetListBotConversationsRequestForm(fb: FormBuilder, dto?: Interfaces.ListBotConversationsRequest | null): FormGroup<IListBotConversationsRequestForm>;
/** Interface for a form from a LoadCriteria*/
export interface ILoadCriteriaForm {
    /**  */
    Skip: FormControl<number | null>;
    /**  */
    Take: FormControl<number | null>;
    /**  */
    FilterBy: FormArray<FormGroup<IFilterCriteriaForm>>;
    /**  */
    OrderBy: FormArray<FormGroup<IOrderCriteriaForm>>;
    /**  */
    GroupBy: FormGroup<IGroupCriteriaForm>;
    /**  */
    Aggregates: FormArray<FormGroup<IAggregateCriteriaForm>>;
}
/**
/* Generates a form from a LoadCriteria
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original LoadCriteria from which to create the form.
/* @returns FormGroup
 */
export declare function GetLoadCriteriaForm(fb: FormBuilder, dto?: Interfaces.LoadCriteria | null): FormGroup<ILoadCriteriaForm>;
/** Interface for a form from a MakePaymentAccountDetailsDto*/
export interface IMakePaymentAccountDetailsDtoForm {
    /** Lesson on Account */
    NameOnAccount: FormControl<string | null>;
    /** Routing # */
    RoutingNumber: FormControl<string | null>;
    /** Account # */
    AccountNumber: FormControl<string | null>;
    /** External Account Types */
    Type: FormControl<Enums.AccountTypes | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
}
/**
/* Generates a form from a MakePaymentAccountDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MakePaymentAccountDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMakePaymentAccountDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.MakePaymentAccountDetailsDto | null): FormGroup<IMakePaymentAccountDetailsDtoForm>;
/** Interface for a form from a MakePaymentCardDetailsDto*/
export interface IMakePaymentCardDetailsDtoForm {
    /** Lesson on Card */
    NameOnCard: FormControl<string | null>;
    /** Expiry Month */
    ExpiryMonth: FormControl<number | null>;
    /** Expiry Year */
    ExpiryYear: FormControl<number | null>;
    /** CVV2 from back of the card */
    CVV2: FormControl<string | null>;
    /** Card # */
    CardNumber: FormControl<string | null>;
}
/**
/* Generates a form from a MakePaymentCardDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MakePaymentCardDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMakePaymentCardDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.MakePaymentCardDetailsDto | null): FormGroup<IMakePaymentCardDetailsDtoForm>;
/** Interface for a form from a MakePaymentDto*/
export interface IMakePaymentDtoForm {
    /** The payment Method used */
    PaymentMethodId: FormControl<number | null>;
    /** The stored credentials to use */
    StoredPaymentCredentialId: FormControl<number | null>;
    /** The payment amount */
    Amount: FormControl<number | null>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
    /** Details about the Invoice allocations for the payment */
    InvoiceDetails: FormArray<FormGroup<IMakePaymentInvoiceDetailDtoForm>>;
    /** The billing address of the contact */
    BillingAddressId: FormControl<number | null>;
    /** The shipping address of the contact */
    ShippingAddressId: FormControl<number | null>;
    /** If using new payment credentials, specify if they should be stored for later use. */
    StorePaymentCredentials: FormControl<boolean | null>;
    /** Date of the Payment */
    Date: FormControl<Date | null>;
}
/**
/* Generates a form from a MakePaymentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MakePaymentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMakePaymentDtoForm(fb: FormBuilder, dto?: Interfaces.MakePaymentDto | null): FormGroup<IMakePaymentDtoForm>;
/** Interface for a form from a MakePaymentInvoiceDetailDto*/
export interface IMakePaymentInvoiceDetailDtoForm {
    /** The invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Amount allocated to the invoice */
    Amount: FormControl<number | null>;
}
/**
/* Generates a form from a MakePaymentInvoiceDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MakePaymentInvoiceDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMakePaymentInvoiceDetailDtoForm(fb: FormBuilder, dto?: Interfaces.MakePaymentInvoiceDetailDto | null): FormGroup<IMakePaymentInvoiceDetailDtoForm>;
/** Interface for a form from a MedallionBadgeDto*/
export interface IMedallionBadgeDtoForm {
    /** Badge Id */
    Id: FormControl<number | null>;
    /** Badge Lesson */
    Name: FormControl<string | null>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a MedallionBadgeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionBadgeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionBadgeDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionBadgeDto | null): FormGroup<IMedallionBadgeDtoForm>;
/** Interface for a form from a MedallionDto*/
export interface IMedallionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Owning Organization */
    OwningOrganizationId: FormControl<number | null>;
    /** Organization */
    OwningOrganization: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Contractor Assigned To */
    AssignedToId: FormControl<number | null>;
    /** Contractor Assigned To Lesson */
    AssignedTo: FormControl<string | null>;
}
/**
/* Generates a form from a MedallionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionDto | null): FormGroup<IMedallionDtoForm>;
/** Interface for a form from a MedallionGroupDto*/
export interface IMedallionGroupDtoForm {
    /** Medallion id */
    MedallionId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Group */
    GroupId: FormControl<number | null>;
    /** Group Lesson */
    GroupName: FormControl<string | null>;
}
/**
/* Generates a form from a MedallionGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionGroupDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionGroupDto | null): FormGroup<IMedallionGroupDtoForm>;
/** Interface for a form from a MedallionHeaderLessonDto*/
export interface IMedallionHeaderLessonDtoForm {
    /** Medallion id */
    MedallionId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Header Lesson Id */
    LessonId: FormControl<number | null>;
    /** Header Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a MedallionHeaderLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionHeaderLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionHeaderLessonDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionHeaderLessonDto | null): FormGroup<IMedallionHeaderLessonDtoForm>;
/** Interface for a form from a MedallionLearningPathDto*/
export interface IMedallionLearningPathDtoForm {
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Medallion Lesson */
    Name: FormControl<string | null>;
    /** Medallion Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Disciplines */
    TotalBadges: FormControl<number | null>;
    /** Number of Completed Disciplines */
    TotalCompletedBadges: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Medallion Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Badges that make up the medallion */
    Badges: FormArray<FormGroup<IBadgeLearningPathDtoForm>>;
    /** Remaining Disciplines to complete */
    ContributesToDisciplines: FormArray<FormGroup<IDisciplinePathDtoForm>>;
    /** Medallion Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
}
/**
/* Generates a form from a MedallionLearningPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionLearningPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionLearningPathDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionLearningPathDto | null): FormGroup<IMedallionLearningPathDtoForm>;
/** Interface for a form from a MedallionPathDto*/
export interface IMedallionPathDtoForm {
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Medallion Lesson */
    Name: FormControl<string | null>;
    /** Medallion Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Disciplines */
    TotalBadges: FormControl<number | null>;
    /** Number of Completed Disciplines */
    TotalCompletedBadges: FormControl<number | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Medallion Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a MedallionPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionPathDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionPathDto | null): FormGroup<IMedallionPathDtoForm>;
/** Interface for a form from a MedallionSyndicationProviderDto*/
export interface IMedallionSyndicationProviderDtoForm {
    /** Medallion id */
    MedallionId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a MedallionSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionSyndicationProviderDto | null): FormGroup<IMedallionSyndicationProviderDtoForm>;
/** Interface for a form from a MedallionTranslationDto*/
export interface IMedallionTranslationDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a MedallionTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionTranslationDto | null): FormGroup<IMedallionTranslationDtoForm>;
/** Interface for a form from a MedallionUserEarnedDto*/
export interface IMedallionUserEarnedDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Earned On */
    EarnedOn: FormControl<Date | null>;
    /** Display Image Id */
    DisplayImageId: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
}
/**
/* Generates a form from a MedallionUserEarnedDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MedallionUserEarnedDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMedallionUserEarnedDtoForm(fb: FormBuilder, dto?: Interfaces.MedallionUserEarnedDto | null): FormGroup<IMedallionUserEarnedDtoForm>;
/** Interface for a form from a MergeFieldDto*/
export interface IMergeFieldDtoForm {
    /** The key of the email template */
    EmailTemplateId: FormControl<string | null>;
    /** The field to be merged */
    Field: FormControl<string | null>;
}
/**
/* Generates a form from a MergeFieldDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original MergeFieldDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetMergeFieldDtoForm(fb: FormBuilder, dto?: Interfaces.MergeFieldDto | null): FormGroup<IMergeFieldDtoForm>;
/** Interface for a form from a NextQuestionDto*/
export interface INextQuestionDtoForm {
    /** The question id */
    QuestionId: FormControl<number | null>;
    /** A question for a user assessment */
    Question: FormGroup<IUserAssessmentQuestionDtoForm>;
    /** Was the previous answer correct? */
    Correct: FormControl<boolean | null>;
}
/**
/* Generates a form from a NextQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original NextQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetNextQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.NextQuestionDto | null): FormGroup<INextQuestionDtoForm>;
/** Interface for a form from a NotificationDto*/
export interface INotificationDtoForm {
    /** Title */
    Title: FormControl<string | null>;
    /** Message */
    Message: FormControl<string | null>;
    /** Url to act on the message */
    Url: FormControl<string | null>;
    /** Notification Message Types */
    MessageType: FormControl<Enums.NotificationMessageTypes | null>;
    /** Custom message image url */
    ImageUrl: FormControl<string | null>;
}
/**
/* Generates a form from a NotificationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original NotificationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetNotificationDtoForm(fb: FormBuilder, dto?: Interfaces.NotificationDto | null): FormGroup<INotificationDtoForm>;
/** Interface for a form from a OrderCriteria*/
export interface IOrderCriteriaForm {
    /**  */
    FieldName: FormControl<string | null>;
    /**  */
    Direction: FormControl<Enums.OrderDirections | null>;
}
/**
/* Generates a form from a OrderCriteria
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrderCriteria from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrderCriteriaForm(fb: FormBuilder, dto?: Interfaces.OrderCriteria | null): FormGroup<IOrderCriteriaForm>;
/** Interface for a form from a OrgUserDto*/
export interface IOrgUserDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The full name of the user */
    Name: FormControl<string | null>;
    /** The user's email address */
    Email: FormControl<string | null>;
    /** The user's phone number */
    PhoneNumber: FormControl<string | null>;
    /** The user's phone number extension */
    PhoneNumberExt: FormControl<string | null>;
    /** Is the user active? */
    Active: FormControl<boolean | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Group */
    GroupId: FormControl<number | null>;
    /** Group Lesson */
    GroupName: FormControl<string | null>;
    /** Level */
    Level: FormControl<string | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Invoice Number */
    InvoiceNumber: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Restrict Reporting to Groups */
    RestrictReportingToGroups: FormControl<boolean | null>;
    /** Restrict User Admin User List to Groups */
    RestrictUserAdminUserListToGroups: FormControl<boolean | null>;
    /** Restrict Question Admin to Groups */
    RestrictContentAdminToGroups: FormControl<boolean | null>;
    /** Restrict Learning Path to Groups */
    RestrictLearningPathToGroups: FormControl<boolean | null>;
    /** User's organizational roles */
    Roles: FormArray<FormControl<Enums.Roles | null>>;
}
/**
/* Generates a form from a OrgUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrgUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrgUserDtoForm(fb: FormBuilder, dto?: Interfaces.OrgUserDto | null): FormGroup<IOrgUserDtoForm>;
/** Interface for a form from a OrgUserWithOrganizationDto*/
export interface IOrgUserWithOrganizationDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The full name of the user */
    Name: FormControl<string | null>;
    /** The user's email address */
    Email: FormControl<string | null>;
    /** The user's phone number */
    PhoneNumber: FormControl<string | null>;
    /** The user's phone number extension */
    PhoneNumberExt: FormControl<string | null>;
    /** Is the user active? */
    Active: FormControl<boolean | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Group */
    GroupId: FormControl<number | null>;
    /** Group Lesson */
    GroupName: FormControl<string | null>;
    /** Level */
    Level: FormControl<string | null>;
    /** Goal */
    Goal: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Invoice Number */
    InvoiceNumber: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Restrict Reporting to Groups */
    RestrictReportingToGroups: FormControl<boolean | null>;
    /** Restrict User Admin User List to Groups */
    RestrictUserAdminUserListToGroups: FormControl<boolean | null>;
    /** Restrict Question Admin to Groups */
    RestrictContentAdminToGroups: FormControl<boolean | null>;
    /** Restrict Learning Path to Groups */
    RestrictLearningPathToGroups: FormControl<boolean | null>;
    /** User's organizational roles */
    Roles: FormArray<FormControl<Enums.Roles | null>>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Organization Id to set */
    OrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a OrgUserWithOrganizationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrgUserWithOrganizationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrgUserWithOrganizationDtoForm(fb: FormBuilder, dto?: Interfaces.OrgUserWithOrganizationDto | null): FormGroup<IOrgUserWithOrganizationDtoForm>;
/** Interface for a form from a OrganizationActivityDetailDto*/
export interface IOrganizationActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Organization Types */
    OrganizationType: FormControl<Enums.OrganizationTypes | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** The groups the user is part of */
    Groups: FormArray<FormControl<string | null>>;
    /** Level */
    Level: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationActivityDetailDto | null): FormGroup<IOrganizationActivityDetailDtoForm>;
/** Interface for a form from a OrganizationAddSubscriptionRequestDto*/
export interface IOrganizationAddSubscriptionRequestDtoForm {
    /** The organization which to add the subscription. If this is null then the other fields for the user must be filled in. */
    OrganizationId: FormControl<number | null>;
    /** The User which to add the subscription. If this is null then the other fields for the user must be filled in. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirmation Password */
    ConfirmPassword: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Provider */
    Provider: FormControl<string | null>;
    /** Unique Provider Key that links the provider to the user. */
    ProviderKey: FormControl<string | null>;
    /** External Access Token */
    ExternalAccessToken: FormControl<string | null>;
    /** Billing Street Address */
    BillingStreetAddress: FormControl<string | null>;
    /** Billing Street Address 2 */
    BillingStreetAddress2: FormControl<string | null>;
    /** Billing TownCity */
    BillingTownCity: FormControl<string | null>;
    /** Billing Postal Code */
    BillingPostalCode: FormControl<string | null>;
    /** Billing State */
    BillingState: FormControl<string | null>;
    /** Billing Country */
    BillingCountry: FormControl<string | null>;
    /** Marketing Campaign Sources (How did you hear about us?) */
    HowDidYouHearAboutUs: FormControl<Enums.HowDidYouHearAboutUs | null>;
    /** Additional information about how the user heard about us */
    HowDidYouHearAboutUsOther: FormControl<string | null>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
    /**  */
    PaymentMethodId: FormControl<number | null>;
    /** The SKU to use for the trial */
    SKU: FormControl<string | null>;
    /** Reseller Id. Used for setting associated organization */
    ResellerId: FormControl<number | null>;
    /** Organization Lesson */
    OrganizationName: FormControl<string | null>;
    /** Organization Size */
    OrganizationSize: FormControl<number | null>;
    /** Organization Domain */
    OrganizationDomain: FormControl<string | null>;
    /** Entitlement Quantity */
    EntitlementQuantity: FormControl<number | null>;
}
/**
/* Generates a form from a OrganizationAddSubscriptionRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationAddSubscriptionRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationAddSubscriptionRequestDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationAddSubscriptionRequestDto | null): FormGroup<IOrganizationAddSubscriptionRequestDtoForm>;
/** Interface for a form from a OrganizationAddSubscriptionResponseDto*/
export interface IOrganizationAddSubscriptionResponseDtoForm {
    /** Error Message */
    ErrorMessage: FormControl<string | null>;
    /** User Subscription Creation Result Codes */
    Result: FormControl<Enums.OrganizationSubscriptionCreationResultCodes | null>;
    /** The main Dto that describes a user */
    User: FormGroup<IUserDtoForm>;
    /** Organization */
    Organization: FormGroup<IOrganizationDtoForm>;
    /** Description */
    Description: FormControl<string | null>;
    /** Invoice Id */
    InvoiceId: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationAddSubscriptionResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationAddSubscriptionResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationAddSubscriptionResponseDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationAddSubscriptionResponseDto | null): FormGroup<IOrganizationAddSubscriptionResponseDtoForm>;
/** Interface for a form from a OrganizationAddressDto*/
export interface IOrganizationAddressDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Is the address the default for the user */
    Default: FormControl<boolean | null>;
    /** Is the address the billing address for the user */
    Billing: FormControl<boolean | null>;
    /** Is the address the shipping address for the user */
    Shipping: FormControl<boolean | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal/Zip Code */
    PostalCode: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** The organization Id */
    OrganizationId: FormControl<number | null>;
    /** The name of the organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationAddressDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationAddressDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationAddressDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationAddressDto | null): FormGroup<IOrganizationAddressDtoForm>;
/** Interface for a form from a OrganizationContentCapabilitiesDto*/
export interface IOrganizationContentCapabilitiesDtoForm {
    /** Can the Organization create custom resources */
    CanCreateCustomResources: FormControl<boolean | null>;
    /** Can the organization create custom Video Lessons */
    CanCreateVideoLessons: FormControl<boolean | null>;
    /** Can share the course */
    CanShare: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationContentCapabilitiesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationContentCapabilitiesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationContentCapabilitiesDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationContentCapabilitiesDto | null): FormGroup<IOrganizationContentCapabilitiesDtoForm>;
/** Interface for a form from a OrganizationContentOptionsDto*/
export interface IOrganizationContentOptionsDtoForm {
    /** CADLearning Question */
    CADLearningContent: FormControl<boolean | null>;
    /** Bluebeam Question */
    BluebeamContent: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationContentOptionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationContentOptionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationContentOptionsDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationContentOptionsDto | null): FormGroup<IOrganizationContentOptionsDtoForm>;
/** Interface for a form from a OrganizationDto*/
export interface IOrganizationDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Is the organization an active customer */
    Active: FormControl<boolean | null>;
    /** When was the organization created */
    CreatedOn: FormControl<Date | null>;
    /** When was the organization updated */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags associated with the organization */
    Tags: FormControl<string | null>;
    /** Option to show only organization assessments */
    ShowOnlyOrgAssessments: FormControl<boolean | null>;
    /** Indicates whether or not the organization is a lead prospect for a partner */
    Lead: FormControl<boolean | null>;
    /** Sales Rep Id */
    SalesRepId: FormControl<number | null>;
    /** Partner */
    PartnerOrganizationId: FormControl<number | null>;
    /** Partner Organization */
    PartnerOrganization: FormControl<string | null>;
    /** Organization Partner Billing Type */
    BillingType: FormControl<Enums.PartnerBillingType | null>;
    /** Organization Answer Sharing Options */
    AnswerSharingOption: FormControl<Enums.OrganizationAnswerSharingOptions | null>;
    /** Organization Bot Escalation Rules */
    BotEscalationRule: FormControl<Enums.OrganizationBotEscalationRules | null>;
    /** Chart Types */
    ScoreSettings: FormControl<Enums.OrganizationScoreSettings | null>;
}
/**
/* Generates a form from a OrganizationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationDto | null): FormGroup<IOrganizationDtoForm>;
/** Interface for a form from a OrganizationEmailDomainDto*/
export interface IOrganizationEmailDomainDtoForm {
    /** Organization id */
    OrganizationId: FormControl<number | null>;
    /** Domain in the format "cadlearning.com" */
    Domain: FormControl<string | null>;
    /** Domain Admin Email Address */
    DomainAdminEmailAddress: FormControl<string | null>;
    /** Specifies if entitlements will be assigned from a pool of available entitlements automatically when a user registers on the site. */
    AllowAutomaticEntitlementAssignment: FormControl<boolean | null>;
    /** The Domain associated with the Email Domain. If not specified, the email address is entitled to register on any site associated with the organization */
    OrganizationDomainId: FormControl<number | null>;
    /** The name of the domain associated with the email domain. */
    OrganizationDomain: FormControl<string | null>;
    /** Verified */
    Verified: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationEmailDomainDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationEmailDomainDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationEmailDomainDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationEmailDomainDto | null): FormGroup<IOrganizationEmailDomainDtoForm>;
/** Interface for a form from a OrganizationEmailTemplateDto*/
export interface IOrganizationEmailTemplateDtoForm {
    /** The Organization Id */
    OrganizationId: FormControl<number | null>;
    /** The email template id */
    EmailTemplateId: FormControl<string | null>;
    /** Friendly Lesson */
    FriendlyName: FormControl<string | null>;
    /** The html */
    Html: FormControl<string | null>;
    /** The subject */
    Subject: FormControl<string | null>;
    /** Base configuration template is internal or not */
    Internal: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationEmailTemplateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationEmailTemplateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationEmailTemplateDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationEmailTemplateDto | null): FormGroup<IOrganizationEmailTemplateDtoForm>;
/** Interface for a form from a OrganizationFeaturesDto*/
export interface IOrganizationFeaturesDtoForm {
    /** Organization access to projects */
    Projects: FormControl<boolean | null>;
    /** Organization access to bot escalation */
    BotEscalation: FormControl<boolean | null>;
    /** Organization access to accomplishments */
    Accomplishments: FormControl<boolean | null>;
    /** Partner Organization access to Accomplishments */
    PartnerAccomplishments: FormControl<boolean | null>;
    /** Languages supported by the organization */
    Languages: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a OrganizationFeaturesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationFeaturesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationFeaturesDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationFeaturesDto | null): FormGroup<IOrganizationFeaturesDtoForm>;
/** Interface for a form from a OrganizationGroupCoursesDto*/
export interface IOrganizationGroupCoursesDtoForm {
    /** The organization applying the group mapping */
    OrganizationId: FormControl<number | null>;
    /** Organization Group Id */
    GroupId: FormControl<number | null>;
    /** the Organization Group */
    Group: FormControl<string | null>;
    /** The course id mapped to the group */
    CourseId: FormControl<number | null>;
    /** The course name assigned to the group */
    CourseName: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationGroupCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationGroupCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationGroupCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationGroupCoursesDto | null): FormGroup<IOrganizationGroupCoursesDtoForm>;
/** Interface for a form from a OrganizationGroupDto*/
export interface IOrganizationGroupDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The organization applying the group mapping */
    OrganizationId: FormControl<number | null>;
    /** Group Lesson */
    Group: FormControl<string | null>;
    /** Logo Url */
    LogoUrl: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationGroupDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationGroupDto | null): FormGroup<IOrganizationGroupDtoForm>;
/** Interface for a form from a OrganizationLessonNoteDto*/
export interface IOrganizationLessonNoteDtoForm {
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Note for Lesson */
    Note: FormControl<string | null>;
    /** Creator of Note Id */
    CreatedById: FormControl<number | null>;
    /** Lesson of Creator */
    CreatedBy: FormControl<string | null>;
    /** Created On date */
    CreatedOn: FormControl<Date | null>;
    /** Updated on Date */
    UpdatedOn: FormControl<Date | null>;
}
/**
/* Generates a form from a OrganizationLessonNoteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationLessonNoteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationLessonNoteDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationLessonNoteDto | null): FormGroup<IOrganizationLessonNoteDtoForm>;
/** Interface for a form from a OrganizationMessageDto*/
export interface IOrganizationMessageDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** the id of the organization */
    OrganizationId: FormControl<number | null>;
    /** The organization's name */
    Organization: FormControl<string | null>;
    /** The message */
    Message: FormControl<string | null>;
    /** When the message will start to display */
    StartOn: FormControl<Date | null>;
    /** When the message will end display */
    EndOn: FormControl<Date | null>;
}
/**
/* Generates a form from a OrganizationMessageDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationMessageDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationMessageDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationMessageDto | null): FormGroup<IOrganizationMessageDtoForm>;
/** Interface for a form from a OrganizationPermissionsDto*/
export interface IOrganizationPermissionsDtoForm {
    /** Organization Id with alotted permissions */
    FromOrganizationId: FormControl<number | null>;
    /** From Organization Lesson */
    FromOrganization: FormControl<string | null>;
    /** Requestee Id */
    RequesteeId: FormControl<number | null>;
    /** Contact Types */
    RequesteeType: FormControl<Enums.ContactTypes | null>;
    /** From Organization can access Custom Question */
    CustomContent: FormControl<boolean | null>;
    /** From Organization can access PlayLists */
    PlayLists: FormControl<boolean | null>;
    /** From Organization can create Users */
    CreateUsers: FormControl<boolean | null>;
    /** From Organization can Update Users */
    UpdateUsers: FormControl<boolean | null>;
    /** Organization can view users */
    ViewUsers: FormControl<boolean | null>;
    /** From Organization can Delete Users */
    DeleteUsers: FormControl<boolean | null>;
    /** From Organization can View Reports */
    ViewReports: FormControl<boolean | null>;
    /** Request Date */
    RequestDate: FormControl<Date | null>;
}
/**
/* Generates a form from a OrganizationPermissionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationPermissionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationPermissionsDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationPermissionsDto | null): FormGroup<IOrganizationPermissionsDtoForm>;
/** Interface for a form from a OrganizationPriceListInventoryDto*/
export interface IOrganizationPriceListInventoryDtoForm {
    /** Inventory Lesson */
    Inventory: FormControl<string | null>;
    /** SKU */
    SKU: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationPriceListInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationPriceListInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationPriceListInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationPriceListInventoryDto | null): FormGroup<IOrganizationPriceListInventoryDtoForm>;
/** Interface for a form from a OrganizationProjectRoleDto*/
export interface IOrganizationProjectRoleDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Role Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationProjectRoleDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationProjectRoleDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationProjectRoleDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationProjectRoleDto | null): FormGroup<IOrganizationProjectRoleDtoForm>;
/** Interface for a form from a OrganizationReportGroupRule*/
export interface IOrganizationReportGroupRuleForm {
    /** Id of the Group */
    Id: FormControl<string | null>;
    /** Should the report automatically be filtered by the criteria? */
    Filtered: FormControl<boolean | null>;
    /** Can this group edit this report? */
    Editable: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationReportGroupRule
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationReportGroupRule from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationReportGroupRuleForm(fb: FormBuilder, dto?: Interfaces.OrganizationReportGroupRule | null): FormGroup<IOrganizationReportGroupRuleForm>;
/** Interface for a form from a OrganizationShortDto*/
export interface IOrganizationShortDtoForm {
    /** Organization Partner Billing Type */
    BillingType: FormControl<Enums.PartnerBillingType | null>;
}
/**
/* Generates a form from a OrganizationShortDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationShortDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationShortDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationShortDto | null): FormGroup<IOrganizationShortDtoForm>;
/** Interface for a form from a OrganizationStatsDto*/
export interface IOrganizationStatsDtoForm {
    /** Badges In Progress */
    BadgesInProgress: FormControl<number | null>;
    /** Completed Badges */
    CompletedBadges: FormControl<number | null>;
    /** Medallions in Progress */
    MedallionsInProgress: FormControl<number | null>;
    /** Completed Medallions */
    CompletedMedallions: FormControl<number | null>;
    /** Total Time spent watching Lessons */
    TotalLessonTime: FormControl<number | null>;
    /** Average completion of roles assigned by the organization */
    AverageRoleCompletionPercentage: FormControl<number | null>;
    /** Active Users in the last month */
    ActiveUsersInLastMonth: FormControl<number | null>;
    /** Badge Completion Percentage */
    BadgeCompletionPercentage: FormControl<number | null>;
    /** Medallion Completion Percentage */
    MedallionCompletionPercentage: FormControl<number | null>;
}
/**
/* Generates a form from a OrganizationStatsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationStatsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationStatsDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationStatsDto | null): FormGroup<IOrganizationStatsDtoForm>;
/** Interface for a form from a OrganizationUserDto*/
export interface IOrganizationUserDtoForm {
    /** Active */
    Active: FormControl<boolean | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Phone Ext. */
    PhoneExt: FormControl<string | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Restrict Reporting to Groups */
    RestrictReportingToGroups: FormControl<boolean | null>;
    /** Roles */
    RoleIds: FormArray<FormControl<number | null>>;
    /** Relationship between an organization and a user */
    Relationship: FormControl<Enums.OrgUserRelationships | null>;
    /** System Support Agent */
    AvailableForSystemSupport: FormControl<boolean | null>;
}
/**
/* Generates a form from a OrganizationUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationUserDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationUserDto | null): FormGroup<IOrganizationUserDtoForm>;
/** Interface for a form from a OrganizationUserFieldsDto*/
export interface IOrganizationUserFieldsDtoForm {
    /** Groups */
    Groups: FormArray<FormGroup<IOrganizationGroupDtoForm>>;
    /** Divisions */
    Divisions: FormArray<FormControl<string | null>>;
    /** Locations */
    Locations: FormArray<FormControl<string | null>>;
    /** Goals */
    Goals: FormArray<FormControl<string | null>>;
    /** Levels */
    Levels: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a OrganizationUserFieldsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationUserFieldsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationUserFieldsDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationUserFieldsDto | null): FormGroup<IOrganizationUserFieldsDtoForm>;
/** Interface for a form from a OrganizationUserGroupDto*/
export interface IOrganizationUserGroupDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Group */
    OrganizationGroupId: FormControl<number | null>;
    /** Group Lesson */
    OrganizationGroupName: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationUserGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationUserGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationUserGroupDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationUserGroupDto | null): FormGroup<IOrganizationUserGroupDtoForm>;
/** Interface for a form from a OrganizationUserRoleDto*/
export interface IOrganizationUserRoleDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role */
    Role: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationUserRoleDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationUserRoleDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationUserRoleDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationUserRoleDto | null): FormGroup<IOrganizationUserRoleDtoForm>;
/** Interface for a form from a OrganizationxApiCredentialsDto*/
export interface IOrganizationxApiCredentialsDtoForm {
    /** Organization id */
    OrganizationId: FormControl<number | null>;
    /** Uri */
    Uri: FormControl<string | null>;
    /** User Lesson */
    UserName: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
}
/**
/* Generates a form from a OrganizationxApiCredentialsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original OrganizationxApiCredentialsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetOrganizationxApiCredentialsDtoForm(fb: FormBuilder, dto?: Interfaces.OrganizationxApiCredentialsDto | null): FormGroup<IOrganizationxApiCredentialsDtoForm>;
/** Interface for a form from a PartnerOrganizationGroupDto*/
export interface IPartnerOrganizationGroupDtoForm {
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IOrganizationGroupDtoForm>>;
}
/**
/* Generates a form from a PartnerOrganizationGroupDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PartnerOrganizationGroupDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPartnerOrganizationGroupDtoForm(fb: FormBuilder, dto?: Interfaces.PartnerOrganizationGroupDto | null): FormGroup<IPartnerOrganizationGroupDtoForm>;
/** Interface for a form from a PartnerProspectDto*/
export interface IPartnerProspectDtoForm {
    /** Partner Organization Id */
    PartnerId: FormControl<number | null>;
    /** Prospect Organization Id */
    ProspectId: FormControl<number | null>;
    /** Proespect organization name */
    ProspectName: FormControl<string | null>;
    /** Estimated close date */
    EstClosedDate: FormControl<Date | null>;
    /** Key Stakeholder Contact (User in Prospect Organization) */
    KeyContact: FormControl<number | null>;
    /** Sales Rep User Id (User in Partner Organization) */
    SalesRep: FormControl<number | null>;
    /** Existing Customer */
    ExistingCustomer: FormControl<boolean | null>;
    /** Deal Size (Money at List Price) */
    DealSize: FormControl<number | null>;
    /** Probability to close */
    CloseProbability: FormControl<number | null>;
}
/**
/* Generates a form from a PartnerProspectDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PartnerProspectDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPartnerProspectDtoForm(fb: FormBuilder, dto?: Interfaces.PartnerProspectDto | null): FormGroup<IPartnerProspectDtoForm>;
/** Interface for a form from a PaymentMethodDto*/
export interface IPaymentMethodDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Payment Methods */
    Type: FormControl<Enums.PaymentMethods | null>;
    /** The provider */
    PaymentProviderId: FormControl<number | null>;
    /** The Provider's name */
    PaymentProvider: FormControl<string | null>;
}
/**
/* Generates a form from a PaymentMethodDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PaymentMethodDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPaymentMethodDtoForm(fb: FormBuilder, dto?: Interfaces.PaymentMethodDto | null): FormGroup<IPaymentMethodDtoForm>;
/** Interface for a form from a PaymentProviderDto*/
export interface IPaymentProviderDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a PaymentProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PaymentProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPaymentProviderDtoForm(fb: FormBuilder, dto?: Interfaces.PaymentProviderDto | null): FormGroup<IPaymentProviderDtoForm>;
/** Interface for a form from a PaymentProviderImplementationDto*/
export interface IPaymentProviderImplementationDtoForm {
    /** The payment provider id */
    PaymentProviderId: FormControl<number | null>;
    /** The name of the payment provider */
    PaymentProvider: FormControl<string | null>;
    /** Payment Methods */
    Method: FormControl<Enums.PaymentMethods | null>;
    /** The Interface used to execute these types of payments */
    Interface: FormControl<string | null>;
}
/**
/* Generates a form from a PaymentProviderImplementationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PaymentProviderImplementationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPaymentProviderImplementationDtoForm(fb: FormBuilder, dto?: Interfaces.PaymentProviderImplementationDto | null): FormGroup<IPaymentProviderImplementationDtoForm>;
/** Interface for a form from a PingDto*/
export interface IPingDtoForm {
    /** Message Id */
    Id: FormControl<number | null>;
    /** Message */
    Message: FormControl<string | null>;
}
/**
/* Generates a form from a PingDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PingDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPingDtoForm(fb: FormBuilder, dto?: Interfaces.PingDto | null): FormGroup<IPingDtoForm>;
/** Interface for a form from a PlatformReportDto*/
export interface IPlatformReportDtoForm {
    /** Report Id */
    Id: FormControl<string | null>;
    /** Is the report active? */
    IsActive: FormControl<boolean | null>;
    /** Organization Limits */
    Organizations: FormArray<FormGroup<IPlatformReportOrganizationDetailsForm>>;
    /** User Limits */
    Users: FormArray<FormControl<number | null>>;
    /** How reports should be persisted to the database for recovery with custom reports etc. */
    Report: FormGroup<IReportDtoForm>;
}
/**
/* Generates a form from a PlatformReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlatformReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlatformReportDtoForm(fb: FormBuilder, dto?: Interfaces.PlatformReportDto | null): FormGroup<IPlatformReportDtoForm>;
/** Interface for a form from a PlatformReportOrganizationDetails*/
export interface IPlatformReportOrganizationDetailsForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Divisions that can access the report */
    Divisions: FormArray<FormGroup<IOrganizationReportGroupRuleForm>>;
    /** Groups that can access the report */
    Groups: FormArray<FormGroup<IOrganizationReportGroupRuleForm>>;
    /** Users that can access the report */
    Users: FormArray<FormGroup<IOrganizationReportGroupRuleForm>>;
}
/**
/* Generates a form from a PlatformReportOrganizationDetails
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlatformReportOrganizationDetails from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlatformReportOrganizationDetailsForm(fb: FormBuilder, dto?: Interfaces.PlatformReportOrganizationDetails | null): FormGroup<IPlatformReportOrganizationDetailsForm>;
/** Interface for a form from a PlayListContentDto*/
export interface IPlayListContentDtoForm {
    /** Play List Id */
    PlayListId: FormControl<number | null>;
    /** Question ItemId */
    ContentItemId: FormControl<number | null>;
    /** Question Item Lesson */
    ContentItemName: FormControl<string | null>;
    /** Question Item Types */
    ContentItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Question Length */
    Length: FormControl<number | null>;
    /** Question Order in Play List */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a PlayListContentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlayListContentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlayListContentDtoForm(fb: FormBuilder, dto?: Interfaces.PlayListContentDto | null): FormGroup<IPlayListContentDtoForm>;
/** Interface for a form from a PlayListHeaderLessonDto*/
export interface IPlayListHeaderLessonDtoForm {
    /** PlayList id */
    PlayListId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Header Lesson Id */
    LessonId: FormControl<number | null>;
    /** Header Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a PlayListHeaderLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlayListHeaderLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlayListHeaderLessonDtoForm(fb: FormBuilder, dto?: Interfaces.PlayListHeaderLessonDto | null): FormGroup<IPlayListHeaderLessonDtoForm>;
/** Interface for a form from a PlayListSyndicationProviderDto*/
export interface IPlayListSyndicationProviderDtoForm {
    /** PlayList id */
    PlayListId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a PlayListSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlayListSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlayListSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.PlayListSyndicationProviderDto | null): FormGroup<IPlayListSyndicationProviderDtoForm>;
/** Interface for a form from a PlayListUserDto*/
export interface IPlayListUserDtoForm {
    /** Play list Id */
    PlayListId: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
}
/**
/* Generates a form from a PlayListUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlayListUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlayListUserDtoForm(fb: FormBuilder, dto?: Interfaces.PlayListUserDto | null): FormGroup<IPlayListUserDtoForm>;
/** Interface for a form from a PlayListWithContentDto*/
export interface IPlayListWithContentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the playlist */
    Name: FormControl<string | null>;
    /** The description if any */
    Description: FormControl<string | null>;
    /** The owner of the playlist */
    OwnerId: FormControl<number | null>;
    /** The owner's name */
    Owner: FormControl<string | null>;
    /** Owning Organization Id */
    OwningOrganizationId: FormControl<number | null>;
    /** Owning Organization Lesson */
    OwningOrganization: FormControl<string | null>;
    /** Contents of the playlist */
    Contents: FormArray<FormGroup<IPlayListContentDtoForm>>;
}
/**
/* Generates a form from a PlayListWithContentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlayListWithContentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlayListWithContentDtoForm(fb: FormBuilder, dto?: Interfaces.PlayListWithContentDto | null): FormGroup<IPlayListWithContentDtoForm>;
/** Interface for a form from a PlaylistActivityDetailDto*/
export interface IPlaylistActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a PlaylistActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PlaylistActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPlaylistActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.PlaylistActivityDetailDto | null): FormGroup<IPlaylistActivityDetailDtoForm>;
/** Interface for a form from a PluginNotifyCommandDto*/
export interface IPluginNotifyCommandDtoForm {
    /** Product Identifier */
    ProductId: FormControl<string | null>;
    /** Product Reported Version */
    VersionId: FormControl<string | null>;
    /** Command */
    Command: FormControl<string | null>;
    /** Plugin Command Notification Types */
    NotificationType: FormControl<Enums.CommandNotificationTypes | null>;
}
/**
/* Generates a form from a PluginNotifyCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PluginNotifyCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPluginNotifyCommandDtoForm(fb: FormBuilder, dto?: Interfaces.PluginNotifyCommandDto | null): FormGroup<IPluginNotifyCommandDtoForm>;
/** Interface for a form from a PluginNotifyPageCommandDto*/
export interface IPluginNotifyPageCommandDtoForm {
    /** Product Identifier */
    ProductId: FormControl<string | null>;
    /** Product Reported Version */
    VersionId: FormControl<string | null>;
    /** Domain */
    Url: FormControl<string | null>;
    /** The command on the page */
    Command: FormControl<string | null>;
}
/**
/* Generates a form from a PluginNotifyPageCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PluginNotifyPageCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPluginNotifyPageCommandDtoForm(fb: FormBuilder, dto?: Interfaces.PluginNotifyPageCommandDto | null): FormGroup<IPluginNotifyPageCommandDtoForm>;
/** Interface for a form from a PluginNotifyPageDto*/
export interface IPluginNotifyPageDtoForm {
    /** Product Identifier */
    ProductId: FormControl<string | null>;
    /** Product Reported Version */
    VersionId: FormControl<string | null>;
    /** Domain */
    Url: FormControl<string | null>;
}
/**
/* Generates a form from a PluginNotifyPageDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PluginNotifyPageDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPluginNotifyPageDtoForm(fb: FormBuilder, dto?: Interfaces.PluginNotifyPageDto | null): FormGroup<IPluginNotifyPageDtoForm>;
/** Interface for a form from a PossibleLessonVersionsDto*/
export interface IPossibleLessonVersionsDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson */
    Lesson: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
}
/**
/* Generates a form from a PossibleLessonVersionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PossibleLessonVersionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPossibleLessonVersionsDtoForm(fb: FormBuilder, dto?: Interfaces.PossibleLessonVersionsDto | null): FormGroup<IPossibleLessonVersionsDtoForm>;
/** Interface for a form from a PriceListDto*/
export interface IPriceListDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The organization that controls this price list */
    OwningOrganizationId: FormControl<number | null>;
    /** The name of the organization that controls this price list */
    OwningOrganization: FormControl<string | null>;
    /** The Lesson of the price list */
    Name: FormControl<string | null>;
    /** The description of the price list */
    Description: FormControl<string | null>;
    /** Price List Types */
    Type: FormControl<Enums.PriceListTypes | null>;
}
/**
/* Generates a form from a PriceListDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PriceListDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPriceListDtoForm(fb: FormBuilder, dto?: Interfaces.PriceListDto | null): FormGroup<IPriceListDtoForm>;
/** Interface for a form from a PriceListRevisionDto*/
export interface IPriceListRevisionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The Id of the parent price list */
    PriceListId: FormControl<number | null>;
    /** The name of the parent price list */
    PriceList: FormControl<string | null>;
    /** When the revision takes effect */
    StartOn: FormControl<Date | null>;
    /** The optional expiration date on the revision */
    EndOn: FormControl<Date | null>;
}
/**
/* Generates a form from a PriceListRevisionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PriceListRevisionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPriceListRevisionDtoForm(fb: FormBuilder, dto?: Interfaces.PriceListRevisionDto | null): FormGroup<IPriceListRevisionDtoForm>;
/** Interface for a form from a PriceListRevisionInventoryDto*/
export interface IPriceListRevisionInventoryDtoForm {
    /** The Revision associated with this item */
    PriceListRevisionId: FormControl<number | null>;
    /** The inventory item associated with this item */
    InventoryId: FormControl<number | null>;
    /** The name of the inventory item */
    Inventory: FormControl<string | null>;
    /** Sku of inventory item */
    SKU: FormControl<string | null>;
    /** The price of this item (optional only used for non-partner price lists) */
    Price: FormControl<number | null>;
    /** The Percent of original sale price (optional, used for Partner price lists) */
    PercentOfSalePrice: FormControl<number | null>;
    /** Inventory Items that are billable when this item is sold. */
    BillableInventory: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a PriceListRevisionInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PriceListRevisionInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPriceListRevisionInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.PriceListRevisionInventoryDto | null): FormGroup<IPriceListRevisionInventoryDtoForm>;
/** Interface for a form from a ProductActivityDetailDto*/
export interface IProductActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version Lesson */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a ProductActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.ProductActivityDetailDto | null): FormGroup<IProductActivityDetailDtoForm>;
/** Interface for a form from a ProductAndVersionIdDto*/
export interface IProductAndVersionIdDtoForm {
    /** The Product Id */
    ProductId: FormControl<number | null>;
    /** The Version Id */
    VersionId: FormControl<number | null>;
}
/**
/* Generates a form from a ProductAndVersionIdDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductAndVersionIdDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductAndVersionIdDtoForm(fb: FormBuilder, dto?: Interfaces.ProductAndVersionIdDto | null): FormGroup<IProductAndVersionIdDtoForm>;
/** Interface for a form from a ProductCategoryDto*/
export interface IProductCategoryDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Featured */
    Featured: FormControl<boolean | null>;
    /** Featured Sort Order */
    FeaturedSortOrder: FormControl<number | null>;
    /** Branding Color */
    BrandingColor: FormControl<string | null>;
}
/**
/* Generates a form from a ProductCategoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductCategoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductCategoryDtoForm(fb: FormBuilder, dto?: Interfaces.ProductCategoryDto | null): FormGroup<IProductCategoryDtoForm>;
/** Interface for a form from a ProductCommandLessonsDto*/
export interface IProductCommandLessonsDtoForm {
    /** The version associated with the commands */
    Version: FormControl<string | null>;
    /** The version id associated with the commands */
    VersionId: FormControl<number | null>;
    /** The list of commands associated with a particular version */
    Commands: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a ProductCommandLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductCommandLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductCommandLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.ProductCommandLessonsDto | null): FormGroup<IProductCommandLessonsDtoForm>;
/** Interface for a form from a ProductDto*/
export interface IProductDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The External Short Form that will be used. */
    ExternalId: FormControl<string | null>;
    /** The name of the product */
    Name: FormControl<string | null>;
    /** The description of the product */
    Description: FormControl<string | null>;
    /** Any tags for searching for the product */
    Tags: FormControl<string | null>;
    /** A flag for if the product is active and will return anywhere on the public portal. */
    Active: FormControl<boolean | null>;
    /** When was the product created? */
    CreatedOn: FormControl<Date | null>;
    /** When was it last updated? */
    UpdatedOn: FormControl<Date | null>;
    /** The color for branding purposes in #RRGGBBAA format */
    BrandingColor: FormControl<string | null>;
    /** Featured Product */
    Featured: FormControl<boolean | null>;
    /** Featured Sort Order */
    FeaturedSortOrder: FormControl<number | null>;
    /** THe owning organization id */
    OwningOrganizationId: FormControl<number | null>;
    /** Display image resource id */
    DisplayImageId: FormControl<number | null>;
    /** Display Image Url (if applicable) */
    DisplayImageUrl: FormControl<string | null>;
}
/**
/* Generates a form from a ProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductDtoForm(fb: FormBuilder, dto?: Interfaces.ProductDto | null): FormGroup<IProductDtoForm>;
/** Interface for a form from a ProductSiteDto*/
export interface IProductSiteDtoForm {
    /** Site */
    Site: FormControl<string | null>;
    /** Site Id */
    SiteId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
}
/**
/* Generates a form from a ProductSiteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductSiteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductSiteDtoForm(fb: FormBuilder, dto?: Interfaces.ProductSiteDto | null): FormGroup<IProductSiteDtoForm>;
/** Interface for a form from a ProductTranslationCategoryDto*/
export interface IProductTranslationCategoryDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Language */
    Languagecode: FormControl<string | null>;
    /** Translation Category from Translator Hub */
    TranslationCategory: FormControl<string | null>;
}
/**
/* Generates a form from a ProductTranslationCategoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductTranslationCategoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductTranslationCategoryDtoForm(fb: FormBuilder, dto?: Interfaces.ProductTranslationCategoryDto | null): FormGroup<IProductTranslationCategoryDtoForm>;
/** Interface for a form from a ProductTranslationDto*/
export interface IProductTranslationDtoForm {
    /** Lesson Id */
    ProductId: FormControl<number | null>;
    /** Lesson Lesson */
    Product: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Marketing */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
}
/**
/* Generates a form from a ProductTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.ProductTranslationDto | null): FormGroup<IProductTranslationDtoForm>;
/** Interface for a form from a ProductVersionAndCourseDto*/
export interface IProductVersionAndCourseDtoForm {
    /** The selected version */
    VersionId: FormControl<number | null>;
    /** The selected version name */
    Version: FormControl<string | null>;
    /** The selected course */
    CourseId: FormControl<number | null>;
    /** Course Lesson */
    Course: FormControl<string | null>;
}
/**
/* Generates a form from a ProductVersionAndCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionAndCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionAndCourseDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionAndCourseDto | null): FormGroup<IProductVersionAndCourseDtoForm>;
/** Interface for a form from a ProductVersionCommandDto*/
export interface IProductVersionCommandDtoForm {
    /** Product Id */
    VersionId: FormControl<number | null>;
    /** Product Lesson */
    Version: FormControl<string | null>;
    /** Product Command */
    Command: FormControl<string | null>;
}
/**
/* Generates a form from a ProductVersionCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionCommandDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionCommandDto | null): FormGroup<IProductVersionCommandDtoForm>;
/** Interface for a form from a ProductVersionCommandTranslationDto*/
export interface IProductVersionCommandTranslationDtoForm {
    /** Command Key */
    Key: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Translated Value */
    Command: FormControl<string | null>;
}
/**
/* Generates a form from a ProductVersionCommandTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionCommandTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionCommandTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionCommandTranslationDto | null): FormGroup<IProductVersionCommandTranslationDtoForm>;
/** Interface for a form from a ProductVersionCommandWithTranslationsDto*/
export interface IProductVersionCommandWithTranslationsDtoForm {
    /** Product Id */
    VersionId: FormControl<number | null>;
    /** Product Lesson */
    Version: FormControl<string | null>;
    /** Product Command */
    Command: FormControl<string | null>;
    /** Translations */
    Translations: FormArray<FormGroup<IProductVersionCommandTranslationDtoForm>>;
}
/**
/* Generates a form from a ProductVersionCommandWithTranslationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionCommandWithTranslationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionCommandWithTranslationsDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionCommandWithTranslationsDto | null): FormGroup<IProductVersionCommandWithTranslationsDtoForm>;
/** Interface for a form from a ProductVersionCoursePreferenceDto*/
export interface IProductVersionCoursePreferenceDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Product Version Id */
    ProductVersionId: FormControl<number | null>;
    /** Product Version Lesson */
    ProductVersion: FormControl<string | null>;
    /** Owned */
    Owned: FormControl<boolean | null>;
}
/**
/* Generates a form from a ProductVersionCoursePreferenceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionCoursePreferenceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionCoursePreferenceDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionCoursePreferenceDto | null): FormGroup<IProductVersionCoursePreferenceDtoForm>;
/** Interface for a form from a ProductVersionDetailsDto*/
export interface IProductVersionDetailsDtoForm {
    /** The Id of the product */
    ProductId: FormControl<number | null>;
    /** The string name of the product */
    Product: FormControl<string | null>;
    /** The version Id of the product */
    VersionId: FormControl<number | null>;
    /** The string name of the version */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a ProductVersionDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionDetailsDto | null): FormGroup<IProductVersionDetailsDtoForm>;
/** Interface for a form from a ProductVersionDto*/
export interface IProductVersionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The product Id */
    ProductId: FormControl<number | null>;
    /** The string representation of the product's name */
    Product: FormControl<string | null>;
    /** The name of the Version. Typically Major + "." + Minor + "." + Revision */
    Name: FormControl<string | null>;
    /** A description of the version if any */
    Description: FormControl<string | null>;
    /** The major version number. */
    Major: FormControl<number | null>;
    /** The minor version number */
    Minor: FormControl<number | null>;
    /** The revision number */
    Revision: FormControl<number | null>;
    /** When was the version released? */
    ReleasedOn: FormControl<Date | null>;
    /** The External Vendor's Id - Autodesk */
    VendorId: FormControl<string | null>;
    /** Default Course that should be used with viewing this product version */
    DefaultCourseId: FormControl<number | null>;
    /** Default Course Lesson */
    DefaultCourse: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
}
/**
/* Generates a form from a ProductVersionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductVersionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductVersionDtoForm(fb: FormBuilder, dto?: Interfaces.ProductVersionDto | null): FormGroup<IProductVersionDtoForm>;
/** Interface for a form from a ProductWebAddressDto*/
export interface IProductWebAddressDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Domain name including wildcards in * notation */
    Domain: FormControl<string | null>;
    /** Site Lesson */
    Site: FormControl<string | null>;
}
/**
/* Generates a form from a ProductWebAddressDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProductWebAddressDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProductWebAddressDtoForm(fb: FormBuilder, dto?: Interfaces.ProductWebAddressDto | null): FormGroup<IProductWebAddressDtoForm>;
/** Interface for a form from a ProjectActivityDetailDto*/
export interface IProjectActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a ProjectActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectActivityDetailDto | null): FormGroup<IProjectActivityDetailDtoForm>;
/** Interface for a form from a ProjectDto*/
export interface IProjectDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Ends On */
    EndsOn: FormControl<Date | null>;
    /** Owning Organization id */
    OwningOrganizationId: FormControl<number | null>;
    /** Owning Organization */
    OwningOrganization: FormControl<string | null>;
    /** Project Manager Id */
    ProjectManagerUserId: FormControl<number | null>;
    /** Project Manager */
    ProjectManagerUser: FormControl<string | null>;
}
/**
/* Generates a form from a ProjectDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectDto | null): FormGroup<IProjectDtoForm>;
/** Interface for a form from a ProjectJobDto*/
export interface IProjectJobDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Project Id */
    ProjectId: FormControl<number | null>;
    /** Project Lesson */
    Project: FormControl<string | null>;
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Pre Hire Assessment Id */
    PreHireAssessmentId: FormControl<number | null>;
    /** Pre-Hire Assessment Lesson */
    PreHireAssessment: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Users */
    Users: FormArray<FormGroup<IProjectJobUserDtoForm>>;
    /** When does the job start? */
    StartsOn: FormControl<Date | null>;
    /** When does the job end? */
    EndsOn: FormControl<Date | null>;
    /** Notes */
    Notes: FormControl<string | null>;
}
/**
/* Generates a form from a ProjectJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectJobDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectJobDto | null): FormGroup<IProjectJobDtoForm>;
/** Interface for a form from a ProjectJobUserDto*/
export interface IProjectJobUserDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** Project Job Statuses */
    Status: FormControl<Enums.ProjectJobStatuses | null>;
    /** User Job Id */
    UserJobId: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** User's Score */
    Score: FormControl<number | null>;
}
/**
/* Generates a form from a ProjectJobUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectJobUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectJobUserDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectJobUserDto | null): FormGroup<IProjectJobUserDtoForm>;
/** Interface for a form from a ProjectManagementCompleteTaskDto*/
export interface IProjectManagementCompleteTaskDtoForm {
    /** The item (KAMs) Id */
    Id: FormControl<number | null>;
}
/**
/* Generates a form from a ProjectManagementCompleteTaskDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectManagementCompleteTaskDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectManagementCompleteTaskDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectManagementCompleteTaskDto | null): FormGroup<IProjectManagementCompleteTaskDtoForm>;
/** Interface for a form from a ProjectManagementIssueDto*/
export interface IProjectManagementIssueDtoForm {
    /** Key (i.e. CDD-140) */
    Key: FormControl<string | null>;
    /** Text of the issue */
    Text: FormControl<string | null>;
    /** Type of Jira ticket (Story, bug) */
    Type: FormControl<string | null>;
    /** Status of the jira ticket */
    Status: FormControl<string | null>;
    /** Subtasks */
    Subtasks: FormArray<FormGroup<IProjectManagementIssueDtoForm>>;
}
/**
/* Generates a form from a ProjectManagementIssueDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectManagementIssueDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectManagementIssueDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectManagementIssueDto | null): FormGroup<IProjectManagementIssueDtoForm>;
/** Interface for a form from a ProjectProductDto*/
export interface IProjectProductDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a ProjectProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectProductDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectProductDto | null): FormGroup<IProjectProductDtoForm>;
/** Interface for a form from a ProjectUserMatchBadgeDto*/
export interface IProjectUserMatchBadgeDtoForm {
    /** The Id of the Competency */
    BadgeId: FormControl<number | null>;
    /** The Lesson of the Competency */
    Badge: FormControl<string | null>;
    /** Score for the badge */
    Score: FormControl<number | null>;
}
/**
/* Generates a form from a ProjectUserMatchBadgeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectUserMatchBadgeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectUserMatchBadgeDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectUserMatchBadgeDto | null): FormGroup<IProjectUserMatchBadgeDtoForm>;
/** Interface for a form from a ProjectUserMatchDto*/
export interface IProjectUserMatchDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Username */
    Username: FormControl<string | null>;
    /** Score */
    Score: FormControl<number | null>;
    /** Badge List */
    Badges: FormArray<FormGroup<IProjectUserMatchBadgeDtoForm>>;
}
/**
/* Generates a form from a ProjectUserMatchDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectUserMatchDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectUserMatchDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectUserMatchDto | null): FormGroup<IProjectUserMatchDtoForm>;
/** Interface for a form from a ProjectUserRankDto*/
export interface IProjectUserRankDtoForm {
    /** Project Job Id */
    ProjectJobId: FormControl<number | null>;
    /** Users matched for project */
    MatchingUsers: FormArray<FormGroup<IProjectUserMatchDtoForm>>;
}
/**
/* Generates a form from a ProjectUserRankDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProjectUserRankDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProjectUserRankDtoForm(fb: FormBuilder, dto?: Interfaces.ProjectUserRankDto | null): FormGroup<IProjectUserRankDtoForm>;
/** Interface for a form from a ProspectOrgUserDto*/
export interface IProspectOrgUserDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The full name of the user */
    Name: FormControl<string | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Description */
    OrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a ProspectOrgUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ProspectOrgUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetProspectOrgUserDtoForm(fb: FormBuilder, dto?: Interfaces.ProspectOrgUserDto | null): FormGroup<IProspectOrgUserDtoForm>;
/** Interface for a form from a PublicLessonDetailsDto*/
export interface IPublicLessonDetailsDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Skill Level */
    SkillLevel: FormControl<string | null>;
    /** Rating */
    Rating: FormControl<number | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Narration Sample */
    NarrationSample: FormControl<string | null>;
    /** Marketing Description */
    MarketingDescription: FormControl<string | null>;
    /** Meta Data Description */
    MetaDescription: FormControl<string | null>;
    /** Meta Data Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
}
/**
/* Generates a form from a PublicLessonDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicLessonDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicLessonDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.PublicLessonDetailsDto | null): FormGroup<IPublicLessonDetailsDtoForm>;
/** Interface for a form from a PublicVideoCourseDto*/
export interface IPublicVideoCourseDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Public Video Lesson */
    PublicVideo: FormControl<string | null>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Course Lesson */
    Course: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoCourseDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoCourseDto | null): FormGroup<IPublicVideoCourseDtoForm>;
/** Interface for a form from a PublicVideoDisciplineDto*/
export interface IPublicVideoDisciplineDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Public Video Lesson */
    PublicVideo: FormControl<string | null>;
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoDisciplineDto | null): FormGroup<IPublicVideoDisciplineDtoForm>;
/** Interface for a form from a PublicVideoDto*/
export interface IPublicVideoDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson of Public Video */
    Name: FormControl<string | null>;
    /** Description of Public Video */
    Description: FormControl<string | null>;
    /** Video Id attached to the public video */
    VideoId: FormControl<number | null>;
    /** Tags for the video */
    Tags: FormControl<string | null>;
    /** YouTube Video Id */
    YouTubeVideoId: FormControl<string | null>;
    /** YouTube Link */
    YouTubeLink: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoDto | null): FormGroup<IPublicVideoDtoForm>;
/** Interface for a form from a PublicVideoJobDto*/
export interface IPublicVideoJobDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Public Video Lesson */
    PublicVideo: FormControl<string | null>;
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoJobDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoJobDto | null): FormGroup<IPublicVideoJobDtoForm>;
/** Interface for a form from a PublicVideoLessonDto*/
export interface IPublicVideoLessonDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Public Video Lesson */
    PublicVideo: FormControl<string | null>;
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoLessonDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoLessonDto | null): FormGroup<IPublicVideoLessonDtoForm>;
/** Interface for a form from a PublicVideoTranslationDto*/
export interface IPublicVideoTranslationDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Lesson of public video */
    PublicVideo: FormControl<string | null>;
    /** Description of public video */
    Description: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
}
/**
/* Generates a form from a PublicVideoTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublicVideoTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublicVideoTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.PublicVideoTranslationDto | null): FormGroup<IPublicVideoTranslationDtoForm>;
/** Interface for a form from a PublishCourseDto*/
export interface IPublishCourseDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
}
/**
/* Generates a form from a PublishCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublishCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublishCourseDtoForm(fb: FormBuilder, dto?: Interfaces.PublishCourseDto | null): FormGroup<IPublishCourseDtoForm>;
/** Interface for a form from a PublishLessonDto*/
export interface IPublishLessonDtoForm {
    /** Course Id */
    LessonId: FormControl<number | null>;
}
/**
/* Generates a form from a PublishLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublishLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublishLessonDtoForm(fb: FormBuilder, dto?: Interfaces.PublishLessonDto | null): FormGroup<IPublishLessonDtoForm>;
/** Interface for a form from a PublishTopicDto*/
export interface IPublishTopicDtoForm {
    /** Course Id */
    TopicId: FormControl<number | null>;
}
/**
/* Generates a form from a PublishTopicDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PublishTopicDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPublishTopicDtoForm(fb: FormBuilder, dto?: Interfaces.PublishTopicDto | null): FormGroup<IPublishTopicDtoForm>;
/** Interface for a form from a PurchaseSubscriptionDto*/
export interface IPurchaseSubscriptionDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Organization Id. Must be supplied if user id is not */
    OrganizationId: FormControl<number | null>;
    /** Billing address id */
    BillingAddressId: FormControl<number | null>;
    /** Stored payment credential id */
    StoredPaymentCredentialId: FormControl<number | null>;
    /** Sku to purchase */
    Sku: FormControl<string | null>;
    /** Number of Units */
    Units: FormControl<number | null>;
    /** Reseller Id */
    ResellerId: FormControl<number | null>;
    /** If an org and true, takes a payment at the time of request. Otherwise it delegates to let the invoice recurring job take care of it when it runs on the orgs bill date */
    TakePayment: FormControl<boolean | null>;
}
/**
/* Generates a form from a PurchaseSubscriptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original PurchaseSubscriptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetPurchaseSubscriptionDtoForm(fb: FormBuilder, dto?: Interfaces.PurchaseSubscriptionDto | null): FormGroup<IPurchaseSubscriptionDtoForm>;
/** Interface for a form from a QBotContentStateDto*/
export interface IQBotContentStateDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Asking Product */
    AskingProduct: FormControl<boolean | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Asking Version */
    AskingVersion: FormControl<boolean | null>;
    /** Q Message */
    Question: FormGroup<IQMessageDtoForm>;
    /** Prompt for Acceptable Answer */
    PromptAcceptableAnswer: FormControl<boolean | null>;
    /** Prompt Escalation */
    PromptEscalation: FormControl<boolean | null>;
    /** Prompt For Question */
    PromptForQuestion: FormControl<boolean | null>;
}
/**
/* Generates a form from a QBotContentStateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QBotContentStateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQBotContentStateDtoForm(fb: FormBuilder, dto?: Interfaces.QBotContentStateDto | null): FormGroup<IQBotContentStateDtoForm>;
/** Interface for a form from a QBotEscalationStateDto*/
export interface IQBotEscalationStateDtoForm {
    /** Sent Please Wait */
    SentPleaseWait: FormControl<boolean | null>;
    /** Asked Queue */
    AskedQueue: FormControl<boolean | null>;
    /** Expert Id */
    ExpertId: FormControl<number | null>;
    /** Invited Expert Id */
    InvitedExpertId: FormControl<number | null>;
    /** The Experts that were considered with scoring */
    ExpertsConsidered: FormArray<FormGroup<IQExpertDtoForm>>;
}
/**
/* Generates a form from a QBotEscalationStateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QBotEscalationStateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQBotEscalationStateDtoForm(fb: FormBuilder, dto?: Interfaces.QBotEscalationStateDto | null): FormGroup<IQBotEscalationStateDtoForm>;
/** Interface for a form from a QBotSupportStateDto*/
export interface IQBotSupportStateDtoForm {
    /** Q Message */
    Question: FormGroup<IQMessageDtoForm>;
    /** Asking for Email Address */
    AskingForEmailAddress: FormControl<boolean | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** asking for Token */
    AskingForToken: FormControl<boolean | null>;
    /** Token */
    Token: FormControl<string | null>;
    /** Prompt Acceptable Answer */
    PromptAcceptableAnswer: FormControl<boolean | null>;
    /** Prompt for Escalation */
    PromptEscalation: FormControl<boolean | null>;
    /** Prompt for Question */
    PromptForQuestion: FormControl<boolean | null>;
}
/**
/* Generates a form from a QBotSupportStateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QBotSupportStateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQBotSupportStateDtoForm(fb: FormBuilder, dto?: Interfaces.QBotSupportStateDto | null): FormGroup<IQBotSupportStateDtoForm>;
/** Interface for a form from a QConversationQuestionAnswerDto*/
export interface IQConversationQuestionAnswerDtoForm {
    /** Conversation Id */
    ConversationId: FormControl<string | null>;
    /** Question */
    Question: FormControl<string | null>;
    /** Answer */
    Answer: FormControl<string | null>;
}
/**
/* Generates a form from a QConversationQuestionAnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QConversationQuestionAnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQConversationQuestionAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.QConversationQuestionAnswerDto | null): FormGroup<IQConversationQuestionAnswerDtoForm>;
/** Interface for a form from a QConversationStateDto*/
export interface IQConversationStateDtoForm {
    /** The Id of the conversation */
    Id: FormControl<string | null>;
    /** Q Message */
    OriginalQuestion: FormGroup<IQMessageDtoForm>;
    /** Has Asked Department */
    HasAskedDepartment: FormControl<boolean | null>;
    /** Q Product Info */
    ProductInfo: FormGroup<IQProductDtoForm>;
    /** Q Bot Question State */
    ContentState: FormGroup<IQBotContentStateDtoForm>;
    /** Q Bot Support State */
    SupportState: FormGroup<IQBotSupportStateDtoForm>;
    /** Escalation State */
    EscalationState: FormGroup<IQBotEscalationStateDtoForm>;
    /** When the conversation was started */
    StartedOn: FormControl<Date | null>;
    /** Q Paticipant */
    StartedBy: FormGroup<IQParticipantDtoForm>;
    /** Ended On */
    EndedOn: FormControl<Date | null>;
    /** Did the conversation result in success? */
    Successful: FormControl<boolean | null>;
    /** Participants */
    Participants: FormArray<FormGroup<IQParticipantDtoForm>>;
    /** Messages */
    Messages: FormArray<FormGroup<IQMessageDtoForm>>;
    /** The answer that was generated by an expert or was already in the system that resolves the question */
    ResolutionAnswerId: FormControl<number | null>;
    /** Q Paticipant */
    ResolvedBy: FormGroup<IQParticipantDtoForm>;
}
/**
/* Generates a form from a QConversationStateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QConversationStateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQConversationStateDtoForm(fb: FormBuilder, dto?: Interfaces.QConversationStateDto | null): FormGroup<IQConversationStateDtoForm>;
/** Interface for a form from a QExpertDto*/
export interface IQExpertDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** If there is no UserId, use the connection Id to respond. */
    ConnectionId: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Access Token */
    AccessToken: FormControl<string | null>;
    /** Q Participant Types */
    Type: FormControl<Enums.QParticipantTypes | null>;
    /** Active in conversation */
    Active: FormControl<boolean | null>;
    /** The active organization of the user */
    OrganizationId: FormControl<number | null>;
    /** Score */
    OverallScore: FormControl<number | null>;
    /** Assessment Score */
    AssessmentScore: FormControl<number | null>;
    /** Usage Score */
    UsageScore: FormControl<number | null>;
    /** Learning Score */
    LearningScore: FormControl<number | null>;
}
/**
/* Generates a form from a QExpertDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QExpertDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQExpertDtoForm(fb: FormBuilder, dto?: Interfaces.QExpertDto | null): FormGroup<IQExpertDtoForm>;
/** Interface for a form from a QExpertEscalationResponseDto*/
export interface IQExpertEscalationResponseDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Verification Token */
    VerificationToken: FormControl<string | null>;
    /** Accepted */
    Accepted: FormControl<boolean | null>;
    /** Conversation to Accept */
    ConversationId: FormControl<string | null>;
}
/**
/* Generates a form from a QExpertEscalationResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QExpertEscalationResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQExpertEscalationResponseDtoForm(fb: FormBuilder, dto?: Interfaces.QExpertEscalationResponseDto | null): FormGroup<IQExpertEscalationResponseDtoForm>;
/** Interface for a form from a QMessageButtonDto*/
export interface IQMessageButtonDtoForm {
    /** Button Text */
    Text: FormControl<string | null>;
    /** Value of the response */
    Value: FormControl<string | null>;
    /** Q Button Action Types */
    Type: FormControl<Enums.QButtonActionTypes | null>;
}
/**
/* Generates a form from a QMessageButtonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QMessageButtonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQMessageButtonDtoForm(fb: FormBuilder, dto?: Interfaces.QMessageButtonDto | null): FormGroup<IQMessageButtonDtoForm>;
/** Interface for a form from a QMessageDto*/
export interface IQMessageDtoForm {
    /** Message Id */
    Id: FormControl<string | null>;
    /** Conversation Id */
    ConversationId: FormControl<string | null>;
    /** Q Paticipant */
    FromParticipant: FormGroup<IQParticipantDtoForm>;
    /** Who is the message to? */
    ToParticipants: FormArray<FormGroup<IQParticipantDtoForm>>;
    /** Q Message Types */
    Type: FormControl<Enums.QMessageTypes | null>;
    /** Message */
    Message: FormControl<string | null>;
    /** Is HTML Message */
    IsHtml: FormControl<boolean | null>;
    /** Time stamp of the message */
    DateTime: FormControl<Date | null>;
    /** The message that this response is in reference to. */
    InResponseToMessageId: FormControl<string | null>;
    /** Q Message */
    InResponseToMessage: FormGroup<IQMessageDtoForm>;
    /** Verification Token used for out of band invites to the call. */
    VerificationToken: FormControl<string | null>;
    /** Buttons that can be selected */
    Buttons: FormArray<FormGroup<IQMessageButtonDtoForm>>;
    /** Only a button press is allowed. */
    ButtonOnly: FormControl<boolean | null>;
    /** Lessons */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
    /** The product Id if known to be sent on the initiation of a conversation */
    InitialProductId: FormControl<number | null>;
    /** The version Id if know to be send on the intiiation of a conversation */
    InitialVersionId: FormControl<number | null>;
    /** Is the initial message a guaranteed content question? */
    IsContent: FormControl<boolean | null>;
    /** Intent Score */
    IntentScore: FormControl<number | null>;
    /** Interpreted Intent */
    Intent: FormControl<string | null>;
    /** Concepts */
    Concepts: FormArray<FormControl<string | null>>;
    /** Entities */
    Entities: FormControl<object | null>;
}
/**
/* Generates a form from a QMessageDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QMessageDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQMessageDtoForm(fb: FormBuilder, dto?: Interfaces.QMessageDto | null): FormGroup<IQMessageDtoForm>;
/** Interface for a form from a QParticipantDto*/
export interface IQParticipantDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** If there is no UserId, use the connection Id to respond. */
    ConnectionId: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Access Token */
    AccessToken: FormControl<string | null>;
    /** Q Participant Types */
    Type: FormControl<Enums.QParticipantTypes | null>;
    /** Active in conversation */
    Active: FormControl<boolean | null>;
    /** The active organization of the user */
    OrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a QParticipantDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QParticipantDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQParticipantDtoForm(fb: FormBuilder, dto?: Interfaces.QParticipantDto | null): FormGroup<IQParticipantDtoForm>;
/** Interface for a form from a QProductDto*/
export interface IQProductDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Text */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version Text */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a QProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQProductDtoForm(fb: FormBuilder, dto?: Interfaces.QProductDto | null): FormGroup<IQProductDtoForm>;
/** Interface for a form from a QuestionDto*/
export interface IQuestionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The text of the question */
    Text: FormControl<string | null>;
    /** Is the question active and published? */
    Active: FormControl<boolean | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
    /** The Answers to the question */
    Answers: FormArray<FormGroup<IAnswerDtoForm>>;
    /** Owning Organization's Id */
    OwningOrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a QuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionDto | null): FormGroup<IQuestionDtoForm>;
/** Interface for a form from a QuestionLessonDto*/
export interface IQuestionLessonDtoForm {
    /** Lesson Id */
    Id: FormControl<number | null>;
    /** Lesson Lesson */
    Name: FormControl<string | null>;
    /** Lesson Length */
    Length: FormControl<number | null>;
    /** Question answers lesson at time */
    Time: FormControl<number | null>;
}
/**
/* Generates a form from a QuestionLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionLessonDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionLessonDto | null): FormGroup<IQuestionLessonDtoForm>;
/** Interface for a form from a QuestionOfTheDayAssessmentDto*/
export interface IQuestionOfTheDayAssessmentDtoForm {
    /** Previous Question (If Applicable) result */
    PreviousQuestionResult: FormControl<boolean | null>;
    /** Suggested lessons if previous result was incorrect */
    SuggestedLessons: FormArray<FormGroup<ILessonDtoForm>>;
    /** Were there questions available */
    QuestionsAvailable: FormControl<boolean | null>;
    /** Current User Assessment Id */
    CurrentUserAssessmentId: FormControl<number | null>;
    /** A question for a user assessment */
    CurrentQuestion: FormGroup<IUserAssessmentQuestionDtoForm>;
    /** Next User Assessment Id */
    NextUserAssessmentId: FormControl<number | null>;
    /** A question for a user assessment */
    NextQuestion: FormGroup<IUserAssessmentQuestionDtoForm>;
    /** Was the previous question skipped */
    Skipped: FormControl<boolean | null>;
}
/**
/* Generates a form from a QuestionOfTheDayAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionOfTheDayAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionOfTheDayAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionOfTheDayAssessmentDto | null): FormGroup<IQuestionOfTheDayAssessmentDtoForm>;
/** Interface for a form from a QuestionSearchResultDto*/
export interface IQuestionSearchResultDtoForm {
    /** Question */
    Question: FormControl<string | null>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version */
    Version: FormControl<string | null>;
    /** Major Version # */
    Major: FormControl<number | null>;
    /** Minor Version # */
    Minor: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Answer */
    Answer: FormControl<string | null>;
    /** Question Id */
    QuestionId: FormControl<number | null>;
    /** An Enumeration of different types of assessments */
    Type: FormControl<Enums.AssessmentTypes | null>;
    /** Date Updated */
    UpdatedOn: FormControl<Date | null>;
    /** Lessons associated with the question. */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Match Liklihood */
    Rank: FormControl<number | null>;
}
/**
/* Generates a form from a QuestionSearchResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionSearchResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionSearchResultDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionSearchResultDto | null): FormGroup<IQuestionSearchResultDtoForm>;
/** Interface for a form from a QuestionTranslationDto*/
export interface IQuestionTranslationDtoForm {
    /** Lesson Id */
    QuestionId: FormControl<number | null>;
    /** Lesson Lesson */
    QuestionText: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Answers to the question */
    Answers: FormArray<FormGroup<IAnswerTranslationDtoForm>>;
}
/**
/* Generates a form from a QuestionTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionTranslationDto | null): FormGroup<IQuestionTranslationDtoForm>;
/** Interface for a form from a QuestionWithProductAndLessonDto*/
export interface IQuestionWithProductAndLessonDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The text of the question */
    Text: FormControl<string | null>;
    /** Is the question active and published? */
    Active: FormControl<boolean | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
    /** The Answers to the question */
    Answers: FormArray<FormGroup<IAnswerDtoForm>>;
    /** Owning Organization's Id */
    OwningOrganizationId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Version Lesson */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a QuestionWithProductAndLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionWithProductAndLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionWithProductAndLessonDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionWithProductAndLessonDto | null): FormGroup<IQuestionWithProductAndLessonDtoForm>;
/** Interface for a form from a QuestionWithWorkflowDto*/
export interface IQuestionWithWorkflowDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The text of the question */
    Text: FormControl<string | null>;
    /** Is the question active and published? */
    Active: FormControl<boolean | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
    /** The Answers to the question */
    Answers: FormArray<FormGroup<IAnswerDtoForm>>;
    /** Owning Organization's Id */
    OwningOrganizationId: FormControl<number | null>;
    /** Lesson of the workflow Step the question is in */
    WorkflowStep: FormControl<string | null>;
}
/**
/* Generates a form from a QuestionWithWorkflowDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionWithWorkflowDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionWithWorkflowDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionWithWorkflowDto | null): FormGroup<IQuestionWithWorkflowDtoForm>;
/** Interface for a form from a QuestionWorkflowAssigneesDto*/
export interface IQuestionWorkflowAssigneesDtoForm {
    /** The Question Id */
    QuestionId: FormControl<number | null>;
    /** The Question */
    Question: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role Lesson */
    Role: FormControl<string | null>;
    /** Description if any */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a QuestionWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuestionWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuestionWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.QuestionWorkflowAssigneesDto | null): FormGroup<IQuestionWorkflowAssigneesDtoForm>;
/** Interface for a form from a QuickSearchResultDto*/
export interface IQuickSearchResultDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Product Id */
    VersionId: FormControl<number | null>;
    /** Product Lesson */
    Version: FormControl<string | null>;
    /** List of Lessons */
    Lessons: FormArray<FormGroup<IShortLessonWithCoursesDtoForm>>;
    /** Courses */
    Courses: FormArray<FormGroup<IShortCourseDtoForm>>;
}
/**
/* Generates a form from a QuickSearchResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original QuickSearchResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetQuickSearchResultDtoForm(fb: FormBuilder, dto?: Interfaces.QuickSearchResultDto | null): FormGroup<IQuickSearchResultDtoForm>;
/** Interface for a form from a RecordQuestionOfTheDayAnswerDto*/
export interface IRecordQuestionOfTheDayAnswerDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Assessment Id */
    UserAssessmentId: FormControl<number | null>;
    /** Question Id */
    QuestionId: FormControl<number | null>;
    /** Answer Id */
    AnswerId: FormControl<number | null>;
    /** Badge Id to get the next question, if applicable */
    BadgeId: FormControl<number | null>;
    /** Medallion Id to get the next question, if applicable */
    MedallionId: FormControl<number | null>;
}
/**
/* Generates a form from a RecordQuestionOfTheDayAnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RecordQuestionOfTheDayAnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRecordQuestionOfTheDayAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.RecordQuestionOfTheDayAnswerDto | null): FormGroup<IRecordQuestionOfTheDayAnswerDtoForm>;
/** Interface for a form from a RedeemTokenDto*/
export interface IRedeemTokenDtoForm {
    /** The token to redeem */
    TokenId: FormControl<string | null>;
    /** The User Id of the user that will receive the benefits */
    UserId: FormControl<number | null>;
}
/**
/* Generates a form from a RedeemTokenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RedeemTokenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRedeemTokenDtoForm(fb: FormBuilder, dto?: Interfaces.RedeemTokenDto | null): FormGroup<IRedeemTokenDtoForm>;
/** Interface for a form from a RejectQuoteDto*/
export interface IRejectQuoteDtoForm {
    /** Quote being rejected */
    QuoteId: FormControl<number | null>;
    /** Reason quote is being rejected */
    Reason: FormControl<string | null>;
}
/**
/* Generates a form from a RejectQuoteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RejectQuoteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRejectQuoteDtoForm(fb: FormBuilder, dto?: Interfaces.RejectQuoteDto | null): FormGroup<IRejectQuoteDtoForm>;
/** Interface for a form from a RemoveProductVersionCommandDto*/
export interface IRemoveProductVersionCommandDtoForm {
    /** Current version id */
    VersionId: FormControl<number | null>;
    /** Product Command */
    Command: FormControl<string | null>;
}
/**
/* Generates a form from a RemoveProductVersionCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RemoveProductVersionCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRemoveProductVersionCommandDtoForm(fb: FormBuilder, dto?: Interfaces.RemoveProductVersionCommandDto | null): FormGroup<IRemoveProductVersionCommandDtoForm>;
/** Interface for a form from a RenewPartnerUserEntitlementDto*/
export interface IRenewPartnerUserEntitlementDtoForm {
    /** User Id on the subscription */
    UserId: FormControl<number | null>;
    /** Partner Id */
    PartnerId: FormControl<number | null>;
    /** Entitlement Id to renew */
    EntitlementId: FormControl<number | null>;
}
/**
/* Generates a form from a RenewPartnerUserEntitlementDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RenewPartnerUserEntitlementDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRenewPartnerUserEntitlementDtoForm(fb: FormBuilder, dto?: Interfaces.RenewPartnerUserEntitlementDto | null): FormGroup<IRenewPartnerUserEntitlementDtoForm>;
/** Interface for a form from a ReportAchievementsTestedOutDto*/
export interface IReportAchievementsTestedOutDtoForm {
    /** Badges tested out of */
    Badges: FormArray<FormGroup<IBadgeDtoForm>>;
    /** Medallions tested out of */
    Medallions: FormArray<FormGroup<IMedallionDtoForm>>;
    /** Disciplines tested out of */
    Disciplines: FormArray<FormGroup<IDisciplineDtoForm>>;
}
/**
/* Generates a form from a ReportAchievementsTestedOutDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportAchievementsTestedOutDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportAchievementsTestedOutDtoForm(fb: FormBuilder, dto?: Interfaces.ReportAchievementsTestedOutDto | null): FormGroup<IReportAchievementsTestedOutDtoForm>;
/** Interface for a form from a ReportActivityItemDto*/
export interface IReportActivityItemDtoForm {
    /** Lesson Detail */
    Lesson: FormGroup<ILessonActivityDetailDtoForm>;
    /** Course Activity Details */
    Course: FormGroup<ICourseActivityDetailDtoForm>;
    /** Organization Details */
    Organization: FormGroup<IOrganizationActivityDetailDtoForm>;
    /** Product Details */
    Product: FormGroup<IProductActivityDetailDtoForm>;
    /** Command */
    Command: FormControl<string | null>;
    /** Date Time */
    DateTime: FormControl<Date | null>;
    /** User Details */
    User: FormGroup<IUserActivityDetailDtoForm>;
}
/**
/* Generates a form from a ReportActivityItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportActivityItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportActivityItemDtoForm(fb: FormBuilder, dto?: Interfaces.ReportActivityItemDto | null): FormGroup<IReportActivityItemDtoForm>;
/** Interface for a form from a ReportBillableInventoryDto*/
export interface IReportBillableInventoryDtoForm {
    /** From Organization Id */
    FromOrganizationId: FormControl<number | null>;
    /** From Organization */
    FromOrganization: FormControl<string | null>;
    /** Grand Total */
    GrandTotal: FormControl<number | null>;
    /** Total Billed */
    TotalBilled: FormControl<number | null>;
    /** Delta */
    Delta: FormControl<number | null>;
    /** Invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Invoice Number */
    InvoiceNumber: FormControl<number | null>;
    /** Date of invoice */
    Date: FormControl<Date | null>;
    /** Billable Inventory */
    BillableInventory: FormControl<number | null>;
}
/**
/* Generates a form from a ReportBillableInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportBillableInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportBillableInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.ReportBillableInventoryDto | null): FormGroup<IReportBillableInventoryDtoForm>;
/** Interface for a form from a ReportCourseCompletionDto*/
export interface IReportCourseCompletionDtoForm {
    /** The course Id */
    CourseId: FormControl<number | null>;
    /** The course name */
    Course: FormControl<string | null>;
    /** The percentage complete */
    PercentComplete: FormControl<number | null>;
}
/**
/* Generates a form from a ReportCourseCompletionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportCourseCompletionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportCourseCompletionDtoForm(fb: FormBuilder, dto?: Interfaces.ReportCourseCompletionDto | null): FormGroup<IReportCourseCompletionDtoForm>;
/** Interface for a form from a ReportCourseCompletionLessonsDto*/
export interface IReportCourseCompletionLessonsDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** The course Id */
    CourseId: FormControl<number | null>;
    /** The course name */
    Course: FormControl<string | null>;
    /** The number of completed lessons on the course */
    CompletedLessons: FormControl<number | null>;
    /** The total number of lessons on the course */
    TotalLessons: FormControl<number | null>;
}
/**
/* Generates a form from a ReportCourseCompletionLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportCourseCompletionLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportCourseCompletionLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportCourseCompletionLessonsDto | null): FormGroup<IReportCourseCompletionLessonsDtoForm>;
/** Interface for a form from a ReportCoursesDto*/
export interface IReportCoursesDtoForm {
    /** Question Type */
    ContentType: FormControl<string | null>;
    /** Course Id */
    CustomerContentID: FormControl<string | null>;
    /** URL */
    URL: FormControl<string | null>;
    /** Image URL */
    ImageURL: FormControl<string | null>;
    /** Title */
    Title: FormControl<string | null>;
    /** Summary */
    Summary: FormControl<string | null>;
    /** Duration */
    Duration: FormControl<number | null>;
    /** Duration Units */
    DurationUnits: FormControl<string | null>;
    /** Publish Date */
    PublishDate: FormControl<Date | null>;
    /** Authors */
    Authors: FormControl<string | null>;
    /** Topics */
    Topics: FormControl<string | null>;
}
/**
/* Generates a form from a ReportCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.ReportCoursesDto | null): FormGroup<IReportCoursesDtoForm>;
/** Interface for a form from a ReportDto*/
export interface IReportDtoForm {
    /** The id of the screen or report */
    Id: FormControl<string | null>;
    /** Report Endpoints */
    ApiEndpoint: FormControl<Enums.ReportEndpoints | null>;
    /** Report Detail Types */
    DetailType: FormControl<Enums.ReportDetailTypes | null>;
    /** Report Date Range */
    DateRange: FormControl<Enums.ReportDateRange | null>;
    /** Report Date Range */
    Visibility: FormControl<Enums.ReportVisibilities | null>;
    /** Custom Range Start Date */
    CustomStartDate: FormControl<Date | null>;
    /** Custom Range End Date */
    CustomEndDate: FormControl<Date | null>;
    /** The custom name of the report if applicable */
    ReportName: FormControl<string | null>;
    /**  */
    LoadCriteria: FormGroup<ILoadCriteriaForm>;
    /** Columns to be displayed in order */
    Columns: FormArray<FormGroup<IColumnDetailForm>>;
    /** List of chart details on how charts should be built on a report */
    Charts: FormArray<FormGroup<IChartDetailForm>>;
    /** Count Field Display Lesson */
    CountFieldDisplayName: FormControl<string | null>;
    /** Count Field Internal Lesson */
    CountFieldInternalName: FormControl<string | null>;
}
/**
/* Generates a form from a ReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportDtoForm(fb: FormBuilder, dto?: Interfaces.ReportDto | null): FormGroup<IReportDtoForm>;
/** Interface for a form from a ReportGroupProductViewsDto*/
export interface IReportGroupProductViewsDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Command */
    Product: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
    /** Lessons Viewed */
    Lessons: FormArray<FormGroup<IShortContentWithViewsDtoForm>>;
}
/**
/* Generates a form from a ReportGroupProductViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportGroupProductViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportGroupProductViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportGroupProductViewsDto | null): FormGroup<IReportGroupProductViewsDtoForm>;
/** Interface for a form from a ReportGroupViewsDto*/
export interface IReportGroupViewsDtoForm {
    /** Group Lesson */
    Group: FormControl<string | null>;
    /** Views */
    TotalViews: FormControl<number | null>;
    /** Total Length */
    TotalTime: FormControl<number | null>;
}
/**
/* Generates a form from a ReportGroupViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportGroupViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportGroupViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportGroupViewsDto | null): FormGroup<IReportGroupViewsDtoForm>;
/** Interface for a form from a ReportLessonActivityDetailsDto*/
export interface IReportLessonActivityDetailsDtoForm {
    /** Date and Tiem of the Activity */
    DateTime: FormControl<Date | null>;
    /** IP of the user */
    Origin: FormControl<string | null>;
    /** Client application that made the request. */
    ClientId: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User name */
    UserName: FormControl<string | null>;
    /** User Full Lesson */
    UserFullName: FormControl<string | null>;
    /** Email Address */
    UserEmailAddress: FormControl<string | null>;
    /** Is the user active? */
    UserIsActive: FormControl<boolean | null>;
    /** User Country */
    UserCountry: FormControl<string | null>;
    /** User's location within the country */
    UserLocation: FormControl<string | null>;
    /** User's Organizational Title */
    UserTitle: FormControl<string | null>;
    /** Organization of the User */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Organization Types */
    OrganizationType: FormControl<Enums.OrganizationTypes | null>;
    /** User's Division */
    OrganizationDivision: FormControl<string | null>;
    /** User's Group */
    OrganizationGroup: FormControl<string | null>;
    /** User's Level */
    OrganizationLevel: FormControl<string | null>;
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    LessonName: FormControl<string | null>;
    /** Lesson Description */
    LessonDescription: FormControl<string | null>;
    /** Lesson Length */
    LessonLength: FormControl<number | null>;
    /** Lesson Tags */
    LessonTags: FormControl<string | null>;
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Course Lesson */
    CourseName: FormControl<string | null>;
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** Topic Lesson */
    TopicName: FormControl<string | null>;
    /** ProjectId */
    ProjectId: FormControl<number | null>;
    /** Project Lesson */
    ProjectName: FormControl<string | null>;
    /** Product Ids */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    ProductName: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version Lesson */
    VersionName: FormControl<string | null>;
}
/**
/* Generates a form from a ReportLessonActivityDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportLessonActivityDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportLessonActivityDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportLessonActivityDetailsDto | null): FormGroup<IReportLessonActivityDetailsDtoForm>;
/** Interface for a form from a ReportLessonViewsDto*/
export interface IReportLessonViewsDtoForm {
    /** The Lesson Id */
    LessonId: FormControl<number | null>;
    /** The name of the lesson */
    Lesson: FormControl<string | null>;
    /** The Length of the lesson */
    Length: FormControl<number | null>;
    /** The number of views */
    Views: FormControl<number | null>;
    /** Courses for the lesson */
    Courses: FormArray<FormGroup<IShortContentDtoForm>>;
}
/**
/* Generates a form from a ReportLessonViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportLessonViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportLessonViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportLessonViewsDto | null): FormGroup<IReportLessonViewsDtoForm>;
/** Interface for a form from a ReportMostActiveProduct*/
export interface IReportMostActiveProductForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
}
/**
/* Generates a form from a ReportMostActiveProduct
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportMostActiveProduct from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportMostActiveProductForm(fb: FormBuilder, dto?: Interfaces.ReportMostActiveProduct | null): FormGroup<IReportMostActiveProductForm>;
/** Interface for a form from a ReportMostTakenAssessmentDto*/
export interface IReportMostTakenAssessmentDtoForm {
    /** Assessment Id */
    AssessmentId: FormControl<number | null>;
    /** Assessment */
    Assessment: FormControl<string | null>;
    /** Times Taken */
    Times: FormControl<number | null>;
}
/**
/* Generates a form from a ReportMostTakenAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportMostTakenAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportMostTakenAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.ReportMostTakenAssessmentDto | null): FormGroup<IReportMostTakenAssessmentDtoForm>;
/** Interface for a form from a ReportOrganizationUserEntitlementsDto*/
export interface IReportOrganizationUserEntitlementsDtoForm {
    /** User's Id */
    Id: FormControl<number | null>;
    /** User Lesson */
    UserName: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Active? */
    Active: FormControl<boolean | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** inventory item */
    InventoryItem: FormControl<string | null>;
    /** inventory item */
    InventoryItemId: FormControl<number | null>;
    /** Price */
    Price: FormControl<number | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Expiration Date */
    ExpirationDate: FormControl<Date | null>;
}
/**
/* Generates a form from a ReportOrganizationUserEntitlementsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportOrganizationUserEntitlementsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportOrganizationUserEntitlementsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportOrganizationUserEntitlementsDto | null): FormGroup<IReportOrganizationUserEntitlementsDtoForm>;
/** Interface for a form from a ReportOrganizationUsersDto*/
export interface IReportOrganizationUsersDtoForm {
    /** User's Id */
    Id: FormControl<number | null>;
    /** User Lesson */
    UserName: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Active? */
    Active: FormControl<boolean | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Division */
    Division: FormControl<string | null>;
    /** Group */
    Group: FormControl<string | null>;
    /** Location */
    Location: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
}
/**
/* Generates a form from a ReportOrganizationUsersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportOrganizationUsersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportOrganizationUsersDtoForm(fb: FormBuilder, dto?: Interfaces.ReportOrganizationUsersDto | null): FormGroup<IReportOrganizationUsersDtoForm>;
/** Interface for a form from a ReportPartnerActivityDto*/
export interface IReportPartnerActivityDtoForm {
    /** Id of the partner */
    PartnerId: FormControl<number | null>;
    /** Lesson of the partner */
    PartnerName: FormControl<string | null>;
    /** Contact Types */
    ToContactType: FormControl<Enums.ContactTypes | null>;
    /** The contact id */
    ToContactId: FormControl<number | null>;
    /** Lesson of the user or organzation */
    ToContactName: FormControl<string | null>;
    /** The date */
    Date: FormControl<Date | null>;
}
/**
/* Generates a form from a ReportPartnerActivityDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportPartnerActivityDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportPartnerActivityDtoForm(fb: FormBuilder, dto?: Interfaces.ReportPartnerActivityDto | null): FormGroup<IReportPartnerActivityDtoForm>;
/** Interface for a form from a ReportPartnerTokenDto*/
export interface IReportPartnerTokenDtoForm {
    /** The internal id */
    Id: FormControl<number | null>;
    /** The Token Id */
    TokenId: FormControl<string | null>;
    /** The date the token expires on */
    ExpiresOn: FormControl<Date | null>;
    /** The date the token was cancelled on, if any. */
    CancelledOn: FormControl<Date | null>;
    /** The day the token was issued */
    IssuedOn: FormControl<Date | null>;
    /** The day the token was redeemed, if any. */
    RedeemedOn: FormControl<Date | null>;
    /** The id of the user/organization the token was redeemed by, if any */
    RedeemedById: FormControl<number | null>;
    /** The name of the user/organization the token was redeemed by, if any */
    RedeemedBy: FormControl<string | null>;
    /** The id of the user the token was cancelled by, if any */
    CancelledById: FormControl<number | null>;
    /** The name of the user the token was cancelled by, if any */
    CancelledBy: FormControl<string | null>;
    /** The invoice inventory the token is attached to */
    InvoiceInventoryId: FormControl<number | null>;
    /** The friendly name of the invoice inventory object the token is attached to */
    InvoiceInventory: FormControl<string | null>;
    /** The owning organization id of the token */
    OrganizationId: FormControl<number | null>;
    /** Price */
    Price: FormControl<number | null>;
}
/**
/* Generates a form from a ReportPartnerTokenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportPartnerTokenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportPartnerTokenDtoForm(fb: FormBuilder, dto?: Interfaces.ReportPartnerTokenDto | null): FormGroup<IReportPartnerTokenDtoForm>;
/** Interface for a form from a ReportPlatformTotalDto*/
export interface IReportPlatformTotalDtoForm {
    /** Client Id */
    ClientId: FormControl<string | null>;
    /** User Count */
    UserCount: FormControl<number | null>;
}
/**
/* Generates a form from a ReportPlatformTotalDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportPlatformTotalDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportPlatformTotalDtoForm(fb: FormBuilder, dto?: Interfaces.ReportPlatformTotalDto | null): FormGroup<IReportPlatformTotalDtoForm>;
/** Interface for a form from a ReportProductCommandViewsDto*/
export interface IReportProductCommandViewsDtoForm {
    /** Command */
    Command: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
    /** Lessons Viewed */
    Lessons: FormArray<FormGroup<IShortContentWithViewsDtoForm>>;
}
/**
/* Generates a form from a ReportProductCommandViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportProductCommandViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportProductCommandViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportProductCommandViewsDto | null): FormGroup<IReportProductCommandViewsDtoForm>;
/** Interface for a form from a ReportProductVersionViewsDto*/
export interface IReportProductVersionViewsDtoForm {
    /** Command */
    Version: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
    /** Lessons Viewed */
    Lessons: FormArray<FormGroup<IShortContentWithViewsDtoForm>>;
}
/**
/* Generates a form from a ReportProductVersionViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportProductVersionViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportProductVersionViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportProductVersionViewsDto | null): FormGroup<IReportProductVersionViewsDtoForm>;
/** Interface for a form from a ReportProductViewsDto*/
export interface IReportProductViewsDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
}
/**
/* Generates a form from a ReportProductViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportProductViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportProductViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportProductViewsDto | null): FormGroup<IReportProductViewsDtoForm>;
/** Interface for a form from a ReportProjectLessonViewsDto*/
export interface IReportProjectLessonViewsDtoForm {
    /** Project Id */
    ProjectId: FormControl<number | null>;
    /** Project Lesson */
    Project: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
}
/**
/* Generates a form from a ReportProjectLessonViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportProjectLessonViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportProjectLessonViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportProjectLessonViewsDto | null): FormGroup<IReportProjectLessonViewsDtoForm>;
/** Interface for a form from a ReportProjectUserViewsDto*/
export interface IReportProjectUserViewsDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** Total Views */
    TotalViews: FormControl<number | null>;
    /** Total Time Watched */
    TotalTimeWatched: FormControl<number | null>;
    /** Lessons Viewed */
    Lessons: FormArray<FormGroup<IShortContentWithViewsDtoForm>>;
}
/**
/* Generates a form from a ReportProjectUserViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportProjectUserViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportProjectUserViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportProjectUserViewsDto | null): FormGroup<IReportProjectUserViewsDtoForm>;
/** Interface for a form from a ReportResourceViewsDto*/
export interface IReportResourceViewsDtoForm {
    /** The resource Id */
    ResourceId: FormControl<number | null>;
    /** The name of the resource */
    Resource: FormControl<string | null>;
    /** The number of views */
    Views: FormControl<number | null>;
    /** Courses for the resource */
    Courses: FormArray<FormGroup<IShortContentDtoForm>>;
    /** Lessons for the for the resource */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
}
/**
/* Generates a form from a ReportResourceViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportResourceViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportResourceViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportResourceViewsDto | null): FormGroup<IReportResourceViewsDtoForm>;
/** Interface for a form from a ReportSalesBySalesRepDto*/
export interface IReportSalesBySalesRepDtoForm {
    /** Sales Rep id */
    SalesRepId: FormControl<number | null>;
    /** Sales Rep Lesson */
    SalesRep: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    OrganizationName: FormControl<string | null>;
    /** Total amount grossed by the sales rep */
    Total: FormControl<number | null>;
}
/**
/* Generates a form from a ReportSalesBySalesRepDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportSalesBySalesRepDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportSalesBySalesRepDtoForm(fb: FormBuilder, dto?: Interfaces.ReportSalesBySalesRepDto | null): FormGroup<IReportSalesBySalesRepDtoForm>;
/** Interface for a form from a ReportScheduleDetail*/
export interface IReportScheduleDetailForm {
    /** Organization Automated Report Types */
    Report: FormControl<Enums.OrganizationReportTypes | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Last Run On */
    LastRunOn: FormControl<Date | null>;
    /** Next Run On */
    NextRunOn: FormControl<Date | null>;
    /** Report Schedules */
    Schedule: FormControl<Enums.ReportSchedules | null>;
    /** Recipients */
    Recipients: FormArray<FormGroup<IReportScheduleRecipientDetailForm>>;
}
/**
/* Generates a form from a ReportScheduleDetail
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportScheduleDetail from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportScheduleDetailForm(fb: FormBuilder, dto?: Interfaces.ReportScheduleDetail | null): FormGroup<IReportScheduleDetailForm>;
/** Interface for a form from a ReportScheduleRecipientDetail*/
export interface IReportScheduleRecipientDetailForm {
    /** User Id if applicable */
    UserId: FormControl<number | null>;
    /** Users Lesson */
    Name: FormControl<string | null>;
    /** Users Email Address */
    EmailAddress: FormControl<string | null>;
    /** Whether or not the user will receive emailed report */
    Receive: FormControl<boolean | null>;
}
/**
/* Generates a form from a ReportScheduleRecipientDetail
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportScheduleRecipientDetail from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportScheduleRecipientDetailForm(fb: FormBuilder, dto?: Interfaces.ReportScheduleRecipientDetail | null): FormGroup<IReportScheduleRecipientDetailForm>;
/** Interface for a form from a ReportSignupsByMonthDetailDto*/
export interface IReportSignupsByMonthDetailDtoForm {
    /** Month and Year */
    MonthAndYear: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Email */
    Email: FormControl<string | null>;
    /** UA Membership Id */
    MembershipId: FormControl<string | null>;
    /** Group or Local Number */
    Group: FormControl<string | null>;
}
/**
/* Generates a form from a ReportSignupsByMonthDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportSignupsByMonthDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportSignupsByMonthDetailDtoForm(fb: FormBuilder, dto?: Interfaces.ReportSignupsByMonthDetailDto | null): FormGroup<IReportSignupsByMonthDetailDtoForm>;
/** Interface for a form from a ReportSignupsByMonthDto*/
export interface IReportSignupsByMonthDtoForm {
    /** Month */
    Month: FormControl<string | null>;
    /** Signups in Month */
    Count: FormControl<number | null>;
}
/**
/* Generates a form from a ReportSignupsByMonthDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportSignupsByMonthDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportSignupsByMonthDtoForm(fb: FormBuilder, dto?: Interfaces.ReportSignupsByMonthDto | null): FormGroup<IReportSignupsByMonthDtoForm>;
/** Interface for a form from a ReportTopOrganizationsByDollarValueDto*/
export interface IReportTopOrganizationsByDollarValueDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organizaiton: FormControl<string | null>;
    /** Amount Sold */
    Amount: FormControl<number | null>;
}
/**
/* Generates a form from a ReportTopOrganizationsByDollarValueDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportTopOrganizationsByDollarValueDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportTopOrganizationsByDollarValueDtoForm(fb: FormBuilder, dto?: Interfaces.ReportTopOrganizationsByDollarValueDto | null): FormGroup<IReportTopOrganizationsByDollarValueDtoForm>;
/** Interface for a form from a ReportTopUsersByDollarValueDto*/
export interface IReportTopUsersByDollarValueDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User */
    User: FormControl<string | null>;
    /** Total Deals */
    TotalDeals: FormControl<number | null>;
    /** Amount Sold */
    Amount: FormControl<number | null>;
}
/**
/* Generates a form from a ReportTopUsersByDollarValueDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportTopUsersByDollarValueDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportTopUsersByDollarValueDtoForm(fb: FormBuilder, dto?: Interfaces.ReportTopUsersByDollarValueDto | null): FormGroup<IReportTopUsersByDollarValueDtoForm>;
/** Interface for a form from a ReportTotalDto*/
export interface IReportTotalDtoForm {
    /** Total */
    Total: FormControl<number | null>;
}
/**
/* Generates a form from a ReportTotalDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportTotalDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportTotalDtoForm(fb: FormBuilder, dto?: Interfaces.ReportTotalDto | null): FormGroup<IReportTotalDtoForm>;
/** Interface for a form from a ReportTranslationErrorDto*/
export interface IReportTranslationErrorDtoForm {
    /** Item with the error */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Description of Error */
    Description: FormControl<string | null>;
    /** User who reported it */
    UserId: FormControl<number | null>;
    /** User's name */
    User: FormControl<string | null>;
}
/**
/* Generates a form from a ReportTranslationErrorDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportTranslationErrorDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportTranslationErrorDtoForm(fb: FormBuilder, dto?: Interfaces.ReportTranslationErrorDto | null): FormGroup<IReportTranslationErrorDtoForm>;
/** Interface for a form from a ReportTrialsDto*/
export interface IReportTrialsDtoForm {
    /** Entitlement Id */
    EntitlementId: FormControl<number | null>;
    /** Inventory Item */
    InventoryItem: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User's Lesson */
    UserName: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Ends On */
    EndsOn: FormControl<Date | null>;
}
/**
/* Generates a form from a ReportTrialsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportTrialsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportTrialsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportTrialsDto | null): FormGroup<IReportTrialsDtoForm>;
/** Interface for a form from a ReportUpcomingOrganizationRenewalsDto*/
export interface IReportUpcomingOrganizationRenewalsDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Renewal Date */
    RenewalDate: FormControl<Date | null>;
    /** Active Users */
    ActiveUsers: FormControl<number | null>;
    /** Inactive Users */
    InactiveUsers: FormControl<number | null>;
}
/**
/* Generates a form from a ReportUpcomingOrganizationRenewalsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportUpcomingOrganizationRenewalsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportUpcomingOrganizationRenewalsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportUpcomingOrganizationRenewalsDto | null): FormGroup<IReportUpcomingOrganizationRenewalsDtoForm>;
/** Interface for a form from a ReportUserDetailViewsDto*/
export interface IReportUserDetailViewsDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User's Lesson */
    User: FormControl<string | null>;
    /** Lesson */
    Lesson: FormControl<string | null>;
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Last Viewed On */
    LastViewedOn: FormControl<Date | null>;
}
/**
/* Generates a form from a ReportUserDetailViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportUserDetailViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportUserDetailViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportUserDetailViewsDto | null): FormGroup<IReportUserDetailViewsDtoForm>;
/** Interface for a form from a ReportUserLessonViewsDto*/
export interface IReportUserLessonViewsDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User's Lesson */
    User: FormControl<string | null>;
    /** Views */
    Views: FormControl<number | null>;
    /** Total Time */
    TotalTime: FormControl<number | null>;
}
/**
/* Generates a form from a ReportUserLessonViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportUserLessonViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportUserLessonViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportUserLessonViewsDto | null): FormGroup<IReportUserLessonViewsDtoForm>;
/** Interface for a form from a ReportWorkFlowTaskDetailsDto*/
export interface IReportWorkFlowTaskDetailsDtoForm {
    /** The item in question */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** The Lesson of the item */
    Name: FormControl<string | null>;
    /** The time of the last action on the item */
    LastActionOn: FormControl<Date | null>;
    /** Last Updated On */
    LastUpdatedOn: FormControl<Date | null>;
    /** The Step in the workflow that the change was made on. */
    Step: FormControl<string | null>;
    /** Who made the change */
    AssignedTo: FormArray<FormControl<string | null>>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Est. Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
}
/**
/* Generates a form from a ReportWorkFlowTaskDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportWorkFlowTaskDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportWorkFlowTaskDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.ReportWorkFlowTaskDetailsDto | null): FormGroup<IReportWorkFlowTaskDetailsDtoForm>;
/** Interface for a form from a ReportWorkflowTaskChangesDto*/
export interface IReportWorkflowTaskChangesDtoForm {
    /** The item in question */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** The Lesson of the item */
    Name: FormControl<string | null>;
    /** The time of the change */
    DateTime: FormControl<Date | null>;
    /** The Step in the workflow that the change was made on. */
    Step: FormControl<string | null>;
    /** Who made the change */
    ExecutedBy: FormControl<string | null>;
    /** The changes made */
    Changes: FormControl<string | null>;
}
/**
/* Generates a form from a ReportWorkflowTaskChangesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ReportWorkflowTaskChangesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetReportWorkflowTaskChangesDtoForm(fb: FormBuilder, dto?: Interfaces.ReportWorkflowTaskChangesDto | null): FormGroup<IReportWorkflowTaskChangesDtoForm>;
/** Interface for a form from a RequestAccessDto*/
export interface IRequestAccessDtoForm {
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** The	email address requesting access */
    EmailAddress: FormControl<string | null>;
    /** The Site that is making the access request */
    RequestingSiteUrl: FormControl<string | null>;
    /** The id of the client making the request */
    ClientId: FormControl<string | null>;
}
/**
/* Generates a form from a RequestAccessDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestAccessDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestAccessDtoForm(fb: FormBuilder, dto?: Interfaces.RequestAccessDto | null): FormGroup<IRequestAccessDtoForm>;
/** Interface for a form from a RequestLessonRightsDto*/
export interface IRequestLessonRightsDtoForm {
    /** The list of lessons that the current user is requesting rights information for. */
    LessonIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a RequestLessonRightsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestLessonRightsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestLessonRightsDtoForm(fb: FormBuilder, dto?: Interfaces.RequestLessonRightsDto | null): FormGroup<IRequestLessonRightsDtoForm>;
/** Interface for a form from a RequestProjectMatchDto*/
export interface IRequestProjectMatchDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** List of Project Job Ids to match */
    ProjectJobIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a RequestProjectMatchDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestProjectMatchDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestProjectMatchDtoForm(fb: FormBuilder, dto?: Interfaces.RequestProjectMatchDto | null): FormGroup<IRequestProjectMatchDtoForm>;
/** Interface for a form from a RequestResetPasswordDto*/
export interface IRequestResetPasswordDtoForm {
    /** The email address to send the password reset token to. */
    Email: FormControl<string | null>;
    /** The Url to use for the link for reset completion */
    ResetUrl: FormControl<string | null>;
    /** The client */
    ClientId: FormControl<string | null>;
}
/**
/* Generates a form from a RequestResetPasswordDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestResetPasswordDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestResetPasswordDtoForm(fb: FormBuilder, dto?: Interfaces.RequestResetPasswordDto | null): FormGroup<IRequestResetPasswordDtoForm>;
/** Interface for a form from a RequestSalesTaxExemptionDto*/
export interface IRequestSalesTaxExemptionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Is the address the default for the user */
    Default: FormControl<boolean | null>;
    /** Is the address the billing address for the user */
    Billing: FormControl<boolean | null>;
    /** Is the address the shipping address for the user */
    Shipping: FormControl<boolean | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal/Zip Code */
    PostalCode: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Sales Tax Id to exempt */
    SalesTaxId: FormControl<number | null>;
    /** Contact Id = null if not yet a contact */
    ContactId: FormControl<number | null>;
    /** Contact Types */
    ContactType: FormControl<Enums.ContactTypes | null>;
    /** Organization Lesson if ContactType = Organization  - Must match on file if Contact Id specified */
    OrganizationName: FormControl<string | null>;
    /** First Lesson if ContactType = User - Must match on file if Contact Id specified */
    FirstName: FormControl<string | null>;
    /** Last Lesson  if ContactType = User - Must match on file if Contact Id specified */
    LastName: FormControl<string | null>;
    /** Contact Email Address - Always required, if existing org, must be linked to an org admin otherwise created as an org admin. */
    EmailAddress: FormControl<string | null>;
    /** Contact phone # - Always required, if existing org, must be linked to an org admin otherwise created as an org admin. */
    PhoneNumber: FormControl<string | null>;
    /** Marketing Campaign Sources (How did you hear about us?) */
    HowDidYouHearAboutUs: FormControl<Enums.HowDidYouHearAboutUs | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Exemption Number */
    ExemptionNumber: FormControl<string | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Expires On */
    ExpiresOn: FormControl<Date | null>;
    /** SSO Provider */
    Provider: FormControl<string | null>;
    /** SSO Provider Key */
    ProviderKey: FormControl<string | null>;
    /** SSO External Access Token */
    ExternalAccessToken: FormControl<string | null>;
    /** The exemption certificate issued by the governing body. */
    File: FormControl<File | null>;
}
/**
/* Generates a form from a RequestSalesTaxExemptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestSalesTaxExemptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestSalesTaxExemptionDtoForm(fb: FormBuilder, dto?: Interfaces.RequestSalesTaxExemptionDto | null): FormGroup<IRequestSalesTaxExemptionDtoForm>;
/** Interface for a form from a RequestVerifyEduDto*/
export interface IRequestVerifyEduDtoForm {
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
}
/**
/* Generates a form from a RequestVerifyEduDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original RequestVerifyEduDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetRequestVerifyEduDtoForm(fb: FormBuilder, dto?: Interfaces.RequestVerifyEduDto | null): FormGroup<IRequestVerifyEduDtoForm>;
/** Interface for a form from a ResetPasswordDto*/
export interface IResetPasswordDtoForm {
    /** The email address of the user that wishes to reset their password */
    Email: FormControl<string | null>;
    /** The code to validate the password reset. */
    Code: FormControl<string | null>;
    /** The new password to set */
    Password: FormControl<string | null>;
    /** The confirmation of the new password to set. */
    ConfirmPassword: FormControl<string | null>;
    /** The client that is executing the reset */
    ClientId: FormControl<string | null>;
}
/**
/* Generates a form from a ResetPasswordDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResetPasswordDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResetPasswordDtoForm(fb: FormBuilder, dto?: Interfaces.ResetPasswordDto | null): FormGroup<IResetPasswordDtoForm>;
/** Interface for a form from a ResourceDto*/
export interface IResourceDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** The language of the item */
    LanguageCode: FormControl<string | null>;
    /** The Uri to download the resource */
    Uri: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
    /** The file name if any of the resource */
    FileName: FormControl<string | null>;
    /** The size of the resource */
    Size: FormControl<string | null>;
    /** the last time it was uploaded */
    DateTimeFileUpdated: FormControl<Date | null>;
    /** Resource Locations */
    Location: FormControl<Enums.ResourceLocations | null>;
    /** Any child resources of this parent */
    ChildResources: FormArray<FormGroup<IChildResourceDtoForm>>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** Directions */
    Directions: FormControl<string | null>;
}
/**
/* Generates a form from a ResourceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResourceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResourceDtoForm(fb: FormBuilder, dto?: Interfaces.ResourceDto | null): FormGroup<IResourceDtoForm>;
/** Interface for a form from a ResourceLocatorDto*/
export interface IResourceLocatorDtoForm {
    /** The Id of the Resource */
    Id: FormControl<number | null>;
    /** Lesson of the Resource */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Uri */
    Uri: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
    /** Size */
    Size: FormControl<string | null>;
    /** File Lesson if Any */
    FileName: FormControl<string | null>;
}
/**
/* Generates a form from a ResourceLocatorDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResourceLocatorDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResourceLocatorDtoForm(fb: FormBuilder, dto?: Interfaces.ResourceLocatorDto | null): FormGroup<IResourceLocatorDtoForm>;
/** Interface for a form from a ResourceViewDto*/
export interface IResourceViewDtoForm {
    /** The Lesson Viewed */
    LessonId: FormControl<number | null>;
    /** The originating Course */
    CourseId: FormControl<number | null>;
    /** The Topic */
    TopicId: FormControl<number | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Project Id */
    ProjectId: FormControl<number | null>;
    /** Playlist Id */
    PlaylistId: FormControl<number | null>;
    /** The client viewing the lesson */
    ClientId: FormControl<string | null>;
    /** Resource Id */
    ResourceId: FormControl<number | null>;
}
/**
/* Generates a form from a ResourceViewDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResourceViewDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResourceViewDtoForm(fb: FormBuilder, dto?: Interfaces.ResourceViewDto | null): FormGroup<IResourceViewDtoForm>;
/** Interface for a form from a ResourceWithParentDto*/
export interface IResourceWithParentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** The language of the item */
    LanguageCode: FormControl<string | null>;
    /** The Uri to download the resource */
    Uri: FormControl<string | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
    /** The file name if any of the resource */
    FileName: FormControl<string | null>;
    /** The size of the resource */
    Size: FormControl<string | null>;
    /** the last time it was uploaded */
    DateTimeFileUpdated: FormControl<Date | null>;
    /** Resource Locations */
    Location: FormControl<Enums.ResourceLocations | null>;
    /** Any child resources of this parent */
    ChildResources: FormArray<FormGroup<IChildResourceDtoForm>>;
    /** The Organization that owns the course */
    OwningOrganizationId: FormControl<number | null>;
    /** Directions */
    Directions: FormControl<string | null>;
    /** The parents of the resource */
    Parents: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a ResourceWithParentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResourceWithParentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResourceWithParentDtoForm(fb: FormBuilder, dto?: Interfaces.ResourceWithParentDto | null): FormGroup<IResourceWithParentDtoForm>;
/** Interface for a form from a ResourcesByTypeDto*/
export interface IResourcesByTypeDtoForm {
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** The string name of the type */
    Type: FormControl<string | null>;
    /** Is the resource type expanded */
    Expanded: FormControl<boolean | null>;
    /** The resources under the type */
    Resources: FormArray<FormGroup<IResourceLocatorDtoForm>>;
}
/**
/* Generates a form from a ResourcesByTypeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ResourcesByTypeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetResourcesByTypeDtoForm(fb: FormBuilder, dto?: Interfaces.ResourcesByTypeDto | null): FormGroup<IResourcesByTypeDtoForm>;
/** Interface for a form from a SalesTaxDto*/
export interface ISalesTaxDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Does the sales tax require that shipping be included in the calculation? */
    IncludesShipping: FormControl<boolean | null>;
    /** The country for which the sales tax is applicable */
    Country: FormControl<string | null>;
    /** The state/province for which the sales tax is applicable */
    State: FormControl<string | null>;
    /** The tax rate as a percentage */
    Rate: FormControl<number | null>;
    /** Specifies the provider to use */
    Provider: FormControl<string | null>;
    /** Specifies the Provider Id */
    ProviderId: FormControl<number | null>;
    /** Specifies the identifier to use for the provider */
    ProviderTaxIdentifier: FormControl<string | null>;
}
/**
/* Generates a form from a SalesTaxDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxDto | null): FormGroup<ISalesTaxDtoForm>;
/** Interface for a form from a SalesTaxExemptRequestResultDto*/
export interface ISalesTaxExemptRequestResultDtoForm {
    /** The reference request Id */
    RequestId: FormControl<string | null>;
}
/**
/* Generates a form from a SalesTaxExemptRequestResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxExemptRequestResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxExemptRequestResultDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxExemptRequestResultDto | null): FormGroup<ISalesTaxExemptRequestResultDtoForm>;
/** Interface for a form from a SalesTaxExemptionDto*/
export interface ISalesTaxExemptionDtoForm {
    /** Sales Tax Id */
    SalesTaxId: FormControl<number | null>;
    /** Sales Tax Lesson */
    SalesTax: FormControl<string | null>;
    /** Contact Id */
    ContactId: FormControl<number | null>;
    /** Contact Types */
    ContactType: FormControl<Enums.ContactTypes | null>;
    /** Exemption Number */
    ExemptionNumber: FormControl<string | null>;
    /** Image of Certificate Uri */
    CertificateUri: FormControl<string | null>;
    /** Sales Tax Exemption */
    Verified: FormControl<boolean | null>;
    /** Verified By */
    VerifiedBy: FormControl<string | null>;
    /** Verified By User Id */
    VerifiedById: FormControl<number | null>;
    /** Deleted */
    Deleted: FormControl<boolean | null>;
    /** RequestId */
    RequestId: FormControl<string | null>;
    /** Requesting User */
    RequestedBy: FormControl<string | null>;
    /** Requesting User Id */
    RequestedById: FormControl<number | null>;
    /** Rejected */
    Rejected: FormControl<boolean | null>;
    /** Rejection Reason */
    RejectionReason: FormControl<string | null>;
    /** Rejected By User */
    RejectedBy: FormControl<string | null>;
    /** Rejected By User Id */
    RejectedById: FormControl<number | null>;
    /** Starts On */
    StartsOn: FormControl<Date | null>;
    /** Expires On */
    ExpiresOn: FormControl<Date | null>;
}
/**
/* Generates a form from a SalesTaxExemptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxExemptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxExemptionDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxExemptionDto | null): FormGroup<ISalesTaxExemptionDtoForm>;
/** Interface for a form from a SalesTaxLineItemDto*/
export interface ISalesTaxLineItemDtoForm {
    /** SKU */
    SKU: FormControl<string | null>;
    /** Inventory Id */
    InventoryId: FormControl<number | null>;
    /** Price */
    Price: FormControl<number | null>;
    /** Units */
    Units: FormControl<number | null>;
}
/**
/* Generates a form from a SalesTaxLineItemDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxLineItemDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxLineItemDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxLineItemDto | null): FormGroup<ISalesTaxLineItemDtoForm>;
/** Interface for a form from a SalesTaxProviderDto*/
export interface ISalesTaxProviderDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson of Provider */
    Name: FormControl<string | null>;
    /** Interface defined in code */
    Interface: FormControl<string | null>;
}
/**
/* Generates a form from a SalesTaxProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxProviderDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxProviderDto | null): FormGroup<ISalesTaxProviderDtoForm>;
/** Interface for a form from a SalesTaxRequestDto*/
export interface ISalesTaxRequestDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Is the address the default for the user */
    Default: FormControl<boolean | null>;
    /** Is the address the billing address for the user */
    Billing: FormControl<boolean | null>;
    /** Is the address the shipping address for the user */
    Shipping: FormControl<boolean | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal/Zip Code */
    PostalCode: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** Contact Id */
    ContactId: FormControl<number | null>;
    /** Contact Types */
    ContactType: FormControl<Enums.ContactTypes | null>;
    /** Shipping Amount */
    ShippingAmount: FormControl<number | null>;
    /** Items */
    Items: FormArray<FormGroup<ISalesTaxLineItemDtoForm>>;
}
/**
/* Generates a form from a SalesTaxRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxRequestDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxRequestDto | null): FormGroup<ISalesTaxRequestDtoForm>;
/** Interface for a form from a SalesTaxResultDto*/
export interface ISalesTaxResultDtoForm {
    /** Sales Tax Id */
    SalesTaxId: FormControl<number | null>;
    /** Sales Tax */
    SalesTax: FormControl<string | null>;
    /** Amount of Sales Tax to be applied */
    Amount: FormControl<number | null>;
}
/**
/* Generates a form from a SalesTaxResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SalesTaxResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSalesTaxResultDtoForm(fb: FormBuilder, dto?: Interfaces.SalesTaxResultDto | null): FormGroup<ISalesTaxResultDtoForm>;
/** Interface for a form from a ScheduleReportDetailsDto*/
export interface IScheduleReportDetailsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Automated Report Types */
    Report: FormControl<Enums.OrganizationReportTypes | null>;
    /** Report Schedules */
    Schedule: FormControl<Enums.ReportSchedules | null>;
    /** Recipients */
    Recipients: FormArray<FormGroup<IScheduleReportRecipientsDtoForm>>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Next time the report will be run. */
    NextRunOn: FormControl<Date | null>;
    /** Last Run On */
    LastRunOn: FormControl<Date | null>;
}
/**
/* Generates a form from a ScheduleReportDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ScheduleReportDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetScheduleReportDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.ScheduleReportDetailsDto | null): FormGroup<IScheduleReportDetailsDtoForm>;
/** Interface for a form from a ScheduleReportDto*/
export interface IScheduleReportDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Automated Report Types */
    Report: FormControl<Enums.OrganizationReportTypes | null>;
    /** Report Schedules */
    Schedule: FormControl<Enums.ReportSchedules | null>;
    /** Recipients */
    Recipients: FormArray<FormGroup<IScheduleReportRecipientsDtoForm>>;
}
/**
/* Generates a form from a ScheduleReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ScheduleReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetScheduleReportDtoForm(fb: FormBuilder, dto?: Interfaces.ScheduleReportDto | null): FormGroup<IScheduleReportDtoForm>;
/** Interface for a form from a ScheduleReportRecipientsDto*/
export interface IScheduleReportRecipientsDtoForm {
    /** Existing User */
    UserId: FormControl<number | null>;
    /** Lesson of external user */
    Name: FormControl<string | null>;
    /** Email address of external user */
    EmailAddress: FormControl<string | null>;
}
/**
/* Generates a form from a ScheduleReportRecipientsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ScheduleReportRecipientsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetScheduleReportRecipientsDtoForm(fb: FormBuilder, dto?: Interfaces.ScheduleReportRecipientsDto | null): FormGroup<IScheduleReportRecipientsDtoForm>;
/** Interface for a form from a SearchFilterDto*/
export interface ISearchFilterDtoForm {
    /** Item Id */
    Id: FormControl<string | null>;
    /** Item Lesson */
    Name: FormControl<string | null>;
    /** Selected */
    Selected: FormControl<boolean | null>;
}
/**
/* Generates a form from a SearchFilterDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SearchFilterDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSearchFilterDtoForm(fb: FormBuilder, dto?: Interfaces.SearchFilterDto | null): FormGroup<ISearchFilterDtoForm>;
/** Interface for a form from a SendEmailDto*/
export interface ISendEmailDtoForm {
    /** Users to send the message to */
    UserIds: FormArray<FormControl<number | null>>;
    /** The subject of the email */
    Subject: FormControl<string | null>;
    /** The body of the email */
    Body: FormControl<string | null>;
}
/**
/* Generates a form from a SendEmailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SendEmailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSendEmailDtoForm(fb: FormBuilder, dto?: Interfaces.SendEmailDto | null): FormGroup<ISendEmailDtoForm>;
/** Interface for a form from a SetCourseItemEditingStatusDto*/
export interface ISetCourseItemEditingStatusDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Itme that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Item Change status for KAMS */
    EditingStatus: FormControl<Enums.ItemChangeStatuses | null>;
    /** Is this a new feature? */
    NewFeature: FormControl<boolean | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Assignees for the step */
    Assignees: FormControl<string | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Labels */
    Labels: FormControl<string | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Number of Questions */
    Questions: FormControl<number | null>;
    /** Versions */
    Versions: FormControl<string | null>;
    /** Is Waiting For Customer Approval */
    IsWaitingForCustomerApproval: FormControl<boolean | null>;
    /** Is Waiting For Question Team */
    IsWaitingForContentTeam: FormControl<boolean | null>;
    /** Child Items */
    ChildItems: FormArray<FormGroup<ICourseStructureForEditingDtoForm>>;
    /** Item Change status for KAMS */
    NewStatus: FormControl<Enums.ItemChangeStatuses | null>;
}
/**
/* Generates a form from a SetCourseItemEditingStatusDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetCourseItemEditingStatusDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetCourseItemEditingStatusDtoForm(fb: FormBuilder, dto?: Interfaces.SetCourseItemEditingStatusDto | null): FormGroup<ISetCourseItemEditingStatusDtoForm>;
/** Interface for a form from a SetDisciplinesDto*/
export interface ISetDisciplinesDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Product Id */
    Disciplines: FormArray<FormGroup<IDisciplineWithProductsDtoForm>>;
}
/**
/* Generates a form from a SetDisciplinesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetDisciplinesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetDisciplinesDtoForm(fb: FormBuilder, dto?: Interfaces.SetDisciplinesDto | null): FormGroup<ISetDisciplinesDtoForm>;
/** Interface for a form from a SetLanguageDto*/
export interface ISetLanguageDtoForm {
    /** Project Id to Set */
    LanguageCode: FormControl<string | null>;
}
/**
/* Generates a form from a SetLanguageDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetLanguageDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetLanguageDtoForm(fb: FormBuilder, dto?: Interfaces.SetLanguageDto | null): FormGroup<ISetLanguageDtoForm>;
/** Interface for a form from a SetLessonUserRatingRequestDto*/
export interface ISetLessonUserRatingRequestDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Rating */
    Rating: FormControl<number | null>;
}
/**
/* Generates a form from a SetLessonUserRatingRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetLessonUserRatingRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetLessonUserRatingRequestDtoForm(fb: FormBuilder, dto?: Interfaces.SetLessonUserRatingRequestDto | null): FormGroup<ISetLessonUserRatingRequestDtoForm>;
/** Interface for a form from a SetLessonUserRatingResponseDto*/
export interface ISetLessonUserRatingResponseDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Lesson Rating */
    LessonRating: FormControl<number | null>;
}
/**
/* Generates a form from a SetLessonUserRatingResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetLessonUserRatingResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetLessonUserRatingResponseDtoForm(fb: FormBuilder, dto?: Interfaces.SetLessonUserRatingResponseDto | null): FormGroup<ISetLessonUserRatingResponseDtoForm>;
/** Interface for a form from a SetOrganizationDto*/
export interface ISetOrganizationDtoForm {
    /** The Organization that the user should be set to. */
    OrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a SetOrganizationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetOrganizationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetOrganizationDtoForm(fb: FormBuilder, dto?: Interfaces.SetOrganizationDto | null): FormGroup<ISetOrganizationDtoForm>;
/** Interface for a form from a SetProjectDto*/
export interface ISetProjectDtoForm {
    /** Project Id to Set */
    ProjectId: FormControl<number | null>;
}
/**
/* Generates a form from a SetProjectDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetProjectDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetProjectDtoForm(fb: FormBuilder, dto?: Interfaces.SetProjectDto | null): FormGroup<ISetProjectDtoForm>;
/** Interface for a form from a SetTopicItemEditingStatusDto*/
export interface ISetTopicItemEditingStatusDtoForm {
    /** The identifier used for linking the tree. */
    Identifier: FormControl<number | null>;
    /** Is the item expanded */
    Expanded: FormControl<boolean | null>;
    /** The parent Id */
    ParentId: FormControl<number | null>;
    /** The Item linked to */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Resource Types */
    ResourceType: FormControl<Enums.ResourceTypes | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of the video associated */
    Length: FormControl<number | null>;
    /** The original Itme that this one is based upon */
    OriginalItemId: FormControl<number | null>;
    /** Item Change status for KAMS */
    EditingStatus: FormControl<Enums.ItemChangeStatuses | null>;
    /** Is this a new feature? */
    NewFeature: FormControl<boolean | null>;
    /** Order */
    Order: FormControl<number | null>;
    /** Workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Assignees for the step */
    Assignees: FormControl<string | null>;
    /** Is the content the current organization's? */
    IsOwnContent: FormControl<boolean | null>;
    /** Labels */
    Labels: FormControl<string | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Number of Questions */
    Questions: FormControl<number | null>;
    /** Versions */
    Versions: FormControl<string | null>;
    /** Is Waiting For Customer Approval */
    IsWaitingForCustomerApproval: FormControl<boolean | null>;
    /** Is Waiting For Question Team */
    IsWaitingForContentTeam: FormControl<boolean | null>;
    /** Item Change status for KAMS */
    NewStatus: FormControl<Enums.ItemChangeStatuses | null>;
}
/**
/* Generates a form from a SetTopicItemEditingStatusDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SetTopicItemEditingStatusDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSetTopicItemEditingStatusDtoForm(fb: FormBuilder, dto?: Interfaces.SetTopicItemEditingStatusDto | null): FormGroup<ISetTopicItemEditingStatusDtoForm>;
/** Interface for a form from a SharepointFileDetailsDto*/
export interface ISharepointFileDetailsDtoForm {
    /** Document Id */
    Id: FormControl<string | null>;
    /** Url */
    Url: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a SharepointFileDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SharepointFileDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSharepointFileDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.SharepointFileDetailsDto | null): FormGroup<ISharepointFileDetailsDtoForm>;
/** Interface for a form from a ShipInvoiceDto*/
export interface IShipInvoiceDtoForm {
    /** Invoice to Ship */
    InvoiceId: FormControl<number | null>;
}
/**
/* Generates a form from a ShipInvoiceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShipInvoiceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShipInvoiceDtoForm(fb: FormBuilder, dto?: Interfaces.ShipInvoiceDto | null): FormGroup<IShipInvoiceDtoForm>;
/** Interface for a form from a ShippingMethodDto*/
export interface IShippingMethodDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the shipping method */
    Name: FormControl<string | null>;
    /** The account # with the provider */
    AccountNo: FormControl<string | null>;
    /** Shipping Providers */
    Provider: FormControl<Enums.ShippingProviders | null>;
}
/**
/* Generates a form from a ShippingMethodDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShippingMethodDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShippingMethodDtoForm(fb: FormBuilder, dto?: Interfaces.ShippingMethodDto | null): FormGroup<IShippingMethodDtoForm>;
/** Interface for a form from a ShortContentDto*/
export interface IShortContentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
}
/**
/* Generates a form from a ShortContentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShortContentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShortContentDtoForm(fb: FormBuilder, dto?: Interfaces.ShortContentDto | null): FormGroup<IShortContentDtoForm>;
/** Interface for a form from a ShortContentWithViewsDto*/
export interface IShortContentWithViewsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Number of views */
    Views: FormControl<number | null>;
}
/**
/* Generates a form from a ShortContentWithViewsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShortContentWithViewsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShortContentWithViewsDtoForm(fb: FormBuilder, dto?: Interfaces.ShortContentWithViewsDto | null): FormGroup<IShortContentWithViewsDtoForm>;
/** Interface for a form from a ShortCourseDto*/
export interface IShortCourseDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Featured Lesson */
    FeaturedLessonId: FormControl<number | null>;
    /** Is The course a workflow? */
    Workflow: FormControl<boolean | null>;
}
/**
/* Generates a form from a ShortCourseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShortCourseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShortCourseDtoForm(fb: FormBuilder, dto?: Interfaces.ShortCourseDto | null): FormGroup<IShortCourseDtoForm>;
/** Interface for a form from a ShortLessonWithCoursesDto*/
export interface IShortLessonWithCoursesDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name */
    Name: FormControl<string | null>;
    /** The description */
    Description: FormControl<string | null>;
    /** The length of video for the content item */
    Length: FormControl<number | null>;
    /** Question Item Types */
    Type: FormControl<Enums.ContentItemTypes | null>;
    /** Courses for the lesson */
    Courses: FormArray<FormGroup<IShortContentDtoForm>>;
}
/**
/* Generates a form from a ShortLessonWithCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original ShortLessonWithCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetShortLessonWithCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.ShortLessonWithCoursesDto | null): FormGroup<IShortLessonWithCoursesDtoForm>;
/** Interface for a form from a SiteDto*/
export interface ISiteDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Domain */
    Domain: FormControl<string | null>;
}
/**
/* Generates a form from a SiteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SiteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSiteDtoForm(fb: FormBuilder, dto?: Interfaces.SiteDto | null): FormGroup<ISiteDtoForm>;
/** Interface for a form from a SkillsGapDto*/
export interface ISkillsGapDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** History data for the spark line */
    History: FormArray<FormGroup<ICompletionHistoryDtoForm>>;
}
/**
/* Generates a form from a SkillsGapDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SkillsGapDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSkillsGapDtoForm(fb: FormBuilder, dto?: Interfaces.SkillsGapDto | null): FormGroup<ISkillsGapDtoForm>;
/** Interface for a form from a SmbRollupSubscriptionRequestDto*/
export interface ISmbRollupSubscriptionRequestDtoForm {
    /** Date to run */
    Date: FormControl<Date | null>;
    /** Is a test run. */
    Test: FormControl<boolean | null>;
    /** Organization Id to run */
    OrganizationId: FormControl<number | null>;
}
/**
/* Generates a form from a SmbRollupSubscriptionRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SmbRollupSubscriptionRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSmbRollupSubscriptionRequestDtoForm(fb: FormBuilder, dto?: Interfaces.SmbRollupSubscriptionRequestDto | null): FormGroup<ISmbRollupSubscriptionRequestDtoForm>;
/** Interface for a form from a SmbRollupSubscriptionResultDto*/
export interface ISmbRollupSubscriptionResultDtoForm {
    /** Organization Id to run */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Date to run */
    Date: FormControl<Date | null>;
    /** Is a test run. */
    Test: FormControl<boolean | null>;
    /** Invoice */
    Invoice: FormGroup<IInvoiceDtoForm>;
    /** Invoice Inventory as apart of the rollup */
    InvoiceInventory: FormArray<FormGroup<IInvoiceInventoryDtoForm>>;
    /** User Subscription Creation Result Codes */
    Result: FormControl<Enums.OrganizationSubscriptionCreationResultCodes | null>;
    /** Result Message */
    Message: FormControl<string | null>;
}
/**
/* Generates a form from a SmbRollupSubscriptionResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SmbRollupSubscriptionResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSmbRollupSubscriptionResultDtoForm(fb: FormBuilder, dto?: Interfaces.SmbRollupSubscriptionResultDto | null): FormGroup<ISmbRollupSubscriptionResultDtoForm>;
/** Interface for a form from a StaticPageTranslationDto*/
export interface IStaticPageTranslationDtoForm {
    /** Page Lesson */
    PageName: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Translated Fields */
    Fields: FormArray<FormGroup<IStaticPageTranslationFieldsDtoForm>>;
}
/**
/* Generates a form from a StaticPageTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original StaticPageTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetStaticPageTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.StaticPageTranslationDto | null): FormGroup<IStaticPageTranslationDtoForm>;
/** Interface for a form from a StaticPageTranslationFieldsDto*/
export interface IStaticPageTranslationFieldsDtoForm {
    /** Tag */
    Tag: FormControl<string | null>;
    /** Localized Value */
    Value: FormControl<string | null>;
}
/**
/* Generates a form from a StaticPageTranslationFieldsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original StaticPageTranslationFieldsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetStaticPageTranslationFieldsDtoForm(fb: FormBuilder, dto?: Interfaces.StaticPageTranslationFieldsDto | null): FormGroup<IStaticPageTranslationFieldsDtoForm>;
/** Interface for a form from a StaticPageTranslationWithLanguagesDto*/
export interface IStaticPageTranslationWithLanguagesDtoForm {
    /** Page Lesson */
    PageName: FormControl<string | null>;
    /** Languages */
    Languages: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a StaticPageTranslationWithLanguagesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original StaticPageTranslationWithLanguagesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetStaticPageTranslationWithLanguagesDtoForm(fb: FormBuilder, dto?: Interfaces.StaticPageTranslationWithLanguagesDto | null): FormGroup<IStaticPageTranslationWithLanguagesDtoForm>;
/** Interface for a form from a StoredPaymentCredentialDto*/
export interface IStoredPaymentCredentialDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Payment Method Id */
    PaymentMethodId: FormControl<number | null>;
    /** Payment Method */
    PaymentMethod: FormControl<string | null>;
    /** Organization Id (null if attached to a user) */
    OrganizationId: FormControl<number | null>;
    /** Organization (null if attached to a user) */
    Organization: FormControl<string | null>;
    /** User Id (null if attached to an organization) */
    UserId: FormControl<number | null>;
    /** User (null if attached to an organization) */
    User: FormControl<string | null>;
    /** The reference number with the processor used to make a payment etc. with the credentials */
    ProcessorReferenceNumber: FormControl<string | null>;
    /** Merchant Payment Profile Id */
    SubProcessorReferenceNumber: FormControl<string | null>;
    /** Card or Account Holder Lesson */
    CardHolderName: FormControl<string | null>;
    /** The masked identifier (either card # or Account # masked) */
    MaskedIdentifier: FormControl<string | null>;
    /** The expiry year if any */
    ExpiryYear: FormControl<number | null>;
    /** The expiry month if any */
    ExpiryMonth: FormControl<number | null>;
    /** Billing Address Id */
    BillingAddressId: FormControl<number | null>;
    /** Is stored credential deleted */
    Deleted: FormControl<boolean | null>;
    /** Contact Types */
    ContactType: FormControl<Enums.ContactTypes | null>;
    /** The Contact Id associated with the stored credentials */
    ContactId: FormControl<number | null>;
}
/**
/* Generates a form from a StoredPaymentCredentialDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original StoredPaymentCredentialDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetStoredPaymentCredentialDtoForm(fb: FormBuilder, dto?: Interfaces.StoredPaymentCredentialDto | null): FormGroup<IStoredPaymentCredentialDtoForm>;
/** Interface for a form from a SubmitQuoteDto*/
export interface ISubmitQuoteDtoForm {
    /** Rfq Id */
    RfqId: FormControl<number | null>;
}
/**
/* Generates a form from a SubmitQuoteDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SubmitQuoteDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSubmitQuoteDtoForm(fb: FormBuilder, dto?: Interfaces.SubmitQuoteDto | null): FormGroup<ISubmitQuoteDtoForm>;
/** Interface for a form from a SupportAnswerDto*/
export interface ISupportAnswerDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Answer */
    Answer: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
}
/**
/* Generates a form from a SupportAnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SupportAnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSupportAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.SupportAnswerDto | null): FormGroup<ISupportAnswerDtoForm>;
/** Interface for a form from a SupportQuestionDto*/
export interface ISupportQuestionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Question */
    Question: FormControl<string | null>;
    /** Support Answer Id */
    SupportAnswerId: FormControl<number | null>;
    /** Support Answer */
    SupportAnswer: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
}
/**
/* Generates a form from a SupportQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SupportQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSupportQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.SupportQuestionDto | null): FormGroup<ISupportQuestionDtoForm>;
/** Interface for a form from a SyndicationProviderDto*/
export interface ISyndicationProviderDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
}
/**
/* Generates a form from a SyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.SyndicationProviderDto | null): FormGroup<ISyndicationProviderDtoForm>;
/** Interface for a form from a SyndicationProviderImplementationDto*/
export interface ISyndicationProviderImplementationDtoForm {
    /** The syndication provider id */
    SyndicationProviderId: FormControl<number | null>;
    /** The name of the syndication provider */
    SyndicationProvider: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** The Interface used to execute these types of syndications */
    Interface: FormControl<string | null>;
}
/**
/* Generates a form from a SyndicationProviderImplementationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SyndicationProviderImplementationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSyndicationProviderImplementationDtoForm(fb: FormBuilder, dto?: Interfaces.SyndicationProviderImplementationDto | null): FormGroup<ISyndicationProviderImplementationDtoForm>;
/** Interface for a form from a SystemMessageDto*/
export interface ISystemMessageDtoForm {
    /** Title */
    Title: FormControl<string | null>;
    /** Message */
    Message: FormControl<string | null>;
}
/**
/* Generates a form from a SystemMessageDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SystemMessageDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSystemMessageDtoForm(fb: FormBuilder, dto?: Interfaces.SystemMessageDto | null): FormGroup<ISystemMessageDtoForm>;
/** Interface for a form from a SystemSettingDto*/
export interface ISystemSettingDtoForm {
    /** Lesson */
    Name: FormControl<string | null>;
    /** Value */
    Value: FormControl<string | null>;
    /** Delta */
    Delta: FormControl<string | null>;
    /** Date Time instead of value */
    DateTime: FormControl<Date | null>;
    /** When was the setting set? */
    SetOn: FormControl<Date | null>;
}
/**
/* Generates a form from a SystemSettingDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original SystemSettingDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetSystemSettingDtoForm(fb: FormBuilder, dto?: Interfaces.SystemSettingDto | null): FormGroup<ISystemSettingDtoForm>;
/** Interface for a form from a TimeSavedAcrossOrganizationResultDto*/
export interface ITimeSavedAcrossOrganizationResultDtoForm {
    /** Time Saved */
    Time: FormControl<number | null>;
    /** Start Date */
    StartDate: FormControl<Date | null>;
    /** End Date */
    EndDate: FormControl<Date | null>;
}
/**
/* Generates a form from a TimeSavedAcrossOrganizationResultDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TimeSavedAcrossOrganizationResultDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTimeSavedAcrossOrganizationResultDtoForm(fb: FormBuilder, dto?: Interfaces.TimeSavedAcrossOrganizationResultDto | null): FormGroup<ITimeSavedAcrossOrganizationResultDtoForm>;
/** Interface for a form from a TokenDto*/
export interface ITokenDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The unique identifier for the token */
    TokenId: FormControl<string | null>;
    /** Issued On */
    IssuedOn: FormControl<Date | null>;
    /** Redeemed On */
    RedeemedOn: FormControl<Date | null>;
    /** Redeemed By Id */
    RedeemedById: FormControl<number | null>;
    /** Redeemed By */
    RedeemedBy: FormControl<string | null>;
    /** Cancelled On */
    CancelledOn: FormControl<Date | null>;
    /** Cancelled By Id */
    CancelledById: FormControl<number | null>;
    /** Cancelled By Lesson */
    CancelledBy: FormControl<string | null>;
    /** Expires On */
    ExpiresOn: FormControl<Date | null>;
    /** Invoice Inventory Id */
    InvoiceInventoryId: FormControl<number | null>;
    /** The Invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Invoice Inventory */
    InvoiceInventory: FormControl<string | null>;
    /** Invoice # */
    InvoiceNumber: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** The Organization assigned the token for distribution if any */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a TokenDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TokenDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTokenDtoForm(fb: FormBuilder, dto?: Interfaces.TokenDto | null): FormGroup<ITokenDtoForm>;
/** Interface for a form from a TopicActivityDetailDto*/
export interface ITopicActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Tags */
    Tags: FormControl<string | null>;
}
/**
/* Generates a form from a TopicActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.TopicActivityDetailDto | null): FormGroup<ITopicActivityDetailDtoForm>;
/** Interface for a form from a TopicAdminDto*/
export interface ITopicAdminDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** Content Preface */
    Introduction: FormControl<string | null>;
    /** The conclusion of the item */
    Conclusion: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
}
/**
/* Generates a form from a TopicAdminDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicAdminDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicAdminDtoForm(fb: FormBuilder, dto?: Interfaces.TopicAdminDto | null): FormGroup<ITopicAdminDtoForm>;
/** Interface for a form from a TopicAtAGlanceReportDto*/
export interface ITopicAtAGlanceReportDtoForm {
    /** Topic Lesson */
    Topic: FormControl<string | null>;
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** Topic Workflow Step */
    TopicWorkflowStep: FormControl<string | null>;
    /** Topic WOrkflow Step Id */
    TopicWorkflowStepId: FormControl<number | null>;
    /** Number of Lessons in Writing */
    Writing: FormControl<number | null>;
    /** Number of Lessons in Copy Edit */
    CopyEdit: FormControl<number | null>;
    /** Number of Lessons  in Narration */
    Narration: FormControl<number | null>;
    /** Number of Lessons in Video Recording */
    VideoRecording: FormControl<number | null>;
    /** Number of Lessons in Video Edit */
    VideoEdit: FormControl<number | null>;
    /** Number of Lessons in Video Q/A 1 */
    VideoQA1: FormControl<number | null>;
    /** Number of Lessons in Video Q/A 2 */
    VideoQA2: FormControl<number | null>;
    /** Number of Lessons in Create Sub Titles */
    CreateSubTitles: FormControl<number | null>;
    /** Number of Lessons in Review and Sign Off */
    ReviewAndSignOff: FormControl<number | null>;
    /** Number of Lessons Completed */
    Complete: FormControl<number | null>;
    /** Total Lessons across all steps */
    Total: FormControl<number | null>;
}
/**
/* Generates a form from a TopicAtAGlanceReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicAtAGlanceReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicAtAGlanceReportDtoForm(fb: FormBuilder, dto?: Interfaces.TopicAtAGlanceReportDto | null): FormGroup<ITopicAtAGlanceReportDtoForm>;
/** Interface for a form from a TopicDto*/
export interface ITopicDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The name of the item */
    Name: FormControl<string | null>;
    /** The description of the item */
    Description: FormControl<string | null>;
    /** Is the item published or not */
    Active: FormControl<boolean | null>;
    /** When was the item created? */
    CreatedOn: FormControl<Date | null>;
    /** When was the item updated? */
    UpdatedOn: FormControl<Date | null>;
    /** Any tags used for search optimization */
    Tags: FormControl<string | null>;
    /** Content Preface */
    Introduction: FormControl<string | null>;
    /** The conclusion of the item */
    Conclusion: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Notes */
    Notes: FormControl<string | null>;
    /** Jira Issue Link */
    JiraIssueLink: FormControl<string | null>;
}
/**
/* Generates a form from a TopicDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicDtoForm(fb: FormBuilder, dto?: Interfaces.TopicDto | null): FormGroup<ITopicDtoForm>;
/** Interface for a form from a TopicSyndicationDto*/
export interface ITopicSyndicationDtoForm {
    /** Topic id */
    TopicId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Syndication Types */
    Type: FormControl<Enums.SyndicationTypes | null>;
    /** Organization */
    Organization: FormControl<string | null>;
}
/**
/* Generates a form from a TopicSyndicationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicSyndicationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicSyndicationDtoForm(fb: FormBuilder, dto?: Interfaces.TopicSyndicationDto | null): FormGroup<ITopicSyndicationDtoForm>;
/** Interface for a form from a TopicSyndicationProviderDto*/
export interface ITopicSyndicationProviderDtoForm {
    /** Topic id */
    TopicId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization */
    Organization: FormControl<string | null>;
    /** Syndication Methods */
    Method: FormControl<Enums.SyndicationMethods | null>;
    /** Syndication Provider Id */
    SyndicationProviderId: FormControl<number | null>;
    /** Syndication Provider Lesson */
    SyndicationProvider: FormControl<string | null>;
}
/**
/* Generates a form from a TopicSyndicationProviderDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicSyndicationProviderDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicSyndicationProviderDtoForm(fb: FormBuilder, dto?: Interfaces.TopicSyndicationProviderDto | null): FormGroup<ITopicSyndicationProviderDtoForm>;
/** Interface for a form from a TopicTranslationDto*/
export interface ITopicTranslationDtoForm {
    /** Course Id */
    TopicId: FormControl<number | null>;
    /** Lesson Lesson */
    Topic: FormControl<string | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** Is the translation Active */
    Active: FormControl<boolean | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Preface */
    Introduction: FormControl<string | null>;
    /** Postface */
    Conclusion: FormControl<string | null>;
    /** Marketing */
    Marketing: FormControl<string | null>;
    /** Meta Keywords */
    MetaKeywords: FormControl<string | null>;
    /** Meta Description */
    MetaDescription: FormControl<string | null>;
}
/**
/* Generates a form from a TopicTranslationDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicTranslationDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicTranslationDtoForm(fb: FormBuilder, dto?: Interfaces.TopicTranslationDto | null): FormGroup<ITopicTranslationDtoForm>;
/** Interface for a form from a TopicWorkflowAssigneesDto*/
export interface ITopicWorkflowAssigneesDtoForm {
    /** The topic id */
    TopicId: FormControl<number | null>;
    /** The topic name */
    Topic: FormControl<string | null>;
    /** The User Id */
    UserId: FormControl<number | null>;
    /** The name of the user */
    User: FormControl<string | null>;
    /** The Role Id */
    RoleId: FormControl<number | null>;
    /** The Role */
    Role: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a TopicWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TopicWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTopicWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.TopicWorkflowAssigneesDto | null): FormGroup<ITopicWorkflowAssigneesDtoForm>;
/** Interface for a form from a TranslationErrorDto*/
export interface ITranslationErrorDtoForm {
    /** User Lesson */
    User: FormControl<string | null>;
    /** Reporter User Id */
    UserId: FormControl<number | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Time of Report */
    TimeStamp: FormControl<Date | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** Item Id */
    ItemId: FormControl<number | null>;
}
/**
/* Generates a form from a TranslationErrorDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TranslationErrorDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTranslationErrorDtoForm(fb: FormBuilder, dto?: Interfaces.TranslationErrorDto | null): FormGroup<ITranslationErrorDtoForm>;
/** Interface for a form from a TranslationWorkflowAssigneeDto*/
export interface ITranslationWorkflowAssigneeDtoForm {
    /** Parent Id */
    ParentId: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Role Id */
    RoleId: FormControl<number | null>;
    /** Role Lesson */
    Role: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a TranslationWorkflowAssigneeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original TranslationWorkflowAssigneeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetTranslationWorkflowAssigneeDtoForm(fb: FormBuilder, dto?: Interfaces.TranslationWorkflowAssigneeDto | null): FormGroup<ITranslationWorkflowAssigneeDtoForm>;
/** Interface for a form from a UpdateAnswerSuggestedLessonsDto*/
export interface IUpdateAnswerSuggestedLessonsDtoForm {
    /** The answer to update */
    AnswerId: FormControl<number | null>;
    /** The Lessons to be assigned to the Answer. */
    Lessons: FormArray<FormGroup<IAnswerLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateAnswerSuggestedLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAnswerSuggestedLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAnswerSuggestedLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAnswerSuggestedLessonsDto | null): FormGroup<IUpdateAnswerSuggestedLessonsDtoForm>;
/** Interface for a form from a UpdateAnswersDto*/
export interface IUpdateAnswersDtoForm {
    /** Question Id */
    QuestionId: FormControl<number | null>;
    /** Answers */
    Answers: FormArray<FormGroup<IAnswerDtoForm>>;
}
/**
/* Generates a form from a UpdateAnswersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAnswersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAnswersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAnswersDto | null): FormGroup<IUpdateAnswersDtoForm>;
/** Interface for a form from a UpdateAssessmentBadgesDto*/
export interface IUpdateAssessmentBadgesDtoForm {
    /** The assessment to manage */
    AssessmentId: FormControl<number | null>;
    /** All of the Badges assigned to the assessment */
    BadgeIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateAssessmentBadgesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentBadgesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentBadgesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentBadgesDto | null): FormGroup<IUpdateAssessmentBadgesDtoForm>;
/** Interface for a form from a UpdateAssessmentCoursesDto*/
export interface IUpdateAssessmentCoursesDtoForm {
    /** The assessment to manage */
    AssessmentId: FormControl<number | null>;
    /** All of the courses assigned to the assessment */
    CourseIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateAssessmentCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentCoursesDto | null): FormGroup<IUpdateAssessmentCoursesDtoForm>;
/** Interface for a form from a UpdateAssessmentDynamicItemsDto*/
export interface IUpdateAssessmentDynamicItemsDtoForm {
    /**  */
    AssessmentId: FormControl<number | null>;
    /**  */
    CourseId: FormControl<number | null>;
    /**  */
    TopicIds: FormArray<FormControl<number | null>>;
    /** Number of Questions */
    NumberOfQuestions: FormControl<number | null>;
}
/**
/* Generates a form from a UpdateAssessmentDynamicItemsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentDynamicItemsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentDynamicItemsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentDynamicItemsDto | null): FormGroup<IUpdateAssessmentDynamicItemsDtoForm>;
/** Interface for a form from a UpdateAssessmentMedallionsDto*/
export interface IUpdateAssessmentMedallionsDtoForm {
    /** The assessment to manage */
    AssessmentId: FormControl<number | null>;
    /** All of the Medallions assigned to the assessment */
    MedallionIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateAssessmentMedallionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentMedallionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentMedallionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentMedallionsDto | null): FormGroup<IUpdateAssessmentMedallionsDtoForm>;
/** Interface for a form from a UpdateAssessmentQuestionsDto*/
export interface IUpdateAssessmentQuestionsDtoForm {
    /** The assessment to update */
    AssessmentId: FormControl<number | null>;
    /** All of the questions associated with the assessment */
    QuestionIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateAssessmentQuestionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentQuestionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentQuestionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentQuestionsDto | null): FormGroup<IUpdateAssessmentQuestionsDtoForm>;
/** Interface for a form from a UpdateAssessmentWorkflowAssigneesDto*/
export interface IUpdateAssessmentWorkflowAssigneesDtoForm {
    /** The assessment to update */
    AssessmentId: FormControl<number | null>;
    /** The assignees to the Assessment (all of them) */
    Assignees: FormArray<FormGroup<IAssessmentWorkflowAssigneesDtoForm>>;
}
/**
/* Generates a form from a UpdateAssessmentWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAssessmentWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAssessmentWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAssessmentWorkflowAssigneesDto | null): FormGroup<IUpdateAssessmentWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateAuthMethodsDto*/
export interface IUpdateAuthMethodsDtoForm {
    /** The domain that the auth methods belong to */
    DomainId: FormControl<number | null>;
    /** The auth methods to update. Should include all auth methods for the domain as all others will be deleted. */
    AuthMethods: FormArray<FormGroup<IAuthMethodAdminDtoForm>>;
}
/**
/* Generates a form from a UpdateAuthMethodsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateAuthMethodsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateAuthMethodsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateAuthMethodsDto | null): FormGroup<IUpdateAuthMethodsDtoForm>;
/** Interface for a form from a UpdateBadgeGroupsDto*/
export interface IUpdateBadgeGroupsDtoForm {
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IBadgeGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateBadgeGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateBadgeGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateBadgeGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateBadgeGroupsDto | null): FormGroup<IUpdateBadgeGroupsDtoForm>;
/** Interface for a form from a UpdateBadgeHeaderLessonsDto*/
export interface IUpdateBadgeHeaderLessonsDtoForm {
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<IBadgeHeaderLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateBadgeHeaderLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateBadgeHeaderLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateBadgeHeaderLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateBadgeHeaderLessonsDto | null): FormGroup<IUpdateBadgeHeaderLessonsDtoForm>;
/** Interface for a form from a UpdateBadgeLessonDto*/
export interface IUpdateBadgeLessonDtoForm {
    /** The question to update */
    BadgeId: FormControl<number | null>;
    /** The Lesson Ids of all lessons associated with the badge */
    Lessons: FormArray<FormGroup<IBadgeLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateBadgeLessonDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateBadgeLessonDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateBadgeLessonDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateBadgeLessonDto | null): FormGroup<IUpdateBadgeLessonDtoForm>;
/** Interface for a form from a UpdateBadgeSyndicationProvidersDto*/
export interface IUpdateBadgeSyndicationProvidersDtoForm {
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<IBadgeSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateBadgeSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateBadgeSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateBadgeSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateBadgeSyndicationProvidersDto | null): FormGroup<IUpdateBadgeSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateCampaignSubscriptionsDto*/
export interface IUpdateCampaignSubscriptionsDtoForm {
    /** Campaign to update */
    CampaignId: FormControl<number | null>;
    /** All Subscriptions for the campaign. */
    Subscriptions: FormArray<FormGroup<ICampaignSubscriptionDtoForm>>;
}
/**
/* Generates a form from a UpdateCampaignSubscriptionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCampaignSubscriptionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCampaignSubscriptionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCampaignSubscriptionsDto | null): FormGroup<IUpdateCampaignSubscriptionsDtoForm>;
/** Interface for a form from a UpdateClientSecretDto*/
export interface IUpdateClientSecretDtoForm {
    /** The Id of the client */
    Id: FormControl<string | null>;
    /** The new Secret */
    Secret: FormControl<string | null>;
}
/**
/* Generates a form from a UpdateClientSecretDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateClientSecretDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateClientSecretDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateClientSecretDto | null): FormGroup<IUpdateClientSecretDtoForm>;
/** Interface for a form from a UpdateCourseAssignedOrganizationsDto*/
export interface IUpdateCourseAssignedOrganizationsDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Organizations */
    Organizations: FormArray<FormGroup<ICourseAssignedOrganizationsDtoForm>>;
}
/**
/* Generates a form from a UpdateCourseAssignedOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCourseAssignedOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCourseAssignedOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCourseAssignedOrganizationsDto | null): FormGroup<IUpdateCourseAssignedOrganizationsDtoForm>;
/** Interface for a form from a UpdateCourseGroupsDto*/
export interface IUpdateCourseGroupsDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<ICourseGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateCourseGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCourseGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCourseGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCourseGroupsDto | null): FormGroup<IUpdateCourseGroupsDtoForm>;
/** Interface for a form from a UpdateCoursePathDto*/
export interface IUpdateCoursePathDtoForm {
    /** The course to update */
    CourseId: FormControl<number | null>;
    /** The layout of the workflow with any user customizations */
    Layout: FormControl<string | null>;
    /** The Root Item */
    Items: FormArray<FormGroup<ICoursePathItemDtoForm>>;
}
/**
/* Generates a form from a UpdateCoursePathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCoursePathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCoursePathDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCoursePathDto | null): FormGroup<IUpdateCoursePathDtoForm>;
/** Interface for a form from a UpdateCoursePublicVideos*/
export interface IUpdateCoursePublicVideosForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Public Videos */
    PublicVideos: FormArray<FormGroup<IPublicVideoCourseDtoForm>>;
}
/**
/* Generates a form from a UpdateCoursePublicVideos
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCoursePublicVideos from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCoursePublicVideosForm(fb: FormBuilder, dto?: Interfaces.UpdateCoursePublicVideos | null): FormGroup<IUpdateCoursePublicVideosForm>;
/** Interface for a form from a UpdateCourseSyndicationProvidersDto*/
export interface IUpdateCourseSyndicationProvidersDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Remove syndications on Lessons and topics under the course or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ICourseSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateCourseSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCourseSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCourseSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCourseSyndicationProvidersDto | null): FormGroup<IUpdateCourseSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateCourseSyndicationsDto*/
export interface IUpdateCourseSyndicationsDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Remove syndications on Lessons and topics under the course or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ICourseSyndicationDtoForm>>;
}
/**
/* Generates a form from a UpdateCourseSyndicationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCourseSyndicationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCourseSyndicationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCourseSyndicationsDto | null): FormGroup<IUpdateCourseSyndicationsDtoForm>;
/** Interface for a form from a UpdateCourseWorkflowAssigneesDto*/
export interface IUpdateCourseWorkflowAssigneesDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** Assignees */
    Assignees: FormArray<FormGroup<ICourseWorkflowAssigneesDtoForm>>;
}
/**
/* Generates a form from a UpdateCourseWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCourseWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCourseWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCourseWorkflowAssigneesDto | null): FormGroup<IUpdateCourseWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateCreditCardPaymentCredentialDto*/
export interface IUpdateCreditCardPaymentCredentialDtoForm {
    /** Stored Payment Credential's Id */
    Id: FormControl<number | null>;
    /** New Expiry Month */
    ExpiryMonth: FormControl<number | null>;
    /** New Expiry Year */
    ExpiryYear: FormControl<number | null>;
    /** Card # */
    CardNumber: FormControl<string | null>;
    /** Updated CVV2 */
    CVV2: FormControl<string | null>;
    /** Lesson on Card */
    NameOnCard: FormControl<string | null>;
    /** Billing Address */
    BillingAddressId: FormControl<number | null>;
}
/**
/* Generates a form from a UpdateCreditCardPaymentCredentialDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCreditCardPaymentCredentialDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCreditCardPaymentCredentialDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCreditCardPaymentCredentialDto | null): FormGroup<IUpdateCreditCardPaymentCredentialDtoForm>;
/** Interface for a form from a UpdateCustomCourseStructureDto*/
export interface IUpdateCustomCourseStructureDtoForm {
    /** Course Id */
    CourseId: FormControl<number | null>;
    /** structure */
    Structure: FormArray<FormGroup<ICourseStructureForEditingWithChildrenDtoForm>>;
}
/**
/* Generates a form from a UpdateCustomCourseStructureDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateCustomCourseStructureDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateCustomCourseStructureDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateCustomCourseStructureDto | null): FormGroup<IUpdateCustomCourseStructureDtoForm>;
/** Interface for a form from a UpdateDisciplineGroupsDto*/
export interface IUpdateDisciplineGroupsDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IDisciplineGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineGroupsDto | null): FormGroup<IUpdateDisciplineGroupsDtoForm>;
/** Interface for a form from a UpdateDisciplineHeaderLessonsDto*/
export interface IUpdateDisciplineHeaderLessonsDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Remove header lessons on badges and medallions under the Discipline or not */
    RemoveSubLessons: FormControl<boolean | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<IDisciplineHeaderLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineHeaderLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineHeaderLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineHeaderLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineHeaderLessonsDto | null): FormGroup<IUpdateDisciplineHeaderLessonsDtoForm>;
/** Interface for a form from a UpdateDisciplineIndustriesDto*/
export interface IUpdateDisciplineIndustriesDtoForm {
    /** The Discipline to update */
    DisciplineId: FormControl<number | null>;
    /** The Industry Ids of all medallions associated with the discipline */
    Industries: FormArray<FormGroup<IDisciplineIndustryDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineIndustriesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineIndustriesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineIndustriesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineIndustriesDto | null): FormGroup<IUpdateDisciplineIndustriesDtoForm>;
/** Interface for a form from a UpdateDisciplineMedallionsDto*/
export interface IUpdateDisciplineMedallionsDtoForm {
    /** The Discipline to update */
    DisciplineId: FormControl<number | null>;
    /** The Medallion Ids of all medallions associated with the badge */
    Medallions: FormArray<FormGroup<IDisciplineMedallionDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineMedallionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineMedallionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineMedallionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineMedallionsDto | null): FormGroup<IUpdateDisciplineMedallionsDtoForm>;
/** Interface for a form from a UpdateDisciplineOrganizationsDto*/
export interface IUpdateDisciplineOrganizationsDtoForm {
    /** The Badge to update */
    DisciplineId: FormControl<number | null>;
    /** The Organization Ids of all Organizations associated with the discipline */
    Organizations: FormArray<FormGroup<IDisciplineAssignedOrganizationsDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineOrganizationsDto | null): FormGroup<IUpdateDisciplineOrganizationsDtoForm>;
/** Interface for a form from a UpdateDisciplineProductDto*/
export interface IUpdateDisciplineProductDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline's Products */
    Products: FormArray<FormGroup<IDisciplineProductDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineProductDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineProductDto | null): FormGroup<IUpdateDisciplineProductDtoForm>;
/** Interface for a form from a UpdateDisciplinePublicVideosDto*/
export interface IUpdateDisciplinePublicVideosDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Public Videos */
    PublicVideos: FormArray<FormGroup<IPublicVideoDisciplineDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplinePublicVideosDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplinePublicVideosDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplinePublicVideosDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplinePublicVideosDto | null): FormGroup<IUpdateDisciplinePublicVideosDtoForm>;
/** Interface for a form from a UpdateDisciplineSyndicationProvidersDto*/
export interface IUpdateDisciplineSyndicationProvidersDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Remove syndications on badges and medallions under the Discipline or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<IDisciplineSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateDisciplineSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDisciplineSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDisciplineSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDisciplineSyndicationProvidersDto | null): FormGroup<IUpdateDisciplineSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateDocumentLinksDto*/
export interface IUpdateDocumentLinksDtoForm {
    /** Document Id */
    DocumentId: FormControl<number | null>;
    /** Links */
    Links: FormArray<FormGroup<IDocumentLinkDtoForm>>;
}
/**
/* Generates a form from a UpdateDocumentLinksDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateDocumentLinksDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateDocumentLinksDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateDocumentLinksDto | null): FormGroup<IUpdateDocumentLinksDtoForm>;
/** Interface for a form from a UpdateEduDomainsDto*/
export interface IUpdateEduDomainsDtoForm {
    /** The list of Edu Domains */
    EduDomains: FormArray<FormGroup<IEduDomainDtoForm>>;
}
/**
/* Generates a form from a UpdateEduDomainsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateEduDomainsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateEduDomainsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateEduDomainsDto | null): FormGroup<IUpdateEduDomainsDtoForm>;
/** Interface for a form from a UpdateEmailTemplateDto*/
export interface IUpdateEmailTemplateDtoForm {
    /** Organization Id */
    Organizationid: FormControl<number | null>;
    /** The list of templates */
    Templates: FormArray<FormGroup<IOrganizationEmailTemplateDtoForm>>;
}
/**
/* Generates a form from a UpdateEmailTemplateDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateEmailTemplateDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateEmailTemplateDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateEmailTemplateDto | null): FormGroup<IUpdateEmailTemplateDtoForm>;
/** Interface for a form from a UpdateEntitlementPaymentDetailsDto*/
export interface IUpdateEntitlementPaymentDetailsDtoForm {
    /** The entitltment to update */
    EntitlementId: FormControl<number | null>;
    /** The updated payment credentials */
    PaymentCredentialsId: FormControl<number | null>;
}
/**
/* Generates a form from a UpdateEntitlementPaymentDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateEntitlementPaymentDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateEntitlementPaymentDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateEntitlementPaymentDetailsDto | null): FormGroup<IUpdateEntitlementPaymentDetailsDtoForm>;
/** Interface for a form from a UpdateInventoryItemsDto*/
export interface IUpdateInventoryItemsDtoForm {
    /** The Id of the inventory to be updated */
    InventoryId: FormControl<number | null>;
    /** All of the items on the inventory */
    Items: FormArray<FormGroup<IInventoryItemDtoForm>>;
}
/**
/* Generates a form from a UpdateInventoryItemsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateInventoryItemsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateInventoryItemsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateInventoryItemsDto | null): FormGroup<IUpdateInventoryItemsDtoForm>;
/** Interface for a form from a UpdateInvoiceInventoryDto*/
export interface IUpdateInvoiceInventoryDtoForm {
    /** Invoice Id */
    InvoiceId: FormControl<number | null>;
    /** Inventory to Save (all of it for the invoice) */
    Inventory: FormArray<FormGroup<IInvoiceInventoryDtoForm>>;
}
/**
/* Generates a form from a UpdateInvoiceInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateInvoiceInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateInvoiceInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateInvoiceInventoryDto | null): FormGroup<IUpdateInvoiceInventoryDtoForm>;
/** Interface for a form from a UpdateJobDisciplinesDto*/
export interface IUpdateJobDisciplinesDtoForm {
    /** The Job to update */
    JobId: FormControl<number | null>;
    /** The Medallion Ids of all disciplines associated with the job */
    Disciplines: FormArray<FormGroup<IJobDisciplineDtoForm>>;
}
/**
/* Generates a form from a UpdateJobDisciplinesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobDisciplinesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobDisciplinesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobDisciplinesDto | null): FormGroup<IUpdateJobDisciplinesDtoForm>;
/** Interface for a form from a UpdateJobGroupsDto*/
export interface IUpdateJobGroupsDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IJobGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateJobGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobGroupsDto | null): FormGroup<IUpdateJobGroupsDtoForm>;
/** Interface for a form from a UpdateJobHeaderLessonsDto*/
export interface IUpdateJobHeaderLessonsDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<IJobHeaderLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateJobHeaderLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobHeaderLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobHeaderLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobHeaderLessonsDto | null): FormGroup<IUpdateJobHeaderLessonsDtoForm>;
/** Interface for a form from a UpdateJobIndustriesDto*/
export interface IUpdateJobIndustriesDtoForm {
    /** The Job to update */
    JobId: FormControl<number | null>;
    /** The Industry Ids of all industries associated with the job */
    Industries: FormArray<FormGroup<IJobIndustryDtoForm>>;
}
/**
/* Generates a form from a UpdateJobIndustriesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobIndustriesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobIndustriesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobIndustriesDto | null): FormGroup<IUpdateJobIndustriesDtoForm>;
/** Interface for a form from a UpdateJobOrganizationsDto*/
export interface IUpdateJobOrganizationsDtoForm {
    /** The Job to update */
    JobId: FormControl<number | null>;
    /** The Organization Ids of all Organizations associated with the medallion */
    Organizations: FormArray<FormGroup<IJobAssignedOrganizationsDtoForm>>;
}
/**
/* Generates a form from a UpdateJobOrganizationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobOrganizationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobOrganizationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobOrganizationsDto | null): FormGroup<IUpdateJobOrganizationsDtoForm>;
/** Interface for a form from a UpdateJobProductDto*/
export interface IUpdateJobProductDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Products */
    Products: FormArray<FormGroup<IJobProductDtoForm>>;
}
/**
/* Generates a form from a UpdateJobProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobProductDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobProductDto | null): FormGroup<IUpdateJobProductDtoForm>;
/** Interface for a form from a UpdateJobPublicVideosDto*/
export interface IUpdateJobPublicVideosDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Public Videos */
    PublicVideos: FormArray<FormGroup<IPublicVideoJobDtoForm>>;
}
/**
/* Generates a form from a UpdateJobPublicVideosDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobPublicVideosDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobPublicVideosDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobPublicVideosDto | null): FormGroup<IUpdateJobPublicVideosDtoForm>;
/** Interface for a form from a UpdateJobSyndicationProvidersDto*/
export interface IUpdateJobSyndicationProvidersDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<IJobSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateJobSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateJobSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateJobSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateJobSyndicationProvidersDto | null): FormGroup<IUpdateJobSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateLessonCommandsDto*/
export interface IUpdateLessonCommandsDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** All commands on Lesson */
    Commands: FormArray<FormGroup<ILessonCommandDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonCommandsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonCommandsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonCommandsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonCommandsDto | null): FormGroup<IUpdateLessonCommandsDtoForm>;
/** Interface for a form from a UpdateLessonDependenciesDto*/
export interface IUpdateLessonDependenciesDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Dependencies */
    Dependencies: FormArray<FormGroup<ILessonDependencyDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonDependenciesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonDependenciesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonDependenciesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonDependenciesDto | null): FormGroup<IUpdateLessonDependenciesDtoForm>;
/** Interface for a form from a UpdateLessonLabelsDto*/
export interface IUpdateLessonLabelsDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Labels */
    Labels: FormArray<FormGroup<ILessonLabelDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonLabelsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonLabelsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonLabelsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonLabelsDto | null): FormGroup<IUpdateLessonLabelsDtoForm>;
/** Interface for a form from a UpdateLessonOverrideThumbnailDto*/
export interface IUpdateLessonOverrideThumbnailDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Resource Id */
    ResourceId: FormControl<number | null>;
}
/**
/* Generates a form from a UpdateLessonOverrideThumbnailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonOverrideThumbnailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonOverrideThumbnailDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonOverrideThumbnailDto | null): FormGroup<IUpdateLessonOverrideThumbnailDtoForm>;
/** Interface for a form from a UpdateLessonPublicVideosDto*/
export interface IUpdateLessonPublicVideosDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Public Videos */
    PublicVideos: FormArray<FormGroup<IPublicVideoLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonPublicVideosDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonPublicVideosDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonPublicVideosDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonPublicVideosDto | null): FormGroup<IUpdateLessonPublicVideosDtoForm>;
/** Interface for a form from a UpdateLessonSyndicationProvidersDto*/
export interface IUpdateLessonSyndicationProvidersDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ILessonSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonSyndicationProvidersDto | null): FormGroup<IUpdateLessonSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateLessonSyndicationsDto*/
export interface IUpdateLessonSyndicationsDtoForm {
    /** Lesson Id */
    LessonId: FormControl<number | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ILessonSyndicationDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonSyndicationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonSyndicationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonSyndicationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonSyndicationsDto | null): FormGroup<IUpdateLessonSyndicationsDtoForm>;
/** Interface for a form from a UpdateLessonWorkflowAssigneesDto*/
export interface IUpdateLessonWorkflowAssigneesDtoForm {
    /** The lesson Id */
    LessonId: FormControl<number | null>;
    /** A complete list of assignees for the lesson */
    Assignees: FormArray<FormGroup<ILessonWorkflowAssigneesDtoForm>>;
}
/**
/* Generates a form from a UpdateLessonWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateLessonWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateLessonWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateLessonWorkflowAssigneesDto | null): FormGroup<IUpdateLessonWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateMedallionBadgesDto*/
export interface IUpdateMedallionBadgesDtoForm {
    /** The Medallion to update */
    MedallionId: FormControl<number | null>;
    /** The badge Ids of all badges associated with the medallion */
    Badges: FormArray<FormGroup<IMedallionBadgeDtoForm>>;
}
/**
/* Generates a form from a UpdateMedallionBadgesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateMedallionBadgesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateMedallionBadgesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateMedallionBadgesDto | null): FormGroup<IUpdateMedallionBadgesDtoForm>;
/** Interface for a form from a UpdateMedallionGroupsDto*/
export interface IUpdateMedallionGroupsDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IMedallionGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateMedallionGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateMedallionGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateMedallionGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateMedallionGroupsDto | null): FormGroup<IUpdateMedallionGroupsDtoForm>;
/** Interface for a form from a UpdateMedallionHeaderLessonsDto*/
export interface IUpdateMedallionHeaderLessonsDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Remove header lessons on badges under the Medallion or not */
    RemoveSubLessons: FormControl<boolean | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<IMedallionHeaderLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateMedallionHeaderLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateMedallionHeaderLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateMedallionHeaderLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateMedallionHeaderLessonsDto | null): FormGroup<IUpdateMedallionHeaderLessonsDtoForm>;
/** Interface for a form from a UpdateMedallionSyndicationProvidersDto*/
export interface IUpdateMedallionSyndicationProvidersDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Remove syndications on badges under the Medallion or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<IMedallionSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateMedallionSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateMedallionSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateMedallionSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateMedallionSyndicationProvidersDto | null): FormGroup<IUpdateMedallionSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateOrganizationAddressesDto*/
export interface IUpdateOrganizationAddressesDtoForm {
    /** The Organization Id */
    OrganizationId: FormControl<number | null>;
    /** All Addresses for the organization */
    Addresses: FormArray<FormGroup<IOrganizationAddressDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationAddressesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationAddressesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationAddressesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationAddressesDto | null): FormGroup<IUpdateOrganizationAddressesDtoForm>;
/** Interface for a form from a UpdateOrganizationEmailDomainsDto*/
export interface IUpdateOrganizationEmailDomainsDtoForm {
    /** The organization id */
    OrganizationId: FormControl<number | null>;
    /** The email domains */
    EmailDomains: FormArray<FormGroup<IOrganizationEmailDomainDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationEmailDomainsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationEmailDomainsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationEmailDomainsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationEmailDomainsDto | null): FormGroup<IUpdateOrganizationEmailDomainsDtoForm>;
/** Interface for a form from a UpdateOrganizationEntitlementUsersDto*/
export interface IUpdateOrganizationEntitlementUsersDtoForm {
    /** Organization to update */
    OrganizationId: FormControl<number | null>;
    /** Entitlements to update (note this does not delete non-existing ones, only updates the ones that have changed and only the UserId) */
    Entitlements: FormArray<FormGroup<IEntitlementDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationEntitlementUsersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationEntitlementUsersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationEntitlementUsersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationEntitlementUsersDto | null): FormGroup<IUpdateOrganizationEntitlementUsersDtoForm>;
/** Interface for a form from a UpdateOrganizationGroupCoursesDto*/
export interface IUpdateOrganizationGroupCoursesDtoForm {
    /** The Organization Id associated with the group courses */
    OrganizationId: FormControl<number | null>;
    /**  */
    GroupId: FormControl<number | null>;
    /** THe list of groups associated with the courses */
    CourseIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateOrganizationGroupCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationGroupCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationGroupCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationGroupCoursesDto | null): FormGroup<IUpdateOrganizationGroupCoursesDtoForm>;
/** Interface for a form from a UpdateOrganizationGroupsDto*/
export interface IUpdateOrganizationGroupsDtoForm {
    /** The Organization Id */
    OrganizationId: FormControl<number | null>;
    /** All groups for the organization */
    Groups: FormArray<FormGroup<IOrganizationGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationGroupsDto | null): FormGroup<IUpdateOrganizationGroupsDtoForm>;
/** Interface for a form from a UpdateOrganizationLessonNotesDto*/
export interface IUpdateOrganizationLessonNotesDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Notes to Update */
    Notes: FormArray<FormGroup<IOrganizationLessonNoteDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationLessonNotesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationLessonNotesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationLessonNotesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationLessonNotesDto | null): FormGroup<IUpdateOrganizationLessonNotesDtoForm>;
/** Interface for a form from a UpdateOrganizationMessagesDto*/
export interface IUpdateOrganizationMessagesDtoForm {
    /** The Id of the organization to update */
    OrganizationId: FormControl<number | null>;
    /** The messages to save under the organization */
    Messages: FormArray<FormGroup<IOrganizationMessageDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationMessagesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationMessagesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationMessagesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationMessagesDto | null): FormGroup<IUpdateOrganizationMessagesDtoForm>;
/** Interface for a form from a UpdateOrganizationUserGroupsDto*/
export interface IUpdateOrganizationUserGroupsDtoForm {
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** Groups */
    Groups: FormArray<FormGroup<IOrganizationUserGroupDtoForm>>;
}
/**
/* Generates a form from a UpdateOrganizationUserGroupsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateOrganizationUserGroupsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateOrganizationUserGroupsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateOrganizationUserGroupsDto | null): FormGroup<IUpdateOrganizationUserGroupsDtoForm>;
/** Interface for a form from a UpdatePartnerProspectsDto*/
export interface IUpdatePartnerProspectsDtoForm {
    /** Partner Organization Id */
    PartnerId: FormControl<number | null>;
    /** List of prospects */
    Prospects: FormArray<FormGroup<IPartnerProspectDtoForm>>;
}
/**
/* Generates a form from a UpdatePartnerProspectsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePartnerProspectsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePartnerProspectsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePartnerProspectsDto | null): FormGroup<IUpdatePartnerProspectsDtoForm>;
/** Interface for a form from a UpdatePaymentProviderImplementationsDto*/
export interface IUpdatePaymentProviderImplementationsDtoForm {
    /** The provider to update */
    ProviderId: FormControl<number | null>;
    /** All implementations for the provider */
    Implementations: FormArray<FormGroup<IPaymentProviderImplementationDtoForm>>;
}
/**
/* Generates a form from a UpdatePaymentProviderImplementationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePaymentProviderImplementationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePaymentProviderImplementationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePaymentProviderImplementationsDto | null): FormGroup<IUpdatePaymentProviderImplementationsDtoForm>;
/** Interface for a form from a UpdatePlayListHeaderLessonsDto*/
export interface IUpdatePlayListHeaderLessonsDtoForm {
    /** PlayList Id */
    PlayListId: FormControl<number | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<IPlayListHeaderLessonDtoForm>>;
}
/**
/* Generates a form from a UpdatePlayListHeaderLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePlayListHeaderLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePlayListHeaderLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePlayListHeaderLessonsDto | null): FormGroup<IUpdatePlayListHeaderLessonsDtoForm>;
/** Interface for a form from a UpdatePlayListSyndicationProvidersDto*/
export interface IUpdatePlayListSyndicationProvidersDtoForm {
    /** PlayList Id */
    PlayListId: FormControl<number | null>;
    /** Remove syndications on Lessons and topics under the PlayList or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<IPlayListSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdatePlayListSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePlayListSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePlayListSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePlayListSyndicationProvidersDto | null): FormGroup<IUpdatePlayListSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdatePriceListRevisionInventoryDto*/
export interface IUpdatePriceListRevisionInventoryDtoForm {
    /** The Revision to update */
    PriceListRevisionId: FormControl<number | null>;
    /** All of the inventory for the revision */
    Inventory: FormArray<FormGroup<IPriceListRevisionInventoryDtoForm>>;
}
/**
/* Generates a form from a UpdatePriceListRevisionInventoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePriceListRevisionInventoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePriceListRevisionInventoryDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePriceListRevisionInventoryDto | null): FormGroup<IUpdatePriceListRevisionInventoryDtoForm>;
/** Interface for a form from a UpdateProductAndVersionsDto*/
export interface IUpdateProductAndVersionsDtoForm {
    /** The course or lesson Id */
    ItemId: FormControl<number | null>;
    /** A complete list of Product Versions for the given course or lesson */
    VersionIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateProductAndVersionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductAndVersionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductAndVersionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductAndVersionsDto | null): FormGroup<IUpdateProductAndVersionsDtoForm>;
/** Interface for a form from a UpdateProductCategoriesDto*/
export interface IUpdateProductCategoriesDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Categories associated with the product */
    Categories: FormArray<FormGroup<IProductCategoryDtoForm>>;
}
/**
/* Generates a form from a UpdateProductCategoriesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductCategoriesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductCategoriesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductCategoriesDto | null): FormGroup<IUpdateProductCategoriesDtoForm>;
/** Interface for a form from a UpdateProductSitesDto*/
export interface IUpdateProductSitesDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Sites */
    ProductSites: FormArray<FormGroup<IProductSiteDtoForm>>;
}
/**
/* Generates a form from a UpdateProductSitesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductSitesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductSitesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductSitesDto | null): FormGroup<IUpdateProductSitesDtoForm>;
/** Interface for a form from a UpdateProductTranslationCategoryDto*/
export interface IUpdateProductTranslationCategoryDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Jargon to save */
    Categories: FormArray<FormGroup<IProductTranslationCategoryDtoForm>>;
}
/**
/* Generates a form from a UpdateProductTranslationCategoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductTranslationCategoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductTranslationCategoryDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductTranslationCategoryDto | null): FormGroup<IUpdateProductTranslationCategoryDtoForm>;
/** Interface for a form from a UpdateProductVendorIdsDto*/
export interface IUpdateProductVendorIdsDtoForm {
    /** The product id */
    ProductId: FormControl<number | null>;
    /** List of vendor ids associated with a product */
    VendorIds: FormArray<FormControl<string | null>>;
}
/**
/* Generates a form from a UpdateProductVendorIdsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVendorIdsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVendorIdsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVendorIdsDto | null): FormGroup<IUpdateProductVendorIdsDtoForm>;
/** Interface for a form from a UpdateProductVersionAddDto*/
export interface IUpdateProductVersionAddDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The product Id */
    ProductId: FormControl<number | null>;
    /** The string representation of the product's name */
    Product: FormControl<string | null>;
    /** The name of the Version. Typically Major + "." + Minor + "." + Revision */
    Name: FormControl<string | null>;
    /** A description of the version if any */
    Description: FormControl<string | null>;
    /** The major version number. */
    Major: FormControl<number | null>;
    /** The minor version number */
    Minor: FormControl<number | null>;
    /** The revision number */
    Revision: FormControl<number | null>;
    /** When was the version released? */
    ReleasedOn: FormControl<Date | null>;
    /** The External Vendor's Id - Autodesk */
    VendorId: FormControl<string | null>;
    /** Default Course that should be used with viewing this product version */
    DefaultCourseId: FormControl<number | null>;
    /** Default Course Lesson */
    DefaultCourse: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Lessons */
    Lessons: FormArray<FormGroup<IAddVersionLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateProductVersionAddDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVersionAddDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVersionAddDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVersionAddDto | null): FormGroup<IUpdateProductVersionAddDtoForm>;
/** Interface for a form from a UpdateProductVersionCommandDto*/
export interface IUpdateProductVersionCommandDtoForm {
    /** Current Command Lesson */
    Key: FormControl<string | null>;
    /** Current version id */
    VersionId: FormControl<number | null>;
    /** Product Version Command with translated values */
    ProductVersionCommand: FormGroup<IProductVersionCommandWithTranslationsDtoForm>;
}
/**
/* Generates a form from a UpdateProductVersionCommandDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVersionCommandDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVersionCommandDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVersionCommandDto | null): FormGroup<IUpdateProductVersionCommandDtoForm>;
/** Interface for a form from a UpdateProductVersionCoursePreferenceDto*/
export interface IUpdateProductVersionCoursePreferenceDtoForm {
    /** Product */
    ProductId: FormControl<number | null>;
    /** Version */
    VersionId: FormControl<number | null>;
    /** Course Id (optional) */
    CourseId: FormControl<number | null>;
    /** Owned */
    Owned: FormControl<boolean | null>;
}
/**
/* Generates a form from a UpdateProductVersionCoursePreferenceDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVersionCoursePreferenceDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVersionCoursePreferenceDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVersionCoursePreferenceDto | null): FormGroup<IUpdateProductVersionCoursePreferenceDtoForm>;
/** Interface for a form from a UpdateProductVersionCoursePreferencesDto*/
export interface IUpdateProductVersionCoursePreferencesDtoForm {
    /** List of preferences */
    Preferences: FormArray<FormGroup<IProductVersionCoursePreferenceDtoForm>>;
}
/**
/* Generates a form from a UpdateProductVersionCoursePreferencesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVersionCoursePreferencesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVersionCoursePreferencesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVersionCoursePreferencesDto | null): FormGroup<IUpdateProductVersionCoursePreferencesDtoForm>;
/** Interface for a form from a UpdateProductVersionsDto*/
export interface IUpdateProductVersionsDtoForm {
    /** The root product */
    ProductId: FormControl<number | null>;
    /** All versions that are currently valid for that product */
    Versions: FormArray<FormGroup<IProductVersionDtoForm>>;
}
/**
/* Generates a form from a UpdateProductVersionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductVersionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductVersionsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductVersionsDto | null): FormGroup<IUpdateProductVersionsDtoForm>;
/** Interface for a form from a UpdateProductWebAddressesDto*/
export interface IUpdateProductWebAddressesDtoForm {
    /** Product that the web addresses are associated with. */
    ProductId: FormControl<number | null>;
    /** Web addresses to upsert. */
    WebAddresses: FormArray<FormGroup<IProductWebAddressDtoForm>>;
}
/**
/* Generates a form from a UpdateProductWebAddressesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProductWebAddressesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProductWebAddressesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProductWebAddressesDto | null): FormGroup<IUpdateProductWebAddressesDtoForm>;
/** Interface for a form from a UpdateProjectProductDto*/
export interface IUpdateProjectProductDtoForm {
    /** Project Id */
    ProjectId: FormControl<number | null>;
    /** Project's Products */
    Products: FormArray<FormGroup<IProjectProductDtoForm>>;
}
/**
/* Generates a form from a UpdateProjectProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateProjectProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateProjectProductDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateProjectProductDto | null): FormGroup<IUpdateProjectProductDtoForm>;
/** Interface for a form from a UpdatePublicVideoCoursesDto*/
export interface IUpdatePublicVideoCoursesDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Course Ids */
    Courses: FormArray<FormGroup<IPublicVideoCourseDtoForm>>;
}
/**
/* Generates a form from a UpdatePublicVideoCoursesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePublicVideoCoursesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePublicVideoCoursesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePublicVideoCoursesDto | null): FormGroup<IUpdatePublicVideoCoursesDtoForm>;
/** Interface for a form from a UpdatePublicVideoDisciplinesDto*/
export interface IUpdatePublicVideoDisciplinesDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Course Ids */
    Disciplines: FormArray<FormGroup<IPublicVideoDisciplineDtoForm>>;
}
/**
/* Generates a form from a UpdatePublicVideoDisciplinesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePublicVideoDisciplinesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePublicVideoDisciplinesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePublicVideoDisciplinesDto | null): FormGroup<IUpdatePublicVideoDisciplinesDtoForm>;
/** Interface for a form from a UpdatePublicVideoJobsDto*/
export interface IUpdatePublicVideoJobsDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Course Ids */
    Jobs: FormArray<FormGroup<IPublicVideoJobDtoForm>>;
}
/**
/* Generates a form from a UpdatePublicVideoJobsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePublicVideoJobsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePublicVideoJobsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePublicVideoJobsDto | null): FormGroup<IUpdatePublicVideoJobsDtoForm>;
/** Interface for a form from a UpdatePublicVideoLessonsDto*/
export interface IUpdatePublicVideoLessonsDtoForm {
    /** Public Video Id */
    PublicVideoId: FormControl<number | null>;
    /** Course Ids */
    Lessons: FormArray<FormGroup<IPublicVideoLessonDtoForm>>;
}
/**
/* Generates a form from a UpdatePublicVideoLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdatePublicVideoLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdatePublicVideoLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdatePublicVideoLessonsDto | null): FormGroup<IUpdatePublicVideoLessonsDtoForm>;
/** Interface for a form from a UpdateQuestionBranchDto*/
export interface IUpdateQuestionBranchDtoForm {
    /** The answer id */
    AnswerId: FormControl<number | null>;
    /** List of question ids to associate with an answer */
    Questions: FormArray<FormGroup<IAnswerQuestionDtoForm>>;
}
/**
/* Generates a form from a UpdateQuestionBranchDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateQuestionBranchDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateQuestionBranchDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateQuestionBranchDto | null): FormGroup<IUpdateQuestionBranchDtoForm>;
/** Interface for a form from a UpdateQuestionLessonTimeDto*/
export interface IUpdateQuestionLessonTimeDtoForm {
    /** The question to update */
    QuestionId: FormControl<number | null>;
    /** The Lesson Ids of all lessons associated with the question */
    Lessons: FormArray<FormGroup<IQuestionLessonDtoForm>>;
}
/**
/* Generates a form from a UpdateQuestionLessonTimeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateQuestionLessonTimeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateQuestionLessonTimeDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateQuestionLessonTimeDto | null): FormGroup<IUpdateQuestionLessonTimeDtoForm>;
/** Interface for a form from a UpdateQuestionLessonsDto*/
export interface IUpdateQuestionLessonsDtoForm {
    /** The question to update */
    QuestionId: FormControl<number | null>;
    /** The Lesson Ids of all lessons associated with the question */
    LessonIds: FormArray<FormControl<number | null>>;
}
/**
/* Generates a form from a UpdateQuestionLessonsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateQuestionLessonsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateQuestionLessonsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateQuestionLessonsDto | null): FormGroup<IUpdateQuestionLessonsDtoForm>;
/** Interface for a form from a UpdateQuestionWorkflowAssigneesDto*/
export interface IUpdateQuestionWorkflowAssigneesDtoForm {
    /** The question to update */
    QuestionId: FormControl<number | null>;
    /** The assignees to the Question (all of them) */
    Assignees: FormArray<FormGroup<IQuestionWorkflowAssigneesDtoForm>>;
}
/**
/* Generates a form from a UpdateQuestionWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateQuestionWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateQuestionWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateQuestionWorkflowAssigneesDto | null): FormGroup<IUpdateQuestionWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateSupportAnswerQuestions*/
export interface IUpdateSupportAnswerQuestionsForm {
    /** Support Answer */
    SupportAnswerId: FormControl<number | null>;
    /** Questions */
    Questions: FormArray<FormGroup<ISupportQuestionDtoForm>>;
}
/**
/* Generates a form from a UpdateSupportAnswerQuestions
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateSupportAnswerQuestions from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateSupportAnswerQuestionsForm(fb: FormBuilder, dto?: Interfaces.UpdateSupportAnswerQuestions | null): FormGroup<IUpdateSupportAnswerQuestionsForm>;
/** Interface for a form from a UpdateSyndicationProviderImplementationsDto*/
export interface IUpdateSyndicationProviderImplementationsDtoForm {
    /** The provider to update */
    ProviderId: FormControl<number | null>;
    /** All implementations for the provider */
    Implementations: FormArray<FormGroup<ISyndicationProviderImplementationDtoForm>>;
}
/**
/* Generates a form from a UpdateSyndicationProviderImplementationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateSyndicationProviderImplementationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateSyndicationProviderImplementationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateSyndicationProviderImplementationsDto | null): FormGroup<IUpdateSyndicationProviderImplementationsDtoForm>;
/** Interface for a form from a UpdateSystemSettingsDto*/
export interface IUpdateSystemSettingsDtoForm {
    /** The list of System Settings */
    Settings: FormArray<FormGroup<ISystemSettingDtoForm>>;
}
/**
/* Generates a form from a UpdateSystemSettingsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateSystemSettingsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateSystemSettingsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateSystemSettingsDto | null): FormGroup<IUpdateSystemSettingsDtoForm>;
/** Interface for a form from a UpdateTopicStructureDto*/
export interface IUpdateTopicStructureDtoForm {
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** structure */
    Structure: FormArray<FormGroup<ICourseStructureForEditingDtoForm>>;
}
/**
/* Generates a form from a UpdateTopicStructureDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateTopicStructureDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateTopicStructureDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateTopicStructureDto | null): FormGroup<IUpdateTopicStructureDtoForm>;
/** Interface for a form from a UpdateTopicSyndicationProvidersDto*/
export interface IUpdateTopicSyndicationProvidersDtoForm {
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** Remove syndications on Lessons and topics under the Topic or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ITopicSyndicationProviderDtoForm>>;
}
/**
/* Generates a form from a UpdateTopicSyndicationProvidersDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateTopicSyndicationProvidersDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateTopicSyndicationProvidersDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateTopicSyndicationProvidersDto | null): FormGroup<IUpdateTopicSyndicationProvidersDtoForm>;
/** Interface for a form from a UpdateTopicSyndicationsDto*/
export interface IUpdateTopicSyndicationsDtoForm {
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** Remove syndications on Lessons under the topic or not */
    RemoveSubSyndications: FormControl<boolean | null>;
    /** Syndications */
    Syndications: FormArray<FormGroup<ITopicSyndicationDtoForm>>;
}
/**
/* Generates a form from a UpdateTopicSyndicationsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateTopicSyndicationsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateTopicSyndicationsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateTopicSyndicationsDto | null): FormGroup<IUpdateTopicSyndicationsDtoForm>;
/** Interface for a form from a UpdateTopicWorkflowAssigneesDto*/
export interface IUpdateTopicWorkflowAssigneesDtoForm {
    /** Topic Id */
    TopicId: FormControl<number | null>;
    /** Assignees */
    Assignees: FormArray<FormGroup<ITopicWorkflowAssigneesDtoForm>>;
}
/**
/* Generates a form from a UpdateTopicWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateTopicWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateTopicWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateTopicWorkflowAssigneesDto | null): FormGroup<IUpdateTopicWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateTranslationWorkflowAssigneesDto*/
export interface IUpdateTranslationWorkflowAssigneesDtoForm {
    /** The assessment to update */
    ParentId: FormControl<number | null>;
    /** Question Item Types */
    ParentType: FormControl<Enums.ContentItemTypes | null>;
    /** Language Code */
    LanguageCode: FormControl<string | null>;
    /** The assignees to the Assessment (all of them) */
    Assignees: FormArray<FormGroup<ITranslationWorkflowAssigneeDtoForm>>;
}
/**
/* Generates a form from a UpdateTranslationWorkflowAssigneesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateTranslationWorkflowAssigneesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateTranslationWorkflowAssigneesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateTranslationWorkflowAssigneesDto | null): FormGroup<IUpdateTranslationWorkflowAssigneesDtoForm>;
/** Interface for a form from a UpdateUserAddressesDto*/
export interface IUpdateUserAddressesDtoForm {
    /** The User Id */
    UserId: FormControl<number | null>;
    /** All Addresses for the user */
    Addresses: FormArray<FormGroup<IUserAddressDtoForm>>;
}
/**
/* Generates a form from a UpdateUserAddressesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateUserAddressesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateUserAddressesDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateUserAddressesDto | null): FormGroup<IUpdateUserAddressesDtoForm>;
/** Interface for a form from a UpdateUserJobsDto*/
export interface IUpdateUserJobsDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Optional Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Jobs */
    Jobs: FormArray<FormGroup<IUserJobDtoForm>>;
}
/**
/* Generates a form from a UpdateUserJobsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateUserJobsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateUserJobsDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateUserJobsDto | null): FormGroup<IUpdateUserJobsDtoForm>;
/** Interface for a form from a UpdateUserSubscriptionDto*/
export interface IUpdateUserSubscriptionDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** List of Subscriptions */
    Subscriptions: FormArray<FormGroup<IUserSubscriptionDtoForm>>;
}
/**
/* Generates a form from a UpdateUserSubscriptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateUserSubscriptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateUserSubscriptionDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateUserSubscriptionDto | null): FormGroup<IUpdateUserSubscriptionDtoForm>;
/** Interface for a form from a UpdateWorkflowStepDto*/
export interface IUpdateWorkflowStepDtoForm {
    /** The related Item */
    ItemId: FormControl<number | null>;
    /** The step to update */
    WorkflowStepId: FormControl<number | null>;
    /** Any notes on the change */
    Notes: FormControl<string | null>;
}
/**
/* Generates a form from a UpdateWorkflowStepDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateWorkflowStepDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateWorkflowStepDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateWorkflowStepDto | null): FormGroup<IUpdateWorkflowStepDtoForm>;
/** Interface for a form from a UpdateWorkflowTaskDto*/
export interface IUpdateWorkflowTaskDtoForm {
    /** Parent Id of the workflow target */
    ParentId: FormControl<number | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
}
/**
/* Generates a form from a UpdateWorkflowTaskDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UpdateWorkflowTaskDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUpdateWorkflowTaskDtoForm(fb: FormBuilder, dto?: Interfaces.UpdateWorkflowTaskDto | null): FormGroup<IUpdateWorkflowTaskDtoForm>;
/** Interface for a form from a UploadDomainStyleSheetDto*/
export interface IUploadDomainStyleSheetDtoForm {
    /** The domain Id */
    DomainId: FormControl<number | null>;
    /** The Style sheet in CSS format */
    StyleSheet: FormControl<string | null>;
}
/**
/* Generates a form from a UploadDomainStyleSheetDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UploadDomainStyleSheetDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUploadDomainStyleSheetDtoForm(fb: FormBuilder, dto?: Interfaces.UploadDomainStyleSheetDto | null): FormGroup<IUploadDomainStyleSheetDtoForm>;
/** Interface for a form from a UserAcceptedTermsDto*/
export interface IUserAcceptedTermsDtoForm {
    /** User has accepted terms */
    AcceptedTerms: FormControl<boolean | null>;
}
/**
/* Generates a form from a UserAcceptedTermsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAcceptedTermsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAcceptedTermsDtoForm(fb: FormBuilder, dto?: Interfaces.UserAcceptedTermsDto | null): FormGroup<IUserAcceptedTermsDtoForm>;
/** Interface for a form from a UserActivityDetailDto*/
export interface IUserActivityDetailDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** User Lesson */
    UserName: FormControl<string | null>;
    /** Full Lesson */
    FullName: FormControl<string | null>;
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** User Active? */
    IsActive: FormControl<boolean | null>;
}
/**
/* Generates a form from a UserActivityDetailDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserActivityDetailDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserActivityDetailDtoForm(fb: FormBuilder, dto?: Interfaces.UserActivityDetailDto | null): FormGroup<IUserActivityDetailDtoForm>;
/** Interface for a form from a UserAddSubscriptionRequestDto*/
export interface IUserAddSubscriptionRequestDtoForm {
    /** The User which to add the subscription. If this is null then the other fields for the user must be filled in. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirmation Password */
    ConfirmPassword: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Provider */
    Provider: FormControl<string | null>;
    /** Unique Provider Key that links the provider to the user. */
    ProviderKey: FormControl<string | null>;
    /** Billing Street Address */
    BillingStreetAddress: FormControl<string | null>;
    /** Billing Street Address 2 */
    BillingStreetAddress2: FormControl<string | null>;
    /** Billing TownCity */
    BillingTownCity: FormControl<string | null>;
    /** Billing Postal Code */
    BillingPostalCode: FormControl<string | null>;
    /** Billing State */
    BillingState: FormControl<string | null>;
    /** Billing Country */
    BillingCountry: FormControl<string | null>;
    /** Shipping Street Address */
    ShippingStreetAddress: FormControl<string | null>;
    /** Shipping Street Address 2 */
    ShippingStreetAddress2: FormControl<string | null>;
    /** Shipping TownCity */
    ShippingTownCity: FormControl<string | null>;
    /** Shipping Postal Code */
    ShippingPostalCode: FormControl<string | null>;
    /** Shipping State */
    ShippingState: FormControl<string | null>;
    /** Shipping Country */
    ShippingCountry: FormControl<string | null>;
    /** Marketing Campaign Sources (How did you hear about us?) */
    HowDidYouHearAboutUs: FormControl<Enums.HowDidYouHearAboutUs | null>;
    /** Additional information about how the user heard about us */
    HowDidYouHearAboutUsOther: FormControl<string | null>;
    /** The credit card details for a payment by credit card */
    CardDetails: FormGroup<IMakePaymentCardDetailsDtoForm>;
    /** Account details for a payment made by bank draft */
    AccountDetails: FormGroup<IMakePaymentAccountDetailsDtoForm>;
    /**  */
    PaymentMethodId: FormControl<number | null>;
    /** The SKU to use for the trial */
    SKU: FormControl<string | null>;
    /** Reseller Id. Used for setting associated organization */
    ResellerId: FormControl<number | null>;
    /** UA Membership Id */
    MembershipId: FormControl<string | null>;
    /** UA Local # */
    LocalNumber: FormControl<string | null>;
    /** UA Local Lesson */
    LocalName: FormControl<string | null>;
    /** Is Local Instructor */
    IsLocalInstructor: FormControl<boolean | null>;
    /** The type of union (i.e. UA or ITI) */
    UnionType: FormControl<string | null>;
    /** Is purchasing cadlearning content */
    CADLearningContent: FormControl<boolean | null>;
    /** Is purchasing Bluebeam content */
    BluebeamContent: FormControl<boolean | null>;
}
/**
/* Generates a form from a UserAddSubscriptionRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddSubscriptionRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddSubscriptionRequestDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddSubscriptionRequestDto | null): FormGroup<IUserAddSubscriptionRequestDtoForm>;
/** Interface for a form from a UserAddSubscriptionResponseDto*/
export interface IUserAddSubscriptionResponseDtoForm {
    /** Error Message */
    ErrorMessage: FormControl<string | null>;
    /** User Subscription Creation Result Codes */
    Result: FormControl<Enums.UserSubscriptionCreationResultCodes | null>;
    /** The main Dto that describes a user */
    User: FormGroup<IUserDtoForm>;
    /** Description */
    Description: FormControl<string | null>;
    /** Invoice Id */
    InvoiceId: FormControl<string | null>;
    /** Organization portal url */
    PortalUrl: FormControl<string | null>;
}
/**
/* Generates a form from a UserAddSubscriptionResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddSubscriptionResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddSubscriptionResponseDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddSubscriptionResponseDto | null): FormGroup<IUserAddSubscriptionResponseDtoForm>;
/** Interface for a form from a UserAddTokenSubscriptionRequestDto*/
export interface IUserAddTokenSubscriptionRequestDtoForm {
    /** Email Address */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirmation Password */
    ConfirmPassword: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** Provider */
    Provider: FormControl<string | null>;
    /** Unique Provider Key that links the provider to the user. */
    ProviderKey: FormControl<string | null>;
    /** External Access Token */
    ExternalAccessToken: FormControl<string | null>;
    /** Marketing Campaign Sources (How did you hear about us?) */
    HowDidYouHearAboutUs: FormControl<Enums.HowDidYouHearAboutUs | null>;
    /** Additional information about how the user heard about us */
    HowDidYouHearAboutUsOther: FormControl<string | null>;
    /** Reseller Id. Used for setting associated organization */
    ResellerId: FormControl<number | null>;
    /** Token to redeem */
    TokenId: FormControl<string | null>;
}
/**
/* Generates a form from a UserAddTokenSubscriptionRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddTokenSubscriptionRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddTokenSubscriptionRequestDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddTokenSubscriptionRequestDto | null): FormGroup<IUserAddTokenSubscriptionRequestDtoForm>;
/** Interface for a form from a UserAddTrialRequestDto*/
export interface IUserAddTrialRequestDtoForm {
    /** The User to add the trial to. If this is null then the other fields for the user must be filled in. */
    UserId: FormControl<number | null>;
    /** Email Address */
    Email: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
    /** Confirmation Password */
    ConfirmPassword: FormControl<string | null>;
    /** The provider used to login */
    Provider: FormControl<string | null>;
    /** Provider Key that links to the account */
    ProviderKey: FormControl<string | null>;
    /** First Lesson */
    FirstName: FormControl<string | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Last Lesson */
    LastName: FormControl<string | null>;
    /** The SKU to use for the trial */
    SKU: FormControl<string | null>;
    /** Marketing Campaign Sources (How did you hear about us?) */
    HowDidYouHearAboutUs: FormControl<Enums.HowDidYouHearAboutUs | null>;
    /** Additional information about how the user heard about us */
    HowDidYouHearAboutUsOther: FormControl<string | null>;
    /** Partner id */
    ResellerId: FormControl<number | null>;
}
/**
/* Generates a form from a UserAddTrialRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddTrialRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddTrialRequestDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddTrialRequestDto | null): FormGroup<IUserAddTrialRequestDtoForm>;
/** Interface for a form from a UserAddTrialResponseDto*/
export interface IUserAddTrialResponseDtoForm {
    /** Error Message */
    ErrorMessage: FormControl<string | null>;
    /** User Trial Creation Result Codes */
    Result: FormControl<Enums.UserTrialCreationResultCodes | null>;
    /** The main Dto that describes a user */
    User: FormGroup<IUserDtoForm>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a UserAddTrialResponseDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddTrialResponseDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddTrialResponseDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddTrialResponseDto | null): FormGroup<IUserAddTrialResponseDtoForm>;
/** Interface for a form from a UserAddressDto*/
export interface IUserAddressDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** Is the address the default for the user */
    Default: FormControl<boolean | null>;
    /** Is the address the billing address for the user */
    Billing: FormControl<boolean | null>;
    /** Is the address the shipping address for the user */
    Shipping: FormControl<boolean | null>;
    /** Street 1 */
    Street1: FormControl<string | null>;
    /** Street 2 */
    Street2: FormControl<string | null>;
    /** City */
    City: FormControl<string | null>;
    /** State */
    State: FormControl<string | null>;
    /** Postal/Zip Code */
    PostalCode: FormControl<string | null>;
    /** Country */
    Country: FormControl<string | null>;
    /** The User Id */
    UserId: FormControl<number | null>;
    /** The name of the user */
    User: FormControl<string | null>;
}
/**
/* Generates a form from a UserAddressDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAddressDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAddressDtoForm(fb: FormBuilder, dto?: Interfaces.UserAddressDto | null): FormGroup<IUserAddressDtoForm>;
/** Interface for a form from a UserAssessmentAnswerDto*/
export interface IUserAssessmentAnswerDtoForm {
    /** The assessment you're answering */
    UserAssessmentId: FormControl<number | null>;
    /** The question you're answering. */
    QuestionId: FormControl<number | null>;
    /** The answer */
    AnswerId: FormControl<number | null>;
    /** Duration */
    Duration: FormControl<number | null>;
}
/**
/* Generates a form from a UserAssessmentAnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAssessmentAnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAssessmentAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.UserAssessmentAnswerDto | null): FormGroup<IUserAssessmentAnswerDtoForm>;
/** Interface for a form from a UserAssessmentDto*/
export interface IUserAssessmentDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The parent assessment id */
    AssessmentId: FormControl<number | null>;
    /** The questions for the assessment. */
    Questions: FormArray<FormGroup<IUserAssessmentQuestionDtoForm>>;
    /** The Lesson of the Assessment */
    Name: FormControl<string | null>;
    /** The total duration the user took to complete the assessment */
    TotalDuration: FormControl<number | null>;
}
/**
/* Generates a form from a UserAssessmentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAssessmentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAssessmentDtoForm(fb: FormBuilder, dto?: Interfaces.UserAssessmentDto | null): FormGroup<IUserAssessmentDtoForm>;
/** Interface for a form from a UserAssessmentQuestionDto*/
export interface IUserAssessmentQuestionDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The text of the question */
    Text: FormControl<string | null>;
    /** The selected answer */
    AnswerId: FormControl<number | null>;
    /** Parent Assessment Id */
    UserAssessmentId: FormControl<number | null>;
    /** An Enumeration of different types of assessments */
    AssessmentType: FormControl<Enums.AssessmentTypes | null>;
    /** The Answers to the question */
    Answers: FormArray<FormGroup<IAnswerDisplayDtoForm>>;
    /** The resources associated with the question */
    Resources: FormArray<FormGroup<IResourceLocatorDtoForm>>;
    /** The duration the user took to answer the question */
    Duration: FormControl<number | null>;
    /** The order of the question */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a UserAssessmentQuestionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAssessmentQuestionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAssessmentQuestionDtoForm(fb: FormBuilder, dto?: Interfaces.UserAssessmentQuestionDto | null): FormGroup<IUserAssessmentQuestionDtoForm>;
/** Interface for a form from a UserAssessmentTranscriptDto*/
export interface IUserAssessmentTranscriptDtoForm {
    /** The assessment id taken */
    AssessmentId: FormControl<number | null>;
    /** The name of the assessment */
    Assessment: FormControl<string | null>;
    /** What the assessment belongs to */
    ParentId: FormControl<number | null>;
    /** The name of the parent of the assessment */
    Parent: FormControl<string | null>;
    /** The Type of the parent that kicked off the assessment */
    ParentType: FormControl<Enums.AssessmentParentTypes | null>;
    /** The user's score */
    Score: FormControl<number | null>;
    /** Total Possible */
    OutOf: FormControl<number | null>;
    /** Is the assessment complete */
    Complete: FormControl<boolean | null>;
    /** Date that the assessment was completed */
    CompletedOn: FormControl<Date | null>;
    /** User Id */
    UserId: FormControl<number | null>;
}
/**
/* Generates a form from a UserAssessmentTranscriptDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserAssessmentTranscriptDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserAssessmentTranscriptDtoForm(fb: FormBuilder, dto?: Interfaces.UserAssessmentTranscriptDto | null): FormGroup<IUserAssessmentTranscriptDtoForm>;
/** Interface for a form from a UserDataRequestDocumentDto*/
export interface IUserDataRequestDocumentDtoForm {
    /** Id */
    Id: FormControl<number | null>;
    /** User data request id */
    UserDataRequestId: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Is return data */
    IsReturnData: FormControl<boolean | null>;
    /** Uri */
    Uri: FormControl<string | null>;
    /** File Lesson */
    FileName: FormControl<string | null>;
    /** File Size */
    Size: FormControl<string | null>;
    /** Date File Updated */
    DateTimeFileUpdated: FormControl<Date | null>;
    /** Resource Locations */
    Location: FormControl<Enums.ResourceLocations | null>;
    /** Resource Types */
    Type: FormControl<Enums.ResourceTypes | null>;
}
/**
/* Generates a form from a UserDataRequestDocumentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDataRequestDocumentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDataRequestDocumentDtoForm(fb: FormBuilder, dto?: Interfaces.UserDataRequestDocumentDto | null): FormGroup<IUserDataRequestDocumentDtoForm>;
/** Interface for a form from a UserDataRequestDto*/
export interface IUserDataRequestDtoForm {
    /** Request Id */
    Id: FormControl<number | null>;
    /** User Id Making Request */
    UserId: FormControl<number | null>;
    /** User Lesson making request */
    User: FormControl<string | null>;
    /** Requested On */
    RequestedOn: FormControl<Date | null>;
    /** Is a data retrieval request */
    DataRequest: FormControl<boolean | null>;
    /** Is a data removal request */
    DataRemoval: FormControl<boolean | null>;
    /** User accepted privacy policy (Used on initial request) */
    AcceptedTerms: FormControl<boolean | null>;
    /** Approved */
    Approved: FormControl<boolean | null>;
    /** Rejected */
    Rejected: FormControl<boolean | null>;
    /** Rejected Reason */
    RejectedReason: FormControl<string | null>;
}
/**
/* Generates a form from a UserDataRequestDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDataRequestDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDataRequestDtoForm(fb: FormBuilder, dto?: Interfaces.UserDataRequestDto | null): FormGroup<IUserDataRequestDtoForm>;
/** Interface for a form from a UserDataRequestRejectDto*/
export interface IUserDataRequestRejectDtoForm {
    /** Id of Request */
    Id: FormControl<number | null>;
    /** Reject Reason */
    RejectReason: FormControl<string | null>;
}
/**
/* Generates a form from a UserDataRequestRejectDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDataRequestRejectDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDataRequestRejectDtoForm(fb: FormBuilder, dto?: Interfaces.UserDataRequestRejectDto | null): FormGroup<IUserDataRequestRejectDtoForm>;
/** Interface for a form from a UserDataRequestWithResourcesDto*/
export interface IUserDataRequestWithResourcesDtoForm {
    /** Request Id */
    Id: FormControl<number | null>;
    /** User Id Making Request */
    UserId: FormControl<number | null>;
    /** User Lesson making request */
    User: FormControl<string | null>;
    /** Requested On */
    RequestedOn: FormControl<Date | null>;
    /** Is a data retrieval request */
    DataRequest: FormControl<boolean | null>;
    /** Is a data removal request */
    DataRemoval: FormControl<boolean | null>;
    /** User accepted privacy policy (Used on initial request) */
    AcceptedTerms: FormControl<boolean | null>;
    /** Approved */
    Approved: FormControl<boolean | null>;
    /** Rejected */
    Rejected: FormControl<boolean | null>;
    /** Rejected Reason */
    RejectedReason: FormControl<string | null>;
    /** Documents */
    Documents: FormArray<FormGroup<IUserDataRequestDocumentDtoForm>>;
}
/**
/* Generates a form from a UserDataRequestWithResourcesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDataRequestWithResourcesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDataRequestWithResourcesDtoForm(fb: FormBuilder, dto?: Interfaces.UserDataRequestWithResourcesDto | null): FormGroup<IUserDataRequestWithResourcesDtoForm>;
/** Interface for a form from a UserDisciplineDto*/
export interface IUserDisciplineDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Discipline with its products */
    Discipline: FormGroup<IDisciplineWithProductsDtoForm>;
}
/**
/* Generates a form from a UserDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.UserDisciplineDto | null): FormGroup<IUserDisciplineDtoForm>;
/** Interface for a form from a UserDisciplineLearningPathDto*/
export interface IUserDisciplineLearningPathDtoForm {
    /** Length of all incomplete lessons */
    Length: FormControl<number | null>;
    /** Is the Path Expanded? */
    Expanded: FormControl<boolean | null>;
    /** Discipline Lesson */
    Name: FormControl<string | null>;
    /** Discipline Id */
    Id: FormControl<number | null>;
    /** A Resource */
    DisplayImage: FormGroup<IResourceDtoForm>;
    /** Total Number of Medallions */
    TotalMedallions: FormControl<number | null>;
    /** Number of Completed Medallions */
    TotalCompletedMedallions: FormControl<number | null>;
    /** Total # of Badges */
    TotalBadges: FormControl<number | null>;
    /** When the Discipline was started. */
    StartedOn: FormControl<Date | null>;
    /** When will the trend hit 0? */
    TrendZeroOn: FormControl<Date | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Discipline Earned Date, if applicable */
    EarnedOn: FormControl<Date | null>;
    /** History of completion */
    History: FormArray<FormGroup<ILearningPathHistoryDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
    /** Was the discipline added by a job? */
    AddedByJob: FormControl<boolean | null>;
    /** Medallions */
    Medallions: FormArray<FormGroup<IMedallionLearningPathDtoForm>>;
    /** Discipline Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
    /** Users first name */
    FirstName: FormControl<string | null>;
    /** Users Last Lesson */
    LastName: FormControl<string | null>;
}
/**
/* Generates a form from a UserDisciplineLearningPathDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDisciplineLearningPathDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDisciplineLearningPathDtoForm(fb: FormBuilder, dto?: Interfaces.UserDisciplineLearningPathDto | null): FormGroup<IUserDisciplineLearningPathDtoForm>;
/** Interface for a form from a UserDto*/
export interface IUserDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** This is the Email Address - Required for Identity Framework */
    UserName: FormControl<string | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The user's full name */
    Name: FormControl<string | null>;
    /** The user's email */
    Email: FormControl<string | null>;
    /** Is the email address confirmed? */
    EmailConfirmed: FormControl<boolean | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Is the phone number confirmed? */
    PhoneNumberConfirmed: FormControl<boolean | null>;
    /** Is the user active? */
    Active: FormControl<boolean | null>;
    /** Creation Date */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** EduConfirmed */
    EduConfirmed: FormControl<boolean | null>;
    /** User Expert Bot Escalation Availabilities */
    ExpertBotEscalationAvailability: FormControl<Enums.UserExpertBotEscalationAvailabilities | null>;
    /** Available for Escalation */
    AvailableForEscalation: FormControl<boolean | null>;
    /** Users selected language */
    LanguageCode: FormControl<string | null>;
}
/**
/* Generates a form from a UserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserDtoForm(fb: FormBuilder, dto?: Interfaces.UserDto | null): FormGroup<IUserDtoForm>;
/** Interface for a form from a UserGridLayoutDto*/
export interface IUserGridLayoutDtoForm {
    /** Id of the Grid that is customized */
    Id: FormControl<string | null>;
    /** Grid Unique Key */
    Key: FormControl<string | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** Default Layout */
    IsDefault: FormControl<boolean | null>;
    /** Title to add to the grid */
    Title: FormControl<string | null>;
    /** The filter criteria for the grid */
    Filters: FormArray<FormGroup<IFilterCriteriaForm>>;
    /** The Sorting rules for the grid */
    Sorting: FormArray<FormGroup<IOrderCriteriaForm>>;
    /**  */
    GroupBy: FormGroup<IGroupCriteriaForm>;
    /** Summary Aggregates for the Grid */
    Aggregates: FormArray<FormGroup<IAggregateCriteriaForm>>;
    /** Column Definition and order */
    Columns: FormArray<FormGroup<IColumnDetailForm>>;
}
/**
/* Generates a form from a UserGridLayoutDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserGridLayoutDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserGridLayoutDtoForm(fb: FormBuilder, dto?: Interfaces.UserGridLayoutDto | null): FormGroup<IUserGridLayoutDtoForm>;
/** Interface for a form from a UserJobDto*/
export interface IUserJobDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** User Id */
    UserId: FormControl<number | null>;
    /** User's Lesson */
    User: FormControl<string | null>;
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Organization Id */
    OrganizationId: FormControl<number | null>;
    /** Organization Lesson */
    Organization: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Products linked to the job. */
    Products: FormArray<FormGroup<IUserJobProductDtoForm>>;
}
/**
/* Generates a form from a UserJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserJobDtoForm(fb: FormBuilder, dto?: Interfaces.UserJobDto | null): FormGroup<IUserJobDtoForm>;
/** Interface for a form from a UserJobProductDto*/
export interface IUserJobProductDtoForm {
    /** Link to the User Job */
    UserJobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product */
    Product: FormControl<string | null>;
    /** Version Id */
    VersionId: FormControl<number | null>;
    /** Version Lesson */
    Version: FormControl<string | null>;
}
/**
/* Generates a form from a UserJobProductDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserJobProductDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserJobProductDtoForm(fb: FormBuilder, dto?: Interfaces.UserJobProductDto | null): FormGroup<IUserJobProductDtoForm>;
/** Interface for a form from a UserProgressStatsDto*/
export interface IUserProgressStatsDtoForm {
    /** Total Badges */
    TotalBadges: FormControl<number | null>;
    /** In Progress Badges */
    InProgressBadges: FormControl<number | null>;
    /** Complete Badges */
    CompleteBadges: FormControl<number | null>;
}
/**
/* Generates a form from a UserProgressStatsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserProgressStatsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserProgressStatsDtoForm(fb: FormBuilder, dto?: Interfaces.UserProgressStatsDto | null): FormGroup<IUserProgressStatsDtoForm>;
/** Interface for a form from a UserReportDto*/
export interface IUserReportDtoForm {
    /** Report Id */
    Id: FormControl<string | null>;
    /** User */
    UserId: FormControl<number | null>;
    /** Organization */
    OrganizationId: FormControl<number | null>;
    /** How reports should be persisted to the database for recovery with custom reports etc. */
    Report: FormGroup<IReportDtoForm>;
    /** Report Schedule */
    Schedule: FormGroup<IReportScheduleDetailForm>;
}
/**
/* Generates a form from a UserReportDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserReportDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserReportDtoForm(fb: FormBuilder, dto?: Interfaces.UserReportDto | null): FormGroup<IUserReportDtoForm>;
/** Interface for a form from a UserSubscriptionDto*/
export interface IUserSubscriptionDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** User Lesson */
    User: FormControl<string | null>;
    /** Campaign Types */
    CampaignType: FormControl<Enums.CampaignTypes | null>;
    /** Subscription Types */
    SubscriptionTypes: FormControl<Enums.SubscriptionTypes | null>;
}
/**
/* Generates a form from a UserSubscriptionDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserSubscriptionDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserSubscriptionDtoForm(fb: FormBuilder, dto?: Interfaces.UserSubscriptionDto | null): FormGroup<IUserSubscriptionDtoForm>;
/** Interface for a form from a UserSuggestedContentDto*/
export interface IUserSuggestedContentDtoForm {
    /** The productId */
    ProductId: FormControl<number | null>;
    /** The Product Lesson */
    Product: FormControl<string | null>;
    /** The key used for generating the image name */
    ProductKey: FormControl<string | null>;
    /** Product Description */
    ProductDescription: FormControl<string | null>;
    /** The Courses associated with the products */
    Courses: FormArray<FormGroup<IShortContentDtoForm>>;
    /** The Brand color of the product */
    BrandingColor: FormControl<string | null>;
}
/**
/* Generates a form from a UserSuggestedContentDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserSuggestedContentDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserSuggestedContentDtoForm(fb: FormBuilder, dto?: Interfaces.UserSuggestedContentDto | null): FormGroup<IUserSuggestedContentDtoForm>;
/** Interface for a form from a UserSuggestedProductsDto*/
export interface IUserSuggestedProductsDtoForm {
    /** Product Id */
    ProductId: FormControl<number | null>;
    /** Product Lesson */
    Product: FormControl<string | null>;
    /** Product Branding Color */
    BrandingColor: FormControl<string | null>;
    /** Owned */
    Owned: FormControl<boolean | null>;
    /** Display Image Url */
    DisplayImageUrl: FormControl<string | null>;
    /** Display String */
    DisplayImageId: FormControl<number | null>;
}
/**
/* Generates a form from a UserSuggestedProductsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserSuggestedProductsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserSuggestedProductsDtoForm(fb: FormBuilder, dto?: Interfaces.UserSuggestedProductsDto | null): FormGroup<IUserSuggestedProductsDtoForm>;
/** Interface for a form from a UserUpdateAvailabilityDto*/
export interface IUserUpdateAvailabilityDtoForm {
    /** User Id */
    UserId: FormControl<number | null>;
    /** Is the User Available */
    Available: FormControl<boolean | null>;
}
/**
/* Generates a form from a UserUpdateAvailabilityDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserUpdateAvailabilityDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserUpdateAvailabilityDtoForm(fb: FormBuilder, dto?: Interfaces.UserUpdateAvailabilityDto | null): FormGroup<IUserUpdateAvailabilityDtoForm>;
/** Interface for a form from a UserWithRolesDto*/
export interface IUserWithRolesDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** This is the Email Address - Required for Identity Framework */
    UserName: FormControl<string | null>;
    /** The user's first name */
    FirstName: FormControl<string | null>;
    /** The user's last name */
    LastName: FormControl<string | null>;
    /** The user's full name */
    Name: FormControl<string | null>;
    /** The user's email */
    Email: FormControl<string | null>;
    /** Is the email address confirmed? */
    EmailConfirmed: FormControl<boolean | null>;
    /** Phone Number */
    PhoneNumber: FormControl<string | null>;
    /** Is the phone number confirmed? */
    PhoneNumberConfirmed: FormControl<boolean | null>;
    /** Is the user active? */
    Active: FormControl<boolean | null>;
    /** Creation Date */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Description */
    Description: FormControl<string | null>;
    /** Tags */
    Tags: FormControl<string | null>;
    /** EduConfirmed */
    EduConfirmed: FormControl<boolean | null>;
    /** User Expert Bot Escalation Availabilities */
    ExpertBotEscalationAvailability: FormControl<Enums.UserExpertBotEscalationAvailabilities | null>;
    /** Available for Escalation */
    AvailableForEscalation: FormControl<boolean | null>;
    /** Users selected language */
    LanguageCode: FormControl<string | null>;
    /** Admin */
    Admin: FormControl<boolean | null>;
    /** Creator */
    Creator: FormControl<boolean | null>;
    /** Reporter */
    Reporter: FormControl<boolean | null>;
    /** Organization Division */
    Division: FormControl<string | null>;
    /** Organization Group */
    GroupId: FormControl<number | null>;
    /** Organization Group Lesson */
    Group: FormControl<string | null>;
    /** Organization Location */
    Location: FormControl<string | null>;
}
/**
/* Generates a form from a UserWithRolesDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original UserWithRolesDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetUserWithRolesDtoForm(fb: FormBuilder, dto?: Interfaces.UserWithRolesDto | null): FormGroup<IUserWithRolesDtoForm>;
/** Interface for a form from a VerifyRequestAccessDto*/
export interface IVerifyRequestAccessDtoForm {
    /** Email Address */
    EmailAddress: FormControl<string | null>;
    /** Verification Code */
    Code: FormControl<string | null>;
    /** Client Id making the request */
    ClientId: FormControl<string | null>;
    /** The Requesting Site */
    RequestingSiteUrl: FormControl<string | null>;
    /** Password */
    Password: FormControl<string | null>;
}
/**
/* Generates a form from a VerifyRequestAccessDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original VerifyRequestAccessDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetVerifyRequestAccessDtoForm(fb: FormBuilder, dto?: Interfaces.VerifyRequestAccessDto | null): FormGroup<IVerifyRequestAccessDtoForm>;
/** Interface for a form from a VideoWithCaptionsDto*/
export interface IVideoWithCaptionsDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** External Id */
    ExternalId: FormControl<string | null>;
    /** File Lesson */
    FileName: FormControl<string | null>;
    /** Extension */
    Extension: FormControl<string | null>;
    /** Size */
    Size: FormControl<string | null>;
    /** Length */
    Length: FormControl<number | null>;
    /** Audio Bit Rate */
    AudioBitRate: FormControl<string | null>;
    /** Data Bit Rate */
    DataBitRate: FormControl<string | null>;
    /** Total Bit Rate */
    TotalBitRate: FormControl<string | null>;
    /** Frames per second */
    FramesPerSecond: FormControl<string | null>;
    /** Width */
    Width: FormControl<string | null>;
    /** Height */
    Height: FormControl<string | null>;
    /** Active */
    Active: FormControl<boolean | null>;
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** Updated On */
    UpdatedOn: FormControl<Date | null>;
    /** Language */
    LanguageCode: FormControl<string | null>;
    /** Video Text */
    Text: FormControl<string | null>;
    /** Video Providers */
    Provider: FormControl<Enums.VideoProviders | null>;
    /** Video streaming Uri without security token */
    StreamingUri: FormControl<string | null>;
    /** Captions */
    Captions: FormArray<FormGroup<ICaptionDtoForm>>;
}
/**
/* Generates a form from a VideoWithCaptionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original VideoWithCaptionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetVideoWithCaptionsDtoForm(fb: FormBuilder, dto?: Interfaces.VideoWithCaptionsDto | null): FormGroup<IVideoWithCaptionsDtoForm>;
/** Interface for a form from a WhatsNextBadgeDto*/
export interface IWhatsNextBadgeDtoForm {
    /** Badge Id */
    BadgeId: FormControl<number | null>;
    /** Badge Lesson */
    Badge: FormControl<string | null>;
    /** Has the badge been earned */
    Earned: FormControl<boolean | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a WhatsNextBadgeDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WhatsNextBadgeDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWhatsNextBadgeDtoForm(fb: FormBuilder, dto?: Interfaces.WhatsNextBadgeDto | null): FormGroup<IWhatsNextBadgeDtoForm>;
/** Interface for a form from a WhatsNextDisciplineDto*/
export interface IWhatsNextDisciplineDtoForm {
    /** Discipline Id */
    DisciplineId: FormControl<number | null>;
    /** Discipline Lesson */
    Discipline: FormControl<string | null>;
    /** Earned */
    Earned: FormControl<boolean | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Associated Medallions */
    Medallions: FormArray<FormGroup<IWhatsNextMedallionsDtoForm>>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a WhatsNextDisciplineDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WhatsNextDisciplineDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWhatsNextDisciplineDtoForm(fb: FormBuilder, dto?: Interfaces.WhatsNextDisciplineDto | null): FormGroup<IWhatsNextDisciplineDtoForm>;
/** Interface for a form from a WhatsNextDto*/
export interface IWhatsNextDtoForm {
    /** Lesson Id value */
    LessonId: FormControl<number | null>;
    /** Lesson Lesson */
    Lesson: FormControl<string | null>;
    /** Lesson Length */
    Length: FormControl<number | null>;
    /** Has the lesson been learned */
    Learned: FormControl<boolean | null>;
    /** Associated Badges */
    Badges: FormArray<FormGroup<IWhatsNextBadgeDtoForm>>;
    /** Associated Medallions */
    Medallions: FormArray<FormGroup<IWhatsNextMedallionsDtoForm>>;
    /** Associated Disciplines */
    Disciplines: FormArray<FormGroup<IWhatsNextDisciplineDtoForm>>;
}
/**
/* Generates a form from a WhatsNextDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WhatsNextDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWhatsNextDtoForm(fb: FormBuilder, dto?: Interfaces.WhatsNextDto | null): FormGroup<IWhatsNextDtoForm>;
/** Interface for a form from a WhatsNextJobDto*/
export interface IWhatsNextJobDtoForm {
    /** Job Id */
    JobId: FormControl<number | null>;
    /** Job Lesson */
    Job: FormControl<string | null>;
    /** Earned */
    Earned: FormControl<boolean | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Associated Medallions */
    Disciplines: FormArray<FormGroup<IWhatsNextDisciplineDtoForm>>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
}
/**
/* Generates a form from a WhatsNextJobDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WhatsNextJobDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWhatsNextJobDtoForm(fb: FormBuilder, dto?: Interfaces.WhatsNextJobDto | null): FormGroup<IWhatsNextJobDtoForm>;
/** Interface for a form from a WhatsNextMedallionsDto*/
export interface IWhatsNextMedallionsDtoForm {
    /** Medallion Id */
    MedallionId: FormControl<number | null>;
    /** Medallion Lesson */
    Medallion: FormControl<string | null>;
    /** Has the medallion been earned */
    Earned: FormControl<boolean | null>;
    /** Percent Complete */
    PercentComplete: FormControl<number | null>;
    /** Associated Badges */
    Badges: FormArray<FormGroup<IWhatsNextBadgeDtoForm>>;
    /** Header Lessons */
    HeaderLessons: FormArray<FormGroup<ILessonDtoForm>>;
    /** Order */
    Order: FormControl<number | null>;
}
/**
/* Generates a form from a WhatsNextMedallionsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WhatsNextMedallionsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWhatsNextMedallionsDtoForm(fb: FormBuilder, dto?: Interfaces.WhatsNextMedallionsDto | null): FormGroup<IWhatsNextMedallionsDtoForm>;
/** Interface for a form from a WorkFlowStepDto*/
export interface IWorkFlowStepDtoForm {
    /** The id of the item */
    Id: FormControl<number | null>;
    /** The workflow Id */
    WorkflowId: FormControl<number | null>;
    /** The name of the step */
    Name: FormControl<string | null>;
    /** Description */
    Description: FormControl<string | null>;
}
/**
/* Generates a form from a WorkFlowStepDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkFlowStepDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkFlowStepDtoForm(fb: FormBuilder, dto?: Interfaces.WorkFlowStepDto | null): FormGroup<IWorkFlowStepDtoForm>;
/** Interface for a form from a WorkflowHistoryDto*/
export interface IWorkflowHistoryDtoForm {
    /** Created On */
    CreatedOn: FormControl<Date | null>;
    /** The referencing item */
    ItemId: FormControl<number | null>;
    /** The workflow Id */
    WorkflowId: FormControl<number | null>;
    /** The name of the workflow */
    Workflow: FormControl<string | null>;
    /** The Step of the history */
    WorkflowStepId: FormControl<number | null>;
    /** The name of the step of the history */
    WorkflowStep: FormControl<string | null>;
    /** How executed the workflow change */
    ExecutedById: FormControl<number | null>;
    /** The name of the person that executed the workflow change */
    ExecutedBy: FormControl<string | null>;
    /** What the next step was based on the choice by the person executing the action if applicable */
    NextWorkflowStepId: FormControl<number | null>;
    /** The name of the next step */
    NextWorkflowStep: FormControl<string | null>;
    /** Workflow Actions */
    Action: FormControl<Enums.WorkflowActions | null>;
    /** A description of what was taken */
    Description: FormControl<string | null>;
    /** Any notes by the person executing the change */
    Notes: FormControl<string | null>;
}
/**
/* Generates a form from a WorkflowHistoryDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkflowHistoryDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkflowHistoryDtoForm(fb: FormBuilder, dto?: Interfaces.WorkflowHistoryDto | null): FormGroup<IWorkflowHistoryDtoForm>;
/** Interface for a form from a WorkflowStatusDetailsDto*/
export interface IWorkflowStatusDetailsDtoForm {
    /** The UserId */
    UserId: FormControl<number | null>;
    /** The user name */
    User: FormControl<string | null>;
    /** the Item that the status is for */
    ItemId: FormControl<number | null>;
    /** Question Item Types */
    ItemType: FormControl<Enums.ContentItemTypes | null>;
    /** The name of hte item */
    ItemName: FormControl<string | null>;
    /** The description of the item */
    ItemDescription: FormControl<string | null>;
    /** The current workflow step Id */
    WorkflowStepId: FormControl<number | null>;
    /** The current workflow step name */
    WorkflowStep: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** The course name */
    Course: FormControl<string | null>;
    /** The Course Id */
    CourseId: FormControl<number | null>;
    /** Has the item been returned for correction? */
    Returned: FormControl<boolean | null>;
}
/**
/* Generates a form from a WorkflowStatusDetailsDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkflowStatusDetailsDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkflowStatusDetailsDtoForm(fb: FormBuilder, dto?: Interfaces.WorkflowStatusDetailsDto | null): FormGroup<IWorkflowStatusDetailsDtoForm>;
/** Interface for a form from a WorkflowStatusInfoDto*/
export interface IWorkflowStatusInfoDtoForm {
    /** The workflow Id */
    WorkflowId: FormControl<number | null>;
    /** The workflow name */
    Workflow: FormControl<string | null>;
    /** The current step Id */
    WorkflowStepId: FormControl<number | null>;
    /** The name of the current step */
    WorkflowStep: FormControl<string | null>;
    /** Started On */
    StartedOn: FormControl<Date | null>;
    /** Due Date */
    DueDate: FormControl<Date | null>;
    /** Estimated Completion Date */
    EstCompletionDate: FormControl<Date | null>;
    /** Importance */
    Importance: FormControl<Enums.Importance | null>;
    /** Flagged */
    Flagged: FormControl<boolean | null>;
    /** Possible next steps */
    NextSteps: FormArray<FormGroup<IWorkFlowStepDtoForm>>;
    /** Who is currently assigned */
    Assignees: FormArray<FormGroup<IWorkflowUserDtoForm>>;
    /** Any notes from the previous step */
    Notes: FormControl<string | null>;
    /** The name of the person that wrote the notes to you */
    NoteWritter: FormControl<string | null>;
    /** Workflow step */
    QuestionApprovalStep: FormGroup<IWorkFlowStepDtoForm>;
    /** Workflow step */
    ScriptApprovalStep: FormGroup<IWorkFlowStepDtoForm>;
    /** Workflow step */
    NarrationApprovalStep: FormGroup<IWorkFlowStepDtoForm>;
    /** Workflow step */
    FinalApprovalStep: FormGroup<IWorkFlowStepDtoForm>;
}
/**
/* Generates a form from a WorkflowStatusInfoDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkflowStatusInfoDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkflowStatusInfoDtoForm(fb: FormBuilder, dto?: Interfaces.WorkflowStatusInfoDto | null): FormGroup<IWorkflowStatusInfoDtoForm>;
/** Interface for a form from a WorkflowUserDto*/
export interface IWorkflowUserDtoForm {
    /** the Id of the user */
    Id: FormControl<number | null>;
    /** Lesson */
    Name: FormControl<string | null>;
    /** Role name */
    Role: FormControl<string | null>;
    /** The Id of the role */
    RoleId: FormControl<number | null>;
}
/**
/* Generates a form from a WorkflowUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkflowUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkflowUserDtoForm(fb: FormBuilder, dto?: Interfaces.WorkflowUserDto | null): FormGroup<IWorkflowUserDtoForm>;
/** Interface for a form from a WorkflowWorkLoadByUserDto*/
export interface IWorkflowWorkLoadByUserDtoForm {
    /** The user id */
    UserId: FormControl<number | null>;
    /** The user's name */
    User: FormControl<string | null>;
    /** How many assignments the person has */
    Assigned: FormControl<number | null>;
}
/**
/* Generates a form from a WorkflowWorkLoadByUserDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WorkflowWorkLoadByUserDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWorkflowWorkLoadByUserDtoForm(fb: FormBuilder, dto?: Interfaces.WorkflowWorkLoadByUserDto | null): FormGroup<IWorkflowWorkLoadByUserDtoForm>;
/** Interface for a form from a WrongAnswerDto*/
export interface IWrongAnswerDtoForm {
    /** The question Id */
    QuestionId: FormControl<number | null>;
    /** The question text */
    Question: FormControl<string | null>;
    /** The given answer id */
    AnswerId: FormControl<number | null>;
    /** The given answer text */
    Answer: FormControl<string | null>;
    /** the correct answer id */
    CorrectAnswerId: FormControl<number | null>;
    /** The correct answer text */
    CorrectAnswer: FormControl<string | null>;
    /** Suggested lessons to review */
    Lessons: FormArray<FormGroup<IShortContentDtoForm>>;
}
/**
/* Generates a form from a WrongAnswerDto
/* @param fb The FormBuilder that will build the form for you
/* @param dto The original WrongAnswerDto from which to create the form.
/* @returns FormGroup
 */
export declare function GetWrongAnswerDtoForm(fb: FormBuilder, dto?: Interfaces.WrongAnswerDto | null): FormGroup<IWrongAnswerDtoForm>;
//# sourceMappingURL=forms.d.ts.map